import getColorValue from '@momentum-ui/utils/lib/getColorValue';
import { uniqueId as uniqueId$1 } from 'lodash';
import reject from 'lodash-es/reject';
import { AutofillMonitor } from '@angular/cdk/text-field';
import { coerceBooleanProperty } from '@angular/cdk/coercion';
import { getSupportedInputTypes, Platform } from '@angular/cdk/platform';
import find from 'lodash-es/find';
import isObject from 'lodash-es/isObject';
import { FocusKeyManager, FocusMonitor, FocusTrapFactory, A11yModule } from '@angular/cdk/a11y';
import { NG_VALUE_ACCESSOR, FormsModule, ReactiveFormsModule, FormGroupDirective, NgControl, NgForm } from '@angular/forms';
import { take, switchMap, startWith, takeUntil, distinctUntilChanged, debounceTime, map, scan, shareReplay, tap, withLatestFrom } from 'rxjs/operators';
import { Overlay, OverlayModule, CdkConnectedOverlay, ViewportRuler, OverlayContainer, OverlayPositionBuilder, ScrollStrategyOptions, OverlayConfig } from '@angular/cdk/overlay';
import { ComponentPortal, PortalModule, PortalInjector, TemplatePortal } from '@angular/cdk/portal';
import { defer, merge, Subject, of, Subscription, BehaviorSubject, fromEvent } from 'rxjs';
import { EventManager, DomSanitizer } from '@angular/platform-browser';
import { ENTER, SPACE, hasModifierKey, DOWN_ARROW, END, HOME, LEFT_ARROW, PAGE_DOWN, PAGE_UP, RIGHT_ARROW, UP_ARROW, BACKSPACE, DELETE } from '@angular/cdk/keycodes';
import findIndex from 'lodash-es/findIndex';
import uniqueId from 'lodash-es/uniqueId';
import { CommonModule, DOCUMENT } from '@angular/common';
import { Component, EventEmitter, HostBinding, Input, Output, ViewEncapsulation, ElementRef, NgModule, CUSTOM_ELEMENTS_SCHEMA, HostListener, ViewChild, ContentChildren, ChangeDetectorRef, NgZone, forwardRef, TemplateRef, Injectable, Directive, Injector, Renderer2, ChangeDetectionStrategy, ContentChild, ViewChildren, Optional, Self, Inject, ViewContainerRef, defineInjectable, inject, INJECTOR } from '@angular/core';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// const getColorValue = require('@momentum-ui/utils/lib/getColorValue');
/** @type {?} */
const iconNames = require('@momentum-ui/icons/data/iconNames.json');
class IconComponent {
    constructor() {
        this.click = new EventEmitter();
        this.getIconNameClass = (/**
         * @return {?}
         */
        () => {
            /** @type {?} */
            const defaultSize = 16;
            /** @type {?} */
            const sizeFromName = Number(this.name.split('_')[1]);
            /** @type {?} */
            let nameWithSize = this.name;
            if (sizeFromName && this.fontSize) {
                nameWithSize = `${this.name.split('_')[0]}_${this.fontSize}`;
            }
            if (!sizeFromName) {
                nameWithSize = `${this.name}_${this.size || defaultSize}`;
            }
            /** @type {?} */
            const lookupIconName = nameWithSize.replace(/^(icon-)/, '');
            /** @type {?} */
            const iconNameClass = `icon-${lookupIconName}`;
            // validate Icon name with Momentum Design
            if (((/** @type {?} */ (iconNames))).indexOf(lookupIconName) < 0) {
                this.consoleHandler('name-error', nameWithSize);
            }
            return iconNameClass;
        });
        this.getColor = (/**
         * @return {?}
         */
        () => {
            if (!this.color) {
                return 'inherit';
            }
            if (this.color.startsWith('#')) {
                this.consoleHandler('color-warn', this.color);
                return this.color;
            }
            return getColorValue(this.color);
        });
        this.consoleHandler = (/**
         * @param {?} message
         * @param {?} data
         * @return {?}
         */
        (message, data) => {
            switch (message) {
                case 'color-warn':
                    console.warn(`[@momentum-ui/angular] Icon: ${data} may not exist in the design system,` +
                        ` please use a color name from http://momentum.design/styles/color`);
                    break;
                case 'name-error':
                    console.warn(`[@momentum-ui/angular] Icon: Icon ${data} does not exist in the design system.` +
                        ` Visit https://momentum.design/styles/icons for a list of available icons or to request a new icon.`);
                    break;
            }
        });
    }
    /**
     * @return {?}
     */
    get _class() {
        return !this.isClickable ? this.classes : '';
    }
    /**
     * @return {?}
     */
    get _color() {
        return !this.isClickable ? this.getColor() : '';
    }
    /**
     * @return {?}
     */
    get _ariaLabelledBy() {
        return !this.isClickable ? this.ariaLabelledBy : '';
    }
    /**
     * @return {?}
     */
    get _ariaLabel() {
        return !this.isClickable ? this.ariaLabel : null;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        // input validations
        if (!this.name) {
            throw new Error('Attribute "name" is required');
        }
        if (this.type && this.type !== 'white' && this.type !== '') {
            throw new Error('Attribute "type" if defined is either "" or "white"');
        }
        this.isClickable = this.click.observers.length > 0;
        this.classes =
            'md-icon icon' +
                `${(this.name && ` ${this.getIconNameClass()}`) || ''}` +
                `${(this.className && ` ${this.className}`) || ''}` +
                ``;
        this.buttonClasses =
            'md-button--icon' +
                `${(this.type && ` md-button--icon-${this.type}`) || ''}` +
                `${(this.buttonClassName && ` ${this.buttonClassName}`) || ''}`;
        /** @type {?} */
        const iconCount = uniqueId();
        this.titleId = `icon-title-${iconCount}`;
        this.descId = this.description ? `icon-desc-${iconCount}` : undefined;
    }
    /**
     * @return {?}
     */
    get ariaLabelledBy() {
        const { ariaLabel, title, description, titleId, descId } = this;
        if (!ariaLabel) {
            if (title && description) {
                return `${titleId} ${descId}`;
            }
            if (title) {
                return `${titleId}`;
            }
            if (description) {
                return `${descId}`;
            }
        }
        return null;
    }
}
IconComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-icon',
                template: `
    <button
      md-button
      *ngIf="isClickable"
      ngClass="{{ buttonClasses }}"
      [attr.aria-labelledby]="ariaLabelledBy"
      [attr.aria-label]="ariaLabel"
    >
      <i class="{{ classes }}" [style.color]="getColor()"></i>
    </button>
  `,
                host: {
                    'style': 'display:inline-flex;'
                },
                encapsulation: ViewEncapsulation.None
            }] }
];
/** @nocollapse */
IconComponent.ctorParameters = () => [];
IconComponent.propDecorators = {
    ariaLabel: [{ type: Input }],
    buttonClassName: [{ type: Input }],
    color: [{ type: Input }],
    className: [{ type: Input }],
    description: [{ type: Input }],
    name: [{ type: Input }],
    size: [{ type: Input }],
    fontSize: [{ type: Input }],
    title: [{ type: Input }],
    type: [{ type: Input }],
    click: [{ type: Output }],
    _class: [{ type: HostBinding, args: ['class',] }],
    _color: [{ type: HostBinding, args: ['style.color',] }],
    _ariaLabelledBy: [{ type: HostBinding, args: ['attr.aria-labelledby',] }],
    _ariaLabel: [{ type: HostBinding, args: ['attr.aria-label',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ButtonComponent {
    /**
     * @param {?} el
     */
    constructor(el) {
        this.el = el;
        /**
         * \@prop Active Sets button to active | false
         */
        this.active = false;
        /**
         * \@prop Creates a circle shaped button | false
         */
        this.circle = false;
        /**
         * \@prop Sets the attribute disabled to Button | false
         */
        this.disabled = false;
        /**
         * \@prop Sets expand css styling to widen the Button | false
         */
        this.expand = false;
        /**
         * \@prop Sets href for an anchor tagged button | ''
         */
        this.href = '';
        /**
         * \@prop Activates the loading animation and sets the button to disabled | false
         */
        this.loading = false;
        /**
         * \@prop Html button type | 'button'
         */
        this.type = 'button';
        this._color = '';
        this._removeStyle = false;
        this._size = 36;
    }
    /**
     * \@prop Sets optional button color | ''
     * @return {?}
     */
    get color() {
        if (this.removeStyle) {
            this.color = null;
            return null;
        }
        return this._color;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set color(value) {
        /** @type {?} */
        const colorName = (/**
         * @param {?} name
         * @return {?}
         */
        (name) => name === 'none' ? 'color-none' : name);
        if (this._color) {
            this.el.nativeElement.classList.remove(`md-button--${colorName(this._color)}`);
        }
        if (value && !this.removeStyle) {
            this.el.nativeElement.classList.add(`md-button--${colorName(value)}`);
        }
        this._color = value;
    }
    /**
     * \@prop Boolean to remove Button's default style | false
     * @return {?}
     */
    get removeStyle() {
        return this._removeStyle;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set removeStyle(value) {
        if (value) {
            this.color = null;
            this.size = null;
        }
        this._removeStyle = value;
    }
    /**
     * \@prop Size value | '36'
     * @return {?}
     */
    get size() {
        if (this.removeStyle) {
            this.size = null;
            return null;
        }
        return this._size;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set size(value) {
        /** @type {?} */
        const sizeName = (/**
         * @param {?} name
         * @return {?}
         */
        (name) => name === 'none' ? 'size-none' : name);
        if (this._size) {
            this.el.nativeElement.classList.remove(`md-button--${sizeName(this._size)}`);
        }
        this._size = value;
        if (!this.circle && !this.checkButtonSize(value)) {
            console.warn(`[@collab-ui/angular] Button: selected size is not supported
         for non-circular button. Size will default to 36`);
            this._size = 36;
        }
        if (this._size && !this.removeStyle) {
            this.el.nativeElement.classList.add(`md-button--${sizeName(this._size)}`);
        }
    }
    /**
     * @return {?}
     */
    get focusIndex() {
        return this._focusIndex;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set focusIndex(value) {
        this._focusIndex = value;
        if (this.index === this._focusIndex && this._focusIndex !== this._prevFocusIndex) {
            this.el.nativeElement.focus();
        }
        this._prevFocusIndex = this._focusIndex;
    }
    /**
     * @return {?}
     */
    get hostElement() {
        return this.el;
    }
    /**
     * @return {?}
     */
    get opacity() {
        return this.loading ? 0 : 1;
    }
    /**
     * @return {?}
     */
    get width() {
        return this._width;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set width(value) {
        this._width = value;
        this.el.nativeElement.style.width = value;
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        setTimeout((/**
         * @return {?}
         */
        () => {
            this.checkAriaLabel();
            if (this.focusOnLoad && this.focusIndex === this.index) {
                this.el.nativeElement.focus();
            }
        }), 0);
    }
    /**
     * @private
     * @param {?} size
     * @return {?}
     */
    checkButtonSize(size) {
        return [null, 'none', '28', '36', '40', '52', 28, 36, 40, 52].includes(size);
    }
    /**
     * @private
     * @return {?}
     */
    checkAriaLabel() {
        /** @type {?} */
        const ariaLabel = this.getAttr('aria-label');
        if (!ariaLabel) {
            console.warn('md-button: content is not a string, you must add an "aria-label" for accessibility.');
        }
    }
    /**
     * @private
     * @param {?} attr
     * @return {?}
     */
    getAttr(attr) {
        return this.el.nativeElement.getAttribute(attr);
    }
}
ButtonComponent.decorators = [
    { type: Component, args: [{
                selector: 'button[md-button], a[md-button], input[md-button]',
                exportAs: 'mdButton',
                template: `
    <md-loading *ngIf="loading"></md-loading>
    <span class="md-button__children" [ngStyle]="{ opacity: opacity }">
      <ng-content></ng-content>
    </span>
  `,
                host: {
                    '[attr.active]': 'active',
                    '[attr.disabled]': 'disabled || loading || null',
                    '[attr.href]': 'href',
                    '[attr.tabindex]': 'index === focusIndex ? 0 : -1',
                    '[attr.type]': 'type',
                    'class': 'md-button md-button--36',
                    '[class.active]': 'active && !disabled',
                    '[class.md-button--circle]': 'circle',
                    '[class.md-button--disabled]': 'disabled || loading',
                    '[class.md-button--expand]': 'expand',
                    '[class.md-button--none]': 'removeStyle',
                }
            }] }
];
/** @nocollapse */
ButtonComponent.ctorParameters = () => [
    { type: ElementRef }
];
ButtonComponent.propDecorators = {
    active: [{ type: Input }],
    circle: [{ type: Input }],
    color: [{ type: Input }],
    disabled: [{ type: Input }],
    expand: [{ type: Input }],
    href: [{ type: Input }],
    loading: [{ type: Input }],
    removeStyle: [{ type: Input }],
    size: [{ type: Input }],
    type: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class LoadingComponent {
    constructor() {
        /**
         * \@option Prop to make the Loading animation small | false
         */
        this.small = false;
    }
    /**
     * @return {?}
     */
    get className() {
        return `md-loading ${this.small ? 'md-loading--small' : ''}`;
    }
}
LoadingComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-loading, CSLoading',
                template: `
    <span class="md-loading__icon"></span>
    <span class="md-loading__icon"></span>
    <span class="md-loading__icon"></span>
  `,
                encapsulation: ViewEncapsulation.None
            }] }
];
/** @nocollapse */
LoadingComponent.ctorParameters = () => [];
LoadingComponent.propDecorators = {
    small: [{ type: Input }],
    className: [{ type: HostBinding, args: ['class',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class LoadingModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: LoadingModule,
            providers: [],
        };
    }
}
LoadingModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                exports: [LoadingComponent],
                declarations: [LoadingComponent],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ButtonModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: ButtonModule,
            providers: [],
        };
    }
}
ButtonModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, LoadingModule.forRoot()],
                exports: [ButtonComponent],
                declarations: [ButtonComponent],
                schemas: [CUSTOM_ELEMENTS_SCHEMA]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class IconModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: IconModule,
            providers: [],
        };
    }
}
IconModule.decorators = [
    { type: NgModule, args: [{
                imports: [ButtonModule, CommonModule],
                declarations: [IconComponent],
                exports: [ButtonModule, IconComponent],
                schemas: [CUSTOM_ELEMENTS_SCHEMA]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AlertBannerComponent {
    constructor() {
        /**
         * Sets the visibility of AlertBanner's close button | false
         */
        this.closable = false;
        /**
         * Sets the AlertBanner type | 'info'
         */
        this.type = 'info';
        /**
         * Event emitted when the user presses on the AlertBanner's close button or hits the esc key
         */
        this.hide = new EventEmitter();
    }
    /**
     * @param {?} event
     * @return {?}
     */
    handleKeydown(event) {
        if (event.key !== 'Tab') {
            this.hide.emit();
        }
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (!this.hide.observers.length && this.closable) {
            throw new Error('Observer for "hide" is required');
        }
    }
    /**
     * @return {?}
     */
    onClick() {
        this.hide.emit();
    }
}
AlertBannerComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-alert-banner',
                template: `
    <div [ngClass]="['md-alert-banner', 'md-alert-banner--' + type]">
      <div class="md-alert-banner__text">
        <ng-content></ng-content>
      </div>
      <div
        *ngIf="closable"
        class="md-alert-banner__close"
        (click)="onClick()"
        (keydown)="handleKeydown($event)"
        tabindex="0"
        role="button"
      >
        <md-icon name="cancel_16"></md-icon>
      </div>
    </div>
  `
            }] }
];
/** @nocollapse */
AlertBannerComponent.ctorParameters = () => [];
AlertBannerComponent.propDecorators = {
    closable: [{ type: Input }],
    type: [{ type: HostBinding, args: ['attr.type',] }, { type: Input }],
    hide: [{ type: Output }],
    handleKeydown: [{ type: HostListener, args: ['document:keydown.escape', ['$event'],] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AlertBannerModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: AlertBannerModule,
            providers: [],
        };
    }
}
AlertBannerModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, IconModule],
                declarations: [AlertBannerComponent],
                exports: [AlertBannerComponent],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AvatarComponent {
    /**
     * @param {?} elementRef
     */
    constructor(elementRef) {
        this.elementRef = elementRef;
        this.ariaLabel = '';
        /**
         * \@option Image alt tag | ''
         */
        this.alt = '';
        /**
         * \@option Set Avatar background color | ''
         */
        this.backgroundColor = '';
        /**
         * \@option Optional css class string for button | ''
         */
        this.buttonClassName = '';
        /**
         * \@option Set Avatar text color | ''
         */
        this.color = '';
        /**
         * \@option Set existance of a failureBadge on the Avatar | false
         */
        this.failureBadge = false;
        /**
         * \@option Set existance of a notification on the Avatar | false
         */
        this.hasNotification = false;
        /**
         * \@option Set the visibility of Avatar's default tooltip | false
         */
        this.hideDefaultTooltip = false;
        /**
         * \@option Set if Avatar's content is decrypting | false
         */
        this.isDecrypting = false;
        /**
         * \@option Set existance of Avatar's Overview | false
         */
        this.isOverview = false;
        this.click = new EventEmitter();
        this._size = 'medium';
        this._type = '';
        this.clickable = false;
        this.isImageLoaded = false;
        this.isImageErrored = false;
    }
    /**
     * \@option Set the size of the Avatar from one of the preconfigured options | 'medium'
     * @return {?}
     */
    get size() {
        return this._size;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set size(value) {
        if (!this.clickable) {
            this.elementRef.nativeElement.classList.remove(`md-avatar--${this._size}`);
            this.elementRef.nativeElement.classList.add(`md-avatar--${value}`);
        }
        this._size = value;
    }
    /**
     * \@option Optional Avatar color theme | null
     * @return {?}
     */
    get theme() {
        return this._theme;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set theme(value) {
        if (!this.clickable) {
            this.elementRef.nativeElement.classList.remove(`md-avatar--${this._theme}`);
            this.elementRef.nativeElement.classList.add(`md-avatar--${value}`);
        }
        this._theme = value;
    }
    /**
     * \@option optional Avatar type | ''
     * @return {?}
     */
    get type() {
        return this._type;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set type(value) {
        if (!this.clickable) {
            this.elementRef.nativeElement.classList.remove(`md-avatar--${this._type}`);
            this.elementRef.nativeElement.classList.add(`md-avatar--${value}`);
        }
        this._type = value;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        /** @type {?} */
        const img = this.image;
        if (img && img.nativeElement.complete) {
            this.handleImgLoaded();
        }
        this.clickable = this.click.observers.length > 0;
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (changes.src && changes.src.previousValue !== changes.src.currentValue) {
            this.handleImgChange();
        }
    }
    /**
     * @return {?}
     */
    handleImgChange() {
        this.isImageLoaded = false;
        this.isImageErrored = false;
    }
    /**
     * @return {?}
     */
    handleImgError() {
        this.isImageErrored = true;
    }
    /**
     * @return {?}
     */
    handleImgLoaded() {
        this.isImageLoaded = true;
    }
    /**
     * @return {?}
     */
    getInitials() {
        if (!this.title || !this.title.replace(/\s/g, '').length) {
            return '';
        }
        /** @type {?} */
        const letters = [];
        /** @type {?} */
        const words = this.title.trim().split(/ +/);
        /** @type {?} */
        const repeatTimes = Math.min((this.type === 'group' && 1) || 2, words.length);
        for (let i = 0; i < repeatTimes; i++) {
            letters.push(String.fromCodePoint(words[i].codePointAt(0)));
        }
        return letters.join('');
    }
}
AvatarComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-avatar',
                template: `
    <button
      md-button
      *ngIf="clickable; else avatarTpl"
      [attr.aria-label]="ariaLabel"
      [class]="buttonClassName"
      [circle]="true"
      [removeStyle]="true"
    >
      <ng-container *ngTemplateOutlet="avatarTpl"></ng-container>
    </button>

    <ng-template #avatarTpl>
      <div
        *ngIf="clickable; else overlayTpl"
        class="md-avatar"
        [ngClass]="[
          'md-avatar--clickable',
          (type && 'md-avatar--' + type) || '',
          (size && 'md-avatar--' + size) || '',
          (theme && 'md-avatar--' + theme) || '',
          (isDecrypting && 'md-decrypting') || '',
          className || ''
        ]"
        [title]="!hideDefaultTooltip ? title : ''"
      >
        <ng-container *ngTemplateOutlet="overlayTpl"></ng-container>
      </div>
    </ng-template>

    <ng-template #overlayTpl>
      <ng-container *ngTemplateOutlet="childrenTpl"></ng-container>
      <md-loading *ngIf="type === 'typing'"></md-loading>
      <span *ngIf="failureBadge" class="md-avatar__failure-badge"></span>
      <span
        *ngIf="hasNotification"
        class="md-avatar__notification-badge"
      ></span>
    </ng-template>

    <ng-template #childrenTpl>
      <span
        *ngIf="type === 'self'; else imageTpl"
        class="md-avatar__self"
        [ngStyle]="{
          'background-color': backgroundColor,
          color: color
        }"
      >
        <md-icon
          [name]="
            size === 40 || size === 'medium'
              ? 'chat-active_18'
              : 'chat-active_16'
          "
          color="blue-50"
        ></md-icon>
      </span>
    </ng-template>

    <ng-template #imageTpl>
      <ng-container *ngIf="src && !isImageErrored; else iconTpl">
        <ng-container *ngIf="title && !isImageLoaded">
          <ng-container *ngTemplateOutlet="letterTpl"></ng-container>
        </ng-container>
        <img
          #image
          [alt]="alt"
          class="md-avatar__img"
          [ngClass]="{ 'md-avatar__img--hidden': !isImageLoaded }"
          draggable="false"
          (error)="handleImgError()"
          (load)="handleImgLoaded()"
          [src]="src"
        />
      </ng-container>
    </ng-template>

    <ng-template #iconTpl>
      <span
        *ngIf="icon; else letterTpl"
        class="md-avatar__icon"
        [ngClass]="{ 'md-avatar__icon--overview': isOverview }"
        [ngStyle]="{
          'background-color': backgroundColor,
          color: color
        }"
      >
        <md-icon [name]="icon"></md-icon>
      </span>
    </ng-template>

    <ng-template #letterTpl>
      <span
        class="md-avatar__letter"
        [ngClass]="{
          'md-decrypting': isDecrypting,
          'md-avatar__img--hidden': isImageLoaded
        }"
        [ngStyle]="{
          'background-color': backgroundColor,
          color: color
        }"
        >{{ getInitials() }}</span
      >
    </ng-template>
  `,
                host: {
                    '[attr.title]': '!hideDefaultTooltip ? title : ""',
                    class: 'md-avatar md-avatar--medium',
                    '[class.md-decrypting]': '!clickable && isDecrypting',
                }
            }] }
];
/** @nocollapse */
AvatarComponent.ctorParameters = () => [
    { type: ElementRef }
];
AvatarComponent.propDecorators = {
    ariaLabel: [{ type: Input }],
    alt: [{ type: Input }],
    backgroundColor: [{ type: Input }],
    buttonClassName: [{ type: Input }],
    className: [{ type: Input }],
    color: [{ type: Input }],
    failureBadge: [{ type: Input }],
    hasNotification: [{ type: Input }],
    hideDefaultTooltip: [{ type: Input }],
    icon: [{ type: Input }],
    isDecrypting: [{ type: Input }],
    isOverview: [{ type: Input }],
    size: [{ type: Input }],
    src: [{ type: Input }],
    theme: [{ type: Input }],
    title: [{ type: Input }],
    type: [{ type: Input }],
    click: [{ type: Output }],
    image: [{ type: ViewChild, args: ['image',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AvatarModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: AvatarModule,
            providers: [],
        };
    }
}
AvatarModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, ButtonModule, IconModule, LoadingModule],
                declarations: [AvatarComponent],
                exports: [AvatarComponent],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class OptionSelectionChange {
    /**
     * @param {?} source
     * @param {?=} isUserInput
     */
    constructor(source, isUserInput = false) {
        this.source = source;
        this.isUserInput = isUserInput;
    }
}
class ListItemComponent {
    /**
     * @param {?} el
     */
    constructor(el) {
        this.el = el;
        this.checkedValues = [''];
        this.isSelectOption = this._hasHostAttributes('md-select-option');
        /**
         * \@prop Active prop to determine styles | false
         */
        this.active = false;
        /**
         * \@prop selected prop to determine styles | false
         */
        this.selected = false;
        /**
         * \@prop Disabled attribute for ListItem to determine styles | false
         */
        this.disabled = false;
        /**
         * \@prop Sets ListItem to a focus state | false
         */
        this.focus = false;
        /**
         * \@prop Sets ListItem id | null
         */
        this.id = uniqueId$1('md-list-item-');
        /**
         * \@prop Determines if is part of a multi select | false
         */
        this.isMulti = false;
        /**
         * \@prop Determines if ListItem is clickable | false
         */
        this.isReadOnly = false;
        /**
         * \@prop ListItem text and form value | ''
         */
        this.label = null;
        /**
         * \@prop external link associated input | ''
         */
        this.link = '';
        /**
         * \@prop ListItem ref name | 'navLink'
         */
        this.role = null;
        /**
         * \@prop Controls whether to show separator or not | false
         */
        this.separator = false;
        /**
         * \@prop ListItem Title | ''
         */
        this.title = '';
        /**
         * \@prop ListItem size | ''
         */
        this._type = null;
        /**
         * \@prop ListItem value for OnSelect value | ''
         */
        this.value = '';
        this.selectionChange = new EventEmitter();
        this.handleClick = (/**
         * @param {?} event
         * @return {?}
         */
        (event) => {
            if (this.isReadOnly) {
                event.stopImmediatePropagation();
            }
            else {
                this._selectViaInteraction();
            }
        });
        this.handleKeydown = (/**
         * @param {?} event
         * @return {?}
         */
        event => {
            if ((event.keyCode === ENTER || event.keyCode === SPACE) && !hasModifierKey(event)) {
                this._selectViaInteraction();
                event.preventDefault();
            }
        });
        this._isTypeOptionValid = (/**
         * @return {?}
         */
        () => (['', 'small', 'large', 'xlarge', 'space', 'header', 36, 52, 60].includes(this._type)));
    }
    /**
     * @return {?}
     */
    get myRole() {
        return this.role || this.isSelectOption ? 'option' : 'listItem';
    }
    /**
     * @param {?} type
     * @return {?}
     */
    set type(type) {
        if (this._type) {
            this.el.nativeElement.classList.remove(`md-list-item--${this._type}`);
        }
        this.el.nativeElement.classList.add(`md-list-item--${type}`);
        this._type = type;
    }
    /**
     * @return {?}
     */
    get myHref() {
        return (this.link && this._getHostElement().localName === 'a') ? this.link : null;
    }
    /**
     * @return {?}
     */
    get theTitle() {
        return this.title || this.label;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this._type && !this._isTypeOptionValid()) {
            throw new Error(`md-list-item: ListItem type option must be one of the following:
        small, large, xlarge, space, header, 36, 52, 60`);
        }
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() { }
    /**
     * @return {?}
     */
    select() {
        if (!this.selected) {
            this.selected = true;
            this._emitSelectionChangeEvent();
        }
    }
    /**
     * Deselects the option.
     * @return {?}
     */
    deselect() {
        if (this.selected) {
            this.selected = false;
            this._emitSelectionChangeEvent();
        }
    }
    // Highlightable Interface methods
    /**
     * @return {?}
     */
    setActiveStyles() {
        this.focus = true;
    }
    /**
     * @return {?}
     */
    setInactiveStyles() {
        this.focus = false;
    }
    /**
     * @return {?}
     */
    getLabel() {
        return this.label;
    }
    /**
     * @return {?}
     */
    _selectViaInteraction() {
        if (!this.disabled) {
            this.selected = !this.selected;
            this.checkStatus = this.selected;
            this._emitSelectionChangeEvent(true);
        }
    }
    /**
     * @param {?=} isUserInput
     * @return {?}
     */
    _emitSelectionChangeEvent(isUserInput = false) {
        return this.selectionChange.emit(new OptionSelectionChange(this, isUserInput));
    }
    /**
     * @return {?}
     */
    _getHostElement() {
        return this.el.nativeElement;
    }
    /**
     * Gets whether the button has one of the given attributes.
     * @param {...?} attributes
     * @return {?}
     */
    _hasHostAttributes(...attributes) {
        return attributes.some((/**
         * @param {?} attribute
         * @return {?}
         */
        attribute => this._getHostElement().hasAttribute(attribute)));
    }
}
ListItemComponent.decorators = [
    { type: Component, args: [{
                selector: 'a[md-list-item], div[md-list-item], div[md-select-option]',
                exportAs: 'mdListItem',
                template: `
      <ng-container *ngIf="isSelectOption">

        <ng-container *ngIf="!isMulti">
          <md-list-item-section key="child-0" position='center'>
              <ng-container *ngIf="label; else content">{{label}}</ng-container>
              <ng-template #content>
                  <ng-content></ng-content>
              </ng-template>
          </md-list-item-section>

          <md-list-item-section key="child-1" position='right'>
              <md-icon *ngIf="selected" name="check_20" color="blue-50"></md-icon>
          </md-list-item-section>
        </ng-container>

        <ng-container *ngIf="isMulti">
          <md-checkbox
            name="{{id}}-checkbox"
            value="{{label}}"
            label="{{label}}"
            [(checkStatus)]="checkStatus"
            htmlId="{{id}}-checkbox">
          </md-checkbox>
        </ng-container>

      </ng-container>

      <ng-container *ngIf="!isSelectOption">
        <div *ngIf="label; else content">{{label}}</div>
        <ng-template #content>
          <ng-content></ng-content>
        </ng-template>
      </ng-container>
  `,
                host: {
                    'class': 'md-list-item',
                    '[class.md-list-item--read-only]': 'isReadOnly',
                    '[class.md-list-item--separator]': 'separator',
                    '[class.md-select-option]': 'isSelectOption',
                    '[class.active]': 'active',
                    '[class.focus]': 'focus',
                    '[class.disabled]': 'disabled',
                }
            }] }
];
/** @nocollapse */
ListItemComponent.ctorParameters = () => [
    { type: ElementRef }
];
ListItemComponent.propDecorators = {
    active: [{ type: Input }],
    selected: [{ type: Input }],
    disabled: [{ type: Input }],
    focus: [{ type: Input }],
    id: [{ type: HostBinding, args: ['attr.id',] }, { type: Input }],
    isMulti: [{ type: Input }],
    isReadOnly: [{ type: Input }],
    label: [{ type: Input }],
    link: [{ type: Input }],
    role: [{ type: Input }],
    myRole: [{ type: HostBinding, args: ['attr.role',] }],
    separator: [{ type: Input }],
    title: [{ type: Input }],
    type: [{ type: Input }],
    value: [{ type: Input }],
    selectionChange: [{ type: Output }],
    myHref: [{ type: HostBinding, args: ['attr.href',] }],
    theTitle: [{ type: HostBinding, args: ['attr.title',] }],
    handleClick: [{ type: HostListener, args: ['click', ['$event'],] }],
    handleKeydown: [{ type: HostListener, args: ['keydown', ['$event'],] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ListComponent {
    /**
     * @param {?} cd
     * @param {?} _ngZone
     * @param {?} el
     */
    constructor(cd, _ngZone, el) {
        this.cd = cd;
        this._ngZone = _ngZone;
        this.el = el;
        /**
         * \@option Optional ID value of List | null
         */
        this.id = uniqueId$1('md-list-');
        /**
         * \@option itemRole prop to set child roles | 'listItem'
         */
        this.itemRole = 'listItem';
        /**
         * \@option Callback function invoked by user selecting an interactive item within list | null
         */
        this.select = new EventEmitter();
        /**
         * \@option Sets the ARIA role for the Nav, in the context of a TabContainer | 'list'
         */
        this.role = 'list';
        /**
         * \@option Sets the orientation of the List | 'vertical'
         */
        this._tabType = 'vertical';
        /**
         * \@option Type sets List size | null
         */
        this.type = null;
        /**
         * \@option Wrap prop type to wrap items to next row
         */
        this.wrap = false;
        /**
         * Combined stream of all of the child options' change events.
         */
        this.optionSelectionChanges = (/** @type {?} */ (defer((/**
         * @return {?}
         */
        () => {
            if (this.listItems) {
                return merge(...this.listItems.map((/**
                 * @param {?} option
                 * @return {?}
                 */
                option => option.selectionChange)));
            }
            return this._ngZone.onStable.asObservable()
                .pipe(take(1), switchMap((/**
             * @return {?}
             */
            () => this.optionSelectionChanges)));
        }))));
        this._isTabTypeOptionValid = (/**
         * @return {?}
         */
        () => (['vertical', 'horizontal'].includes(this._tabType)));
        this._isTypeOptionValid = (/**
         * @return {?}
         */
        () => (['small', 'large', 'space', 'xlarge'].includes(this.type)));
        this.optionSelectionChanges.subscribe((/**
         * @param {?} event
         * @return {?}
         */
        event => {
            this._onSelect(event.source);
        }));
    }
    /**
     * @param {?} tabType
     * @return {?}
     */
    set tabType(tabType) {
        if (this._tabType) {
            this.el.nativeElement.classList.remove(`md-list--${this._tabType}`);
        }
        this.el.nativeElement.classList.add(`md-list--${tabType}`);
        this._tabType = tabType;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this._tabType && !this._isTabTypeOptionValid()) {
            throw new Error(`md-list: List tabType option must be one of the following:
        vertical, horizontal`);
        }
        if (this.type && !this._isTypeOptionValid()) {
            throw new Error(`md-list: List type option must be one of the following:
        small, large, space, xlarge`);
        }
    }
    /**
     * @return {?}
     */
    ngAfterContentInit() {
        // set up listItems children with props
        this.listItems.forEach((/**
         * @param {?} listItem
         * @return {?}
         */
        listItem => {
            if (this.type) {
                listItem.type = this.type;
            }
            listItem.role = this.itemRole;
        }));
        this.cd.detectChanges();
    }
    /**
     * Invoked when an option is clicked.
     * @private
     * @param {?} option
     * @return {?}
     */
    _onSelect(option) {
        if (this.select) {
            this.listItems.forEach((/**
             * @param {?} listItem
             * @return {?}
             */
            listItem => {
                if (listItem !== option) {
                    listItem.active = false;
                }
            }));
            option.active = true;
            return this.select.emit(option);
        }
    }
}
ListComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-list',
                template: `
    <ng-content></ng-content>
  `,
                host: {
                    'class': 'md-list',
                    '[class.md-list--wrap]': 'wrap'
                }
            }] }
];
/** @nocollapse */
ListComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: NgZone },
    { type: ElementRef }
];
ListComponent.propDecorators = {
    id: [{ type: HostBinding, args: ['id',] }, { type: Input }],
    itemRole: [{ type: Input }],
    select: [{ type: Output }],
    role: [{ type: HostBinding, args: ['attr.role',] }, { type: Input }],
    tabType: [{ type: Input }],
    type: [{ type: Input }],
    wrap: [{ type: Input }],
    listItems: [{ type: ContentChildren, args: [ListItemComponent,] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ListModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: ListModule,
            providers: [],
        };
    }
}
ListModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [ListComponent],
                exports: [ListComponent],
                schemas: [CUSTOM_ELEMENTS_SCHEMA]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ListItemSectionComponent {
    constructor() {
        /**
         * \@option position Determine the ListItemSection's position | 'center'
         */
        this.position = 'center';
        /**
         * \@option class Optional css class name | ''
         */
        this.class = '';
        this.isValidPosition = (/**
         * @return {?}
         */
        () => ['left', 'center', 'right', 'center-align'].includes(this.position));
    }
    /**
     * @return {?}
     */
    get className() {
        return (`md-list-item__${this.position}` +
            `${(this.class && ` ${this.class}`) || ''}`);
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.position && !this.isValidPosition()) {
            throw new Error(`md-list-item-section: ListItemSection position option
        must be one of the following: left, center, right, center-align`);
        }
    }
}
ListItemSectionComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-list-item-section',
                template: `
    <ng-content></ng-content>
  `
            }] }
];
/** @nocollapse */
ListItemSectionComponent.ctorParameters = () => [];
ListItemSectionComponent.propDecorators = {
    position: [{ type: Input }],
    class: [{ type: Input }],
    className: [{ type: HostBinding, args: ['class',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ListItemSectionModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: ListItemSectionModule,
            providers: [],
        };
    }
}
ListItemSectionModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [ListItemSectionComponent],
                exports: [ListItemSectionComponent],
                schemas: [CUSTOM_ELEMENTS_SCHEMA]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// tslint:disable:no-use-before-declare
/** @type {?} */
const CUSTOM_CHECKBOX_CONTROL_VALUE_ACCESSOR = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef((/**
     * @return {?}
     */
    () => CheckboxComponent)),
    multi: true,
};
// tslint:enable:no-use-before-declare
class CheckboxComponent {
    /**
     * @param {?} cdr
     * @param {?} elementRef
     */
    constructor(cdr, elementRef) {
        this.cdr = cdr;
        this.elementRef = elementRef;
        /**
         * \@prop indicates if single checkbox not in checkbox group | false
         */
        this.solo = false;
        /**
         * \@prop Optional CSS class name on checkbox input | ''
         */
        this.className = '';
        /**
         * \@prop String value that corresponds with Checkbox  | ''
         */
        this.value = '';
        /**
         * \@prop index of the checkbox in tab order
         */
        this.tabIndex = 0;
        /**
         * \@prop Optional css class string | ''
         */
        this.class = '';
        /**
         * \@prop Sets the disabled attribute of the Input | false
         */
        this.disabled = false;
        /**
         * \@prop Help Text to appear under the radio | ''
         */
        this.helpText = '';
        /**
         * \@prop Optional indeterminate capabilities of checkbox | false
         */
        this.indeterminate = false;
        /**
         * \@prop Input label text | ''
         */
        this.label = '';
        /**
         * \@prop Optional required setting for Checkbox input | false
         */
        this.required = false;
        /**
         * \@prop Unique HTML ID. Used for tying label to HTML input | ''
         */
        this.htmlId = '';
        /**
         * \@prop sets value of the Checkbox input element | false
         */
        this.selectedItem = false;
        /**
         * \@prop Sets the attribute name to the Checkbox input element | ''
         */
        this.name = '';
        /**
         * \@prop optional emitter to invoke an checkStatusChange handler when checkbox toggles
         */
        this.checkStatusChange = new EventEmitter();
        this.checked = false;
        this.onListChange = (/**
         * @return {?}
         */
        () => { });
        this.onListTouched = (/**
         * @return {?}
         */
        () => { });
    }
    /**
     * @return {?}
     */
    get checkStatus() {
        return this.checked;
    }
    /**
     * @param {?} status
     * @return {?}
     */
    set checkStatus(status) {
        if (status !== undefined) {
            this.checked = status;
            if (!this.disabled) {
                this.updateList();
            }
        }
    }
    /**
     * \@prop Sets optional checkbox nestedLevel | null
     * @param {?} nestedLevel
     * @return {?}
     */
    set nestedLevel(nestedLevel) {
        if (this._nestedLevel) {
            this.elementRef.nativeElement.classList.remove(`md-input--nested-${this._nestedLevel}`);
        }
        this.elementRef.nativeElement.classList.add(`md-input--nested-${nestedLevel}`);
        this._nestedLevel = nestedLevel;
    }
    /**
     * @param {?} list
     * @return {?}
     */
    writeValue(list) {
        this.list = list;
        this.checked = this.isChecked();
        this.cdr.markForCheck();
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnChange(fn) {
        this.onListChange = fn;
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnTouched(fn) {
        this.onListTouched = fn;
    }
    /**
     * @param {?} isDisabled
     * @return {?}
     */
    setDisabledState(isDisabled) {
        this.disabled = isDisabled;
    }
    /**
     * @param {?} e
     * @return {?}
     */
    onClick(e) {
        e.preventDefault();
        if (this.disabled) {
            return;
        }
        this.checked = !this.checked;
        if (this.checkStatusChange.observers.length > 0) {
            this.checkStatusChange.emit(this.checked);
        }
        this.updateList();
    }
    /**
     * @return {?}
     */
    updateList() {
        if (this.indeterminate) {
            return;
        }
        if (this.solo) {
            this.onListChange(this.checked);
        }
        else {
            if (this.checked) {
                this.addCheck();
            }
            else {
                this.unCheck();
            }
            this.onListChange(this.list);
            if (this.formControl) {
                this.formControl.setValue(this.list);
            }
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    handleChange(event) {
        this.checked = event.target.checked;
        this.updateList();
    }
    /**
     * @return {?}
     */
    isChecked() {
        if (this.solo) {
            return this.list;
        }
        else {
            return this.list && this.list.includes(this.value);
        }
    }
    /**
     * @return {?}
     */
    unCheck() {
        if (this.list) {
            this.list = this.list.filter((/**
             * @param {?} check
             * @return {?}
             */
            check => check !== this.value));
        }
    }
    /**
     * @return {?}
     */
    addCheck() {
        if (this.list) {
            this.list = [...this.list, this.value];
        }
        else {
            this.list = [this.value];
        }
    }
}
CheckboxComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-checkbox',
                template: `
    <input
      class="md-input md-checkbox__input"
      [ngClass]="[indeterminate ? 'indeterminate' : '', className]"
      type="checkbox"
      (change)="handleChange($event)"
      [value]="value"
      [checked]="checked"
      [name]="name"
      [attr.id]="htmlId"
      [attr.tabindex]="tabIndex"
      [disabled]="disabled"
      [required]="required"
    />

    <label
      class="md-checkbox__label"
      [attr.for]="htmlId"
      (click)="onClick($event)"
    >
      <span>{{ label }}</span>
    </label>
    <md-input-helper *ngIf="helpText">{{ helpText }}</md-input-helper>
    <ng-content></ng-content>
  `,
                providers: [CUSTOM_CHECKBOX_CONTROL_VALUE_ACCESSOR],
                host: {
                    class: 'md-input-container md-checkbox',
                }
            }] }
];
/** @nocollapse */
CheckboxComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: ElementRef }
];
CheckboxComponent.propDecorators = {
    solo: [{ type: Input }],
    className: [{ type: Input }],
    value: [{ type: Input }],
    tabIndex: [{ type: Input }],
    formControl: [{ type: Input }],
    class: [{ type: Input }],
    disabled: [{ type: Input }],
    helpText: [{ type: Input }],
    indeterminate: [{ type: Input }],
    label: [{ type: Input }],
    required: [{ type: Input }],
    htmlId: [{ type: Input }],
    selectedItem: [{ type: Input }],
    name: [{ type: Input }],
    checkStatus: [{ type: Input }],
    nestedLevel: [{ type: Input }],
    checkStatusChange: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class LabelComponent {
}
LabelComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-label',
                template: `
    <label
      [attr.for]="htmlFor"
      [ngClass]="[
        'md-label',
        (theme && 'md-label--' + theme) || '',
        (className && className) || ''
      ]"
    >
      <span *ngIf="label">{{label}}</span>
      <ng-content></ng-content>
    </label>
  `
            }] }
];
LabelComponent.propDecorators = {
    className: [{ type: Input }],
    theme: [{ type: Input }],
    label: [{ type: Input }],
    htmlFor: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class LabelModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: LabelModule,
            providers: [],
        };
    }
}
LabelModule.decorators = [
    { type: NgModule, args: [{
                declarations: [LabelComponent],
                imports: [CommonModule],
                exports: [LabelComponent],
                schemas: [CUSTOM_ELEMENTS_SCHEMA],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class InputHelperComponent {
    /**
     * @return {?}
     */
    get _class() {
        return (`md-input__help-text` +
            `${this.className ? ` ${this.className}` : ''}`);
    }
}
InputHelperComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-input-helper',
                template: `<ng-content></ng-content>`
            }] }
];
InputHelperComponent.propDecorators = {
    className: [{ type: Input }],
    _class: [{ type: HostBinding, args: ['class',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class InputHelperModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: InputHelperModule,
            providers: [],
        };
    }
}
InputHelperModule.decorators = [
    { type: NgModule, args: [{
                declarations: [InputHelperComponent],
                imports: [CommonModule],
                exports: [InputHelperComponent],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CheckboxModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: CheckboxModule,
            providers: [],
        };
    }
}
CheckboxModule.decorators = [
    { type: NgModule, args: [{
                declarations: [CheckboxComponent],
                imports: [
                    CommonModule,
                    FormsModule,
                    ReactiveFormsModule,
                    LabelModule,
                    InputHelperModule,
                ],
                exports: [CheckboxComponent],
                schemas: [CUSTOM_ELEMENTS_SCHEMA]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ListItemModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: ListItemModule,
            providers: [],
        };
    }
}
ListItemModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CheckboxModule,
                    CommonModule,
                    IconModule,
                    ListItemSectionModule
                ],
                declarations: [ListItemComponent],
                exports: [ListItemComponent],
                schemas: [CUSTOM_ELEMENTS_SCHEMA]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ListItemHeaderComponent {
    /**
     * @param {?} elementRef
     */
    constructor(elementRef) {
        this.elementRef = elementRef;
        /**
         * HTML ID for associated input | ''
         */
        this.id = '';
        /**
         * Determines if ListItemHeader is Clickable | true
         */
        this.isReadOnly = true;
        /**
         * ListItem title | ''
         */
        this.title = '';
        this._type = '';
    }
    /**
     * ListItemHeader type variation | ''
     * @return {?}
     */
    get type() {
        return this._type;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set type(value) {
        this.elementRef.nativeElement.classList.remove(`md-list-item-header--${this._type}`);
        this.elementRef.nativeElement.classList.add(`md-list-item-header--${value}`);
        this._type = value;
    }
    /**
     * @return {?}
     */
    getTitle() {
        return !this.title ? this.header : this.title;
    }
}
ListItemHeaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-list-item-header',
                template: `
    <div
      md-list-item
      class="md-list-item-header"
      [isReadOnly]="isReadOnly"
      [title]="getTitle()"
    >
      <md-list-item-section position="center">
        <div class="md-list-item__header">{{ header }}</div>
      </md-list-item-section>
      <md-list-item-section position="right">
        <ng-content></ng-content>
      </md-list-item-section>
    </div>
  `
            }] }
];
/** @nocollapse */
ListItemHeaderComponent.ctorParameters = () => [
    { type: ElementRef }
];
ListItemHeaderComponent.propDecorators = {
    header: [{ type: Input }],
    id: [{ type: Input }],
    isReadOnly: [{ type: Input }],
    title: [{ type: Input }],
    type: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ListItemHeaderModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: ListItemHeaderModule,
            providers: [],
        };
    }
}
ListItemHeaderModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, ListItemModule, ListItemSectionModule],
                declarations: [ListItemHeaderComponent],
                exports: [ListItemHeaderComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// Used internally by the alert call service.
class AlertCallComponent {
    constructor() {
        this.devices = [];
        this.title = '';
        this.answerShare = new EventEmitter();
        this.answerVideo = new EventEmitter();
        this.answerVoice = new EventEmitter();
        this.reject = new EventEmitter();
        this.deviceSelect = new EventEmitter();
    }
    /**
     * @return {?}
     */
    onAnswerShare() {
        this.answerShare.emit(this.key);
    }
    /**
     * @return {?}
     */
    onAnswerVideo() {
        this.answerVideo.emit(this.key);
    }
    /**
     * @return {?}
     */
    onAnswerVoice() {
        this.answerVoice.emit(this.key);
    }
    /**
     * @return {?}
     */
    onReject() {
        this.reject.emit(this.key);
    }
    /**
     * @param {?} device
     * @return {?}
     */
    onDeviceSelect(device) {
        device.key = this.key;
        this.deviceSelect.emit(device);
    }
}
AlertCallComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-alert-call',
                template: `
    <div class="md-alert__title">{{ title }}</div>
    <div class="md-alert__caller">
      <ng-container *ngIf="avatar; else callerTemplate" [ngTemplateOutlet]="avatar"></ng-container>
      <div class="md-alert__caller-title">{{ caller.title }}</div>
      <div class="md-alert__caller-subtitle">{{ caller.alt }}</div>
    </div>
    <md-device-list-call
      *ngIf="devices.length > 0"
      mdRemoveHost
      [devices]="devices"
      [selectedDevice]="defaultSelectedDevice"
      [header]="deviceListHeader"
      (select)="onDeviceSelect($event)"
      ></md-device-list-call>
    <div class="md-alert--call--buttons">
      <button
        *ngIf="answerShareButtonVisible"
        md-button
        [attr.aria-label]="shareAriaLabel"
        [circle]="true"
        color="blue"
        size="44"
        tabindex="0"
        (click)="onAnswerShare()"
      >
        <md-icon name="share-screen_24"></md-icon>
      </button>
      <button
        *ngIf="answerVideoButtonVisible"
        md-button
        [attr.aria-label]="videoAriaLabel"
        [circle]="true"
        color="green"
        size="44"
        tabindex="0"
        (click)="onAnswerVideo()"
      >
        <md-icon name="camera_24"></md-icon>
      </button>
      <button
        *ngIf="answerVoiceButtonVisible"
        md-button
        [attr.aria-label]="voiceAriaLabel"
        [circle]="true"
        color="green"
        size="44"
        tabindex="0"
        (click)="onAnswerVoice()"
      >
        <md-icon name="handset_24"></md-icon>
      </button>
      <button
        md-button
        [attr.aria-label]="rejectAriaLabel"
        [circle]="true"
        color="red"
        size="44"
        tabindex="0"
        (click)="onReject()"
      >
        <md-icon name="cancel_24"></md-icon>
      </button>
    </div>

    <ng-template #callerTemplate>
      <ng-container [ngSwitch]="caller.type">
        <md-avatar *ngSwitchCase="'number'" title="#" [alt]="caller.title" size="xlarge"></md-avatar>
        <md-avatar *ngSwitchCase="'device'" icon="spark-board_32" [alt]="caller.title" size="xlarge"></md-avatar>
        <md-avatar *ngSwitchDefault [title]="caller.title" [alt]="caller.title" size="xlarge"></md-avatar>
      </ng-container>
    </ng-template>
  `,
                host: {
                    'class': 'md-alert md-alert--call',
                }
            }] }
];
AlertCallComponent.propDecorators = {
    key: [{ type: Input }],
    answerShareButtonVisible: [{ type: Input }],
    answerVideoButtonVisible: [{ type: Input }],
    answerVoiceButtonVisible: [{ type: Input }],
    avatar: [{ type: Input }],
    caller: [{ type: Input }],
    defaultSelectedDevice: [{ type: Input }],
    deviceListHeader: [{ type: Input }],
    devices: [{ type: Input }],
    rejectAriaLabel: [{ type: Input }],
    shareAriaLabel: [{ type: Input }],
    title: [{ type: Input }],
    videoAriaLabel: [{ type: Input }],
    voiceAriaLabel: [{ type: Input }],
    answerShare: [{ type: Output }],
    answerVideo: [{ type: Output }],
    answerVoice: [{ type: Output }],
    reject: [{ type: Output }],
    deviceSelect: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// Used internally by the alert call service.
class AlertCallContainerComponent {
    constructor() {
        this._onDestroy = new Subject();
        this.alertList = [];
    }
    /**
     * @param {?} alert
     * @return {?}
     */
    addAlert(alert) {
        alert.key = uniqueId('alert_call_');
        this.alertList.push(alert);
        return alert.key;
    }
    /**
     * @param {?} key
     * @return {?}
     */
    removeAlert(key) {
        this.alertList = reject(this.alertList, { key });
        if (!this.alertList.length) {
            this.destroy();
        }
    }
    /**
     * @param {?} key
     * @return {?}
     */
    onAnswerShare(key) {
        /** @type {?} */
        const alert = find(this.alertList, { key });
        if (alert && alert.onAnswerShare) {
            alert.onAnswerShare(alert);
        }
        this.removeAlert(key);
    }
    /**
     * @param {?} key
     * @return {?}
     */
    onAnswerVideo(key) {
        /** @type {?} */
        const alert = find(this.alertList, { key });
        if (alert && alert.onAnswerVideo) {
            alert.onAnswerVideo(alert);
        }
        this.removeAlert(key);
    }
    /**
     * @param {?} key
     * @return {?}
     */
    onAnswerVoice(key) {
        /** @type {?} */
        const alert = find(this.alertList, { key });
        if (alert && alert.onAnswerVoice) {
            alert.onAnswerVoice(alert);
        }
        this.removeAlert(key);
    }
    /**
     * @param {?} key
     * @return {?}
     */
    onReject(key) {
        /** @type {?} */
        const alert = find(this.alertList, { key });
        if (alert && alert.onReject) {
            alert.onReject(alert);
        }
        this.removeAlert(key);
    }
    /**
     * @param {?} device
     * @return {?}
     */
    onDeviceSelect(device) {
        /** @type {?} */
        const alert = find(this.alertList, { key: device.key });
        if (alert && alert.onDeviceSelect) {
            alert.onDeviceSelect(device);
        }
    }
    /**
     * @return {?}
     */
    destroy() {
        this._onDestroy.next();
        this._onDestroy.complete();
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.destroy();
    }
}
AlertCallContainerComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-alert-call-container',
                template: `
    <md-alert-call *ngFor="let alert of alertList"
      [key]="alert.key"
      [answerShareButtonVisible]="!!alert.onAnswerShare"
      [answerVideoButtonVisible]="!!alert.onAnswerVideo"
      [answerVoiceButtonVisible]="!!alert.onAnswerVoice"
      [avatar]="alert.avatar"
      [caller]="alert.caller"
      [defaultSelectedDevice]="alert.defaultSelectedDevice"
      [deviceListHeader]="alert.deviceListHeader"
      [remindAriaLabel]="alert.remindAriaLabel"
      [devices]="alert.devices"
      [rejectAriaLabel]="alert.rejectAriaLabel"
      [shareAriaLabel]="alert.shareAriaLabel"
      [title]="alert.title"
      [videoAriaLabel]="alert.videoAriaLabel"
      [voiceAriaLabel]="alert.voiceAriaLabel"
      (answerShare)="onAnswerShare($event)"
      (answerVideo)="onAnswerVideo($event)"
      (answerVoice)="onAnswerVoice($event)"
      (deviceSelect)="onDeviceSelect($event)"
      (reject)="onReject($event)"
    ></md-alert-call>
  `,
                host: {
                    'class': 'md-alert__container md-alert__container--call'
                }
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// Configuration used when opening an alert.
class AlertCallConfig {
    constructor() {
        /**
         * Optional default selected device by index or value | 0
         */
        this.defaultSelectedDevice = 0;
        /**
         * Optional header string for device selection list | "Device selection"
         */
        this.deviceListHeader = 'Device selection';
        /**
         * Optional list of devices to answer call with | []
         */
        this.devices = [];
        /**
         * Optional aria-label reject message | 'reject call'
         */
        this.rejectAriaLabel = 'reject call';
        /**
         * Optional aria-label share | 'answer call with share'
         */
        this.shareAriaLabel = 'answer call with share';
        /**
         * Optional title of AlertCall | ''
         */
        this.title = '';
        /**
         * Optional aria-label video | 'answer call with voice and video'
         */
        this.videoAriaLabel = 'answer call with voice and video';
        /**
         * Optional aria-label voice | 'answer call with voice only'
         */
        this.voiceAriaLabel = 'answer call with voice only';
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AlertCallDevice {
    constructor() {
        this.id = uniqueId('alert_call_device_');
    }
}
class DeviceListCallComponent {
    constructor() {
        this.select = new EventEmitter();
    }
    /**
     * @param {?} listItem
     * @return {?}
     */
    onSelect(listItem) {
        /** @type {?} */
        const device = find(this.devices, { id: listItem.id });
        this.selectedDevice = device.value;
        this.select.emit(device);
    }
}
DeviceListCallComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-device-list-call',
                template: `
    <md-list tabType="vertical" (select)="onSelect($event)">
      <md-list-item-header mdRemoveHost [header]="header"></md-list-item-header>
      <div md-list-item *ngFor="let device of devices; index as i"
        [id]="device.id"
        [value]="device.value"
        [title]="device.title || device.name"
        role="listItem"
      >
        <md-list-item-section position="left">
          <ng-container [ngSwitch]="device.type">
            <md-icon *ngSwitchCase="'device'" name="spark-board_20"></md-icon>
            <md-icon *ngSwitchDefault name="laptop_20"></md-icon>
          </ng-container>
        </md-list-item-section>
        <md-list-item-section position="center">
          <div class="md-list-item__header">
            {{ device.name }}
          </div>
        </md-list-item-section>
        <md-list-item-section position="right">
          <md-icon *ngIf="i === selectedDevice || device.value === selectedDevice" name="check_20" color="blue-50"></md-icon>
        </md-list-item-section>
      </div>
    </md-list>
  `
            }] }
];
DeviceListCallComponent.propDecorators = {
    selectedDevice: [{ type: Input }],
    devices: [{ type: Input }],
    header: [{ type: Input }],
    select: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AlertCallService {
    /**
     * @param {?} _overlay
     */
    constructor(_overlay) {
        this._overlay = _overlay;
        this._overlayRef = null;
        this._alertContainerRef = null;
    }
    /**
     * @param {?} config
     * @return {?}
     */
    show(config) {
        if (!this._overlayRef) {
            this._overlayRef = this._overlay.create();
        }
        /** @type {?} */
        const container = this._attachAlertContainer(this._overlayRef);
        if (config.devices) {
            config.devices = config.devices.map((/**
             * @param {?} device
             * @return {?}
             */
            device => {
                return Object.assign({}, new AlertCallDevice(), device);
            }));
        }
        /** @type {?} */
        const _config = Object.assign({}, new AlertCallConfig(), config);
        return container.addAlert(_config);
    }
    /**
     * @param {?} key
     * @return {?}
     */
    hide(key) {
        if (this._alertContainerRef) {
            this._alertContainerRef.instance.removeAlert(key);
        }
    }
    /**
     * @private
     * @param {?} overlayRef
     * @return {?}
     */
    _attachAlertContainer(overlayRef) {
        if (this._alertContainerRef) {
            return this._alertContainerRef.instance;
        }
        /** @type {?} */
        const containerPortal = new ComponentPortal(AlertCallContainerComponent);
        this._alertContainerRef = overlayRef.attach(containerPortal);
        /** @type {?} */
        const onDestroySub = this._alertContainerRef.instance._onDestroy.subscribe((/**
         * @return {?}
         */
        () => {
            onDestroySub.unsubscribe();
            this._dispose();
        }));
        return this._alertContainerRef.instance;
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this._alertContainerRef) {
            this._alertContainerRef.instance.destroy();
        }
    }
    /**
     * @private
     * @return {?}
     */
    _dispose() {
        this._alertContainerRef = null;
        this._overlayRef.dispose();
        this._overlayRef = null;
    }
}
AlertCallService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
AlertCallService.ctorParameters = () => [
    { type: Overlay }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class RemoveHostDirective {
    /**
     * @param {?} _element
     */
    constructor(_element) {
        this._element = _element;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        /** @type {?} */
        const nativeElement = this._element.nativeElement;
        /** @type {?} */
        const parentElement = nativeElement.parentElement;
        // move all children out of the host element
        while (nativeElement.firstChild) {
            parentElement.insertBefore(nativeElement.firstChild, nativeElement);
        }
        // remove the empty host element
        parentElement.removeChild(nativeElement);
    }
}
RemoveHostDirective.decorators = [
    { type: Directive, args: [{
                selector: '[mdRemoveHost]'
            },] }
];
/** @nocollapse */
RemoveHostDirective.ctorParameters = () => [
    { type: ElementRef }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AlertCallModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: AlertCallModule,
            providers: [],
        };
    }
}
AlertCallModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    OverlayModule,
                    PortalModule,
                    CommonModule,
                    AvatarModule,
                    ButtonModule,
                    IconModule,
                    ListModule,
                    ListItemModule,
                    ListItemHeaderModule,
                    ListItemSectionModule,
                ],
                declarations: [
                    AlertCallComponent,
                    AlertCallContainerComponent,
                    DeviceListCallComponent,
                    RemoveHostDirective,
                ],
                exports: [AlertCallContainerComponent],
                entryComponents: [AlertCallContainerComponent],
                providers: [AlertCallService],
                schemas: [CUSTOM_ELEMENTS_SCHEMA],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CompositeAvatarComponent {
    constructor() {
        this.className = '';
        this.size = 'medium';
    }
    /**
     * @return {?}
     */
    get _class() {
        return ('md-composite-avatar' +
            `${(this.size && ` md-composite-avatar--${this.size}`) || ''}` +
            `${(this.className && ` ${this.className}`) || ''}`);
    }
}
CompositeAvatarComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-composite-avatar',
                template: `
    <ng-content></ng-content>
  `
            }] }
];
/** @nocollapse */
CompositeAvatarComponent.ctorParameters = () => [];
CompositeAvatarComponent.propDecorators = {
    className: [{ type: Input }],
    size: [{ type: Input }],
    _class: [{ type: HostBinding, args: ['class',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CompositeAvatarModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: CompositeAvatarModule,
            providers: [],
        };
    }
}
CompositeAvatarModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, AvatarModule],
                declarations: [CompositeAvatarComponent],
                exports: [CompositeAvatarComponent],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// Used internally by the alert meeting service.
class AlertMeetingComponent {
    constructor() {
        this.attendees = [];
        this.closeAriaLabel = 'close';
        this.message = '';
        this.remindAriaLabel = 'snooze';
        this.status = '';
        this.title = '';
        this.mouseclick = new EventEmitter();
        this.hide = new EventEmitter();
        this.snooze = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (!this.avatar && this.attendees.length === 0) {
            throw new Error('MeetingAlert needs at least one attendee to render an avatar.');
        }
    }
    /**
     * @return {?}
     */
    onClick() {
        this.mouseclick.emit(this.key);
    }
    /**
     * @return {?}
     */
    onSnooze() {
        this.snooze.emit(this.key);
    }
    /**
     * @return {?}
     */
    onHide() {
        this.hide.emit(this.key);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onKeydown(event) {
        if (event.code === 'Space' || event.code === 'Enter') {
            this.onClick();
            event.preventDefault();
        }
    }
}
AlertMeetingComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-alert-meeting',
                template: `
    <ng-container *ngIf="avatar; else avatarTemplate" [ngTemplateOutlet]="avatar"></ng-container>
    <div [ngClass]="[
      'md-alert__content',
      this.snoozeButtonVisible ? '' : 'md-alert__content--wide'
    ]">
      <div class="md-alert__title" [attr.title]="title">{{ title }}</div>
      <div class="md-alert__status">{{ status }}</div>
      <div class="md-alert__message" [attr.title]="message">{{ message }}</div>
    </div>
    <div class="md-alert__button" *ngIf="snoozeButtonVisible">
      <button
        md-button
        [attr.aria-label]="remindAriaLabel"
        [circle]="true"
        size="44"
        tabindex="0"
        (click)="onSnooze()"
      >
        <md-icon name="alarm_16"></md-icon>
      </button>
    </div>
    <div class="md-alert__button">
      <button
        md-button
        [attr.aria-label]="closeAriaLabel"
        [circle]="true"
        size="44"
        tabindex="0"
        (click)="onHide()"
      >
        <md-icon name="cancel_16"></md-icon>
      </button>
    </div>

    <ng-template #avatarTemplate>
      <md-composite-avatar *ngIf="attendees.length >= 2">
        <md-avatar
          [title]="attendees[0].title"
          [alt]="attendees[0].alt"
          [src]="attendees[0].src"
        ></md-avatar>
        <md-avatar
          [title]="attendees[1].title"
          [alt]="attendees[1].alt"
          [src]="attendees[1].src"
        ></md-avatar>
      </md-composite-avatar>
      <md-avatar
        *ngIf="attendees.length === 1"
        [title]="attendees[0].title"
        [alt]="attendees[0].alt"
        [src]="attendees[0].src"
      ></md-avatar>
    </ng-template>
  `,
                host: {
                    'class': 'md-alert md-alert--meeting',
                    '[attr.role]': 'clickable ? "button" : null',
                    '[attr.tabindex]': 'clickable ? "0" : null',
                    '(click)': 'clickable ? onClick() : null',
                    '(keydown)': 'clickable ? onKeydown($event) : null',
                }
            }] }
];
AlertMeetingComponent.propDecorators = {
    key: [{ type: Input }],
    attendees: [{ type: Input }],
    avatar: [{ type: Input }],
    clickable: [{ type: Input }],
    closeAriaLabel: [{ type: Input }],
    message: [{ type: Input }],
    remindAriaLabel: [{ type: Input }],
    snoozeButtonVisible: [{ type: Input }],
    status: [{ type: Input }],
    title: [{ type: Input }],
    mouseclick: [{ type: Output }],
    hide: [{ type: Output }],
    snooze: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// Used internally by the alert meeting service.
class AlertMeetingContainerComponent {
    constructor() {
        this._onDestroy = new Subject();
        this.alertList = [];
    }
    /**
     * @param {?} alert
     * @return {?}
     */
    addAlert(alert) {
        alert.key = uniqueId('alert_meeting_');
        this.alertList.push(alert);
        return alert.key;
    }
    /**
     * @param {?} key
     * @return {?}
     */
    removeAlert(key) {
        this.alertList = reject(this.alertList, { key });
        if (!this.alertList.length) {
            this.destroy();
        }
    }
    /**
     * @param {?} key
     * @return {?}
     */
    onClick(key) {
        /** @type {?} */
        const alert = find(this.alertList, { key });
        if (alert && alert.onClick) {
            alert.onClick();
        }
        this.removeAlert(key);
    }
    /**
     * @param {?} key
     * @return {?}
     */
    onHide(key) {
        /** @type {?} */
        const alert = find(this.alertList, { key });
        if (alert && alert.onHide) {
            alert.onHide();
        }
        this.removeAlert(key);
    }
    /**
     * @param {?} key
     * @return {?}
     */
    onSnooze(key) {
        /** @type {?} */
        const alert = find(this.alertList, { key });
        if (alert && alert.onSnooze) {
            alert.onSnooze();
        }
        this.removeAlert(key);
    }
    /**
     * @return {?}
     */
    destroy() {
        this._onDestroy.next();
        this._onDestroy.complete();
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.destroy();
    }
}
AlertMeetingContainerComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-alert-meeting-container',
                template: `
    <md-alert-meeting *ngFor="let alert of alertList"
      [key]="alert.key"
      [attendees]="alert.attendees"
      [avatar]="alert.avatar"
      [clickable]="!!alert.onClick"
      [closeAriaLabel]="alert.closeAriaLabel"
      [message]="alert.message"
      [remindAriaLabel]="alert.remindAriaLabel"
      [snoozeButtonVisible]="!!alert.onSnooze"
      [status]="alert.status"
      [title]="alert.title"
      (mouseclick)="onClick($event)"
      (hide)="onHide($event)"
      (snooze)="onSnooze($event)"
    ></md-alert-meeting>
  `,
                host: {
                    'class': 'md-alert__container md-alert__container--bottom-right'
                }
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// Configuration used when opening an alert.
class AlertMeetingConfig {
    constructor() {
        /**
         * Optional attendee array. If more than one attendee, a Composite Avatar with only the first 2 attendees is created.
         */
        this.attendees = [];
        /**
         * Optional aria label for the close button | 'close'
         */
        this.closeAriaLabel = 'close';
        /**
         * Optional AlertMeeting Message | ''
         */
        this.message = '';
        /**
         * Optional aria label for snooze buton | 'snooze'
         */
        this.remindAriaLabel = 'snooze';
        /**
         * Optional AlertMeeting status | ''
         */
        this.status = '';
        /**
         * Optional AlertMeeting title | ''
         */
        this.title = '';
        /**
         * Optional callback function invoked on click of alert | null
         */
        this.onClick = null;
        /**
         * Optional handler invoked when the user presses on the Alert's close button or hit's the esc key | null
         */
        this.onHide = null;
        /**
         * Optional callback function invoked when the snooze button is clicked | null
         */
        this.onSnooze = null;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AlertMeetingService {
    /**
     * @param {?} _overlay
     */
    constructor(_overlay) {
        this._overlay = _overlay;
        this._overlayRef = null;
        this._alertContainerRef = null;
    }
    /**
     * @param {?} config
     * @return {?}
     */
    show(config) {
        if (!this._overlayRef) {
            this._overlayRef = this._overlay.create();
        }
        /** @type {?} */
        const container = this._attachAlertContainer(this._overlayRef);
        /** @type {?} */
        const _config = Object.assign({}, new AlertMeetingConfig(), config);
        return container.addAlert(_config);
    }
    /**
     * @param {?} key
     * @return {?}
     */
    hide(key) {
        if (this._alertContainerRef) {
            this._alertContainerRef.instance.removeAlert(key);
        }
    }
    /**
     * @private
     * @param {?} overlayRef
     * @return {?}
     */
    _attachAlertContainer(overlayRef) {
        if (this._alertContainerRef) {
            return this._alertContainerRef.instance;
        }
        /** @type {?} */
        const containerPortal = new ComponentPortal(AlertMeetingContainerComponent);
        this._alertContainerRef = overlayRef.attach(containerPortal);
        /** @type {?} */
        const onDestroySub = this._alertContainerRef.instance._onDestroy.subscribe((/**
         * @return {?}
         */
        () => {
            onDestroySub.unsubscribe();
            this._dispose();
        }));
        return this._alertContainerRef.instance;
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this._alertContainerRef) {
            this._alertContainerRef.instance.destroy();
        }
    }
    /**
     * @private
     * @return {?}
     */
    _dispose() {
        this._alertContainerRef = null;
        this._overlayRef.dispose();
        this._overlayRef = null;
    }
}
AlertMeetingService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
AlertMeetingService.ctorParameters = () => [
    { type: Overlay }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AlertMeetingModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: AlertMeetingModule,
            providers: [],
        };
    }
}
AlertMeetingModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    OverlayModule,
                    PortalModule,
                    CommonModule,
                    AvatarModule,
                    ButtonModule,
                    CompositeAvatarModule,
                    IconModule,
                ],
                declarations: [AlertMeetingComponent, AlertMeetingContainerComponent],
                exports: [AlertMeetingContainerComponent],
                entryComponents: [AlertMeetingContainerComponent],
                providers: [AlertMeetingService]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// Used internally by the alert service.
class AlertComponent {
    constructor() {
        this.dismissed = new EventEmitter();
    }
    /**
     * @return {?}
     */
    get className() {
        return `md-alert md-alert--${this.type}`;
    }
    /**
     * @return {?}
     */
    dismiss() {
        this.dismissed.emit(this.key);
    }
}
AlertComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-alert',
                template: `
    <div class="md-alert__icon"></div>
    <div class="md-alert__content">
      <div class="md-alert__title">{{ title }}</div>
      <div class="md-alert__message">{{ message }}</div>
    </div>
    <div class="md-alert__button" *ngIf="closable">
      <button
        md-button
        #closeButton
        [attr.aria-label]="ariaLabel"
        [circle]="true"
        size="44"
        (click)="dismiss()"
      >
        <md-icon name="cancel_16"></md-icon>
      </button>
    </div>
  `
            }] }
];
/** @nocollapse */
AlertComponent.ctorParameters = () => [];
AlertComponent.propDecorators = {
    key: [{ type: Input }],
    type: [{ type: Input }],
    ariaLabel: [{ type: Input }],
    closable: [{ type: Input }],
    message: [{ type: Input }],
    title: [{ type: Input }],
    className: [{ type: HostBinding, args: ['class',] }],
    dismissed: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Configuration used when opening an alert.
 */
class AlertConfig {
    constructor() {
        this.ariaLabel = 'Close';
        /**
         * To show/hide Close button of the Alert | true
         */
        this.closable = true;
        /**
         * Optional Alert message | ''
         */
        this.message = '';
        /**
         * Handler invoked when the user presses on the Alert's close button | null
         */
        this.onHide = null;
        /**
         * Display newest alert messages first | true
         */
        this.orderNewest = true;
        /**
         * Define alert's position with css class name: 'bottom-right'
         */
        this.position = 'bottom-right';
        /**
         * Optional Alert title | ''
         */
        this.title = '';
        /**
         * Sets the type of the Alert | 'info'
         */
        this.type = 'info';
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Used internally by the alert service.
 */
class AlertContainerComponent {
    /**
     * @param {?} alertConfig
     */
    constructor(alertConfig) {
        this.alertConfig = alertConfig;
        this.role = 'alert';
        this._onDestroy = new Subject();
        this.alertList = [];
    }
    /**
     * @return {?}
     */
    get className() {
        return `md-alert__container md-alert__container--${this.alertConfig.position}`;
    }
    /**
     * @param {?} alert
     * @return {?}
     */
    addAlert(alert) {
        alert.key = uniqueId('alert_');
        this.alertList = this.alertConfig.orderNewest
            ? [alert, ...this.alertList]
            : [...this.alertList, alert];
        return alert.key;
    }
    /**
     * @param {?} key
     * @return {?}
     */
    removeAlert(key) {
        /** @type {?} */
        const alert = find(this.alertList, { key: key });
        if (alert && alert.onHide) {
            alert.onHide();
        }
        this.alertList = reject(this.alertList, { key: key });
        if (!this.alertList.length) {
            this.destroy();
        }
    }
    /**
     * @return {?}
     */
    destroy() {
        this._onDestroy.next();
        this._onDestroy.complete();
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.destroy();
    }
}
AlertContainerComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-alert-container',
                template: `
    <ng-container *ngFor="let alert of alertList">
      <md-alert
        [key]="alert.key"
        [ariaLabel]="alert.ariaLabel"
        [type]="alert.type"
        [title]="alert.title"
        [message]="alert.message"
        [closable]="alert.closable"
        (dismissed)="removeAlert($event)"
      ></md-alert>
    </ng-container>
  `
            }] }
];
/** @nocollapse */
AlertContainerComponent.ctorParameters = () => [
    { type: AlertConfig }
];
AlertContainerComponent.propDecorators = {
    role: [{ type: HostBinding, args: ['attr.role',] }],
    className: [{ type: HostBinding, args: ['class',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AlertService {
    /**
     * @param {?} _overlay
     * @param {?} _injector
     */
    constructor(_overlay, _injector) {
        this._overlay = _overlay;
        this._injector = _injector;
        this._overlayRef = null;
        this._alertContainerRef = null;
    }
    /**
     * @param {?} title
     * @param {?} message
     * @param {?=} config
     * @return {?}
     */
    info(title, message, config) {
        return this._open('info', title, message, config);
    }
    /**
     * @param {?} title
     * @param {?} message
     * @param {?=} config
     * @return {?}
     */
    success(title, message, config) {
        return this._open('success', title, message, config);
    }
    /**
     * @param {?} title
     * @param {?} message
     * @param {?=} config
     * @return {?}
     */
    warning(title, message, config) {
        return this._open('warning', title, message, config);
    }
    /**
     * @param {?} title
     * @param {?} message
     * @param {?=} config
     * @return {?}
     */
    error(title, message, config) {
        return this._open('error', title, message, config);
    }
    /**
     * @param {?} key
     * @return {?}
     */
    hide(key) {
        if (this._alertContainerRef) {
            this._alertContainerRef.instance.removeAlert(key);
        }
    }
    /**
     * @private
     * @param {?} type
     * @param {?} title
     * @param {?} message
     * @param {?=} config
     * @return {?}
     */
    _open(type, title, message, config) {
        /** @type {?} */
        const _config = Object.assign({}, new AlertConfig(), config);
        _config.type = type;
        _config.title = title;
        _config.message = message;
        if (!this._overlayRef) {
            this._overlayRef = this._overlay.create();
        }
        /** @type {?} */
        const container = this._attachAlertContainer(this._overlayRef, _config);
        return container.addAlert(_config);
    }
    /**
     * @private
     * @param {?} overlayRef
     * @param {?} config
     * @return {?}
     */
    _attachAlertContainer(overlayRef, config) {
        if (this._alertContainerRef) {
            return this._alertContainerRef.instance;
        }
        /** @type {?} */
        const injector = new PortalInjector(this._injector, new WeakMap([[AlertConfig, config]]));
        /** @type {?} */
        const containerPortal = new ComponentPortal(AlertContainerComponent, null, injector);
        this._alertContainerRef = overlayRef.attach(containerPortal);
        /** @type {?} */
        const onDestroySub = this._alertContainerRef.instance._onDestroy.subscribe((/**
         * @return {?}
         */
        () => {
            onDestroySub.unsubscribe();
            this._dispose();
        }));
        return this._alertContainerRef.instance;
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this._alertContainerRef) {
            this._alertContainerRef.instance.destroy();
        }
    }
    /**
     * @private
     * @return {?}
     */
    _dispose() {
        this._alertContainerRef = null;
        this._overlayRef.dispose();
        this._overlayRef = null;
    }
}
AlertService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
AlertService.ctorParameters = () => [
    { type: Overlay },
    { type: Injector }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AlertModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: AlertModule,
            providers: [],
        };
    }
}
AlertModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    OverlayModule,
                    PortalModule,
                    CommonModule,
                    ButtonModule,
                    IconModule,
                ],
                declarations: [AlertComponent, AlertContainerComponent],
                exports: [AlertContainerComponent],
                entryComponents: [AlertContainerComponent],
                providers: [AlertService],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class BadgeComponent {
    /**
     * @param {?} elementRef
     */
    constructor(elementRef) {
        this.elementRef = elementRef;
        /**
         * \@option Sets the optional rounded class | false
         */
        this.rounded = false;
        this._color = null;
    }
    /**
     * \@option Sets optional button color | null
     * @param {?} color
     * @return {?}
     */
    set color(color) {
        if (this._color) {
            this.elementRef.nativeElement.classList.remove(`md-badge--${this._color}`);
        }
        this.elementRef.nativeElement.classList.add(`md-badge--${color}`);
        this._color = color;
    }
}
BadgeComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-badge',
                template: `
    <ng-content></ng-content>
  `,
                host: {
                    class: 'md-badge',
                    '[class.md-badge--round]': 'rounded',
                }
            }] }
];
/** @nocollapse */
BadgeComponent.ctorParameters = () => [
    { type: ElementRef }
];
BadgeComponent.propDecorators = {
    rounded: [{ type: Input }],
    color: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class BadgeModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: BadgeModule,
            providers: [],
        };
    }
}
BadgeModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [BadgeComponent],
                exports: [BadgeComponent],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ButtonGroupComponent {
    /**
     * @param {?} elementRef
     * @param {?} renderer
     */
    constructor(elementRef, renderer) {
        this.elementRef = elementRef;
        this.renderer = renderer;
        /**
         * \@prop Text to display for blindness accessibility features | ''
         */
        this.ariaLabel = '';
        /**
         * \@prop Set focus to ButtonGroup when page is loaded | false
         */
        this.focusOnLoad = false;
        /**
         * \@prop Highlights the selected button within group | true
         */
        this.highlightSelected = true;
        /**
         * \@prop Optional text-justified css styling | true
         */
        this.justified = true;
        /**
         * \@prop Sets width of a pill Button | '60px'
         */
        this.pillWidth = '60px';
        this.select = new EventEmitter();
        this._focusIndex = 0;
        this._theme = '';
        this._type = '';
    }
    /**
     * \@prop Optional Button color theme for ButtonGroup | ''
     * @return {?}
     */
    get theme() {
        return this._theme;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set theme(value) {
        this.elementRef.nativeElement.classList.remove(`md-button-group--${this._theme}`);
        this.elementRef.nativeElement.classList.add(`md-button-group--${value}`);
        this._theme = value;
    }
    /**
     * \@prop Optional Button type for ButtonGroup | ''
     * @return {?}
     */
    get type() {
        return this._type;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set type(value) {
        this.elementRef.nativeElement.classList.remove(`md-button-group--${this._type}`);
        this.elementRef.nativeElement.classList.add(`md-button-group--${value}`);
        this._type = value;
    }
    /**
     * @return {?}
     */
    ngAfterContentInit() {
        this.buttonList.forEach((/**
         * @param {?} button
         * @param {?} idx
         * @return {?}
         */
        (button, idx) => {
            button.focusOnLoad = this.focusOnLoad;
            button.index = idx;
            if (this.pillWidth) {
                button.width = this.pillWidth;
            }
            this.renderer.listen(button.hostElement.nativeElement, 'click', (/**
             * @param {?} e
             * @return {?}
             */
            e => this.handleClick(e, button.index)));
            this.renderer.listen(button.hostElement.nativeElement, 'keydown', (/**
             * @param {?} e
             * @return {?}
             */
            e => this.handleKeydown(e, button.index)));
        }));
        /** @type {?} */
        const initialFocus = this.getNewIndex(this._focusIndex - 1, 1);
        this.setFocusIndex(initialFocus);
        if (this.activeIndex !== null) {
            this.determineInitialActive();
        }
    }
    /**
     * @param {?} currentIndex
     * @param {?} change
     * @return {?}
     */
    getNewIndex(currentIndex, change) {
        /** @type {?} */
        const length = this.buttonList.length - 1;
        /** @type {?} */
        const getPossibleIndex = (/**
         * @return {?}
         */
        () => {
            if (currentIndex + change < 0) {
                return length;
            }
            else if (currentIndex + change > length) {
                return 0;
            }
            return currentIndex + change;
        });
        /** @type {?} */
        const possibleIndex = getPossibleIndex();
        /** @type {?} */
        const potentialTarget = this.buttonList.toArray()[possibleIndex];
        return potentialTarget.disabled
            ? this.getNewIndex(possibleIndex, change)
            : possibleIndex;
    }
    /**
     * @param {?} index
     * @return {?}
     */
    setFocusIndex(index) {
        this._focusIndex = index;
        this.buttonList.forEach((/**
         * @param {?} button
         * @return {?}
         */
        button => {
            button.focusIndex = index;
        }));
    }
    /**
     * @return {?}
     */
    determineInitialActive() {
        if (this.activeIndex < 0 && this.activeIndex > this.buttonList.length - 1) {
            console.warn('[@collab-ui/angular] ButtonGroup: activeIndex is out of bound');
            return;
        }
        if (!isNaN(this.activeIndex)) {
            /** @type {?} */
            const initialActive = this.getNewIndex(this.activeIndex - 1, 1);
            this.setActiveIndex(initialActive);
        }
    }
    /**
     * @param {?} index
     * @return {?}
     */
    setActiveIndex(index) {
        if (this.activeIndex !== index) {
            this.activeIndex = index;
            this.buttonList.forEach((/**
             * @param {?} button
             * @param {?} idx
             * @return {?}
             */
            (button, idx) => {
                button.active = this.type === 'pill' ? false : this.highlightSelected && this.activeIndex === idx;
            }));
        }
    }
    /**
     * @param {?} str
     * @param {?} char
     * @return {?}
     */
    getIncludesFirstCharacter(str, char) {
        return str
            .charAt(0)
            .toLowerCase()
            .includes(char);
    }
    /**
     * @param {?} char
     * @param {?} currentIdx
     * @return {?}
     */
    setFocusByFirstCharacter(char, currentIdx) {
        /** @type {?} */
        const length = this.buttonList.length - 1;
        /** @type {?} */
        const newIndex = this.buttonList
            .toArray()
            .reduce((/**
         * @param {?} agg
         * @param {?} _
         * @param {?} idx
         * @param {?} arr
         * @return {?}
         */
        (agg, _, idx, arr) => {
            /** @type {?} */
            const index = currentIdx + idx + 1 > length
                ? Math.abs(currentIdx + idx - length)
                : currentIdx + idx + 1;
            /** @type {?} */
            const label = arr[index].hostElement.nativeElement.innerText;
            return (!agg.length
                && !arr[index].disabled
                && this.getIncludesFirstCharacter(label, char))
                ? agg.concat(index)
                : agg;
        }), []);
        if (!isNaN(newIndex[0])) {
            this.setFocusIndex(newIndex[0]);
        }
    }
    /**
     * @param {?} event
     * @param {?} index
     * @return {?}
     */
    handleClick(event, index) {
        this.setFocusIndex(index);
        this.setActiveIndex(index);
        this.select.emit({ event: event, index: index });
    }
    /**
     * @param {?} event
     * @param {?} index
     * @return {?}
     */
    handleKeydown(event, index) {
        /** @type {?} */
        let newIndex;
        /** @type {?} */
        let flag = false;
        /** @type {?} */
        const char = event.key;
        /** @type {?} */
        const isPrintableCharacter = (/**
         * @param {?} str
         * @return {?}
         */
        (str) => {
            return str.length === 1 && str.match(/\S/);
        });
        switch (event.code) {
            case 'ArrowLeft':
            case 'ArrowUp':
                newIndex = this.getNewIndex(index, -1);
                this.setFocusIndex(newIndex);
                flag = true;
                break;
            case 'ArrowRight':
            case 'ArrowDown':
                newIndex = this.getNewIndex(index, 1);
                this.setFocusIndex(newIndex);
                flag = true;
                break;
            default:
                if (isPrintableCharacter(char)) {
                    this.setFocusByFirstCharacter(char, index);
                    flag = true;
                }
                break;
        }
        if (flag) {
            event.stopPropagation();
            event.preventDefault();
        }
    }
}
ButtonGroupComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-button-group',
                template: `<ng-content></ng-content>`,
                host: {
                    '[attr.aria-label]': 'ariaLabel',
                    'class': 'md-button-group',
                    '[class.md-button-group--justified]': 'justified',
                    'role': 'group',
                }
            }] }
];
/** @nocollapse */
ButtonGroupComponent.ctorParameters = () => [
    { type: ElementRef },
    { type: Renderer2 }
];
ButtonGroupComponent.propDecorators = {
    activeIndex: [{ type: Input }],
    ariaLabel: [{ type: Input }],
    focusOnLoad: [{ type: Input }],
    highlightSelected: [{ type: Input }],
    justified: [{ type: Input }],
    pillWidth: [{ type: Input }],
    theme: [{ type: Input }],
    type: [{ type: Input }],
    select: [{ type: Output }],
    buttonList: [{ type: ContentChildren, args: [ButtonComponent,] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ButtonGroupModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: ButtonGroupModule,
            providers: [],
        };
    }
}
ButtonGroupModule.decorators = [
    { type: NgModule, args: [{
                declarations: [ButtonGroupComponent],
                imports: [CommonModule],
                exports: [ButtonGroupComponent],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const activeRed = ['camera-muted', 'cancel', 'microphone-muted', 'speaker'];
/** @type {?} */
const activeBlue = ['camera', 'participant-list', 'share-screen'];
class CallControlComponent {
    /**
     * @param {?} _element
     */
    constructor(_element) {
        this._element = _element;
        /**
         * \@prop Sets active css styling | false
         */
        this.active = false;
        /**
         * \@prop Text to display for blindness accessibility features | ''
         */
        this.ariaLabel = '';
        /**
         * \@prop Sets the attribute disabled to the CallControl button | false
         */
        this.disabled = false;
        /**
         * \@prop Optional icon color prop | $md-white-100
         */
        this.iconColor = 'white-100';
        /**
         * \@prop Optional numeric icon size prop | 24
         */
        this.iconSize = 24;
        /**
         * \@prop Optional numeric size prop for CallControl button | 56
         */
        this.size = 56;
        this.click = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.hostClassName = this._element.nativeElement.className;
        /** @type {?} */
        const nativeElement = this._element.nativeElement;
        /** @type {?} */
        const parentElement = nativeElement.parentElement;
        while (nativeElement.firstChild) {
            parentElement.insertBefore(nativeElement.firstChild, nativeElement);
        }
        parentElement.removeChild(nativeElement);
    }
    /**
     * @private
     * @return {?}
     */
    _getActiveColor() {
        switch (true) {
            case (activeRed.includes(this.type)):
                return 'red';
            case (activeBlue.includes(this.type)):
                return 'blue';
            default:
                return 'dark-gray';
        }
    }
    /**
     * @return {?}
     */
    getColor() {
        return this.active
            ? this._getActiveColor()
            : 'dark-gray';
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onClick(event) {
        this.click.emit(event);
    }
}
CallControlComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-call-control',
                template: `
    <button
      md-button
      [attr.aria-label]="ariaLabel || type"
      [attr.id]="id"
      [circle]="true"
      (click)="onClick($event)"
      [color]="type === 'cancel' ? 'red' : getColor()"
      [disabled]="disabled"
      [ngClass]="['md-call-control', hostClassName]"
      [size]="size"
    >
      <md-icon [name]="type + '_' + iconSize" [color]="iconColor"></md-icon>
    </button>
  `
            }] }
];
/** @nocollapse */
CallControlComponent.ctorParameters = () => [
    { type: ElementRef }
];
CallControlComponent.propDecorators = {
    active: [{ type: Input }],
    ariaLabel: [{ type: Input }],
    disabled: [{ type: Input }],
    iconColor: [{ type: Input }],
    iconSize: [{ type: Input }],
    id: [{ type: Input }],
    size: [{ type: Input }],
    type: [{ type: Input }],
    click: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CallControlModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: CallControlModule,
            providers: [],
        };
    }
}
CallControlModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, ButtonModule, IconModule],
                declarations: [CallControlComponent],
                exports: [CallControlComponent],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
let nextUniqueId = 0;
class InputMessageComponent {
    constructor() {
        /**
         * \@prop Unique HTML ID used for automated testing | null
         */
        this.id = `md-error-${nextUniqueId++}`;
    }
}
InputMessageComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-input-message',
                template: `<ng-content></ng-content>`,
                host: {
                    'class': 'md-input__message',
                    'role': 'alert',
                    '[attr.id]': 'id'
                }
            }] }
];
InputMessageComponent.propDecorators = {
    id: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class InputMessageModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: InputMessageModule,
            providers: [],
        };
    }
}
InputMessageModule.decorators = [
    { type: NgModule, args: [{
                declarations: [InputMessageComponent],
                imports: [CommonModule],
                exports: [InputMessageComponent],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class InputSectionComponent {
    constructor() {
        /**
         * \@prop Determine the InputSection's position | 'before'
         */
        this.position = 'before';
    }
    /**
     * @return {?}
     */
    get _class() {
        return (`md-input__${this.position || 'before'}` +
            `${this.className ? ` ${this.className}` : ''}`);
    }
}
InputSectionComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-input-section',
                template: `
    <ng-content></ng-content>
  `
            }] }
];
InputSectionComponent.propDecorators = {
    position: [{ type: Input }],
    className: [{ type: Input }],
    _class: [{ type: HostBinding, args: ['class',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class InputSectionModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: InputSectionModule,
            providers: [],
        };
    }
}
InputSectionModule.decorators = [
    { type: NgModule, args: [{
                declarations: [InputSectionComponent],
                imports: [CommonModule],
                exports: [InputSectionComponent],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * An interface which allows a control to work inside of a `InputContainer`.
 * @abstract
 * @template T
 */
class InputContainerService {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class InputService {
    constructor() {
        this.addBeforePadding = new Subject();
        this.addBeforePadding$ = this.addBeforePadding.asObservable();
        this.addAfterPadding = new Subject();
        this.addAfterPadding$ = this.addAfterPadding.asObservable();
    }
    /**
     * @param {?} position
     * @param {?} value
     * @return {?}
     */
    onPaddingChange(position, value) {
        this[`add${position}Padding`].next(value);
    }
}
InputService.decorators = [
    { type: Injectable }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
let nextUniqueId$1 = 0;
class InputContainerComponent {
    /**
     * @param {?} _changeDetectorRef
     * @param {?} inputService
     */
    constructor(_changeDetectorRef, inputService) {
        this._changeDetectorRef = _changeDetectorRef;
        this.inputService = inputService;
        this._destroyed = new Subject();
        this._clear = false;
        this._status = '';
        this._isError = false;
        // Unique id for the hint label.
        this._helpTextId = `md-input__help-text-${nextUniqueId$1++}`;
        /**
         * \@prop Optional css class string | ''
         */
        this.class = '';
        /**
         * \@prop Optional clear aria label string | 'clear'
         */
        this.clearAriaLabel = 'clear';
        /**
         * \@prop Overall input container size | ''
         */
        this.containerSize = '';
        /**
         * \@prop Help Text to appear under the input | ''
         */
        this.helpText = '';
        /**
         * \@prop Input wrapper size | ''
         */
        this.inputSize = '';
        /**
         * \@prop Sets the filled class of the Input Container | false
         */
        this.isFilled = false;
        /**
         * \@prop Input label text | ''
         */
        this.label = '';
        /**
         * \@prop Set the level of nested Input components | 0
         */
        this.nestedLevel = 0;
        /**
         * \@prop Secondary Input label | ''
         */
        this.secondaryLabel = '';
        this._determineStatus = (/**
         * @param {?} array
         * @return {?}
         */
        array => {
            return array.reduce((/**
             * @param {?} agg
             * @param {?} e
             * @return {?}
             */
            (agg, e) => {
                return agg === 'error' ? agg : e.type || '';
            }), '');
        });
        this._filterMessagesByType = (/**
         * @param {?} array
         * @param {?} value
         * @return {?}
         */
        (array, value) => {
            return array.reduce((/**
             * @param {?} agg
             * @param {?} e
             * @return {?}
             */
            (agg, e) => (e.type === value ? agg.concat(e.message) : agg)), []);
        });
    }
    /**
     * \@prop Optional button to clear input text | false
     * @return {?}
     */
    get clear() { return this._clear; }
    /**
     * @param {?} value
     * @return {?}
     */
    set clear(value) {
        this._clear = value || false;
    }
    /**
     * \@prop Optional status to override error status | ''
     * @return {?}
     */
    get status() { return this._status; }
    /**
     * @param {?} value
     * @return {?}
     */
    set status(value) {
        this._status = value || '';
    }
    /**
     * @return {?}
     */
    get _control() {
        // TODO: we need this hacky workaround in order to support both Ivy
        // and ViewEngine. We should clean this up once Ivy is the default renderer.
        return this._explicitFormFieldControl || this._controlNonStatic || this._controlStatic;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set _control(value) {
        this._explicitFormFieldControl = value;
    }
    /**
     * @return {?}
     */
    get _class() {
        return ('md-input-container' +
            `${this.isFilled ? ' md-input--filled' : ''}` +
            `${this.containerSize ? ` ${this.containerSize} columns` : ''}` +
            `${this._control.readonly ? ' md-read-only' : ''}` +
            `${this._control.disabled ? ' md-disabled' : ''}` +
            `${this.nestedLevel ? ` md-input--nested-${this.nestedLevel}` : ''}` +
            `${(this._isError || this.status) ? ` md-${this._isError ? 'error' : this.status}` : ''}` +
            `${this.class ? ` ${this.class}` : ''}`);
    }
    /**
     * @return {?}
     */
    ngAfterContentInit() {
        /** @type {?} */
        const control = this._control;
        // Initial sync of input padding styles
        this._syncInputPadding();
        // Subscribe to changes in the child control state in order to update the form field UI.
        control.stateChanges.pipe(startWith(of({}))).subscribe((/**
         * @return {?}
         */
        () => {
            this._syncErrorState();
            this._syncDescribedByIds();
            this._changeDetectorRef.markForCheck();
        }));
        // Run change detection if the value changes.
        if (control.ngControl && control.ngControl.valueChanges) {
            control.ngControl.valueChanges
                .pipe(takeUntil(this._destroyed))
                .subscribe((/**
             * @return {?}
             */
            () => this._changeDetectorRef.markForCheck()));
        }
        // Update the aria-described by when the number of errors changes.
        this._contentMessageChildren.changes.pipe(startWith((/** @type {?} */ (null)))).subscribe((/**
         * @return {?}
         */
        () => {
            this._syncDescribedByIds();
            this._changeDetectorRef.markForCheck();
        }));
        // Update the padding class when icon children change.
        this._iconChildren.changes.pipe(startWith((/** @type {?} */ (null)))).subscribe((/**
         * @return {?}
         */
        () => {
            this._syncInputPadding();
            this._changeDetectorRef.markForCheck();
        }));
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        // Required for view children changes
        this._changeDetectorRef.detectChanges();
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (changes.messageArr) {
            /** @type {?} */
            const changedArr = changes.messageArr.currentValue;
            if (changedArr && changedArr.length > 0) {
                this._status = this._determineStatus(changedArr);
                this.messages = this._status && this._filterMessagesByType(changedArr, this._status) || [];
            }
        }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this._destroyed.next();
        this._destroyed.complete();
    }
    /**
     * @param {?} event
     * @return {?}
     */
    handleClear(event) {
        if (this._control.ngControl) {
            this._control.ngControl.reset();
        }
        else if (this._control.value) {
            this._control.value = '';
        }
    }
    /**
     * @return {?}
     */
    showClear() {
        return this.clear && !this._control.empty;
    }
    /**
     * @private
     * @return {?}
     */
    _syncDescribedByIds() {
        if (this._control) {
            /** @type {?} */
            const ids = [];
            if (this.helpText) {
                ids.push(this._helpTextId);
            }
            else if (this._viewMessageChildren) {
                this._viewMessageChildren.map((/**
                 * @param {?} ele
                 * @return {?}
                 */
                ele => ids.push(ele.id)));
            }
            else if (this._contentMessageChildren) {
                this._contentMessageChildren.map((/**
                 * @param {?} ele
                 * @return {?}
                 */
                ele => ids.push(ele.id)));
            }
            this._control.setDescribedByIds(ids);
        }
    }
    /**
     * @private
     * @return {?}
     */
    _syncErrorState() {
        if (this._control && this._control.errorState && !this._isError) {
            this._isError = true;
        }
        else if (this._isError && !this._control.errorState) {
            this._isError = false;
        }
    }
    /**
     * @private
     * @return {?}
     */
    _syncInputPadding() {
        /** @type {?} */
        let before = false;
        /** @type {?} */
        let after = false;
        this._iconChildren.forEach((/**
         * @param {?} child
         * @return {?}
         */
        child => {
            if (child.position === 'before') {
                before = true;
            }
            else if (child.position === 'after') {
                after = true;
            }
        }));
        this.inputService.onPaddingChange('Before', before);
        this.inputService.onPaddingChange('After', this.clear || after);
    }
}
InputContainerComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-input-container',
                template: `
    <md-label
      *ngIf="label"
      [label]="label"
      class="md-input__label"
      [htmlFor]='_control.id'
    ></md-label>

    <div class="md-input__wrapper" [ngClass]="[inputSize && inputSize + ' columns' || '']">
      <ng-content></ng-content>
      <md-input-section *ngIf='this.showClear()' position='after'>
        <md-icon
          [ariaLabel]="clearAriaLabel"
          buttonClassName="md-input__icon-clear"
          name="clear-active_16"
          (click)="handleClear($event)"
        ></md-icon>
      </md-input-section>
    </div>

    <!-- Secondary Label -->
    <md-label
      *ngIf="secondaryLabel"
      [label]="secondaryLabel"
      class="md-input__secondary-label"
      [htmlFor]='_control.id'
    ></md-label>

    <!-- Helper Text -->
    <md-input-helper
      *ngIf="helpText"
      [id]='_helpTextId'
    >
      {{helpText}}
    </md-input-helper>

    <!-- Error Input -->
    <div class="md-input__messages" *ngIf="(messages && messages.length) || (_contentMessageChildren && _contentMessageChildren.length)">
      <md-input-message *ngFor="let message of messages">
        {{message}}
      </md-input-message>
      <ng-content select="md-input-message"></ng-content>
    </div>
  `,
                changeDetection: ChangeDetectionStrategy.OnPush,
                providers: [InputService]
            }] }
];
/** @nocollapse */
InputContainerComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: InputService }
];
InputContainerComponent.propDecorators = {
    class: [{ type: Input }],
    clear: [{ type: Input }],
    clearAriaLabel: [{ type: Input }],
    containerSize: [{ type: Input }],
    helpText: [{ type: Input }],
    inputSize: [{ type: Input }],
    isFilled: [{ type: Input }],
    label: [{ type: Input }],
    messageArr: [{ type: Input }],
    nestedLevel: [{ type: Input }],
    secondaryLabel: [{ type: Input }],
    status: [{ type: Input }],
    _controlNonStatic: [{ type: ContentChild, args: [InputContainerService,] }],
    _controlStatic: [{ type: ContentChild, args: [InputContainerService,] }],
    _iconChildren: [{ type: ContentChildren, args: [InputSectionComponent,] }],
    _contentMessageChildren: [{ type: ContentChildren, args: [InputMessageComponent,] }],
    _viewMessageChildren: [{ type: ViewChildren, args: [InputMessageComponent,] }],
    _class: [{ type: HostBinding, args: ['class',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class InputContainerModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: InputContainerModule,
            providers: [],
        };
    }
}
InputContainerModule.decorators = [
    { type: NgModule, args: [{
                declarations: [InputContainerComponent],
                imports: [
                    CommonModule,
                    FormsModule,
                    IconModule,
                    InputHelperModule,
                    InputMessageModule,
                    InputSectionModule,
                    LabelModule,
                    ReactiveFormsModule,
                ],
                exports: [InputContainerComponent],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
let nextUniqueId$2 = 0;
// Invalid input type. Using one of these will throw an MDInputUnsupportedTypeError.
/** @type {?} */
const MD_INPUT_INVALID_TYPES = [
    'button',
    'checkbox',
    'file',
    'hidden',
    'image',
    'radio',
    'range',
    'reset',
    'submit'
];
/**
 * @param {?} type
 * @return {?}
 */
function getMDInputUnsupportedTypeError(type) {
    return Error(`Input type "${type}" isn't supported by mdInput.`);
}
class InputDirective {
    /**
     * @param {?} _elementRef
     * @param {?} _platform
     * @param {?} _autofillMonitor
     * @param {?} inputService
     * @param {?} ngControl
     * @param {?} _parentForm
     * @param {?} _parentFormGroup
     */
    constructor(_elementRef, _platform, _autofillMonitor, inputService, ngControl, _parentForm, _parentFormGroup) {
        this._elementRef = _elementRef;
        this._platform = _platform;
        this._autofillMonitor = _autofillMonitor;
        this.inputService = inputService;
        this.ngControl = ngControl;
        this._destroyed = new Subject();
        this._readonly = false;
        this._disabled = false;
        this._required = false;
        this._type = 'text';
        this._uid = `md-input-${nextUniqueId$2++}`;
        this.stateChanges = new Subject();
        this.autofilled = false;
        this._inputAfter = false;
        this._inputBefore = false;
        this.focused = false;
        this.errorState = false;
        /**
         * \@prop Placeholder text to display when Input is empty | ''
         */
        this.placeholder = '';
        /**
         * \@prop Input shape property | ''
         */
        this.shape = '';
        this._neverEmptyInputTypes = [
            'date',
            'datetime',
            'datetime-local',
            'month',
            'time',
            'week'
        ].filter((/**
         * @param {?} t
         * @return {?}
         */
        t => getSupportedInputTypes().has(t)));
        this.onChange = (/**
         * @return {?}
         */
        () => { });
        this.onTouch = (/**
         * @return {?}
         */
        () => { });
        /** @type {?} */
        const element = this._elementRef.nativeElement;
        this.id = this.id;
        this._inputValueAccessor = (ngControl && ngControl.valueAccessor) || element;
        this._parentForm = _parentForm;
        this._parentFormGroup = _parentFormGroup;
        this._ngControl = ngControl;
        this.inputService.addBeforePadding$
            .pipe(takeUntil(this._destroyed))
            .subscribe((/**
         * @param {?} value
         * @return {?}
         */
        value => this._inputBefore = coerceBooleanProperty(value)));
        this.inputService.addAfterPadding$
            .pipe(takeUntil(this._destroyed))
            .subscribe((/**
         * @param {?} value
         * @return {?}
         */
        value => this._inputAfter = coerceBooleanProperty(value)));
    }
    /**
     * \@prop Unique HTML ID used for tying label to HTML input | 'md-in-<uniqueId>'
     * @return {?}
     */
    get id() { return this._id; }
    /**
     * @param {?} value
     * @return {?}
     */
    set id(value) { this._id = value || this._uid; }
    /**
     * @return {?}
     */
    get disabled() {
        if (this.ngControl && this.ngControl.disabled !== null) {
            return this.ngControl.disabled;
        }
        return this._disabled;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set disabled(value) {
        this._disabled = coerceBooleanProperty(value);
        // Browsers may not fire the blur event if the input is disabled too quickly.
        // Reset from here to ensure that the element doesn't become stuck.
        if (this.focused) {
            this.focused = false;
            this.stateChanges.next();
        }
    }
    /**
     * \@prop Determines if Input can be edited | false
     * @return {?}
     */
    get readonly() { return this._readonly; }
    /**
     * @param {?} value
     * @return {?}
     */
    set readonly(value) { this._readonly = coerceBooleanProperty(value); }
    /**
     * \@prop Determines if Input is required | false
     * @return {?}
     */
    get required() { return this._required; }
    /**
     * @param {?} value
     * @return {?}
     */
    set required(value) { this._required = coerceBooleanProperty(value); }
    /**
     * @return {?}
     */
    get type() { return this._type; }
    /**
     * @param {?} value
     * @return {?}
     */
    set type(value) {
        this._type = value || 'text';
        this._validateType();
        // When using Angular inputs, developers are no longer able to set the properties on the native
        // input element. To ensure that bindings for `type` work, we need to sync the setter
        // with the native property. Textarea elements don't support the type property or attribute.
        if (!this._isTextarea() && getSupportedInputTypes().has(this._type)) {
            ((/** @type {?} */ (this._elementRef.nativeElement))).type = this._type;
        }
    }
    /**
     * \@prop Input value | ''
     * @return {?}
     */
    get value() {
        return this._inputValueAccessor.value;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set value(value) {
        if (value !== this.value) {
            this._inputValueAccessor.value = value;
            this.stateChanges.next();
        }
    }
    /**
     * @return {?}
     */
    get _class() {
        return ('md-input' +
            `${this._isTextarea() ? ' md-input--multiline' : ''}` +
            `${this.shape ? ` md-input--${this.shape}` : ''}` +
            `${this._inputBefore ? ` md-input--before` : ''}` +
            `${this._inputAfter ? ` md-input--after` : ''}` +
            `${this.focused ? ` md-active` : ''}` +
            `${this.readonly ? ' md-read-only' : ''}` +
            `${this.disabled ? ' md-disabled' : ''}` +
            `${(this._ngControl && this._ngControl.dirty) ? ` md-dirty` : ''}`);
    }
    /**
     * @return {?}
     */
    ngDoCheck() {
        if (this.ngControl) {
            // We need to re-evaluate this on every change detection cycle, because there are some
            // error triggers that we can't subscribe to (e.g. parent form submissions). This means
            // that whatever logic is in here has to be super lean or we risk destroying the performance.
            this.updateErrorState();
        }
        // We need to dirty-check the native element's value, because there are some cases where
        // we won't be notified when it changes (e.g. the consumer isn't using forms or they're
        // updating the value using `emitEvent: false`).
        this._dirtyCheckNativeValue();
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        this.stateChanges.next();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this._platform.isBrowser) {
            this._autofillMonitor.monitor(this._elementRef.nativeElement).subscribe((/**
             * @param {?} event
             * @return {?}
             */
            event => {
                this.autofilled = event.isAutofilled;
                this.stateChanges.next();
            }));
        }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this._destroyed.next();
        this._destroyed.complete();
        this.stateChanges.complete();
        if (this._platform.isBrowser) {
            this._autofillMonitor.stopMonitoring(this._elementRef.nativeElement);
        }
    }
    /**
     * @protected
     * @return {?}
     */
    _isNeverEmpty() {
        return this._neverEmptyInputTypes.indexOf(this._type) > -1;
    }
    /**
     * Checks whether the input is invalid based on the native validation.
     * @protected
     * @return {?}
     */
    _isBadInput() {
        // The `validity` property won't be present on platform-server.
        /** @type {?} */
        const validity = ((/** @type {?} */ (this._elementRef.nativeElement))).validity;
        return validity && validity.badInput;
    }
    /**
     * @protected
     * @return {?}
     */
    _isTextarea() {
        return this._elementRef.nativeElement.nodeName.toLowerCase() === 'textarea';
    }
    /**
     * @protected
     * @return {?}
     */
    _validateType() {
        if (MD_INPUT_INVALID_TYPES.indexOf(this._type) > -1) {
            throw getMDInputUnsupportedTypeError(this._type);
        }
    }
    /**
     * @return {?}
     */
    get empty() {
        return !this._isNeverEmpty() && !this._elementRef.nativeElement.value && !this._isBadInput() &&
            !this.autofilled;
    }
    /**
     * Callback for the cases where the focused state of the input changes.
     * @param {?} isFocused
     * @return {?}
     */
    handleFocusChange(isFocused) {
        if (isFocused !== this.focused && (!this.readonly || !isFocused)) {
            this.focused = isFocused;
            this.stateChanges.next();
        }
    }
    /**
     * @return {?}
     */
    handleInput() {
        // This is a noop function and is used to let Angular know whenever the value changes.
        // Angular will run a new change detection each time the `input` event has been dispatched.
        // It's necessary that Angular recognizes the value change, because when floatingLabel
        // is set to false and Angular forms aren't used, the placeholder won't recognize the
        // value changes and will not disappear.
        // Listening to the input event wouldn't be necessary when the input is using the
        // FormsModule or ReactiveFormsModule, because Angular forms also listens to input events.
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnChange(fn) {
        this.onChange = fn;
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnTouched(fn) {
        this.onTouch = fn;
    }
    /**
     * @param {?} ids
     * @return {?}
     */
    setDescribedByIds(ids) {
        this._ariaDescribedby = ids.join(' ');
    }
    /**
     * @param {?} isDisabled
     * @return {?}
     */
    setDisabledState(isDisabled) {
        this.disabled = isDisabled;
    }
    /**
     * @return {?}
     */
    updateErrorState() {
        /** @type {?} */
        const oldState = this.errorState;
        /** @type {?} */
        const parent = this._parentFormGroup || this._parentForm;
        /** @type {?} */
        const control = this.ngControl ? (/** @type {?} */ (this.ngControl.control)) : null;
        /** @type {?} */
        const newState = !!(control &&
            control.invalid &&
            (control.dirty || (parent && parent.submitted)));
        if (newState !== oldState) {
            this.errorState = newState;
            this.stateChanges.next();
        }
        return;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    writeValue(value) {
        if (value !== this._inputValueAccessor.value) {
            this._inputValueAccessor.value = value;
        }
    }
    /**
     * @private
     * @return {?}
     */
    _dirtyCheckNativeValue() {
        /** @type {?} */
        const newValue = this._elementRef.nativeElement.value;
        if (this._previousNativeValue !== newValue) {
            this._previousNativeValue = newValue;
            this.stateChanges.next();
        }
    }
}
InputDirective.decorators = [
    { type: Directive, args: [{
                selector: `input[mdInput], textarea[mdInput]`,
                exportAs: 'mdInput',
                host: {
                    '[attr.id]': 'id',
                    '[attr.placeholder]': 'placeholder',
                    '[attr.aria-describedby]': '_ariaDescribedby || null',
                    '[disabled]': 'disabled',
                    '[required]': 'required',
                    '[readonly]': 'readonly || null',
                    '(blur)': 'handleFocusChange(false)',
                    '(focus)': 'handleFocusChange(true)',
                    '(input)': 'handleInput()'
                },
                providers: [
                    { provide: InputContainerService, useExisting: InputDirective }
                ]
            },] }
];
/** @nocollapse */
InputDirective.ctorParameters = () => [
    { type: ElementRef },
    { type: Platform },
    { type: AutofillMonitor },
    { type: InputService },
    { type: NgControl, decorators: [{ type: Optional }, { type: Self }] },
    { type: NgForm, decorators: [{ type: Optional }] },
    { type: FormGroupDirective, decorators: [{ type: Optional }] }
];
InputDirective.propDecorators = {
    id: [{ type: Input }],
    disabled: [{ type: Input }],
    placeholder: [{ type: Input }],
    readonly: [{ type: Input }],
    required: [{ type: Input }],
    shape: [{ type: Input }],
    type: [{ type: Input }],
    value: [{ type: Input }],
    _class: [{ type: HostBinding, args: ['class',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class InputModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: InputModule,
            providers: [InputService],
        };
    }
}
InputModule.decorators = [
    { type: NgModule, args: [{
                declarations: [InputDirective],
                imports: [
                    CommonModule,
                    FormsModule,
                    IconModule,
                    InputHelperModule,
                    InputContainerModule,
                    InputMessageModule,
                    InputSectionModule,
                    LabelModule,
                    ReactiveFormsModule,
                ],
                exports: [
                    InputDirective,
                    IconModule,
                    InputHelperModule,
                    InputContainerModule,
                    InputMessageModule,
                    InputSectionModule,
                    LabelModule,
                ],
                providers: [InputService],
                schemas: [CUSTOM_ELEMENTS_SCHEMA],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// tslint:disable:no-use-before-declare
/** @type {?} */
const CUI_COMBOBOX_VALUE_ACCESSOR = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef((/**
     * @return {?}
     */
    () => ComboBoxComponent)),
    multi: true,
};
class ComboBoxComponent {
    /**
     * @param {?} _changeDetectorRef
     * @param {?} _viewportRuler
     * @param {?} _overlayContainer
     * @param {?} _document
     */
    constructor(_changeDetectorRef, _viewportRuler, _overlayContainer, _document) {
        this._changeDetectorRef = _changeDetectorRef;
        this._viewportRuler = _viewportRuler;
        this._overlayContainer = _overlayContainer;
        /**
         * \@prop Sets the initial input element as empty | false
         */
        this.clear = false;
        /**
         * \@prop Sets the attribute disabled to the ComboBox | false
         */
        this.disabled = false;
        /**
         * \@prop Sets the ComboBox to have a search icon | true
         */
        this.hasSearchIcon = true;
        /**
         * \@prop Array of options for the ComboBox dropdown | []
         */
        this.options = [];
        /**
         * \@prop Text that initially populates the input field for guidence | ''
         */
        this.placeholder = '';
        /**
         * \@prop Sets the search prop | 'label'
         */
        this.searchProp = 'label';
        /**
         * \@prop Sets the target offset | { horizontal: 0, vertical: 4 }
         */
        this.targetOffset = { horizontal: 0, vertical: 4 };
        /**
         * \@prop Sets the color theme of the ComboBox | ''
         */
        this.theme = '';
        this.select = new EventEmitter();
        this._destroy = new Subject();
        this._inputValue = '';
        this._value = '';
        this.activeIndex = -1;
        this.allowMutationObserver = true;
        this.filteredOptions = [];
        this.offsetY = 0;
        this.positions = [
            {
                originX: 'start',
                originY: 'bottom',
                overlayX: 'start',
                overlayY: 'top',
            }
        ];
        this._onMousedown = (/**
         * @param {?} _
         * @return {?}
         */
        (_) => {
            this.close();
        });
        this._document = _document;
    }
    /**
     * @return {?}
     */
    get value() {
        return this._value;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set value(value) {
        if (this._value !== value) {
            this._value = value;
            this._change(value);
            this._changeDetectorRef.markForCheck();
            this.inputValue = isObject(value) ? value[this.searchProp] : value;
        }
    }
    /**
     * @return {?}
     */
    get inputValue() {
        return this._inputValue;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set inputValue(value) {
        if (this._inputValue !== value) {
            this._inputValue = value;
            /** @type {?} */
            const option = find(this.options, { value });
            if (option) {
                this.value = option;
            }
            else {
                this.value = value;
            }
        }
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.isObject = isObject;
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this._destroy.next();
        this._destroy.complete();
    }
    /**
     * @param {?} value
     * @return {?}
     */
    writeValue(value) {
        if (value !== null) {
            this.value = value;
        }
    }
    /**
     * @param {?} disabled
     * @return {?}
     */
    setDisabledState(disabled) {
        this.disabled = disabled;
        this._changeDetectorRef.markForCheck();
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnChange(fn) {
        this._change = fn;
    }
    /**
     * @param {?} _
     * @return {?}
     */
    registerOnTouched(_) { }
    /**
     * @private
     * @param {?} _
     * @return {?}
     */
    _change(_) { }
    /**
     * @param {?} option
     * @return {?}
     */
    selectOption(option) {
        this.activeIndex = isObject(option)
            ? findIndex(this.filteredOptions, option[this.searchProp])
            : findIndex(this.filteredOptions, option);
        this.select.emit(option);
        this.value = option;
        this.close();
    }
    /**
     * @param {?} event
     * @return {?}
     */
    handleOptionMousedown(event) {
        event.stopPropagation();
    }
    /**
     * @return {?}
     */
    handleInput() {
        this._shouldUpdatePosition = true;
        this.filteredOptions = isObject(this.value)
            ? this.applyFilter(this.value[this.searchProp])
            : this.applyFilter(this.value);
        if (this.filteredOptions.length === 1 && this.filteredOptions[0]['isHeader']) {
            this.filteredOptions = [];
        }
        this.filteredOptions.length ? this.open() : this.close();
    }
    /**
     * @param {?} event
     * @return {?}
     */
    handleInputMousedown(event) {
        event.stopPropagation();
    }
    /**
     * @param {?} value
     * @return {?}
     */
    applyFilter(value) {
        /** @type {?} */
        const isSubString = (/**
         * @param {?} string
         * @return {?}
         */
        (string) => value && string.toLowerCase().includes(value.toLowerCase()));
        return this.options.filter((/**
         * @param {?} option
         * @return {?}
         */
        option => {
            if (isObject(option)) {
                return isSubString(option[this.searchProp]) || option['isHeader'];
            }
            else {
                return isSubString(option);
            }
        }));
    }
    /**
     * @return {?}
     */
    open() {
        if (this.disabled || !this.options || !this.options.length || this.dropdownOpen) {
            return;
        }
        this.dropdownOpen = true;
        this._changeDetectorRef.markForCheck();
        this._document.addEventListener('mousedown', this._onMousedown);
    }
    /**
     * @return {?}
     */
    attached() {
        this.overlayDir.positionChange.pipe(takeUntil(this._destroy)).subscribe((/**
         * @return {?}
         */
        () => {
            this._calculateOverlayPosition();
        }));
        if (this.allowMutationObserver) {
            /** @type {?} */
            const overlayContainerElement = this._overlayContainer.getContainerElement();
            this._mutationObserver = new MutationObserver((/**
             * @param {?} _
             * @return {?}
             */
            _ => {
                if (this._shouldUpdatePosition) {
                    this._shouldUpdatePosition = false;
                    this._calculateOverlayPosition();
                    this.overlayDir.overlayRef.updatePosition();
                }
                if (this.dropdown) {
                    /** @type {?} */
                    const listItems = overlayContainerElement.querySelector('.md-combo-box__options');
                    /** @type {?} */
                    const observer = new MutationObserver((/**
                     * @param {?} mutations
                     * @return {?}
                     */
                    mutations => {
                        this._calculateOverlayPosition();
                        this.overlayDir.overlayRef.updatePosition();
                        observer.disconnect();
                    }));
                    observer.observe(listItems, {
                        attributes: true,
                        childList: true,
                    });
                }
            }));
            this._mutationObserver.observe(overlayContainerElement, {
                attributes: true,
                childList: true,
                subtree: true
            });
        }
    }
    /**
     * @private
     * @return {?}
     */
    _calculateOverlayPosition() {
        this._changeDetectorRef.detectChanges();
        /** @type {?} */
        const triggerRect = this.trigger.nativeElement.getBoundingClientRect();
        /** @type {?} */
        const dropdownRect = this.dropdown.nativeElement.getBoundingClientRect();
        /** @type {?} */
        const viewportSize = this._viewportRuler.getViewportSize();
        this.dropdownWidth = triggerRect.width;
        /** @type {?} */
        const panelHeight = dropdownRect.height;
        /** @type {?} */
        const topSpaceAvailable = triggerRect.top;
        /** @type {?} */
        const bottomSpaceAvailable = viewportSize.height - triggerRect.bottom;
        if (panelHeight > bottomSpaceAvailable && panelHeight < topSpaceAvailable) {
            this.offsetY = -(panelHeight + triggerRect.height + this.targetOffset.vertical);
        }
        else if (panelHeight > bottomSpaceAvailable && panelHeight > topSpaceAvailable) {
            this.offsetY = -(topSpaceAvailable + triggerRect.height);
        }
        else {
            this.offsetY = 0;
        }
    }
    /**
     * @return {?}
     */
    close() {
        if (this.dropdownOpen) {
            this.dropdownOpen = false;
            this._changeDetectorRef.markForCheck();
            this._document.removeEventListener('mousedown', this._onMousedown);
            if (this._mutationObserver) {
                this._mutationObserver.disconnect();
                this._mutationObserver = null;
            }
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    handleKeydown(event) {
        /** @type {?} */
        const length = this.filteredOptions && this.filteredOptions.length - 1;
        /** @type {?} */
        const getNewIndex = (/**
         * @param {?} currentIndex
         * @param {?} change
         * @return {?}
         */
        (currentIndex, change) => {
            /** @type {?} */
            const getPossibleIndex = (/**
             * @return {?}
             */
            () => {
                if (currentIndex + change < 0) {
                    return length;
                }
                else if (currentIndex + change > length) {
                    return 0;
                }
                return currentIndex + change;
            });
            /** @type {?} */
            const possibleIndex = getPossibleIndex();
            /** @type {?} */
            const potentialTarget = this.filteredOptions[possibleIndex];
            return (isObject(potentialTarget) && (potentialTarget['disabled'] ||
                potentialTarget['isReadOnly'] ||
                potentialTarget['isHeader']))
                ? getNewIndex(possibleIndex, change)
                : possibleIndex;
        });
        if (!this.disabled && this.dropdownOpen) {
            /** @type {?} */
            let flag = false;
            if (event.code === 'ArrowDown') {
                this.activeIndex = getNewIndex(this.activeIndex, 1);
                flag = true;
            }
            else if (event.code === 'ArrowUp') {
                this.activeIndex = getNewIndex(this.activeIndex, -1);
                flag = true;
            }
            else if (event.code === 'Enter') {
                if (this.filteredOptions[this.activeIndex]) {
                    this.selectOption(this.filteredOptions[this.activeIndex]);
                }
                flag = true;
            }
            if (flag) {
                event.stopPropagation();
                event.preventDefault();
            }
        }
    }
}
ComboBoxComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-combo-box',
                template: `
    <div
      cdk-overlay-origin
      #origin="cdkOverlayOrigin"
      #trigger
    >
      <md-input-container
        [clear]="clear"
      >
        <input
          mdInput
          aria-autocomplete="list"
          [disabled]="disabled"
          (input)="handleInput()"
          (click)="handleInput()"
          (mousedown)="handleInputMousedown($event)"
          (keydown)="handleKeydown($event)"
          [(ngModel)]="inputValue"
          [placeholder]="placeholder"
        >
        <md-input-section
          *ngIf="hasSearchIcon"
        >
          <md-icon name="search_20"></md-icon>
        </md-input-section>
      </md-input-container>
    </div>

    <ng-template
      cdk-connected-overlay
      [cdkConnectedOverlayOrigin]="origin"
      [cdkConnectedOverlayOpen]="dropdownOpen"
      [cdkConnectedOverlayPositions]="positions"
      [cdkConnectedOverlayOffsetY]="offsetY"
      [cdkConnectedOverlayWidth]="dropdownWidth"
      (attach)="attached()"
      (detach)="close()"
      >
      <div #dropdown class="md-event-overlay__children">
        <div
          class="md-combo-box__options"
          [id]="id"
          [ngStyle]="{width: dropdownWidth + 'px'}"
          role="listbox"
          >
          <ng-container *ngFor="let option of filteredOptions; index as i">
            <div
              *ngIf="isObject(option) && !option['isHeader'] || !isObject(option)"
              md-list-item
              [active]="i === activeIndex"
              (click)="selectOption(option)"
              (mousedown)="handleOptionMousedown($event)"
              [disabled]="isObject(option) && option['disabled'] || null"
              [isReadOnly]="isObject(option) && option['isReadOnly'] || null"
              [label]="isObject(option) ? option[searchProp] : option"
              role="option"
              tabindex="-1"
            ></div>
            <md-list-item-header
              *ngIf="isObject(option) && option['isHeader']"
              [header]="option[searchProp]"
            ></md-list-item-header>
          </ng-container>
        </div>
      </div>
    </ng-template>
  `,
                host: {
                    '[attr.aria-expanded]': 'dropdownOpen',
                    'aria-haspopup': 'listbox',
                    'class': 'md-combo-box',
                    'role': 'combobox',
                },
                providers: [CUI_COMBOBOX_VALUE_ACCESSOR]
            }] }
];
/** @nocollapse */
ComboBoxComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: ViewportRuler },
    { type: OverlayContainer },
    { type: undefined, decorators: [{ type: Inject, args: [DOCUMENT,] }] }
];
ComboBoxComponent.propDecorators = {
    clear: [{ type: Input }],
    disabled: [{ type: Input }],
    hasSearchIcon: [{ type: Input }],
    id: [{ type: Input }],
    options: [{ type: Input }],
    placeholder: [{ type: Input }],
    searchProp: [{ type: Input }],
    targetOffset: [{ type: Input }],
    theme: [{ type: Input }],
    value: [{ type: Input }],
    select: [{ type: Output }],
    overlayDir: [{ type: ViewChild, args: [CdkConnectedOverlay,] }],
    dropdown: [{ type: ViewChild, args: ['dropdown',] }],
    trigger: [{ type: ViewChild, args: ['trigger',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ComboBoxModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: ComboBoxModule,
            providers: [],
        };
    }
}
ComboBoxModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    FormsModule,
                    IconModule,
                    InputContainerModule,
                    InputModule,
                    InputSectionModule,
                    ListItemHeaderModule,
                    ListItemModule,
                    OverlayModule,
                    ReactiveFormsModule,
                ],
                declarations: [ComboBoxComponent],
                exports: [ComboBoxComponent],
                schemas: [CUSTOM_ELEMENTS_SCHEMA],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const cb = (/**
 * @return {?}
 */
() => { });
class EditableTextfieldComponent {
    /**
     * @param {?} control
     * @param {?} elementRef
     */
    constructor(control, elementRef) {
        this.control = control;
        this.elementRef = elementRef;
        this._alignment = null;
        /**
         * \@option Optional css class name for non-edit text div | null
         */
        this.buttonClass = '';
        /**
         * \@option Optional css class string on div wrapping input | ''
         */
        this.className = '';
        /**
         * \@option Sets the disabled attribute of the Input | false
         */
        this.disabled = false;
        /**
         * \@option Unique HTML ID used for tying label to HTML input for automated testing
         */
        this.htmlId = '';
        /**
         * \@option Input css class name string
         */
        this.inputClass = '';
        /**
         * \@option Overall input group size | ''
         */
        this.containerSize = '';
        /**
         * \@option Input size | ''
         */
        this.inputSize = '';
        /**
         * \@option Placeholder text to display when Input is empty | ''
         */
        this.placeholder = '';
        /**
         * \@option Determines if Input can be edited | false
         */
        this.readOnly = false;
        /**
         * \@option Input type | 'text'
         */
        this.type = 'text';
        /**
         * \@option Sets the attribute name to the input element | ''
         */
        this.name = '';
        /**
         * \@option Optional function after done editing
         */
        this.handleDoneEditing = new EventEmitter();
        this.innerValue = '';
        this.isEditing = false;
        this.onTouchedCallback = cb;
        this.onChangeCallback = cb;
        this.handleClick = (/**
         * @return {?}
         */
        () => {
            if (this.disabled) {
                return;
            }
            else {
                this.isEditing = true;
                setTimeout((/**
                 * @return {?}
                 */
                () => this.inputRef.nativeElement.focus()), 100);
            }
        });
        if (this.control) {
            this.control.valueAccessor = this;
        }
    }
    /**
     * \@option Sets optional button alignment | null
     * @param {?} alignment
     * @return {?}
     */
    set alignment(alignment) {
        if (this._alignment) {
            this.elementRef.nativeElement.classList.remove(`md-editable-textfield--${this._alignment}`);
        }
        this.elementRef.nativeElement.classList.add(`md-editable-textfield--${alignment}`);
        this._alignment = alignment;
    }
    /**
     * @return {?}
     */
    get value() {
        return this.innerValue;
    }
    /**
     * @param {?} v
     * @return {?}
     */
    set value(v) {
        if (v !== this.innerValue) {
            this.innerValue = v;
            this.onChangeCallback(v);
        }
    }
    /**
     * @param {?} value
     * @return {?}
     */
    writeValue(value) {
        if (value !== this.innerValue) {
            this.innerValue = value;
        }
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnChange(fn) {
        this.onChangeCallback = fn;
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnTouched(fn) {
        this.onTouchedCallback = fn;
    }
    /**
     * @param {?} e
     * @return {?}
     */
    onKeyDown(e) {
        if (e.keyCode === 27) {
            this.isEditing = false;
        }
        else if (e.keyCode === 13) {
            this.handleEnter(e, e.target.value);
        }
    }
    /**
     * @param {?} e
     * @param {?} value
     * @return {?}
     */
    handleEnter(e, value) {
        this.isEditing = false;
    }
    // keydown on non edit button
    /**
     * @param {?} event
     * @return {?}
     */
    handleKey(event) {
        if (!this.disabled) {
            if ((event.keyCode >= 65 && event.keyCode <= 90) ||
                (event.keyCode >= 48 && event.keyCode <= 57) ||
                event.keyCode === 32) {
                this.isEditing = true;
                setTimeout((/**
                 * @return {?}
                 */
                () => this.inputRef.nativeElement.focus()), 100);
                this.value = this.value.concat(event.key);
            }
        }
    }
    /**
     * @param {?} e
     * @return {?}
     */
    onBlur(e) {
        this.isEditing = false;
        this.handleDoneEditing.emit(this.value);
        e.stopPropagation();
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onFocus(event) {
        if (this.disabled) {
            event.stopPropagation();
            return;
        }
        this.isEditing = true;
    }
}
EditableTextfieldComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-editable-textfield',
                template: `
    <md-input-container
      *ngIf="isEditing"
      [class]="
        'md-editable-textfield__editing' +
        (className ? ' ' + className : '')
      "
      [containerSize]="containerSize"
      [inputSize]="inputSize"
    >
      <input
        mdInput
        #inputRef
        [class]="inputClass"
        [attr.id]="htmlId"
        [(ngModel)]="value"
        [placeholder]="placeholder"
        [readonly]="readOnly"
        [disabled]="disabled"
        [type]="type"
        [name]="name"
        (blur)="onBlur($event)"
        (focus)="onFocus($event)"
        (keydown)="onKeyDown($event)"
      />
    </md-input-container>

    <!-- Not in Edit Mode -->
    <div
      [hidden]="isEditing"
      class="md-editable-textfield__button"
      [ngClass]="[
        inputSize ? inputSize + ' columns' : '',
        buttonClass
      ]"
      role="button"
      tabindex="0"
      (click)="handleClick()"
      (keydown)="handleKey($event)"
    >
      {{ value }}
    </div>
  `,
                host: {
                    class: 'md-editable-textfield',
                }
            }] }
];
/** @nocollapse */
EditableTextfieldComponent.ctorParameters = () => [
    { type: NgControl, decorators: [{ type: Optional }, { type: Self }] },
    { type: ElementRef }
];
EditableTextfieldComponent.propDecorators = {
    alignment: [{ type: Input }],
    buttonClass: [{ type: Input }],
    className: [{ type: Input }],
    disabled: [{ type: Input }],
    htmlId: [{ type: Input }],
    inputClass: [{ type: Input }],
    containerSize: [{ type: Input }],
    inputSize: [{ type: Input }],
    placeholder: [{ type: Input }],
    readOnly: [{ type: Input }],
    type: [{ type: Input }],
    name: [{ type: Input }],
    handleDoneEditing: [{ type: Output }],
    inputRef: [{ type: ViewChild, args: ['inputRef',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class EditableTextfieldModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: EditableTextfieldModule,
            providers: [],
        };
    }
}
EditableTextfieldModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    InputContainerModule,
                    InputModule,
                    FormsModule,
                    ReactiveFormsModule
                ],
                declarations: [EditableTextfieldComponent],
                exports: [EditableTextfieldComponent],
                schemas: [CUSTOM_ELEMENTS_SCHEMA],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FormComponent {
}
FormComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-form',
                template: `
    <ng-content></ng-content>
  `,
                host: {
                    'class': 'md-form',
                    '[attr.name]': 'name',
                }
            }] }
];
FormComponent.propDecorators = {
    name: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * FormContent helps organize the content within a form section and provides a S wrapper;
 *
 */
class FormContentComponent {
}
FormContentComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-form-content',
                template: `
    <ng-content></ng-content>
  `,
                host: {
                    'class': 'section__content',
                }
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * FormInfo is supplemental, organizational component used to help divide form
 *
 */
class FormInfoComponent {
    constructor() {
        /**
         * \@prop Optional FormInfo description text | ''
         */
        this.description = '';
        /**
         * \@prop Optional FormInfo title | ''
         */
        this.title = '';
    }
}
FormInfoComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-form-info',
                template: `
    <h4 class="section__title">{{ title }}</h4>
    <p *ngIf="description" class="section__description">{{ description }}</p>
  `,
                host: {
                    'class': 'section__info',
                }
            }] }
];
FormInfoComponent.propDecorators = {
    description: [{ type: Input }],
    title: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FormSectionComponent {
    constructor() {
        /**
         * \@prop Optional FormSection description | ''
         */
        this.description = '';
    }
}
FormSectionComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-form-section',
                template: `
    <md-form-info [title]="title" [description]="description"></md-form-info>
    <md-form-content><ng-content></ng-content></md-form-content>
  `,
                host: {
                    'class': 'md-form__section',
                }
            }] }
];
FormSectionComponent.propDecorators = {
    description: [{ type: Input }],
    title: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FormSubSectionComponent {
    constructor() {
        /**
         * \@prop Optional FormSubSection description text | ''
         */
        this.description = '';
        /**
         * \@prop Optional FormSubSection label text | ''
         */
        this.label = '';
    }
}
FormSubSectionComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-form-sub-section',
                template: `
    <h5 *ngIf="label" class="sub-section__label">{{ label }}</h5>
    <p *ngIf="description" class="sub-section__description">{{ description }}</p>
    <ng-content></ng-content>
  `,
                host: {
                    'class': 'sub-section',
                }
            }] }
];
FormSubSectionComponent.propDecorators = {
    description: [{ type: Input }],
    label: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FormModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: FormModule,
            providers: [],
        };
    }
}
FormModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                ],
                declarations: [
                    FormComponent,
                    FormContentComponent,
                    FormInfoComponent,
                    FormSectionComponent,
                    FormSubSectionComponent,
                ],
                exports: [
                    FormComponent,
                    FormContentComponent,
                    FormInfoComponent,
                    FormSectionComponent,
                    FormSubSectionComponent,
                ],
                schemas: [CUSTOM_ELEMENTS_SCHEMA],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SpinnerComponent {
    constructor() {
        this.color = 'black';
        this.size = 36;
        this.showCheck = false;
        this.showPercentage = false;
        this.checkPercentage = (/**
         * @param {?} percent
         * @return {?}
         */
        percent => {
            if (!isNaN(percent)) {
                this.isPercentage = true;
                this.percentage = Math.round(percent);
            }
            if (Number(this.size) !== 36 && this.showPercentage) {
                console.warn('Spinner: Percentage will not be shown for sizes smaller than 36');
            }
        });
        this.sizeCheck = (/**
         * @param {?} size
         * @return {?}
         */
        size => {
            /** @type {?} */
            const sizes = [16, 20, 28, 36];
            if (sizes.includes(Number(size))) {
                return true;
            }
            console.warn('Only sizes 16, 20, 28, 36 are acceptable for spinner');
            return false;
        });
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.checkPercentage(this.percentage);
    }
    /**
     * @return {?}
     */
    get defaultClasses() {
        return {
            ['md-spinner--' + this.size]: this.sizeCheck(this.size),
            ['md-spinner--36']: Number(this.size) === 36,
            ['md-spinner--' + this.color]: this.color,
            [this.className]: this.className,
        };
    }
    /**
     * @return {?}
     */
    get percentageClasses() {
        return {
            ['md-spinner-progress--' + this.size]: this.sizeCheck(this.size),
            ['md-spinner-progress__percentage-' + this.percentage]: this.percentage,
            ['md-spinner-progress--' + this.color]: this.color,
            [this.className]: this.className,
        };
    }
    /**
     * @return {?}
     */
    get checkMarkClasses() {
        return {
            ['md-spinner-progress__inset-circle--check']: this.sizeCheck(this.size) && this.showCheck,
            ['md-spinner-progress__inset-circle--check' + this.percentage]: this.showCheck && Number(this.percentage) === 100,
        };
    }
}
SpinnerComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-spinner',
                template: "<div\n  *ngIf=\"isPercentage; else normal\"\n  [ngClass]=\"percentageClasses\"\n  class=\"md-spinner-progress\"\n>\n  <div class=\"md-spinner-progress__circle\">\n    <div class=\"md-spinner-progress__mask md-spinner-progress__full\">\n      <div class=\"md-spinner-progress__fill\"></div>\n    </div>\n    <div class=\"md-spinner-progress__mask md-spinner-progress__half\">\n      <div class=\"md-spinner-progress__fill\"></div>\n      <div class=\"md-spinner-progress__fill md-spinner-progress__fix\"></div>\n    </div>\n    <div\n      [ngClass]=\"checkMarkClasses\"\n      class=\"md-spinner-progress__inset-circle\"\n    >\n      <div\n        *ngIf=\"size === 36 && showPercentage && !showCheck\"\n        class=\"md-spinner-progress__percentage\"\n      >\n        {{ percentage | number: '1.0-0' }}\n      </div>\n    </div>\n  </div>\n</div>\n\n<ng-template #normal>\n  <i [ngClass]=\"defaultClasses\" class=\"md-spinner\"></i>\n</ng-template>\n"
            }] }
];
/** @nocollapse */
SpinnerComponent.ctorParameters = () => [];
SpinnerComponent.propDecorators = {
    className: [{ type: Input }],
    color: [{ type: Input }],
    size: [{ type: Input }],
    percentage: [{ type: Input }],
    showCheck: [{ type: Input }],
    showPercentage: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SpinnerModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: SpinnerModule,
            providers: [],
        };
    }
}
SpinnerModule.decorators = [
    { type: NgModule, args: [{
                declarations: [SpinnerComponent],
                imports: [CommonModule],
                exports: [SpinnerComponent],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TooltipComponent {
    /**
     * @param {?} _vcr
     */
    constructor(_vcr) {
        this._vcr = _vcr;
        this.text = '';
        this.maximumWidth = this.maxWidth;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.tooltipTemplate) {
            this._vcr.createEmbeddedView(this.tooltipTemplate);
        }
    }
}
TooltipComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-tooltip',
                template: `
  <div id="{{id}}" [style.max-width.px]="maxWidth" class="md-tooltip__wrapper">
    <span *ngIf="text != ''" class="md-tooltip__text" role="tooltip">{{ text }}</span>
    <ng-content></ng-content>
  </div>
  `,
                styles: [".md-tooltip__wrapper{text-align:center}"]
            }] }
];
/** @nocollapse */
TooltipComponent.ctorParameters = () => [
    { type: ViewContainerRef }
];
TooltipComponent.propDecorators = {
    text: [{ type: Input }],
    tooltipTemplate: [{ type: Input }],
    id: [{ type: Input }],
    maxWidth: [{ type: Input }],
    maximumWidth: [{ type: HostBinding, args: ['style.max-width.px',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TooltipContainerComponent {
    /**
     * @param {?} elementRef
     */
    constructor(elementRef) {
        this.elementRef = elementRef;
        /**
         * \@prop shows the arrow or not
         */
        this.showArrow = true;
        this.mouseLeaveEvent = new EventEmitter();
        this.mouseEnterEvent = new EventEmitter();
        this.classList = {};
        this.isTooltip = true;
    }
    /**
     * \@prop Sets direction of the tooltip | null
     * @param {?} direction
     * @return {?}
     */
    set direction(direction) {
        this.classList['md-event-overlay--top'] = direction === 'top';
        this.classList['md-event-overlay--bottom'] = direction === 'bottom';
        this.classList['md-event-overlay--left'] = direction === 'left';
        this.classList['md-event-overlay--right'] = direction === 'right';
    }
    /**
     * @return {?}
     */
    closeNow() {
        this.mouseLeaveEvent.emit(false);
    }
    /**
     * @return {?}
     */
    stayOpen() {
        this.mouseEnterEvent.emit(true);
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.classList['md-tooltip'] = this.isTooltip;
        this.classList['md-event-overlay--arrow'] = this.showArrow;
    }
}
TooltipContainerComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-tooltip-container',
                template: `
  <div [ngClass]="classList" class="md-event-overlay">
    <div *ngIf="showArrow" class="md-event-overlay__arrow" ></div>
    <div  class="md-event-overlay__children">
        <md-tooltip
          #mdtooltip
          id={{this.id}}
          text={{this.text}}
          maxWidth={{this.maxWidth}}
          [tooltipTemplate]="tooltipTemplate"
        ></md-tooltip>
    </div>
  </div>
  `,
                styles: [".md-tooltip.md-event-overlay{position:static}.md-tooltip.md-event-overlay>.md-event-overlay__children{position:static;padding:12px}.md-tooltip.md-event-overlay>.md-event-overlay__arrow{z-index:1027}.md-tooltip.md-event-overlay.md-event-overlay--arrow.md-event-overlay--right{display:flex;flex-direction:row;align-items:center}.md-tooltip.md-event-overlay.md-event-overlay--arrow.md-event-overlay--right>.md-event-overlay__arrow{margin-top:0}.md-tooltip.md-event-overlay.md-event-overlay--arrow.md-event-overlay--left{display:flex;flex-direction:row-reverse;align-items:center}.md-tooltip.md-event-overlay.md-event-overlay--arrow.md-event-overlay--left>.md-event-overlay__arrow{margin-left:-2px;margin-top:0}.md-tooltip.md-event-overlay.md-event-overlay--arrow.md-event-overlay--left>.md-event-overlay__children{margin-right:14px}.md-tooltip.md-event-overlay.md-event-overlay--arrow.md-event-overlay--bottom{display:flex;flex-direction:column;align-items:center}.md-tooltip.md-event-overlay.md-event-overlay--arrow.md-event-overlay--bottom>.md-event-overlay__arrow{margin-left:0}.md-tooltip.md-event-overlay.md-event-overlay--arrow.md-event-overlay--top{display:flex;flex-direction:column-reverse;align-items:center}.md-tooltip.md-event-overlay.md-event-overlay--arrow.md-event-overlay--top>.md-event-overlay__arrow{margin-top:-2px;margin-left:0}.md-tooltip.md-event-overlay.md-event-overlay--arrow.md-event-overlay--top>.md-event-overlay__children{margin-bottom:14px}"]
            }] }
];
/** @nocollapse */
TooltipContainerComponent.ctorParameters = () => [
    { type: ElementRef }
];
TooltipContainerComponent.propDecorators = {
    text: [{ type: Input }],
    tooltipTemplate: [{ type: Input }],
    direction: [{ type: Input }],
    allowHover: [{ type: Input }],
    showArrow: [{ type: Input }],
    id: [{ type: Input }],
    maxWidth: [{ type: Input }],
    mouseLeaveEvent: [{ type: Output }],
    mouseEnterEvent: [{ type: Output }],
    closeNow: [{ type: HostListener, args: ['mouseleave',] }],
    stayOpen: [{ type: HostListener, args: ['mouseenter',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
let id = 0;
class TooltipDirective {
    /**
     * @param {?} overlay
     * @param {?} overlayPositionBuilder
     * @param {?} _sso
     * @param {?} elementRef
     */
    constructor(overlay, overlayPositionBuilder, _sso, elementRef) {
        this.overlay = overlay;
        this.overlayPositionBuilder = overlayPositionBuilder;
        this._sso = _sso;
        this.elementRef = elementRef;
        this.tooltipId = id++;
        /**
         * \@prop Sets direction of the tooltip right,left,top, or bottom
         */
        this.direction = 'top';
        /**
         * \@prop Sets delay for before closing the tooltip
         */
        this.delay = 500;
        /**
         * \@prop Sets the tooltip trigger MouseEnter, Click or Focus - MouseEnter is default
         */
        this.tooltipTrigger = 'MouseEnter';
        /**
         * \@prop Sets the offset of the tooltip from the host
         */
        this.offset = 5;
        /**
         * \@prop Sets the maxwidth of the tooltip
         */
        this.maxWidth = 200;
        /**
         * \@prop Allows tooltip to stay open until you click outside | false
         */
        this.closeOnClick = false;
        /**
         * \@prop Allows tooltip to stay open when you hover over the tooltip | false
         */
        this.allowHover = false;
        this.ariaDescribedby = `md-tooltip-${this.tooltipId}`;
        this.positions = [];
        this.keepTooltipOpen = false;
        this.isOnTarget = false;
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.delay = 0;
        this.isOnTarget = false;
        this.keepTooltipOpen = false;
        this.close();
    }
    /**
     * @return {?}
     */
    showtoolitp() {
        if (this.tooltipTrigger === 'MouseEnter') {
            this.isOnTarget = this.allowHover; // only checks on allowHover is true
            this.show();
        }
    }
    /**
     * @return {?}
     */
    hide() {
        this.isOnTarget = false;
        if ((this.tooltipTrigger === 'MouseEnter' && !this.closeOnClick && !this.allowHover) || this.tooltipTrigger === 'Click') {
            this.close();
        }
        else if (this.allowHover && !this.keepTooltipOpen) {
            this.close();
        }
    }
    /**
     * @return {?}
     */
    onClick() {
        if (this.tooltipTrigger === 'Click') {
            this.show();
        }
    }
    /**
     * @param {?} targetElement
     * @return {?}
     */
    closeTooltip(targetElement) {
        if (this.tooltipTrigger === 'Click' || this.closeOnClick) {
            /** @type {?} */
            const clickedOutside = !this.elementRef.nativeElement.contains(targetElement);
            if (clickedOutside) {
                this.close();
            }
        }
    }
    /**
     * @return {?}
     */
    onFocus() {
        if (this.tooltipTrigger === 'Focus') {
            this.show();
        }
    }
    /**
     * @return {?}
     */
    onFocusout() {
        if (this.tooltipTrigger === 'Focus') {
            this.close();
        }
    }
    /**
     * @return {?}
     */
    show() {
        switch (this.direction) {
            case 'right':
                this.positions = [{
                        originX: 'end',
                        originY: 'center',
                        overlayX: 'start',
                        overlayY: 'center',
                        offsetX: this.offset
                    },
                    {
                        originX: 'start',
                        originY: 'center',
                        overlayX: 'end',
                        overlayY: 'center',
                        offsetX: -this.offset
                    }
                ];
                break;
            case 'left':
                this.positions = [{
                        originX: 'start',
                        originY: 'center',
                        overlayX: 'end',
                        overlayY: 'center',
                        offsetX: -this.offset
                    },
                    {
                        originX: 'end',
                        originY: 'center',
                        overlayX: 'start',
                        overlayY: 'center',
                        offsetX: this.offset
                    }];
                break;
            case 'bottom':
                this.positions = [{
                        originX: 'center',
                        originY: 'bottom',
                        overlayX: 'center',
                        overlayY: 'top',
                        offsetY: this.offset
                    },
                    {
                        originX: 'center',
                        originY: 'top',
                        overlayX: 'center',
                        overlayY: 'bottom',
                        offsetY: -this.offset
                    }];
                break;
            case 'top':
                this.positions = [{
                        originX: 'center',
                        originY: 'top',
                        overlayX: 'center',
                        overlayY: 'bottom',
                        offsetY: -this.offset
                    },
                    {
                        originX: 'center',
                        originY: 'bottom',
                        overlayX: 'center',
                        overlayY: 'top',
                        offsetY: this.offset
                    }];
                break;
        }
        /** @type {?} */
        const strategy = this.overlayPositionBuilder
            .flexibleConnectedTo(this.elementRef)
            .withPositions(this.positions);
        this.overlayRef = this.overlay.create({
            positionStrategy: (/** @type {?} */ (strategy)),
            scrollStrategy: this._sso.close(),
        });
        if (!this.tooltipRef) {
            this.tooltipRef
                = this.overlayRef.attach(new ComponentPortal(TooltipContainerComponent));
            this.tooltipRef.instance.id = 'md-tooltip-' + this.tooltipId;
            this.tooltipRef.instance.maxWidth = this.maxWidth;
            if (typeof this.content === 'string') {
                this.tooltipRef.instance.text = this.content;
            }
            if (this.content instanceof TemplateRef) {
                this.tooltipRef.instance.tooltipTemplate = this.content;
            }
            this.tooltipRef.instance.direction = this.direction;
            this.tooltipRef.instance.allowHover = this.allowHover;
            if (this.allowHover) {
                this.eventSubs = new Subscription();
                this.eventSubs.add(this.tooltipRef.instance.mouseLeaveEvent.subscribe((/**
                 * @return {?}
                 */
                () => {
                    this.keepTooltipOpen = false;
                    this.close();
                })));
                this.eventSubs.add(this.tooltipRef.instance.mouseEnterEvent.subscribe((/**
                 * @param {?} keepOpen
                 * @return {?}
                 */
                keepOpen => {
                    if (keepOpen && this.allowHover) {
                        this.keepTooltipOpen = true;
                    }
                })));
            }
        }
    }
    /**
     * @return {?}
     */
    close() {
        setTimeout((/**
         * @return {?}
         */
        () => {
            if (!this.keepTooltipOpen && !this.isOnTarget) {
                if (this.overlayRef) {
                    this.overlayRef.detach();
                }
                if (this.tooltipRef) {
                    if (this.allowHover) {
                        this.eventSubs.unsubscribe();
                    }
                    this.tooltipRef.destroy();
                    this.tooltipRef = null;
                }
            }
        }), this.delay);
    }
}
TooltipDirective.decorators = [
    { type: Directive, args: [{ selector: '[mdTooltip]' },] }
];
/** @nocollapse */
TooltipDirective.ctorParameters = () => [
    { type: Overlay },
    { type: OverlayPositionBuilder },
    { type: ScrollStrategyOptions },
    { type: ElementRef }
];
TooltipDirective.propDecorators = {
    content: [{ type: Input, args: ['mdTooltip',] }],
    direction: [{ type: Input }],
    delay: [{ type: Input }],
    tooltipTrigger: [{ type: Input }],
    offset: [{ type: Input }],
    maxWidth: [{ type: Input }],
    closeOnClick: [{ type: Input }],
    allowHover: [{ type: Input }],
    ariaDescribedby: [{ type: HostBinding, args: ['attr.aria-describedby',] }],
    showtoolitp: [{ type: HostListener, args: ['mouseenter',] }],
    hide: [{ type: HostListener, args: ['mouseleave',] }],
    onClick: [{ type: HostListener, args: ['document:',] }, { type: HostListener, args: ['click',] }],
    closeTooltip: [{ type: HostListener, args: ['document:click', ['$event.target'],] }],
    onFocus: [{ type: HostListener, args: ['focus',] }],
    onFocusout: [{ type: HostListener, args: ['focusout',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TooltipModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: TooltipModule,
            providers: [],
        };
    }
}
TooltipModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    TooltipComponent,
                    TooltipDirective,
                    TooltipContainerComponent
                ],
                imports: [
                    CommonModule,
                    OverlayModule
                ],
                exports: [TooltipComponent, TooltipDirective, TooltipContainerComponent],
                schemas: [CUSTOM_ELEMENTS_SCHEMA],
                entryComponents: [TooltipContainerComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class LightboxTooltips {
    constructor() {
        this.download = 'Download';
        this.downloading = 'Downloading...';
        this.exit = 'Exit';
        this.previous = 'Previous';
        this.next = 'Next';
        this.zoomIn = 'Zoom in';
        this.zoomOut = 'Zoom out';
    }
}
/**
 * Configuration used when opening a lightbox.
 */
class LightboxConfig {
    constructor() {
        /**
         * Determines if info is decrypting | false
         */
        this.decrypting = false;
        /**
         * Optional downloading css styling | false
         */
        this.downloading = false;
        /**
         * Initial index of start page | 0
         */
        this.index = 0;
        /**
         * Required name prop for Lightbox
         */
        this.name = '';
        /**
         * Collection of predefined tootips for various Lightbox actions | { download: 'Download', etc }
         */
        this.tooltips = new LightboxTooltips();
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class LightboxComponent {
    /**
     * @param {?} _config
     * @param {?} _document
     */
    constructor(_config, _document) {
        this._config = _config;
        this.math = Math;
        this.viewportDimensions = {
            width: 600,
            height: 600
        };
        this.zoom = 1;
        this._onDestroy = new Subject();
        this.handleResize = (/**
         * @return {?}
         */
        () => {
            this.viewportDimensions = {
                width: this.viewportRef.nativeElement.offsetWidth,
                height: this.viewportRef.nativeElement.offsetHeight
            };
        });
        this.handleKeydown = (/**
         * @param {?} e
         * @return {?}
         */
        (e) => {
            /** @type {?} */
            let newIndex;
            switch (e.code) {
                case 'Escape':
                    this.destroy();
                    return;
                case 'ArrowLeft':
                case 'ArrowUp':
                    newIndex = Math.max(this.index - 1, 0);
                    break;
                case 'ArrowRight':
                case 'ArrowDown':
                    newIndex = Math.min(this.index + 1, this.pages.length - 1);
                    break;
                case 'PageUp':
                case 'Home':
                    newIndex = 0;
                    break;
                case 'PageDown':
                case 'End':
                    newIndex = this.pages.length - 1;
                    break;
                case 'Digit1':
                case 'Digit2':
                case 'Digit3':
                case 'Digit4':
                case 'Digit5':
                case 'Digit6':
                case 'Digit7':
                case 'Digit8':
                case 'Digit9':
                    newIndex = Math.min(Number(e.code.substr(-1)) - 1, this.pages.length - 1);
                    break;
                default:
                    return;
            }
            this.triggerPageChange(newIndex, e);
        });
        this.decrypting = _config.decrypting;
        this.downloading = _config.downloading;
        this.height = _config.height;
        this.index = _config.index;
        this.info = _config.info;
        this.name = _config.name;
        this.pages = _config.pages;
        this.tooltips = _config.tooltips;
        this.width = _config.width;
        this._document = _document;
    }
    /**
     * @return {?}
     */
    get currentPage() {
        return this.pages[this.index];
    }
    /**
     * @return {?}
     */
    get controlStyle() {
        return this.currentPage.content ? {
            visibility: 'hidden'
        } : {};
    }
    /**
     * @return {?}
     */
    get thumbnailDecryptingStyle() {
        return { height: Math.round(this.height / (this.width / 150)) };
    }
    /**
     * @return {?}
     */
    get viewportStyle() {
        /** @type {?} */
        const srcWidth = this.width * this.zoom;
        /** @type {?} */
        const srcHeight = this.height * this.zoom;
        /** @type {?} */
        const maxWidth = this.viewportDimensions.width;
        /** @type {?} */
        const maxHeight = this.viewportDimensions.height;
        /** @type {?} */
        const ratio = Math.min(maxWidth / srcWidth, maxHeight / srcHeight, 1);
        /** @type {?} */
        const width = Math.round(srcWidth * ratio);
        /** @type {?} */
        const height = Math.round(srcHeight * ratio);
        return this.zoom <= 1 ? {
            width: `${width}px`,
            height: `${height}px`
        } : {};
    }
    /**
     * @return {?}
     */
    get config() {
        return this._config;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this._document.addEventListener('keydown', this.handleKeydown);
        this._document.addEventListener('resize', this.handleResize);
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this._document.removeEventListener('keydown', this.handleKeydown);
        this._document.removeEventListener('resize', this.handleResize);
        if (this._config.onClose) {
            this._config.onClose();
        }
    }
    /**
     * @param {?} index
     * @return {?}
     */
    handleThumbnailClick(index) {
        this.index = index;
        if (this._config.onChange) {
            this._config.onChange(index);
        }
    }
    /**
     * @param {?} index
     * @param {?} e
     * @return {?}
     */
    triggerPageChange(index, e) {
        /** @type {?} */
        const target = this.headerRef.nativeElement.querySelector(`[dataindex="${index}"]`);
        if (index >= 0 && index <= this.pages.length - 1) {
            this.index = index;
            if (this._config.onChange) {
                this._config.onChange(index);
            }
        }
        if (target) {
            target.scrollIntoView();
        }
        e.stopPropagation();
    }
    /**
     * @param {?} e
     * @return {?}
     */
    stopPropagation(e) {
        e.stopPropagation();
    }
    /**
     * @param {?} increment
     * @return {?}
     */
    setZoom(increment) {
        /** @type {?} */
        const newZoom = this.zoom + increment;
        this.zoom = newZoom < 0.25 ? 0.25 : newZoom;
    }
    /**
     * @return {?}
     */
    handleDownload() {
        if (this._config.onDownload) {
            this._config.onDownload(this.currentPage);
        }
    }
    /**
     * @param {?} e
     * @param {?} type
     * @param {?=} param
     * @return {?}
     */
    handleKeypress(e, type, param) {
        if (e.code === 'Enter' || e.code === 'Space') {
            switch (type) {
                case 'destroy':
                    this.destroy();
                    break;
                case 'thumbnail':
                    this.handleThumbnailClick(param);
                    break;
                case 'change':
                    this.triggerPageChange(param, e);
                    break;
                case 'download':
                    this.handleDownload();
                    break;
                case 'zoom':
                    this.setZoom(param);
                    break;
            }
        }
    }
    /**
     * @return {?}
     */
    destroy() {
        this._onDestroy.next();
        this._onDestroy.complete();
    }
}
LightboxComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-lightbox',
                template: `
    <div class="md-lightbox">
      <div #headerRef class="md-lightbox__header">
        <div class="md-lightbox__header-item--left">
          <div class="md-lightbox__header-meta">
            <div class="md-lightbox__header-sharer">{{ info.sharedBy }}</div>
            <div class="md-lightbox__header-timestamp">{{ info.sharedOn }}</div>
          </div>
        </div>
        <div class="md-lightbox__header-item--center">
          <div class="md-lightbox__header-name">{{ name }}</div>
        </div>
        <div class="md-lightbox__header-item--right">
          <div class="md-lightbox__control"
            [mdTooltip]="tooltips.exit"
            direction="left"
            delay="0"
            (click)="destroy()"
            (keypress)="handleKeypress($event, 'destroy')"
            role="button"
            tabindex="0">
              <md-icon name="cancel_16"></md-icon>
          </div>
        </div>
      </div>
      <div class="md-lightbox__body">
        <ng-container *ngTemplateOutlet="thumbnailsTemplate"></ng-container>
        <div
          class="md-lightbox__content"
          (click)="destroy()"
          (keypress)="handleKeypress($event, 'destroy')"
          role="button"
          tabindex="0"
        >
          <div
            #viewportRef
            class="md-lightbox__viewport"
            [ngClass]="{ 'md-lightbox__viewport--decrypting': !!currentPage.decrypting }"
          >
            <md-spinner *ngIf="pages[index].decrypting" class="md-lightbox__decrypting-spinner"></md-spinner>
            <ng-container *ngTemplateOutlet="viewportTemplate"></ng-container>
          </div>
          <ng-container *ngTemplateOutlet="leftArrowControlTemplate"></ng-container>
          <ng-container *ngTemplateOutlet="rightArrowControlTemplate"></ng-container>
          <ng-container *ngTemplateOutlet="viewportControlsTemplate"></ng-container>
        </div>
      </div>
    </div>

    <ng-template #thumbnailsTemplate>
      <div *ngIf="pages.length > 1" class="md-lightbox__list">
        <div *ngFor="let page of pages; index as idx"
          class="md-lightbox__thumbnail-wrapper"
          [ngClass]="{ 'md-lightbox__thumbnail-wrapper--selected': idx === index }"
          (click)="handleThumbnailClick(idx)"
          (keypress)="handleKeypress($event, 'thumbnail', idx)"
          role="button"
          tabindex="0"
        >
          <div *ngIf="page.decrypting"
            class="md-lightbox__thumbnail md-lightbox__thumbnail--decrypting"
            [attr.dataindex]="idx"
            [ngStyle]="thumbnailDecryptingStyle"
          >
            <md-icon class="md-lightbox__thumbnail--icon" name="secure_28"></md-icon>
          </div>
          <img *ngIf="!page.decrypting"
            alt=""
            class="md-lightbox__thumbnail"
            [attr.dataindex]="idx"
            [attr.draggable]="false"
            [attr.src]="page.thumb"
          />
          <div>
            {{ idx + 1 }}
          </div>
        </div>
      </div>
    </ng-template>

    <ng-template #viewportTemplate>
      <div
        class="md-lightbox__viewport-wrapper"
        [ngStyle]="viewportStyle"
      >
        <div *ngIf="currentPage.content">
          <div
            class="md-lightbox__viewport-content"
            [attr.draggable]="false"
            (click)="stopPropagation($event)"
            (keypress)="stopPropagation($event)"
            (doubleclick)="setZoom(0.25)"
            role="button"
            tabindex="0"
          >
            {{ currentPage.content }}
          </div>
        </div>
        <div *ngIf="currentPage.image">
          <div *ngIf="zoom <= 1">
            <img
              alt=""
              class="md-lightbox__viewport-image"
              [attr.draggable]="false"
              (click)="stopPropagation($event)"
              (keypress)="stopPropagation($event)"
              (doubleclick)="setZoom(0.25)"
              [attr.src]="currentPage.thumb"
            />
          </div>
          <div *ngIf="zoom > 1">
            <img
              alt=""
              class="md-lightbox__viewport-image"
              [attr.draggable]="false"
              (click)="stopPropagation($event)"
              (keypress)="stopPropagation($event)"
              (doubleclick)="setZoom(0.25)"
              [attr.src]="currentPage.thumb"
              [ngStyle]="{
                'object-fit': 'contain',
                'max-height': height * zoom + 'px',
                'max-width': width * zoom + 'px',
                'min-height': height * zoom + 'px',
                'min-width': width * zoom + 'px'
              }"
            />
          </div>
        </div>
      </div>
    </ng-template>

    <ng-template #leftArrowControlTemplate>
      <div *ngIf="pages.length > 1"
        [mdTooltip]="tooltips.previous"
        direction="right"
        delay="0"
        class="md-lightbox__page-control md-lightbox__page-control-icon md-lightbox__page-controls--left"
        role="button"
        tabindex="0"
        (click)="triggerPageChange(index - 1, $event)"
        (keypress)="handleKeypress($event, 'change', index - 1)"
        style="transform: rotate(-180deg)"
      >
        <md-icon name="icon-arrow-right_16"></md-icon>
      </div>
    </ng-template>

    <ng-template #rightArrowControlTemplate>
      <div *ngIf="pages.length > 1"
        [mdTooltip]="tooltips.next"
        direction="left"
        delay="0"
        class="md-lightbox__page-control md-lightbox__page-control-icon md-lightbox__page-controls--right"
        role="button"
        tabindex="0"
        (click)="triggerPageChange(index + 1, $event)"
        (keypress)="handleKeypress($event, 'change', index + 1)"
      >
        <md-icon name="icon-arrow-right_16"></md-icon>
      </div>
    </ng-template>

    <ng-template #viewportControlsTemplate>
      <div
        class="md-lightbox__viewer-controls"
        (click)="stopPropagation($event)"
        (keypress)="stopPropagation($event)"
        role="button"
        tabindex="0"
      >
        <div class="md-lightbox__controls" [ngStyle]="controlStyle">
          <div class="md-lightbox__control"
            [mdTooltip]="tooltips.zoomOut"
            delay="0"
            (click)="setZoom(-0.25)"
            (keypress)="handleKeypress($event, 'zoom', -0.25)"
            role="button"
            tabindex="0"
          >
              <md-icon name="zoom-out_16"></md-icon>
          </div>
          <span class="md-lightbox__control-value">{{ math.round(zoom * 100) }}%</span>
          <div class="md-lightbox__control"
            [mdTooltip]="tooltips.zoomIn"
            delay="0"
            (click)="setZoom(0.25)"
            (keypress)="handleKeypress($event, 'zoom', 0.25)"
            role="button"
            tabindex="0"
          >
            <md-icon name="zoom-in_16"></md-icon>
          </div>
        </div>
        <ng-container *ngTemplateOutlet="pageControlTemplate"></ng-container>
        <div class="md-lightbox__controls" [ngStyle]="controlStyle">
          <span class="md-lightbox__control-value">{{ info.size }}</span>
          <div *ngIf="downloading"
            [mdTooltip]="tooltips.downloading"
            delay="0"
            class="md-lightbox__control md-lightbox__control-spinner">
            <md-spinner size="28"></md-spinner>
          </div>
          <div *ngIf="!downloading"
            [mdTooltip]="tooltips.download"
            delay="0"
            class="md-lightbox__control md-lightbox__control-download"
            (click)="handleDownload()"
            (keypress)="handleKeypress($event, 'download')"
            role="button"
            tabindex="0"
          >
            <md-icon name="download_16"></md-icon>
          </div>
        </div>
      </div>
    </ng-template>

    <ng-template #pageControlTemplate>
      <div *ngIf="pages.length > 1" class="md-lightbox__controls md-lightbox__controls--center">
        <div class="md-lightbox__control"
          [mdTooltip]="tooltips.previous"
          delay="0"
          (click)="triggerPageChange(index - 1, $event)"
          (keypress)="handleKeypress($event, 'change', index - 1)"
          role="button"
          tabindex="0"
          style="transform: rotate(-180deg)"
        >
          <md-icon name="icon-arrow-right_16"></md-icon>
        </div>
        <span class="md-lightbox__control-value">{{ index + 1 }} / {{ pages.length }}</span>
        <div class="md-lightbox__control"
          [mdTooltip]="tooltips.next"
          delay="0"
          (click)="triggerPageChange(index + 1, $event)"
          (keypress)="handleKeypress($event, 'change', index + 1)"
          role="button"
          tabindex="0"
        >
          <md-icon name="icon-arrow-right_16"></md-icon>
        </div>
      </div>
      <div *ngIf="pages.length === 1" class="md-lightbox__controls">
        <span class="md-lightbox__control-value">{{ index + 1 }}</span>
      </div>
    </ng-template>
  `,
                host: {
                    'class': 'md-lightbox__container'
                }
            }] }
];
/** @nocollapse */
LightboxComponent.ctorParameters = () => [
    { type: LightboxConfig },
    { type: undefined, decorators: [{ type: Inject, args: [DOCUMENT,] }] }
];
LightboxComponent.propDecorators = {
    headerRef: [{ type: ViewChild, args: ['headerRef',] }],
    viewportRef: [{ type: ViewChild, args: ['viewportRef',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class LightboxService {
    /**
     * @param {?} _overlay
     * @param {?} _injector
     */
    constructor(_overlay, _injector) {
        this._overlay = _overlay;
        this._injector = _injector;
        this._overlayRef = null;
        this._lightboxRef = null;
    }
    /**
     * @param {?} config
     * @return {?}
     */
    open(config) {
        /** @type {?} */
        const _config = Object.assign({}, new LightboxConfig(), config);
        if (!this._overlayRef) {
            this._overlayRef = this._overlay.create();
        }
        return this._attachLightboxContainer(this._overlayRef, _config);
    }
    /**
     * @return {?}
     */
    close() {
        if (this._lightboxRef) {
            this._lightboxRef.instance.destroy();
        }
    }
    /**
     * @private
     * @param {?} overlayRef
     * @param {?} config
     * @return {?}
     */
    _attachLightboxContainer(overlayRef, config) {
        if (this._lightboxRef) {
            return this._lightboxRef.instance;
        }
        /** @type {?} */
        const injector = new PortalInjector(this._injector, new WeakMap([[LightboxConfig, config]]));
        /** @type {?} */
        const containerPortal = new ComponentPortal(LightboxComponent, null, injector);
        this._lightboxRef = overlayRef.attach(containerPortal);
        /** @type {?} */
        const onDestroySub = this._lightboxRef.instance._onDestroy.subscribe((/**
         * @return {?}
         */
        () => {
            onDestroySub.unsubscribe();
            this._dispose();
        }));
        return this._lightboxRef.instance;
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this._lightboxRef) {
            this._lightboxRef.instance.destroy();
        }
    }
    /**
     * @private
     * @return {?}
     */
    _dispose() {
        this._lightboxRef = null;
        this._overlayRef.dispose();
        this._overlayRef = null;
    }
}
LightboxService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
LightboxService.ctorParameters = () => [
    { type: Overlay },
    { type: Injector }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class LightboxModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: LightboxModule,
            providers: [],
        };
    }
}
LightboxModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    OverlayModule,
                    PortalModule,
                    IconModule,
                    SpinnerModule,
                    TooltipModule,
                ],
                declarations: [LightboxComponent],
                exports: [LightboxComponent],
                entryComponents: [LightboxComponent],
                providers: [LightboxService],
                schemas: [CUSTOM_ELEMENTS_SCHEMA],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ListSeparatorComponent {
    /**
     * @return {?}
     */
    get _backgroundColor() {
        return this.backgroundColor;
    }
    /**
     * @return {?}
     */
    get _lineColor() {
        return this.lineColor;
    }
    /**
     * @return {?}
     */
    get _margin() {
        return this.margin;
    }
}
ListSeparatorComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-list-separator',
                template: `
    <span class="md-list-separator__container">
      <ng-content *ngIf="!text; else textTemplate"></ng-content>
    </span>

    <ng-template #textTemplate>
      <span
        class="md-list-separator__text"
        [ngStyle]="{ color: textColor, padding: textPadding }"
        >{{ text }}</span
      >
    </ng-template>
  `,
                host: {
                    class: 'md-list-separator',
                }
            }] }
];
ListSeparatorComponent.propDecorators = {
    backgroundColor: [{ type: Input }],
    lineColor: [{ type: Input }],
    margin: [{ type: Input }],
    text: [{ type: Input }],
    textColor: [{ type: Input }],
    textPadding: [{ type: Input }],
    _backgroundColor: [{ type: HostBinding, args: ['style.background-color',] }],
    _lineColor: [{ type: HostBinding, args: ['style.color',] }],
    _margin: [{ type: HostBinding, args: ['style.margin',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ListSeparatorModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: ListSeparatorModule,
            providers: [],
        };
    }
}
ListSeparatorModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [ListSeparatorComponent],
                exports: [ListSeparatorComponent],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class MenuComponent {
    constructor() {
        /**
         * \@prop Text to display for accessibility features | ''
         */
        this.ariaLabel = '';
        /**
         * \@prop Determines if the Menu should show the arrow | false
         */
        this.showArrow = false;
        /**
         * Event emitted when the menu is closed.
         */
        this.closed = new EventEmitter();
        this.select = new EventEmitter();
        this._direction = 'bottom-left';
        this._items = [];
        this._itemChanges = new Subject();
        this.classList = {};
    }
    /**
     * \@prop Sets the direction in which the EventOverlay extends | 'bottom-left'
     * @return {?}
     */
    get direction() { return this._direction; }
    /**
     * @param {?} value
     * @return {?}
     */
    set direction(value) {
        this._direction = value;
        this._setPositionClasses();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this._setPositionClasses();
    }
    /**
     * @return {?}
     */
    ngAfterContentInit() {
        this._keyManager = new FocusKeyManager(this._items).withWrap().withTypeAhead();
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.closed.complete();
    }
    /**
     * @param {?} item
     * @return {?}
     */
    addItem(item) {
        if (this._items.indexOf(item) === -1) {
            this._items.push(item);
            this._itemChanges.next(this._items);
        }
    }
    /**
     * @param {?} item
     * @return {?}
     */
    removeItem(item) {
        /** @type {?} */
        const index = this._items.indexOf(item);
        if (this._items.indexOf(item) > -1) {
            this._items.splice(index, 1);
            this._itemChanges.next(this._items);
        }
    }
    /**
     * @private
     * @return {?}
     */
    _setPositionClasses() {
        /** @type {?} */
        const side = this.direction.split('-')[0];
        this.classList['md-event-overlay--arrow'] = this.showArrow;
        this.classList['md-event-overlay--top'] = side === 'top';
        this.classList['md-event-overlay--bottom'] = side === 'bottom';
        this.classList['md-event-overlay--left'] = side === 'left';
        this.classList['md-event-overlay--right'] = side === 'right';
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onKeydown(event) {
        switch (event.code) {
            case 'Escape':
                this.closed.emit('keydown');
                break;
            case 'ArrowLeft':
                if (this.parentMenu) {
                    this.closed.emit('keydown');
                }
                break;
            case 'ArrowRight':
                if (this.parentMenu) {
                    this.closed.emit('keydown');
                }
                break;
            default:
                if (event.code === 'ArrowUp' || event.code === 'ArrowDown') {
                    this._keyManager.setFocusOrigin('keyboard');
                }
                this._keyManager.onKeydown(event);
        }
    }
    /**
     * @param {?=} origin
     * @return {?}
     */
    focusFirstItem(origin = 'program') {
        this._keyManager.setFocusOrigin(origin).setFirstItemActive();
    }
}
MenuComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-menu',
                template: `
    <ng-template>
      <div
        [ngClass]="classList"
        class="md-menu-overlay"
        (keydown)="onKeydown($event)"
        >
        <div *ngIf="showArrow" class="md-event-overlay__arrow"></div>
        <div class="md-event-overlay__children">
          <div class="md-menu md-menu-item-container" [attr.aria-label]="ariaLabel" role="menubar">
            <ng-content></ng-content>
          </div>
        </div>
      </div>
    </ng-template>
  `,
                styles: [`
    .md-menu-overlay {
      position: relative;
    }
    .md-event-overlay__arrow {
      position: absolute;
    }
    .md-event-overlay__children {
      position: relative;
    }
  `]
            }] }
];
MenuComponent.propDecorators = {
    ariaLabel: [{ type: Input }],
    direction: [{ type: Input }],
    hasBackdrop: [{ type: Input }],
    showArrow: [{ type: Input }],
    closed: [{ type: Output }],
    select: [{ type: Output }],
    templateRef: [{ type: ViewChild, args: [TemplateRef,] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class MenuContentComponent {
}
MenuContentComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-menu-content',
                template: `
    <ng-content></ng-content>
  `,
                host: {
                    'class': 'md-menu-content'
                }
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class MenuItemComponent {
    /**
     * @param {?} _elementRef
     * @param {?=} _focusMonitor
     * @param {?=} _parentMenu
     */
    constructor(_elementRef, _focusMonitor, _parentMenu) {
        this._elementRef = _elementRef;
        this._focusMonitor = _focusMonitor;
        this._parentMenu = _parentMenu;
        /**
         * \@prop Active prop to determine styles | false
         */
        this.active = false;
        /**
         * \@prop Determines if MenuItem is the header | false
         */
        this.isHeader = false;
        /**
         * \@prop Initial selected value within SubMenu | ''
         */
        this.selectedValue = '';
        /**
         * Whether the menu item acts as a trigger for a sub-menu.
         */
        this.triggersSubmenu = false;
        if (_focusMonitor) {
            _focusMonitor.monitor(this._elementRef, false);
        }
        if (_parentMenu && _parentMenu.addItem) {
            _parentMenu.addItem(this);
        }
    }
    /**
     * @return {?}
     */
    get listItemElement() {
        return this._elementRef.nativeElement.querySelector('.md-list-item');
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this._focusMonitor) {
            this._focusMonitor.stopMonitoring(this._elementRef);
        }
        if (this._parentMenu && this._parentMenu.removeItem) {
            this._parentMenu.removeItem(this);
        }
    }
    /**
     * @param {?=} origin
     * @return {?}
     */
    focus(origin = 'program') {
        if (this._focusMonitor) {
            this._focusMonitor.focusVia(this.listItemElement, origin);
        }
        else {
            this.listItemElement.focus();
        }
    }
    /**
     * @return {?}
     */
    getLabel() {
        return this.listItemElement.textContent.trim();
    }
    /**
     * @param {?} _
     * @return {?}
     */
    onClick(_) {
        if (this._parentMenu && !this.triggersSubmenu && !this.isHeader) {
            this._parentMenu.select.emit(this);
            this._parentMenu.closed.emit('click');
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onKeydown(event) {
        switch (event.code) {
            case 'Enter':
            case 'Space':
                if (this._parentMenu && !this.triggersSubmenu && !this.isHeader) {
                    this._parentMenu.select.emit(this);
                    this._parentMenu.closed.emit('click');
                }
                break;
        }
    }
}
MenuItemComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-menu-item',
                template: `
    <div
      md-list-item
      [active]="active"
      [isReadOnly]="isHeader"
      [ngClass]="{'md-menu-item__header': isHeader}"
      role="menuitem"
      tabindex="-1"
    >
      <ng-container *ngIf="!triggersSubmenu; else submenuTemplate">
        <ng-container *ngTemplateOutlet="contentTemplate"></ng-container>
      </ng-container>
    </div>

    <ng-template #contentTemplate>
      <ng-content></ng-content>
    </ng-template>

    <ng-template #submenuTemplate>
      <div class="md-menu-item__content">
        <ng-container *ngTemplateOutlet="contentTemplate"></ng-container>
      </div>
      <div
        *ngIf="selectedValue"
        class="md-menu-item__selected-value"
        [attr.title]="selectedValue"
        >{{ selectedValue }}</div>
      <div class="md-menu-item__arrow">
        <md-icon name="icon-arrow-right_16"></md-icon>
      </div>
    </ng-template>
  `,
                host: {
                    'class': 'md-menu-item',
                    '(click)': 'onClick($event)',
                    '(keydown)': 'onKeydown($event)',
                }
            }] }
];
/** @nocollapse */
MenuItemComponent.ctorParameters = () => [
    { type: ElementRef },
    { type: FocusMonitor },
    { type: MenuComponent, decorators: [{ type: Optional }] }
];
MenuItemComponent.propDecorators = {
    active: [{ type: Input }],
    isHeader: [{ type: Input }],
    selectedValue: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class MenuTriggerDirective {
    /**
     * @param {?} _overlay
     * @param {?} _element
     * @param {?} _viewContainerRef
     * @param {?} _parentMenu
     * @param {?} _menuItemInstance
     * @param {?=} _focusMonitor
     */
    constructor(_overlay, _element, _viewContainerRef, _parentMenu, _menuItemInstance, _focusMonitor) {
        this._overlay = _overlay;
        this._element = _element;
        this._viewContainerRef = _viewContainerRef;
        this._parentMenu = _parentMenu;
        this._menuItemInstance = _menuItemInstance;
        this._focusMonitor = _focusMonitor;
        this.menuOpened = new EventEmitter();
        this.menuClosed = new EventEmitter();
        this._menuOpen = false;
        this._openedBy = null;
        this._overlayRef = null;
        this._closingActionsSubscription = Subscription.EMPTY;
        this._menuCloseSubscription = Subscription.EMPTY;
        if (_menuItemInstance) {
            _menuItemInstance.triggersSubmenu = this.triggersSubmenu();
        }
    }
    /**
     * @return {?}
     */
    get menu() { return this._menu; }
    /**
     * @param {?} menu
     * @return {?}
     */
    set menu(menu) {
        if (menu === this._menu) {
            return;
        }
        this._menu = menu;
        this._menuCloseSubscription.unsubscribe();
        if (menu) {
            this._menuCloseSubscription = menu.closed.asObservable().subscribe((/**
             * @param {?} reason
             * @return {?}
             */
            reason => {
                this._destroyMenu();
                if (reason === 'click' && this._parentMenu) {
                    this._parentMenu.closed.emit(reason);
                }
            }));
        }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this._overlayRef) {
            this._overlayRef.dispose();
            this._overlayRef = null;
        }
        this._cleanUpSubscriptions();
        this._closingActionsSubscription.unsubscribe();
    }
    /**
     * @return {?}
     */
    get menuOpen() {
        return this._menuOpen;
    }
    /**
     * @return {?}
     */
    triggersSubmenu() {
        return !!(this._menuItemInstance && this._parentMenu);
    }
    /**
     * @return {?}
     */
    toggleMenu() {
        return this._menuOpen ? this.closeMenu() : this.openMenu();
    }
    /**
     * @return {?}
     */
    openMenu() {
        if (this._menuOpen) {
            return;
        }
        /** @type {?} */
        const overlayRef = this._createOverlay();
        /** @type {?} */
        const overlayConfig = overlayRef.getConfig();
        /** @type {?} */
        const positionStrategy = (/** @type {?} */ (overlayConfig.positionStrategy));
        this._setPosition(positionStrategy);
        overlayConfig.hasBackdrop = this.menu.hasBackdrop == null ? !this.triggersSubmenu() : this.menu.hasBackdrop;
        overlayRef.attach(this._getPortal());
        this._closingActionsSubscription = this._menuClosingActions().subscribe((/**
         * @return {?}
         */
        () => this.closeMenu()));
        this._initMenu();
    }
    /**
     * @return {?}
     */
    closeMenu() {
        this.menu.closed.emit();
    }
    /**
     * @param {?=} origin
     * @return {?}
     */
    focus(origin = 'program') {
        if (this._focusMonitor) {
            this._focusMonitor.focusVia(this._element, origin);
            if (this._menuItemInstance) {
                this._menuItemInstance.focus();
            }
        }
        else {
            this._element.nativeElement.focus();
        }
    }
    /**
     * @private
     * @return {?}
     */
    _destroyMenu() {
        if (!this._overlayRef || !this.menuOpen) {
            return;
        }
        this._closingActionsSubscription.unsubscribe();
        this._overlayRef.detach();
        this._resetMenu();
    }
    /**
     * @private
     * @return {?}
     */
    _initMenu() {
        this.menu.parentMenu = this.triggersSubmenu() ? this._parentMenu : undefined;
        this._setIsMenuOpen(true);
        this.menu.focusFirstItem(this._openedBy || 'program');
    }
    /**
     * @private
     * @return {?}
     */
    _resetMenu() {
        this._setIsMenuOpen(false);
        if (!this._openedBy) {
            this.focus();
        }
        else if (!this.triggersSubmenu()) {
            this.focus(this._openedBy);
        }
        this._openedBy = null;
    }
    /**
     * @private
     * @param {?} isOpen
     * @return {?}
     */
    _setIsMenuOpen(isOpen) {
        this._menuOpen = isOpen;
        this._menuOpen ? this.menuOpened.emit() : this.menuClosed.emit();
        if (this.triggersSubmenu()) {
            this._menuItemInstance.active = isOpen;
        }
    }
    /**
     * @private
     * @return {?}
     */
    _createOverlay() {
        if (!this._overlayRef) {
            /** @type {?} */
            const config = this._getOverlayConfig();
            this._subscribeToPositions((/** @type {?} */ (config.positionStrategy)));
            this._overlayRef = this._overlay.create(config);
        }
        return this._overlayRef;
    }
    /**
     * @private
     * @return {?}
     */
    _getOverlayConfig() {
        return new OverlayConfig({
            positionStrategy: this._overlay.position()
                .flexibleConnectedTo(this._element)
                .withLockedPosition()
                .withTransformOriginOn('.md-event-overlay__children'),
            backdropClass: 'cdk-overlay-transparent-backdrop',
        });
    }
    /**
     * @private
     * @param {?} position
     * @return {?}
     */
    _subscribeToPositions(position) {
        position.positionChanges.subscribe((/**
         * @param {?} change
         * @return {?}
         */
        change => {
            /** @type {?} */
            const overlayX = change.connectionPair.overlayX;
            /** @type {?} */
            const overlayY = change.connectionPair.overlayY;
            this._setArrowPosition(overlayX, overlayY);
        }));
    }
    /**
     * @private
     * @param {?} overlayX
     * @param {?} overlayY
     * @return {?}
     */
    _setArrowPosition(overlayX, overlayY) {
        if (this.menu.showArrow) {
            /** @type {?} */
            const side = this.menu.direction.split('-')[0];
            /** @type {?} */
            const menuWrapper = (/** @type {?} */ (this._overlayRef.hostElement.querySelector('.md-menu-overlay')));
            /** @type {?} */
            const arrow = (/** @type {?} */ (this._overlayRef.hostElement.querySelector('.md-event-overlay__arrow')));
            /** @type {?} */
            const menu = (/** @type {?} */ (this._overlayRef.hostElement.querySelector('.md-event-overlay__children')));
            if (['top', 'bottom'].includes(side) && ['top', 'bottom'].includes(overlayY)) {
                /** @type {?} */
                const minWidth = Math.min(this._element.nativeElement.offsetWidth, menu.offsetWidth);
                switch (overlayX) {
                    case 'start':
                        arrow.style['left'] = `${minWidth / 2}px`;
                        break;
                    case 'end':
                        arrow.style['left'] = `${menu.offsetWidth - minWidth / 2}px`;
                        break;
                    case 'center':
                        arrow.style['left'] = `${menu.offsetWidth / 2}px`;
                        break;
                }
                if (overlayY === 'top') {
                    menu.style['margin-top'] = `${arrow.offsetHeight}px`;
                    menu.style['margin-bottom'] = 'auto';
                    arrow.style['top'] = '1px';
                    arrow.style['bottom'] = 'auto';
                }
                else {
                    menu.style['margin-bottom'] = `${arrow.offsetHeight}px`;
                    menu.style['margin-top'] = 'auto';
                    arrow.style['bottom'] = '1px';
                    arrow.style['top'] = 'auto';
                }
            }
            if (['left', 'right'].includes(side) && ['start', 'end'].includes(overlayX)) {
                /** @type {?} */
                const minHeight = Math.min(this._element.nativeElement.offsetHeight, menu.offsetHeight);
                switch (overlayY) {
                    case 'top':
                        arrow.style['top'] = `${minHeight / 2}px`;
                        break;
                    case 'bottom':
                        arrow.style['top'] = `${menu.offsetHeight - minHeight / 2}px`;
                        break;
                    case 'center':
                        arrow.style['top'] = `${menu.offsetHeight / 2}px`;
                        break;
                }
                if (overlayX === 'start') {
                    menu.style['margin-left'] = `${arrow.offsetWidth}px`;
                    menu.style['margin-right'] = 'auto';
                    arrow.style['left'] = '1px';
                    arrow.style['right'] = 'auto';
                }
                else {
                    menu.style['margin-right'] = `${arrow.offsetWidth}px`;
                    menu.style['margin-left'] = 'auto';
                    arrow.style['right'] = '1px';
                    arrow.style['left'] = 'auto';
                }
            }
            /** @type {?} */
            let newSide;
            if (['top', 'bottom'].includes(side)) {
                if (overlayY === 'top') {
                    newSide = 'bottom';
                }
                else {
                    newSide = 'top';
                }
            }
            else {
                if (overlayX === 'start') {
                    newSide = 'right';
                }
                else {
                    newSide = 'left';
                }
            }
            menuWrapper.classList.remove('md-event-overlay--top');
            menuWrapper.classList.remove('md-event-overlay--bottom');
            menuWrapper.classList.remove('md-event-overlay--left');
            menuWrapper.classList.remove('md-event-overlay--right');
            menuWrapper.classList.add(`md-event-overlay--${newSide}`);
        }
    }
    /**
     * @private
     * @param {?} positionStrategy
     * @return {?}
     */
    _setPosition(positionStrategy) {
        const [side, pos] = this.menu.direction.split('-');
        let [originX, originFallbackX, overlayX, overlayFallbackX, originFallbackX2, overlayFallbackX2,] = [];
        let [originY, originFallbackY, overlayY, overlayFallbackY, originFallbackY2, overlayFallbackY2,] = [];
        /** @type {?} */
        const offsetY = 0;
        switch (side) {
            case 'top':
                [originY, originFallbackY] = ['top', 'bottom'];
                [overlayY, overlayFallbackY] = ['bottom', 'top'];
                break;
            case 'bottom':
                [originY, originFallbackY] = ['bottom', 'top'];
                [overlayY, overlayFallbackY] = ['top', 'bottom'];
                break;
            case 'left':
                [originX, originFallbackX] = ['start', 'end'];
                [overlayX, overlayFallbackX] = ['end', 'start'];
                break;
            case 'right':
                [originX, originFallbackX] = ['end', 'start'];
                [overlayX, overlayFallbackX] = ['start', 'end'];
                break;
        }
        switch (pos) {
            case 'left':
                [originX, originFallbackX] = [overlayX, overlayFallbackX] = ['start', 'end'];
                break;
            case 'right':
                [originX, originFallbackX] = [overlayX, overlayFallbackX] = ['end', 'start'];
                break;
            case 'top':
                [originY, originFallbackY] = [overlayY, overlayFallbackY] = ['top', 'bottom'];
                break;
            case 'bottom':
                [originY, originFallbackY] = [overlayY, overlayFallbackY] = ['bottom', 'top'];
                break;
            case 'center':
                if (['bottom', 'top'].includes(side)) {
                    originX = overlayX = 'center';
                    originFallbackX = overlayFallbackX = 'start';
                    originFallbackX2 = overlayFallbackX2 = 'end';
                }
                else {
                    originY = overlayY = 'center';
                    originFallbackY = overlayFallbackY = 'top';
                    originFallbackY2 = overlayFallbackY2 = 'bottom';
                }
                break;
        }
        if (this.triggersSubmenu()) {
            if (side !== 'left') {
                [originX, originFallbackX] = ['end', 'start'];
                [overlayX, overlayFallbackX] = ['start', 'end'];
            }
            else {
                [originX, originFallbackX] = ['start', 'end'];
                [overlayX, overlayFallbackX] = ['end', 'start'];
            }
            originY = originFallbackY = overlayY = overlayFallbackY = 'top';
        }
        /** @type {?} */
        let positions = [
            { originX, originY, overlayX, overlayY, offsetY },
            {
                originX: originFallbackX,
                originY,
                overlayX: overlayFallbackX,
                overlayY, offsetY
            },
            {
                originX,
                originY: originFallbackY,
                overlayX,
                overlayY: overlayFallbackY,
                offsetY: -offsetY
            },
            {
                originX: originFallbackX,
                originY: originFallbackY,
                overlayX: overlayFallbackX,
                overlayY: overlayFallbackY,
                offsetY: -offsetY
            }
        ];
        if (originFallbackX2 && overlayFallbackX2 && !this.triggersSubmenu()) {
            positions = positions.concat([
                {
                    originX: originFallbackX2,
                    originY,
                    overlayX: overlayFallbackX2,
                    overlayY, offsetY
                },
                {
                    originX: originFallbackX2,
                    originY: originFallbackY,
                    overlayX: overlayFallbackX2,
                    overlayY: overlayFallbackY,
                    offsetY: -offsetY
                }
            ]);
        }
        if (originFallbackY2 && overlayFallbackY2 && !this.triggersSubmenu()) {
            positions = positions.concat([
                {
                    originX,
                    originY: originFallbackY2,
                    overlayX,
                    overlayY: overlayFallbackY2,
                    offsetY: -offsetY
                },
                {
                    originX: originFallbackX,
                    originY: originFallbackY2,
                    overlayX: overlayFallbackX,
                    overlayY: overlayFallbackY2,
                    offsetY: -offsetY
                }
            ]);
        }
        positionStrategy.withPositions(positions);
    }
    /**
     * @private
     * @return {?}
     */
    _cleanUpSubscriptions() {
        this._closingActionsSubscription.unsubscribe();
    }
    /**
     * @private
     * @return {?}
     */
    _menuClosingActions() {
        /** @type {?} */
        const backdrop = this._overlayRef.backdropClick();
        /** @type {?} */
        const detachments = this._overlayRef.detachments();
        if (this._parentMenu) {
            /** @type {?} */
            const parentClose = this._parentMenu.closed;
            return merge(backdrop, detachments, parentClose);
        }
        else {
            return merge(backdrop, detachments);
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onClick(event) {
        if (this.triggersSubmenu()) {
            event.stopPropagation();
            this.openMenu();
        }
        else {
            this.toggleMenu();
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onKeydown(event) {
        if (this.triggersSubmenu() && (event.code === 'ArrowRight' ||
            event.code === 'ArrowLeft' ||
            event.code === 'Enter' ||
            event.code === 'Space')) {
            this.openMenu();
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onMousedown(event) {
        this._openedBy = event.button === 0 ? 'mouse' : null;
        if (this.triggersSubmenu()) {
            event.preventDefault();
        }
    }
    /**
     * @private
     * @return {?}
     */
    _getPortal() {
        if (!this._portal || this._portal.templateRef !== this.menu.templateRef) {
            this._portal = new TemplatePortal(this.menu.templateRef, this._viewContainerRef);
        }
        return this._portal;
    }
}
MenuTriggerDirective.decorators = [
    { type: Directive, args: [{
                selector: `[mdMenuTriggerFor]`,
                host: {
                    'aria-haspopup': 'true',
                    '[attr.aria-expanded]': 'menuOpen || null',
                    '(click)': 'onClick($event)',
                    '(keydown)': 'onKeydown($event)',
                    '(mousedown)': 'onMousedown($event)',
                }
            },] }
];
/** @nocollapse */
MenuTriggerDirective.ctorParameters = () => [
    { type: Overlay },
    { type: ElementRef },
    { type: ViewContainerRef },
    { type: MenuComponent, decorators: [{ type: Optional }] },
    { type: MenuItemComponent, decorators: [{ type: Optional }, { type: Self }] },
    { type: FocusMonitor }
];
MenuTriggerDirective.propDecorators = {
    menu: [{ type: Input, args: ['mdMenuTriggerFor',] }],
    menuOpened: [{ type: Output }],
    menuClosed: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class MenuModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: MenuModule,
            providers: [],
        };
    }
}
MenuModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    IconModule,
                    ListItemModule,
                    OverlayModule,
                ],
                declarations: [
                    MenuComponent,
                    MenuContentComponent,
                    MenuItemComponent,
                    MenuTriggerDirective,
                ],
                exports: [
                    MenuComponent,
                    MenuContentComponent,
                    MenuItemComponent,
                    MenuTriggerDirective,
                ],
                schemas: [CUSTOM_ELEMENTS_SCHEMA],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @template T
 */
class ModalRef {
    /**
     * @param {?} overlay
     * @param {?} content
     * @param {?} data
     * @param {?} backdropClickExit
     */
    constructor(overlay, content, data, backdropClickExit) {
        this.overlay = overlay;
        this.content = content;
        this.data = data;
        this.backdropClickExit = backdropClickExit;
        this.onHide = new Subject();
        this.onHide$ = this.onHide.asObservable();
        if (backdropClickExit) {
            overlay.backdropClick().subscribe((/**
             * @return {?}
             */
            () => {
                this._close('backdropClick', null);
            }));
        }
    }
    /**
     * @param {?=} data
     * @return {?}
     */
    close(data) {
        this._close('close', data);
    }
    /**
     * @private
     * @param {?} type
     * @param {?=} data
     * @return {?}
     */
    _close(type, data) {
        this.overlay.detach();
        this.onHide.next({
            type,
            data
        });
        this.onHide.complete();
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ModalComponent {
    /**
     * @param {?} modalRef
     * @param {?} _elRef
     * @param {?} _focusTrapFactory
     */
    constructor(modalRef, _elRef, _focusTrapFactory) {
        this.modalRef = modalRef;
        this._elRef = _elRef;
        this._focusTrapFactory = _focusTrapFactory;
        /**
         * \@prop Determines the visibility and ability to edit the backdrop of the Modal | true
         */
        this.backdrop = true;
        /**
         * \@prop size of the modal | 'default'
         */
        this.sizeType = 'default';
        /**
         * \@prop htmlId for modal | 'md-modal'
         */
        this.htmlId = 'md-modal';
        /**
         * \@prop ariaLabel for modal | ''
         */
        this.ariaLabel = '';
    }
    /**
     * \@propptional css class names | ''
     * @param {?} value
     * @return {?}
     */
    set class(value) {
        this._classList = value;
    }
    /**
     * @return {?}
     */
    get class() {
        return this._classList;
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        this._trapFocus();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.content = this.modalRef.content;
        this.context = {
            close: this.modalRef.close.bind(this.modalRef)
        };
    }
    /**
     * @private
     * @return {?}
     */
    _trapFocus() {
        // creates a focus trap region
        /** @type {?} */
        const focusTrap = this._focusTrapFactory.create(this._elRef.nativeElement);
        // Moves the focus in the form (by default the first field)
        focusTrap.focusInitialElement();
    }
}
ModalComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-modal',
                template: `
    <div
      role="dialog"
      id="{{htmlId}}"
      class="md-modal md-modal--{{sizeType}} in {{class}}"
      attr.aria-labelledby="{{ariaLabel}}"
      aria-modal="true"
    >
      <div class="md-modal__content" cdkTrapFocus >
        <div class="md-modal__flex-container">
          <ng-content></ng-content>
        </div>
      </div>
    </div>
  `,
                styles: [`
  .md-modal.md-modal--full {
      position: static;
    }
  `]
            }] }
];
/** @nocollapse */
ModalComponent.ctorParameters = () => [
    { type: ModalRef },
    { type: ElementRef },
    { type: FocusTrapFactory }
];
ModalComponent.propDecorators = {
    backdrop: [{ type: Input }],
    class: [{ type: Input }],
    sizeType: [{ type: Input }],
    htmlId: [{ type: Input }],
    ariaLabel: [{ type: Input }],
    data: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ModalBodyComponent {
    constructor() {
        /**
         * \@prop css class names | '' | ''
         */
        this.class = '';
    }
    /**
     * @return {?}
     */
    get className() {
        return 'md-modal__body' + `${(this.class && ` ${this.class}`) || ''}` + ``;
    }
}
ModalBodyComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-modal-body',
                template: `
    <ng-content></ng-content>
  `
            }] }
];
ModalBodyComponent.propDecorators = {
    class: [{ type: Input }],
    className: [{ type: HostBinding, args: ['class',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ModalFooterComponent {
    constructor() {
        /**
         * \@prop css class names | '' | ''
         */
        this.class = '';
    }
    /**
     * @return {?}
     */
    get className() {
        return ('md-modal__footer' + `${(this.class && ` ${this.class}`) || ''}` + ``);
    }
}
ModalFooterComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-modal-footer',
                template: `
    <ng-content></ng-content>
  `
            }] }
];
ModalFooterComponent.propDecorators = {
    class: [{ type: Input }],
    className: [{ type: HostBinding, args: ['class',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ModalHeaderComponent {
    /**
     * @param {?} modalRef
     */
    constructor(modalRef) {
        this.modalRef = modalRef;
        /**
         * \@prop Optional css class string | ''
         */
        this.class = '';
        /**
         * \@prop ModalHeader label text | ''
         */
        this.headerLabel = '';
        /**
         * \@prop Modal message | ''
         */
        this.message = '';
        /**
         * \@prop show/hide close button | true
         */
        this.showCloseButton = true;
    }
    /**
     * @return {?}
     */
    get className() {
        return ('md-modal__header' + `${(this.class && ` ${this.class}`) || ''}` + ``);
    }
    /**
     * @param {?} _
     * @return {?}
     */
    handleKeydown(_) {
        this.close();
    }
    /**
     * @return {?}
     */
    close() {
        this.modalRef.close();
    }
}
ModalHeaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-modal-header',
                template: `
  <span class="md-modal__title">{{headerLabel}}</span>
  <span *ngIf="message" class="md-modal__message">{{
    message
  }}</span>
  <button
    *ngIf="showCloseButton"
    class="md-close md-modal__close"
    (click)="close()"
    (keydown)="handleKeydown($event)"
    aria-label="close"
  >
  </button>
  `
            }] }
];
/** @nocollapse */
ModalHeaderComponent.ctorParameters = () => [
    { type: ModalRef }
];
ModalHeaderComponent.propDecorators = {
    class: [{ type: Input }],
    headerLabel: [{ type: Input }],
    message: [{ type: Input }],
    showCloseButton: [{ type: Input }],
    className: [{ type: HostBinding, args: ['class',] }],
    handleKeydown: [{ type: HostListener, args: ['document:keydown.escape', ['$event'],] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ModalContainerComponent {
    /**
     * @param {?} modalRef
     */
    constructor(modalRef) {
        this.modalRef = modalRef;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.content = this.modalRef.content;
        this.context = {
            close: this.modalRef.close.bind(this.modalRef)
        };
    }
}
ModalContainerComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-modal-container',
                template: `
  <ng-container>
    <ng-container *ngComponentOutlet="content"></ng-container>
  </ng-container>
  `
            }] }
];
/** @nocollapse */
ModalContainerComponent.ctorParameters = () => [
    { type: ModalRef }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ModalService {
    /**
     * @param {?} overlay
     * @param {?} injector
     */
    constructor(overlay, injector) {
        this.overlay = overlay;
        this.injector = injector;
    }
    /**
     * @param {?} __0
     * @return {?}
     */
    open({ content, data, backdrop, backdropClickExit, }) {
        // set defaults if not set
        if (typeof backdropClickExit === 'undefined') {
            backdropClickExit = true;
        }
        /** @type {?} */
        const strategy = this.overlay
            .position()
            .global()
            .centerHorizontally()
            .centerVertically();
        /** @type {?} */
        const config = new OverlayConfig({
            hasBackdrop: true,
            positionStrategy: strategy,
        });
        /** @type {?} */
        const overlayRef = this.overlay.create(config);
        /** @type {?} */
        const modalRef = new ModalRef(overlayRef, content, data, backdropClickExit);
        /** @type {?} */
        const injector = this.createInjector(modalRef, this.injector);
        overlayRef.attach(new ComponentPortal(ModalContainerComponent, null, injector));
        return modalRef;
    }
    /**
     * @param {?} modalRef
     * @param {?} injector
     * @return {?}
     */
    createInjector(modalRef, injector) {
        /** @type {?} */
        const tokens = new WeakMap([[ModalRef, modalRef]]);
        return new PortalInjector(injector, tokens);
    }
}
ModalService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
ModalService.ctorParameters = () => [
    { type: Overlay },
    { type: Injector }
];
/** @nocollapse */ ModalService.ngInjectableDef = defineInjectable({ factory: function ModalService_Factory() { return new ModalService(inject(Overlay), inject(INJECTOR)); }, token: ModalService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ModalModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: ModalModule,
            providers: [],
        };
    }
}
ModalModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    ModalComponent,
                    ModalBodyComponent,
                    ModalFooterComponent,
                    ModalHeaderComponent,
                    ModalContainerComponent
                ],
                imports: [
                    CommonModule,
                    A11yModule,
                    OverlayModule
                ],
                exports: [
                    ModalComponent,
                    ModalBodyComponent,
                    ModalFooterComponent,
                    ModalHeaderComponent,
                    ModalContainerComponent
                ],
                entryComponents: [ModalContainerComponent],
                providers: [ModalService],
                schemas: [CUSTOM_ELEMENTS_SCHEMA]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// tslint:disable:no-use-before-declare
/** @type {?} */
const CUSTOM_RADIO_VALUE_ACCESSOR = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef((/**
     * @return {?}
     */
    () => RadioComponent)),
    multi: true,
};
// tslint:enable:no-use-before-declare
class RadioComponent {
    /**
     * @param {?} cdr
     * @param {?} elementRef
     */
    constructor(cdr, elementRef) {
        this.cdr = cdr;
        this.elementRef = elementRef;
        /**
         * \@option Optional CSS class name on individual radio input | ''
         */
        this.className = '';
        /**
         * \@option Sets the attribute disabled to the Radio | false
         */
        this.disabled = false;
        /**
         * \@option Help Text to appear under the radio | ''
         */
        this.helpText = '';
        /**
         * \@option Unique HTML ID used for tying label to HTML input for automated testing
         */
        this.htmlId = '';
        /**
         * \@option Radio label text | ''
         */
        this.label = '';
        /**
         * \@option Radio name for group | ''
         */
        this.name = '';
        /**
         * \@option String value that corresponds with Radio button | ''
         */
        this.value = '';
        /**
         * \@option Callback function invoked when user clicks the Radio button | null
         */
        this.radioClick = new EventEmitter();
        this.onChangeCallback = (/**
         * @return {?}
         */
        () => { });
        this.onTouchedCallback = (/**
         * @return {?}
         */
        () => { });
    }
    /**
     * @param {?} nestedLevel
     * @return {?}
     */
    set nestedLevel(nestedLevel) {
        if (this._nestedLevel) {
            this.elementRef.nativeElement.classList.remove(`md-input--nested-${this._nestedLevel}`);
        }
        this.elementRef.nativeElement.classList.add(`md-input--nested-${nestedLevel}`);
        this._nestedLevel = nestedLevel;
    }
    /**
     * @param {?} e
     * @return {?}
     */
    onToggle(e) {
        if (!this.disabled) {
            this.radioViewChild.nativeElement.checked = true;
            this.checked = true;
            this.onChangeCallback(this.value);
            this.radioClick.emit(e);
        }
    }
    /**
     * @param {?} value
     * @return {?}
     */
    writeValue(value) {
        this.checked = value === this.value;
        if (this.radioViewChild.nativeElement) {
            this.radioViewChild.nativeElement.checked = this.checked;
        }
        this.cdr.markForCheck();
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnTouched(fn) {
        this.onTouchedCallback = fn;
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnChange(fn) {
        this.onChangeCallback = fn;
    }
    /**
     * @param {?} isDisabled
     * @return {?}
     */
    setDisabledState(isDisabled) {
        this.disabled = isDisabled;
    }
}
RadioComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-radio',
                template: `
    <input
      class="md-input md-radio__input"
      [ngClass]="[className]"
      type="radio"
      #radioInput
      (change)="onToggle($event)"
      [attr.id]="htmlId"
      [attr.name]="name"
      [attr.tabindex]="tabIndex"
      [attr.value]="value"
      [checked]="checked"
      [disabled]="disabled"
    />

    <label class="md-radio__label" (radioClick)="onToggle($event)" [attr.for]="htmlId">
      <span>{{ label }}</span>
    </label>
    <md-input-helper *ngIf="helpText">{{ helpText }}</md-input-helper>
    <ng-content></ng-content>
  `,
                providers: [CUSTOM_RADIO_VALUE_ACCESSOR],
                host: {
                    class: 'md-input-container md-radio',
                }
            }] }
];
/** @nocollapse */
RadioComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: ElementRef }
];
RadioComponent.propDecorators = {
    className: [{ type: Input }],
    disabled: [{ type: Input }],
    helpText: [{ type: Input }],
    htmlId: [{ type: Input }],
    label: [{ type: Input }],
    name: [{ type: Input }],
    tabIndex: [{ type: Input }],
    value: [{ type: Input }],
    nestedLevel: [{ type: Input }],
    radioClick: [{ type: Output }],
    radioViewChild: [{ type: ViewChild, args: ['radioInput',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class RadioModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: RadioModule,
            providers: [],
        };
    }
}
RadioModule.decorators = [
    { type: NgModule, args: [{
                declarations: [RadioComponent],
                imports: [CommonModule, FormsModule, ReactiveFormsModule, InputHelperModule],
                exports: [RadioComponent],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// tslint:disable:no-use-before-declare
/** @type {?} */
const CUI_SLIDER_VALUE_ACCESSOR = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef((/**
     * @return {?}
     */
    () => SliderComponent)),
    multi: true,
};
class SliderComponent {
    /**
     * @param {?} changeDetectorRef
     */
    constructor(changeDetectorRef) {
        this.changeDetectorRef = changeDetectorRef;
        /**
         * \@option Determines if minimum pointer can cross over maximum pointer | false
         */
        this.canCross = false;
        /**
         * \@option Set the attribute disabled to Slider | false
         */
        this.disabled = false;
        /**
         * \@option Set the initial minimum value | 0
         */
        this.min = 0;
        /**
         * \@option Set visual step measurement | 1
         */
        this.step = 1;
        /**
         * \@option Set increment of x-axis labels | 0
         */
        this.tick = 0;
        /**
         * Event emitted when change a pointer position
         */
        this.change = new EventEmitter();
        this._value = 0;
    }
    /**
     * \@option Set either maximum pointer value or a combination of high and low pointer values | 0
     * @return {?}
     */
    get value() {
        return this._value;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set value(value) {
        if (this._value !== value) {
            this._value = value;
            this.sliderLow =
                (isObject(this.value) && ((/** @type {?} */ (this.value))).low) || this.min;
            this.sliderHigh =
                (isObject(this.value) && ((/** @type {?} */ (this.value))).high) ||
                    ((/** @type {?} */ (this.value)));
            this.returnCurrentValues();
            this.changeDetectorRef.markForCheck();
        }
    }
    /**
     * @return {?}
     */
    get sliderLow() {
        return this._sliderLow;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set sliderLow(value) {
        this._sliderLow = value;
    }
    /**
     * @return {?}
     */
    get sliderHigh() {
        return this._sliderHigh;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set sliderHigh(value) {
        this._sliderHigh = value;
    }
    /**
     * @return {?}
     */
    get sliderLowPosition() {
        return ((this.sliderLow - this.min) / (this.max - this.min)) * 100;
    }
    /**
     * @return {?}
     */
    get sliderHighPosition() {
        return ((this.sliderHigh - this.min) / (this.max - this.min)) * 100;
    }
    /**
     * @private
     * @param {?} _
     * @return {?}
     */
    _change(_) { }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (!this.max) {
            throw new Error('Initial maximum(max) value is required');
        }
        this.isObject = isObject;
        this.scale = [this.min, this.max];
        this.getScale(this.min, this.max, this.tick);
        this.getSelectionWidth();
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        this.setScalePos(this.scale, this.min, this.max);
    }
    /**
     * @param {?} value
     * @return {?}
     */
    writeValue(value) {
        if (value !== null) {
            this.value = value;
        }
    }
    /**
     * @param {?} disabled
     * @return {?}
     */
    setDisabledState(disabled) {
        this.disabled = disabled;
        this.changeDetectorRef.markForCheck();
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnChange(fn) {
        this._change = fn;
    }
    /**
     * @param {?} _
     * @return {?}
     */
    registerOnTouched(_) { }
    /**
     * @param {?} scale
     * @param {?} min
     * @param {?} max
     * @return {?}
     */
    setScalePos(scale, min, max) {
        this.ticksContainer.nativeElement
            .querySelectorAll('span')
            .forEach((/**
         * @param {?} child
         * @param {?} idx
         * @return {?}
         */
        (child, idx) => {
            /** @type {?} */
            const leftValue = `${((scale[idx] - min) / max) * 100}%`;
            child.style.left = `calc(${leftValue} - ${child.offsetWidth / 2}px)`;
        }));
    }
    /**
     * @param {?=} low
     * @param {?=} high
     * @param {?=} tick
     * @return {?}
     */
    getScale(low = 0, high, tick) {
        if (this.tick > 0) {
            /** @type {?} */
            let value = high;
            /** @type {?} */
            const ticksArray = [high];
            while (value > 0 && value - tick >= low) {
                value -= tick;
                ticksArray.unshift(Math.abs(Math.round(value / tick) * tick));
            }
            this.scale = ticksArray;
        }
    }
    /**
     * @return {?}
     */
    getSliderWidth() {
        return this.sliderBar.nativeElement.getBoundingClientRect().width;
    }
    /**
     * @return {?}
     */
    getStepWidth() {
        /** @type {?} */
        const maxValue = this.max - this.min;
        /** @type {?} */
        const maxWidth = this.getSliderWidth();
        return (this.step / maxValue) * maxWidth;
    }
    /**
     * @param {?} position
     * @return {?}
     */
    getSteps(position) {
        if (position.isKeyBoard) {
            return 1;
        }
        /** @type {?} */
        const diff = position.direction === 1
            ? position.to - position.from
            : position.from - position.to;
        if (diff < 0) {
            return 0;
        }
        /** @type {?} */
        const steps = diff / this.getStepWidth();
        return steps - Math.floor(steps) >= 0.5
            ? Math.ceil(steps)
            : Math.floor(steps);
    }
    /**
     * @param {?} pointerKey
     * @param {?} direction
     * @return {?}
     */
    getLimit(pointerKey, direction) {
        if (pointerKey === 'sliderLow') {
            return this.canCross
                ? direction === 1
                    ? this.max
                    : this.min
                : direction === 1
                    ? this.sliderHigh
                    : this.min;
        }
        else if (pointerKey === 'sliderHigh') {
            return this.canCross
                ? direction === 1
                    ? this.max
                    : this.min
                : direction === 1
                    ? this.max
                    : this.sliderLow;
        }
    }
    /**
     * @return {?}
     */
    returnCurrentValues() {
        this.getSelectionWidth();
        /** @type {?} */
        const value = isObject(this.value)
            ? {
                low: Math.min(this.sliderHigh, this.sliderLow),
                high: Math.max(this.sliderHigh, this.sliderLow),
            }
            : this.sliderHigh;
        this._change(value);
        this.change.emit(value);
    }
    /**
     * @param {?} key
     * @param {?} pixelMove
     * @param {?} limit
     * @return {?}
     */
    moveForward(key, pixelMove, limit) {
        /** @type {?} */
        const newPosition = this[key] + pixelMove <= limit ? this[key] + pixelMove : limit;
        this[key] = newPosition;
        this.returnCurrentValues();
    }
    /**
     * @param {?} key
     * @param {?} pixelMove
     * @param {?} limit
     * @return {?}
     */
    moveBack(key, pixelMove, limit) {
        /** @type {?} */
        const newPosition = this[key] - pixelMove >= limit ? this[key] - pixelMove : limit;
        this[key] = newPosition;
        this.returnCurrentValues();
    }
    /**
     * @param {?} key
     * @param {?} position
     * @return {?}
     */
    onSliderMove(key, position) {
        if (this.disabled) {
            return;
        }
        /** @type {?} */
        const limit = this.getLimit(key, position.direction);
        /** @type {?} */
        const pixelMove = this.getSteps(position) * this.step;
        position.direction === 1
            ? this.moveForward(key, pixelMove, limit)
            : this.moveBack(key, pixelMove, limit);
    }
    /**
     * @return {?}
     */
    getSelectionWidth() {
        /** @type {?} */
        const baseValue = Number.isInteger(this.sliderLow)
            ? this.sliderLow
            : this.min;
        this.selectionLeft =
            ((Math.min(baseValue, this.sliderHigh) - this.min) / this.max) * 100;
        this.selectionWidth =
            (Math.abs(this.sliderHigh - baseValue) / this.max) * 100;
    }
}
SliderComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-slider',
                template: `
    <span #sliderBar class="md-slider__bar"></span>
    <span
      class="md-slider__selection"
      [ngStyle]="{ 'left.%': selectionLeft, 'width.%': selectionWidth }"
    ></span>
    <md-slider-pointer
      *ngIf="isObject(value)"
      [position]="sliderLowPosition"
      (move)="onSliderMove('sliderLow', $event)"
    ></md-slider-pointer>
    <md-slider-pointer
      [position]="sliderHighPosition"
      (move)="onSliderMove('sliderHigh', $event)"
    ></md-slider-pointer>
    <div #ticksContainer>
      <span *ngFor="let tickValue of scale" class="md-slider__hashlabel">{{
        (translateFn && translateFn(tickValue)) || tickValue
      }}</span>
    </div>
  `,
                host: {
                    class: 'md-slider',
                    '[class.md-slider--disabled]': 'disabled',
                },
                providers: [CUI_SLIDER_VALUE_ACCESSOR]
            }] }
];
/** @nocollapse */
SliderComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
SliderComponent.propDecorators = {
    canCross: [{ type: Input }],
    disabled: [{ type: Input }],
    max: [{ type: Input }],
    min: [{ type: Input }],
    step: [{ type: Input }],
    tick: [{ type: Input }],
    translateFn: [{ type: Input }],
    value: [{ type: Input }],
    change: [{ type: Output }],
    sliderBar: [{ type: ViewChild, args: ['sliderBar',] }],
    ticksContainer: [{ type: ViewChild, args: ['ticksContainer',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SliderPointerComponent {
    /**
     * @param {?} elementRef
     * @param {?} _document
     */
    constructor(elementRef, _document) {
        this.elementRef = elementRef;
        /**
         * \@option Set Slider Pointer's position | 0
         */
        this.position = 0;
        /**
         * Event emitted when user moves the Slider Pointer
         */
        this.move = new EventEmitter();
        this.onMousemove = (/**
         * @param {?} event
         * @return {?}
         */
        (event) => {
            /** @type {?} */
            const xPos = event.clientX;
            /** @type {?} */
            const direction = this.getDirections(xPos);
            this.move.emit({
                from: this.elementRef.nativeElement.getBoundingClientRect().left,
                to: xPos,
                direction: direction,
                isKeyBoard: false,
            });
        });
        this.onMouseup = (/**
         * @param {?} _
         * @return {?}
         */
        (_) => {
            this._document.removeEventListener('mousemove', this.onMousemove);
            this._document.removeEventListener('mouseup', this.onMouseup);
        });
        this._document = _document;
    }
    /**
     * @return {?}
     */
    get left() {
        return this.position;
    }
    /**
     * @param {?} currentPos
     * @return {?}
     */
    getDirections(currentPos) {
        if (currentPos > this._previousPosition) {
            return 1;
        }
        return -1;
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onKeydown(event) {
        switch (event.code) {
            case 'ArrowUp':
            case 'ArrowRight':
                this.move.emit({
                    direction: 1,
                    isKeyBoard: true,
                });
                event.preventDefault();
                break;
            case 'ArrowDown':
            case 'ArrowLeft':
                this.move.emit({
                    direction: -1,
                    isKeyBoard: true,
                });
                event.preventDefault();
                break;
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onMousedown(event) {
        this._document.addEventListener('mousemove', this.onMousemove);
        this._document.addEventListener('mouseup', this.onMouseup);
        this._previousPosition = event.clientX;
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onTouchstart(event) {
        this._previousPosition = event.touches[0].clientX;
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onTouchmove(event) {
        /** @type {?} */
        const xPos = event.touches[0].clientX;
        /** @type {?} */
        const direction = this.getDirections(xPos);
        this.move.emit({
            from: this.elementRef.nativeElement.getBoundingClientRect().left,
            to: xPos,
            direction: direction,
            isKeyBoard: false,
        });
    }
}
SliderPointerComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-slider-pointer',
                template: ``,
                host: {
                    class: 'md-slider__pointer',
                    role: 'button',
                    tabindex: '0',
                    '(keydown)': 'onKeydown($event)',
                    '(mousedown)': 'onMousedown($event)',
                    '(touchstart)': 'onTouchstart($event)',
                    '(touchmove)': 'onTouchmove($event)',
                }
            }] }
];
/** @nocollapse */
SliderPointerComponent.ctorParameters = () => [
    { type: ElementRef },
    { type: undefined, decorators: [{ type: Inject, args: [DOCUMENT,] }] }
];
SliderPointerComponent.propDecorators = {
    position: [{ type: Input }],
    move: [{ type: Output }],
    left: [{ type: HostBinding, args: ['style.left.%',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SliderModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: SliderModule,
            providers: [],
        };
    }
}
SliderModule.decorators = [
    { type: NgModule, args: [{
                declarations: [SliderComponent, SliderPointerComponent],
                imports: [CommonModule],
                exports: [SliderComponent],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FilterUtils {
    /**
     * @param {?} valuesToFilter
     * @param {?} filterFieldKeys
     * @param {?} filterValue
     * @param {?} filterMode
     * @return {?}
     */
    static filter(valuesToFilter, filterFieldKeys, filterValue, filterMode) {
        /** @type {?} */
        const filteredItems = [];
        /** @type {?} */
        const filterText = filterValue.toLowerCase();
        /** @type {?} */
        let fieldValue;
        if (valuesToFilter) {
            for (const item of valuesToFilter) {
                for (const field of filterFieldKeys) {
                    if (field === 'label') {
                        fieldValue = String(item[field]).toLowerCase();
                    }
                    else {
                        fieldValue = String(item['value'][field]).toLowerCase();
                    }
                    if (FilterUtils[filterMode](fieldValue, filterText)) {
                        filteredItems.push(item);
                        break;
                    }
                }
            }
        }
        return filteredItems;
    }
    /**
     * @param {?} value
     * @param {?} filter
     * @return {?}
     */
    static startsWith(value, filter) {
        if (filter === undefined || filter === null || filter.trim() === '') {
            return true;
        }
        if (value === undefined || value === null) {
            return false;
        }
        /** @type {?} */
        const filterValue = filter.toString().toLowerCase();
        /** @type {?} */
        const stringValue = value.toString().toLowerCase();
        return stringValue.slice(0, filterValue.length) === filterValue;
    }
    /**
     * @param {?} value
     * @param {?} filter
     * @return {?}
     */
    static contains(value, filter) {
        if (filter === undefined || filter === null || (typeof filter === 'string' && filter.trim() === '')) {
            return true;
        }
        if (value === undefined || value === null) {
            return false;
        }
        /** @type {?} */
        const filterValue = filter.toString().toLowerCase();
        /** @type {?} */
        const stringValue = value.toString().toLowerCase();
        return stringValue.indexOf(filterValue) !== -1;
    }
    /**
     * @param {?} value
     * @param {?} filter
     * @return {?}
     */
    static endsWith(value, filter) {
        if (filter === undefined || filter === null || filter.trim() === '') {
            return true;
        }
        if (value === undefined || value === null) {
            return false;
        }
        /** @type {?} */
        const filterValue = filter.toString().toLowerCase();
        /** @type {?} */
        const stringValue = value.toString().toLowerCase();
        return stringValue.indexOf(filterValue, stringValue.length - filterValue.length) !== -1;
    }
    /**
     * @param {?} value
     * @param {?} filter
     * @return {?}
     */
    static equals(value, filter) {
        if (filter === undefined || filter === null || (typeof filter === 'string' && filter.trim() === '')) {
            return true;
        }
        if (value === undefined || value === null) {
            return false;
        }
        return value.toString().toLowerCase() === filter.toString().toLowerCase();
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SelectService {
    constructor() {
        this.selectionSource = new Subject();
        this.selectionSource$ = this.selectionSource.asObservable();
    }
    /**
     * @return {?}
     */
    onSelectionChange() {
        this.selectionSource.next();
    }
}
SelectService.decorators = [
    { type: Injectable }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TableService {
    constructor() {
        this.sortSource = new Subject(); // used for sort icon arrow
        // used for sort icon arrow
        this.sortSource$ = this.sortSource.asObservable();
        this.dataSource = new BehaviorSubject({});
        this.dataSource$ = this.dataSource.asObservable();
        this.dataCountSource = new Subject();
        this.dataCountSource$ = this.dataCountSource.asObservable();
        this.columnsSource = new Subject();
        this.columnsSource$ = this.columnsSource.asObservable();
        this.selectionSource = new Subject();
        this.selectionSource$ = this.selectionSource.asObservable();
    }
    /**
     * @param {?} sortObj
     * @return {?}
     */
    afterSort(sortObj) {
        this.sortSource.next(sortObj);
    }
    /**
     * @param {?} value
     * @return {?}
     */
    onDataChange(value) {
        this.dataSource.next(value);
    }
    /**
     * @param {?} value
     * @return {?}
     */
    onDataCountChange(value) {
        this.dataCountSource.next(value);
    }
    /**
     * @param {?} columns
     * @return {?}
     */
    onColumnsChange(columns) {
        this.columnsSource.next(columns);
    }
    /**
     * @return {?}
     */
    onSelectionChange() {
        this.selectionSource.next();
    }
    /**
     * @param {?} value
     * @param {?} rowIndex
     * @return {?}
     */
    onSelectChange(value, rowIndex) {
        this.dataSource.value[rowIndex].status = value.status;
    }
}
TableService.decorators = [
    { type: Injectable }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TemplateNameDirective {
    /**
     * @param {?} template
     */
    constructor(template) {
        this.template = template;
    }
    /**
     * @return {?}
     */
    getType() {
        return this.name;
    }
}
TemplateNameDirective.decorators = [
    { type: Directive, args: [{
                selector: '[mdTemplateName]',
                host: {}
            },] }
];
/** @nocollapse */
TemplateNameDirective.ctorParameters = () => [
    { type: TemplateRef }
];
TemplateNameDirective.propDecorators = {
    type: [{ type: Input }],
    name: [{ type: Input, args: ['mdTemplateName',] }]
};
class SharedModule {
}
SharedModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                exports: [TemplateNameDirective],
                declarations: [TemplateNameDirective]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const SELECT_VALUE_ACCESSOR = {
    provide: NG_VALUE_ACCESSOR,
    // tslint:disable-next-line: no-use-before-declare
    useExisting: forwardRef((/**
     * @return {?}
     */
    () => SelectComponent)),
    multi: true
};
class SelectChange {
    /**
     * @param {?} source
     * @param {?} value
     */
    constructor(source, value) {
        this.source = source;
        this.value = value;
    }
}
class SelectComponent {
    /**
     * @param {?} selectService
     * @param {?} tableService
     * @param {?} el
     * @param {?} cd
     */
    constructor(selectService, tableService, el, cd) {
        this.selectService = selectService;
        this.tableService = tableService;
        this.el = el;
        this.cd = cd;
        this.overlayOpen = false;
        this.anchorWidth = null;
        this.selectionKeys = {}; // for adding and removing to multi-selection
        /**
         * \@prop set the scroll height of the overlay | ''
         */
        this.scrollHeight = '22rem';
        /**
         * \@prop show the filter search | false
         */
        this.filter = false;
        /**
         * \@prop set which key or keys the filter will use, filtering by multiple keys example: '[name, id]' | 'label'
         */
        this.filterBy = 'label';
        /**
         * \@prop set how the string should be filtered | 'contains'
         */
        this.filterMode = 'contains';
        /**
         * \@prop set the filter search placeholder | ''
         */
        this.filterPlaceholder = '';
        /**
         * \@prop set the aria-label on the filter input | ''
         */
        this.ariaFilterLabel = '';
        /**
         * \@prop dataKey can be used to find selected options from multi-select, otherwise findIndex will run
         */
        this.dataKey = null;
        /**
         * \@prop message to show when filter returns null | 'No Results Found'
         */
        this.noResultsMessage = 'No Results Found';
        /**
         * \@prop add optional css class to the overlay | null
         */
        this.overlayClass = null;
        /**
         * \@prop add search icon on the filter search input | true
         */
        this.hasSearchIcon = true;
        /**
         * \@prop set the inline style of the select button | null
         */
        this.buttonStyle = null;
        /**
         * \@prop Optional CSS button class name | ''
         */
        this.buttonClass = '';
        /**
         * \@prop Optional CSS class on each select option
         */
        this.optionClass = '';
        /**
         * \@prop Set the default value for the select | ''
         */
        this.defaultValue = '';
        /**
         * \@prop Disable the Select Component | false
         */
        this.disabled = false;
        /**
         * \@prop Set ID for Select Component | null
         */
        this.id = uniqueId('md-select-');
        /**
         * \@prop Optional prop to know if user is able to select multiple options | false
         */
        this.isMulti = false;
        /**
         * \@prop Optional prop to to set the setTimeout duration for closing the panel | false
         */
        this.closeDuration = 150;
        /**
         * \@prop emitter to fire the select option value change
         */
        this.handleChange = new EventEmitter();
        /**
         * \@prop emitter to fire after showing the overlay select options panel
         */
        this.handleShow = new EventEmitter();
        /**
         * \@prop emit function when multi-checked selection changes
         */
        this.selectionChange = new EventEmitter();
        /**
         * \@prop emit function when row is checked
         */
        this.rowCheck = new EventEmitter();
        /**
         * \@prop emit funciton when row is unchecked
         */
        this.rowUncheck = new EventEmitter();
        /**
         * \@prop emit function when the filter value changes
         */
        this.filterValueChange = new EventEmitter();
        /**
         * Handles keyboard events when the selected is open.
         */
        this._handleOpenKeydown = (/**
         * @param {?} event
         * @return {?}
         */
        (event) => {
            if (!this.selectOptionsToDisplay || this.selectOptionsToDisplay.length === null || !this.overlayOpen) {
                return;
            }
            // tslint:disable-next-line: deprecation
            /** @type {?} */
            const key = event.key || event.which || event.keyCode;
            /** @type {?} */
            let selectedItemIndex;
            switch (key) {
                case 'ArrowDown':
                case 40:
                    if (!this.overlayOpen && event.altKey) {
                        this.open();
                    }
                    else {
                        selectedItemIndex = this.selectedOption ? this.findSelectOptionIndex(this.selectedOption.value, this.selectOptionsToDisplay) : -1;
                        /** @type {?} */
                        const nextEnabledOption = this.findNextOption(selectedItemIndex);
                        if (nextEnabledOption) {
                            this.selectItem(event, nextEnabledOption);
                            this.selectedItemUpdated = true;
                        }
                    }
                    event.preventDefault();
                    break;
                case 'ArrowUp':
                case 38:
                    selectedItemIndex = this.selectedOption ? this.findSelectOptionIndex(this.selectedOption.value, this.selectOptionsToDisplay) : -1;
                    /** @type {?} */
                    const prevEnabledOption = this.findPrevOption(selectedItemIndex);
                    if (prevEnabledOption) {
                        this.selectItem(event, prevEnabledOption);
                        this.selectedItemUpdated = true;
                    }
                    event.preventDefault();
                    break;
                case 'Enter':
                case 13:
                    if (this.selectOptionsToDisplay && this.selectOptionsToDisplay.length > 0) {
                        this.onModelChange(this.value);
                        this.finalOption = this.selectedOption;
                        this.handleChange.emit({
                            value: this.value
                        });
                        if (this.tableRowIndex >= 0) {
                            this.tableService.onSelectChange(this.value, this.tableRowIndex);
                        }
                        if (this.isMulti) {
                            this.toggleRowWithCheckbox(this.selectedOption.value);
                        }
                        else {
                            this.close();
                        }
                    }
                    event.preventDefault();
                    break;
                case 'Escape':
                case 'Tab':
                case 27:
                case 9:
                    this.close();
                    break;
            }
        });
        this.toggle = (/**
         * @return {?}
         */
        () => {
            this.overlayOpen ? this.close() : this.open();
        });
        this.open = (/**
         * @return {?}
         */
        () => {
            if (!this.options) {
                return;
            }
            this.handleShow.emit();
            this.overlayOpen = true;
            this.cd.detectChanges();
            if (this.filterViewChild && this.filterViewChild.nativeElement) {
                this.filterViewChild.nativeElement.focus();
            }
        });
        this.close = (/**
         * @return {?}
         */
        () => {
            if (this.overlayOpen) {
                this.overlayOpen = false;
            }
        });
        this.onModelChange = (/**
         * @return {?}
         */
        () => { });
        this.onModelTouched = (/**
         * @return {?}
         */
        () => { });
        this._setAnchorWidth = (/**
         * @param {?} elementAnchor
         * @return {?}
         */
        (elementAnchor) => {
            /** @type {?} */
            const anchor = elementAnchor && elementAnchor.getBoundingClientRect();
            this.anchorWidth = anchor.width;
        });
    }
    /**
     * \@prop set the select item options
     * @return {?}
     */
    get options() {
        return this._options;
    }
    /**
     * @param {?} item
     * @return {?}
     */
    set options(item) {
        /** @type {?} */
        const options = this.optionLabel ? this.makeSelectOptions(item, this.optionLabel) : item;
        this._options = options;
        this.selectOptionsToDisplay = this._options;
        this.updateSelectedItem(this.value);
        if (this.filterValue && this.filterValue.length) {
            this.startFilter();
        }
    }
    /**
     * \@prop sets the selection from multi-select
     * @return {?}
     */
    get selection() {
        return this._selection;
    }
    /**
     * @param {?} item
     * @return {?}
     */
    set selection(item) {
        this._selection = item;
        if (!this.preventPropagation) {
            this.updateSelectionKeys();
            this.selectService.onSelectionChange();
        }
        this.preventPropagation = false;
    }
    /**
     * @param {?} index
     * @return {?}
     */
    findPrevOption(index) {
        /** @type {?} */
        let prevEnabledOption;
        if (this.selectOptionsToDisplay && this.selectOptionsToDisplay.length) {
            for (let i = (index - 1); 0 <= i; i--) {
                /** @type {?} */
                const option = this.selectOptionsToDisplay[i];
                if (option.disabled) {
                    continue;
                }
                else {
                    prevEnabledOption = option;
                    break;
                }
            }
            if (!prevEnabledOption) {
                for (let i = this.selectOptionsToDisplay.length - 1; i >= index; i--) {
                    /** @type {?} */
                    const option = this.selectOptionsToDisplay[i];
                    if (option.disabled) {
                        continue;
                    }
                    else {
                        prevEnabledOption = option;
                        break;
                    }
                }
            }
        }
        return prevEnabledOption;
    }
    /**
     * @param {?} index
     * @return {?}
     */
    findNextOption(index) {
        /** @type {?} */
        let nextEnabledOption;
        if (this.selectOptionsToDisplay && this.selectOptionsToDisplay.length) {
            for (let i = (index + 1); index < (this.selectOptionsToDisplay.length - 1); i++) {
                /** @type {?} */
                const option = this.selectOptionsToDisplay[i];
                if (option.disabled) {
                    continue;
                }
                else {
                    nextEnabledOption = option;
                    break;
                }
            }
            if (!nextEnabledOption) {
                for (let i = 0; i < index; i++) {
                    /** @type {?} */
                    const option = this.selectOptionsToDisplay[i];
                    if (option.disabled) {
                        continue;
                    }
                    else {
                        nextEnabledOption = option;
                        break;
                    }
                }
            }
        }
        return nextEnabledOption;
    }
    /**
     * @param {?} option
     * @param {?} label
     * @return {?}
     */
    makeSelectOptions(option, label) {
        /** @type {?} */
        let selectItems;
        if (option && option.length) {
            selectItems = [];
            for (const item of option) {
                selectItems.push({ label: item[label], value: item });
            }
        }
        return selectItems;
    }
    /**
     * @param {?} item
     * @return {?}
     */
    updateSelectedItem(item) {
        this.selectedOption = this.findSelectOption(item, this.selectOptionsToDisplay);
        this.selectedItemUpdated = true;
    }
    /**
     * @param {?} item
     * @param {?} options
     * @return {?}
     */
    findSelectOption(item, options) {
        /** @type {?} */
        const index = this.findSelectOptionIndex(item, options);
        return (index !== -1) ? options[index] : null;
    }
    /**
     * @param {?} item
     * @param {?} options
     * @return {?}
     */
    findSelectOptionIndex(item, options) {
        /** @type {?} */
        let index = -1;
        if (options) {
            for (let i = 0; i < options.length; i++) {
                if ((item === null && options[i].value === null) || item === options[i].value) {
                    index = i;
                    break;
                }
            }
        }
        return index;
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onFilter(event) {
        /** @type {?} */
        const inputValue = event.target.value;
        if (inputValue && inputValue.length) {
            this.filterValue = inputValue;
            this.startFilter();
        }
        else {
            this.filterValue = null;
            this.selectOptionsToDisplay = this.options;
        }
    }
    /**
     * @return {?}
     */
    startFilter() {
        /** @type {?} */
        const filterBy = Array.isArray(this.filterBy) ? this.filterBy : this.filterBy.split(',');
        this.filterValueChange.emit(this.filterValue);
        if (this.options && this.options.length) {
            this.selectOptionsToDisplay = FilterUtils.filter(this.options, filterBy, this.filterValue, this.filterMode);
        }
    }
    /**
     * @return {?}
     */
    resetFilter() {
        if (this.filterViewChild && this.filterViewChild.nativeElement) {
            this.filterValue = null;
            this.filterViewChild.nativeElement.value = '';
        }
        this.selectOptionsToDisplay = this.options;
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onSelectItemClick(event) {
        /** @type {?} */
        const option = event.option;
        if (!option.disabled) {
            this.selectedOption = option;
            this.finalOption = option;
            this.value = option.value;
            this.onModelChange(option.value);
            this.handleChange.emit({
                value: option.value
            });
            if (this.tableRowIndex >= 0) {
                this.tableService.onSelectChange(option.value, this.tableRowIndex);
            }
        }
        setTimeout((/**
         * @return {?}
         */
        () => {
            if (!this.isMulti) {
                this.close();
            }
        }), this.closeDuration);
    }
    /**
     * @param {?} event
     * @param {?} option
     * @return {?}
     */
    selectItem(event, option) {
        if (this.selectedOption !== option) {
            this.selectedOption = option;
            this.value = option.value;
        }
    }
    /**
     * @param {?} rowData
     * @return {?}
     */
    isSelected(rowData) {
        if (rowData && this.selection) {
            if (this.dataKey) {
                for (let i = 0; i < this.selection.length; i++) {
                    if (this.selection[i][this.dataKey] === rowData[this.dataKey]) {
                        this.selectionKeys[rowData[this.dataKey]] = 1;
                    }
                }
                return this.selectionKeys[rowData[this.dataKey]] !== undefined; // found in selection
            }
            else {
                if (this.selection instanceof Array) {
                    return findIndex(this.selection, rowData) > -1;
                }
                else {
                    return this.selection === rowData;
                }
            }
        }
        return false;
    }
    /**
     * @param {?} rowData
     * @return {?}
     */
    toggleRowWithCheckbox(rowData) {
        this.selection = this.selection || [];
        /** @type {?} */
        const isChecked = this.isSelected(rowData);
        /** @type {?} */
        const rowDataKeyValue = this.dataKey ? String(rowData[this.dataKey]) : null;
        this.preventPropagation = true;
        if (isChecked) { // then uncheck from selection
            // then uncheck from selection
            /** @type {?} */
            const checkedIndex = findIndex(this.selection, rowData);
            this._selection = this.selection.filter((/**
             * @param {?} item
             * @param {?} i
             * @return {?}
             */
            (item, i) => i !== checkedIndex));
            this.selectionChange.emit(this.selection);
            this.rowUncheck.emit({
                data: rowData,
            });
            if (rowDataKeyValue) {
                delete this.selectionKeys[rowDataKeyValue];
            }
        }
        else { // add to selection
            this._selection = this.selection ? [...this.selection, rowData] : [rowData];
            this.selectionChange.emit(this.selection);
            this.rowCheck.emit({
                data: rowData,
            });
            if (rowDataKeyValue) {
                this.selectionKeys[rowDataKeyValue] = 1;
            }
        }
        this.selectService.onSelectionChange();
    }
    /**
     * @return {?}
     */
    updateSelectionKeys() {
        if (this.dataKey && this._selection) {
            this.selectionKeys = {};
            if (Array.isArray(this._selection)) {
                for (const data of this._selection) {
                    this.selectionKeys[String(data[this.dataKey])] = 1;
                }
            }
            else {
                this.selectionKeys[String(this._selection[this.dataKey])] = 1;
            }
        }
    }
    /**
     * @return {?}
     */
    ngAfterContentChecked() {
        this._setAnchorWidth(this.originButton.el.nativeElement);
    }
    /**
     * @return {?}
     */
    ngAfterContentInit() {
        this.templates.forEach((/**
         * @param {?} item
         * @return {?}
         */
        (item) => {
            switch (item.getType()) {
                case 'option':
                    this.optionTemplate = item.template;
                    break;
                case 'selectedOption':
                    this.selectedOptionTemplate = item.template;
                    break;
                default:
                    this.optionTemplate = item.template;
                    break;
            }
        }));
    }
    /**
     * @param {?} value
     * @return {?}
     */
    writeValue(value) {
        if (this.filter) {
            this.resetFilter();
        }
        this.value = value;
        this.updateSelectedItem(value);
        this.cd.markForCheck();
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnChange(fn) {
        this.onModelChange = fn;
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnTouched(fn) {
        this.onModelTouched = fn;
    }
    /**
     * @param {?} isDisabled
     * @return {?}
     */
    setDisabledState(isDisabled) {
        this.disabled = isDisabled;
    }
}
SelectComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-select',
                template: `
    <button
      md-button
      cdkOverlayOrigin
      #trigger="cdkOverlayOrigin"
      [attr.name]='id'
      aria-label="select button"
      [attr.id]='id'
      (click)='toggle()'
      [ngClass]="[
        disabled ? 'disabled' : '',
        buttonClass
      ]"
      [ngStyle]="buttonStyle"
      type="button"
    >
      <div class='md-select__label' id="{{id}}__label">

        <ng-container *ngTemplateOutlet="selectedOptionTemplate; context: {$implicit: finalOption}"></ng-container>

        <span *ngIf="!selectedOptionTemplate">
          {{isMulti && selection && selection.length > 0 ? selection.length + ' Items Selected'
          : finalOption && !isMulti ? finalOption.label
          : defaultValue ? defaultValue
          : placeholder ? placeholder
          : 'Select An Option'}}
        </span>

        <md-icon name="arrow-down_16"></md-icon>
      </div>
    </button>

    <ng-template
      cdkConnectedOverlay
      [cdkConnectedOverlayOrigin]="trigger"
      [cdkConnectedOverlayOpen]="overlayOpen"
      [cdkConnectedOverlayWidth]="this.anchorWidth"
      [cdkConnectedOverlayOffsetY]="6"
      [cdkConnectedOverlayPanelClass]="['md-select__dropdown', overlayClass]"
      [cdkConnectedOverlayHasBackdrop]="true"
      [cdkConnectedOverlayBackdropClass]="'cdk-overlay-transparent-backdrop'"
      (backdropClick)="close()"
      (detach)="close()"
    >
      <div
        *ngIf="filter"
        class="md-select__filter md-input-container md-search-input md-search-input--pill"
        (click)="$event.stopPropagation()"
      >
        <md-input-container>
          <input
            mdInput
            shape="pill"
            #filterSearch
            aria-autocomplete="list"
            [(ngModel)]="filterValue"
            [placeholder]="filterPlaceholder"
            (input)="onFilter($event)"
            (keydown)="_handleOpenKeydown($event)"
            (keydown.enter)="$event.preventDefault()"
          >
          <md-input-section
            *ngIf="hasSearchIcon"
          >
            <md-icon name="search_20"></md-icon>
          </md-input-section>
        </md-input-container>
      </div>

      <div
        class="md-list md-list--vertical"
        [style.max-height]="scrollHeight"
        role="listbox"
        style="align-items: normal; overflow: scroll; overflow-x:hidden"
      >
        <ng-container>
          <ng-container
            *ngTemplateOutlet="itemslist; context: {
              $implicit: selectOptionsToDisplay,
              selectedOption: selectedOption
            }">
          </ng-container>
        </ng-container>

        <ng-template #itemslist let-options let-selectedOption="selectedOption">
          <ng-template ngFor let-option let-i="index" [ngForOf]="options">
            <md-select-item
              [option]="option"
              [optionClass]="optionClass"
              [selected]="selectedOption === option"
              (handleClick)="onSelectItemClick($event)"
              [selectItemSize]="selectItemSize"
              [template]="optionTemplate">
            </md-select-item>
          </ng-template>
        </ng-template>

        <li
          *ngIf="filter && selectOptionsToDisplay && selectOptionsToDisplay.length === 0"
          class="md-select__filter--empty"
        >
          {{noResultsMessage}}
        </li>
      </div>
    </ng-template>
  `,
                providers: [SELECT_VALUE_ACCESSOR, SelectService, TableService],
                host: {
                    class: 'md-input-container md-select',
                    '[class.disabled]': 'disabled'
                }
            }] }
];
/** @nocollapse */
SelectComponent.ctorParameters = () => [
    { type: SelectService },
    { type: TableService },
    { type: ElementRef },
    { type: ChangeDetectorRef }
];
SelectComponent.propDecorators = {
    scrollHeight: [{ type: Input }],
    placeholder: [{ type: Input }],
    tableRowIndex: [{ type: Input }],
    optionLabel: [{ type: Input }],
    filter: [{ type: Input }],
    filterBy: [{ type: Input }],
    filterMode: [{ type: Input }],
    filterPlaceholder: [{ type: Input }],
    ariaFilterLabel: [{ type: Input }],
    dataKey: [{ type: Input }],
    noResultsMessage: [{ type: Input }],
    selectItemSize: [{ type: Input }],
    overlayClass: [{ type: Input }],
    hasSearchIcon: [{ type: Input }],
    options: [{ type: Input }],
    selection: [{ type: Input }],
    buttonStyle: [{ type: Input }],
    buttonClass: [{ type: Input }],
    optionClass: [{ type: Input }],
    defaultValue: [{ type: Input }],
    disabled: [{ type: HostBinding, args: ['attr.disabled',] }, { type: Input }],
    id: [{ type: Input }],
    isMulti: [{ type: Input }],
    closeDuration: [{ type: Input }],
    handleChange: [{ type: Output }],
    handleShow: [{ type: Output }],
    selectionChange: [{ type: Output }],
    rowCheck: [{ type: Output }],
    rowUncheck: [{ type: Output }],
    filterValueChange: [{ type: Output }],
    originButton: [{ type: ViewChild, args: [ButtonComponent,] }],
    filterViewChild: [{ type: ViewChild, args: ['filterSearch',] }],
    templates: [{ type: ContentChildren, args: [TemplateNameDirective,] }],
    _handleOpenKeydown: [{ type: HostListener, args: ['keydown', ['$event'],] }]
};
class SelectItemComponent {
    /**
     * @param {?} sc
     */
    constructor(sc) {
        this.sc = sc;
        this.handleClick = new EventEmitter();
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onSelectOptionClick(event) {
        this.handleClick.emit({
            option: this.option
        });
        if (this.sc.isMulti) {
            this.sc.toggleRowWithCheckbox(this.option.value);
            if (this.sc.filterViewChild && this.sc.filterViewChild.nativeElement) {
                this.sc.filterViewChild.nativeElement.focus();
            }
            else {
                this.sc.originButton.el.nativeElement.focus();
            }
        }
    }
}
SelectItemComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-select-item',
                template: `
    <div
      (click)="onSelectOptionClick($event)"
      (keydown)="sc._handleOpenKeydown($event)"
      role="option"
      [attr.aria-label]="option.label"
      [ngStyle]="{'height': selectItemSize + 'px'}"
      class="md-list-item"
      [ngClass]="[
        selected ? 'active' : '',
        optionClass
      ]"
    >

    <div *ngIf="!template && !sc.isMulti" class="md-list-item__center">{{option.label||'empty'}}</div>
      <!-- Multi Check Box Conditional -->

      <ng-container *ngIf="sc.isMulti">
        <md-select-checkbox
          [data]="option.value"
          [label]="option.label">
        </md-select-checkbox>
      </ng-container>

      <ng-container *ngTemplateOutlet="template; context: {$implicit: option}"></ng-container>
    </div>
  `
            }] }
];
/** @nocollapse */
SelectItemComponent.ctorParameters = () => [
    { type: SelectComponent }
];
SelectItemComponent.propDecorators = {
    option: [{ type: Input }],
    optionClass: [{ type: Input }],
    selected: [{ type: Input }],
    selectItemSize: [{ type: Input }],
    template: [{ type: Input }],
    handleClick: [{ type: Output }]
};
class SelectCheckboxComponent {
    /**
     * @param {?} sc
     * @param {?} selectService
     */
    constructor(sc, selectService) {
        this.sc = sc;
        this.selectService = selectService;
        this.label = '';
        this.className = '';
        this.id = uniqueId('md-select-item-');
        this.subscription = this.sc.selectService.selectionSource$.subscribe((/**
         * @return {?}
         */
        () => {
            this.checkStatus = this.sc.isSelected(this.data);
        }));
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.checkStatus = this.sc.isSelected(this.data);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    handleClick(event) {
        this.sc.toggleRowWithCheckbox(this.data);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    changeCheck(event) {
        this.checkStatus = event;
        this.sc.toggleRowWithCheckbox(this.data);
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this.subscription) {
            this.subscription.unsubscribe();
        }
    }
}
SelectCheckboxComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-select-checkbox',
                template: `
    <div
      class="md-select__checkbox--wrapper"
      [ngClass]="[className]"
      (click)="handleClick($event)"
    >
      <div>
        <md-checkbox
          name="{{id}}-checkbox"
          [value]="label"
          [label]="label"
          [(checkStatus)]="checkStatus"
          (checkStatusChange)="changeCheck($event)"
          htmlId="{{id}}-checkbox">
        </md-checkbox>
      </div>
    </div>
  `
            }] }
];
/** @nocollapse */
SelectCheckboxComponent.ctorParameters = () => [
    { type: SelectComponent },
    { type: SelectService }
];
SelectCheckboxComponent.propDecorators = {
    data: [{ type: Input }],
    label: [{ type: Input }],
    className: [{ type: Input }],
    id: [{ type: HostBinding, args: ['attr.id',] }, { type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SelectModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: SelectModule,
            providers: [],
        };
    }
}
SelectModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    ButtonModule,
                    IconModule,
                    PortalModule,
                    OverlayModule,
                    A11yModule,
                    FormsModule,
                    ReactiveFormsModule,
                    CheckboxModule,
                    InputContainerModule,
                    InputSectionModule,
                    InputModule,
                    SharedModule
                ],
                exports: [
                    SelectComponent,
                    SelectItemComponent,
                    SelectCheckboxComponent
                ],
                declarations: [
                    SelectComponent,
                    SelectItemComponent,
                    SelectCheckboxComponent
                ],
                schemas: [CUSTOM_ELEMENTS_SCHEMA]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TabsService {
    constructor() {
        this.Pane = -1;
        this.Tabs = -1;
        this.currentTabValue = 0;
        this.currentFocusValue = 0;
        this.TabDic = {};
        this.TabDisables = {};
        this.current = new Subject();
        this.current$ = this.current.asObservable();
        this.focusIndex = new Subject();
        this.focusIndex$ = this.focusIndex.asObservable();
        this.tabSize = new Subject();
        this.tabSize$ = this.tabSize.asObservable();
        this.paneSize = new Subject();
        this.paneSize$ = this.paneSize.asObservable();
        this.registerPane = (/**
         * @return {?}
         */
        () => {
            /** @type {?} */
            const index = this.Pane + 1;
            this.paneSize.next(index);
            return index;
        });
        this.registerTab = (/**
         * @return {?}
         */
        () => {
            /** @type {?} */
            const index = this.Tabs + 1;
            this.tabSize.next(index);
            return index;
        });
        this.registerDisable = (/**
         * @param {?} index
         * @param {?} disable
         * @return {?}
         */
        (index, disable) => {
            this.TabDisables[index] = disable;
        });
        this.registerKey = (/**
         * @param {?} key
         * @param {?} value
         * @return {?}
         */
        (key, value) => {
            key = key.toLowerCase();
            if (this.TabDic[key] === undefined) {
                this.TabDic[key] = [];
            }
            this.TabDic[key].push(value);
        });
        this.select = (/**
         * @param {?} index
         * @param {?=} ifFocusSelect
         * @return {?}
         */
        (index, ifFocusSelect) => {
            if (this.TabDisables[index] === false || ifFocusSelect) {
                this.setFocus(index);
                this.current.next(index);
            }
        });
        this.selectFocus = (/**
         * @param {?} index
         * @return {?}
         */
        (index) => {
            if (this.currentFocusValue !== this.currentTabValue) {
                this.current.next(this.currentFocusValue);
            }
        });
        this.setFocus = (/**
         * @param {?} index
         * @return {?}
         */
        (index) => {
            this.focusIndex.next(index);
        });
        this.setFocusPre = (/**
         * @return {?}
         */
        () => {
            this.setFocus(Math.max(0, this.currentFocusValue - 1));
        });
        this.setFocusNext = (/**
         * @return {?}
         */
        () => {
            this.setFocus(Math.min(this.Tabs, this.currentFocusValue + 1));
        });
        this.setFocusLast = (/**
         * @return {?}
         */
        () => {
            this.setFocus(this.Tabs);
        });
        this.setFocusByFirstCharacter = (/**
         * @param {?} key
         * @return {?}
         */
        key => {
            key = key.toLowerCase();
            /** @type {?} */
            const arr = this.TabDic[key];
            /** @type {?} */
            let index;
            /** @type {?} */
            let length;
            /** @type {?} */
            let tabIndex = this.currentFocusValue;
            if (arr !== undefined) {
                length = arr.length;
                index = arr.indexOf(this.currentFocusValue);
                if (index !== -1 && length > 1 && index + 1 < length) {
                    tabIndex = arr[index + 1];
                }
                else {
                    tabIndex = arr[0];
                }
            }
            if (tabIndex !== this.currentFocusValue) {
                this.setFocus(tabIndex);
                return true;
            }
            return false;
        });
        this.current$.subscribe((/**
         * @param {?} index
         * @return {?}
         */
        index => {
            this.currentTabValue = index;
        }));
        this.focusIndex$.subscribe((/**
         * @param {?} index
         * @return {?}
         */
        index => {
            this.currentFocusValue = index;
        }));
        this.tabSize$.subscribe((/**
         * @param {?} n
         * @return {?}
         */
        n => {
            this.Tabs = n;
        }));
        this.paneSize$.subscribe((/**
         * @param {?} n
         * @return {?}
         */
        n => {
            this.Pane = n;
        }));
    }
}
TabsService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
TabsService.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TabsComponent {
    /**
     * @param {?} tabsService
     */
    constructor(tabsService) {
        this.tabsService = tabsService;
        /**
         * \@prop Optional CSS class name | ''
         */
        this.className = '';
        /**
         * \@prop Set the index of the focused Tab | 0
         */
        this.focus = 0;
        /**
         * \@prop Determines if the Tabs are in a justified layout | false
         */
        this.justified = false;
        /**
         * \@prop Type of Tabs | 'tabs'
         */
        this.tabType = 'tabs';
        /**
         * \@prop Callback function invoked when user selects a tab | null
         */
        this.whenSelect = new EventEmitter();
        this.tabsService.current$.subscribe((/**
         * @param {?} currentIndex
         * @return {?}
         */
        currentIndex => {
            this.whenSelect.emit(currentIndex);
        }));
    }
    /**
     * @return {?}
     */
    get classes() {
        return ('md-tab' +
            `${(this.tabType && ` md-tab--${this.tabType}`) || ''}` +
            `${(this.justified && ' md-tab--justified') || ''}` +
            `${(this.className && ` ${this.className}`) || ''}` +
            ``);
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.tabsService.select(this.focus, true);
    }
}
TabsComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-tabs',
                template: `
    <ng-content></ng-content>
  `,
                providers: [TabsService]
            }] }
];
/** @nocollapse */
TabsComponent.ctorParameters = () => [
    { type: TabsService }
];
TabsComponent.propDecorators = {
    className: [{ type: Input }],
    focus: [{ type: Input }],
    justified: [{ type: Input }],
    tabType: [{ type: Input }],
    whenSelect: [{ type: Output }],
    classes: [{ type: HostBinding, args: ['class',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TabHeaderComponent {
    constructor() {
        /**
         * \@prop Subheader text | ''
         */
        this.subHeading = '';
    }
}
TabHeaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-tab-header',
                template: `
    {{ heading }}
    <div *ngIf="subHeading" class="md-tab-header__subheading">{{ subHeading }}</div>
  `
            }] }
];
TabHeaderComponent.propDecorators = {
    heading: [{ type: Input }],
    subHeading: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TabListComponent {
    constructor() {
        /**
         * \@prop Tab's anchor role type | 'tablist'
         */
        this.role = 'tablist';
    }
}
TabListComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-tab-list',
                template: `
    <ul
      class="md-tab__list"
      [attr.role]="role"
    >
      <ng-content></ng-content>
    </ul>
  `
            }] }
];
TabListComponent.propDecorators = {
    role: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TabComponent {
    /**
     * @param {?} tabsService
     * @param {?} el
     */
    constructor(tabsService, el) {
        this.tabsService = tabsService;
        this.el = el;
        /**
         * \@prop Optional CSS class name
         */
        this.className = '';
        /**
         * \@prop Sets the attribute disabled to the Tab | false
         */
        this.disabled = false;
        /**
         * \@prop Tab's anchor role type | 'tab'
         */
        this.role = 'tab';
        /**
         * \@prop Callback function invoked when user click a tab | null
         */
        this.whenPress = new EventEmitter();
        /**
         * \@prop Callback function invoked when user press a key | null
         */
        this.whenKeyDown = new EventEmitter();
        this.attrRole = 'presentation';
        /*
          @HostBinding('attr.tabIndex') get attrTabIndex():number {
            return this.tabIndex;
          };
          @HostBinding('attr.aria-posinset') ariaPosinset = this.tabIndex;
          @HostBinding('attr.aria-setsize') ariaSetsize = this.tabSize;
          @HostBinding('attr.aria-selected') ariaSelected = this.ifCurrent;
          @HostBinding('attr.aria-disabled') ariaDisabled = this.disabled;
          */
        this.regIsCharacter = /\S/;
        this.isPrintableCharacter = (/**
         * @param {?} str
         * @return {?}
         */
        str => {
            return str.length === 1 && str.match(this.regIsCharacter);
        });
        this.onKeyDown = (/**
         * @param {?} e
         * @return {?}
         */
        e => {
            /** @type {?} */
            const key = e.keyCode;
            /** @type {?} */
            const tgt = e.target;
            /** @type {?} */
            let flag = false;
            /** @type {?} */
            let clickEvent;
            switch (key) {
                case 32: // Space
                case 13: // Page up
                    try {
                        clickEvent = new MouseEvent('click', {
                            view: window,
                            bubbles: true,
                            cancelable: true,
                        });
                    }
                    catch (err) {
                        if (document.createEvent) {
                            clickEvent = document.createEvent('MouseEvents');
                            clickEvent.initEvent('click', true, true);
                        }
                    }
                    tgt.dispatchEvent(clickEvent);
                    flag = true;
                    break;
                case 38: // Up Arrow
                case 37: // Left Arrow
                    this.tabsService.setFocusPre();
                    flag = true;
                    break;
                case 39: // Right Arrow
                case 40: // Down Arrow
                    this.tabsService.setFocusNext();
                    flag = true;
                    break;
                case 33: // Page Up
                case 36: // Home
                    this.tabsService.setFocus(0);
                    flag = true;
                    break;
                case 34: // Page Down
                case 35: // End
                    this.tabsService.setFocusLast();
                    flag = true;
                    break;
                default:
                    if (this.isPrintableCharacter(e.key)) {
                        flag = this.tabsService.setFocusByFirstCharacter(e.key);
                    }
                    break;
            }
            if (flag) {
                e.stopPropagation();
                e.preventDefault();
            }
        });
        this.tabIndex = tabsService.registerTab();
        this.tabSize = this.tabIndex;
        this.tabsService.current$.subscribe((/**
         * @param {?} index
         * @return {?}
         */
        index => {
            this.ifCurrent = this.tabIndex === index;
        }));
        this.tabsService.focusIndex$.subscribe((/**
         * @param {?} index
         * @return {?}
         */
        index => {
            this.ifFocus = this.tabIndex === index;
            if (this.ifFocus) {
                this.el.nativeElement.getElementsByTagName('A')[0].focus();
            }
        }));
        this.tabsService.tabSize$.subscribe((/**
         * @param {?} n
         * @return {?}
         */
        n => {
            this.tabSize = n;
        }));
    }
    /**
     * @return {?}
     */
    select() {
        this.tabsService.select(this.tabIndex);
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.tabsService.registerDisable(this.tabIndex, this.disabled);
        /** @type {?} */
        const innerText = this.el.nativeElement.innerText;
        if (innerText) {
            this.tabsService.registerKey(innerText[0], this.tabIndex);
        }
    }
}
TabComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-tab',
                template: `
  <li
    role="presentation"
    class="md-tab__item"
    [ngClass]="[
      ifCurrent ? 'active' : '',
      disabled ? 'disabled' : '',
      className
    ]"
    tabindex="0"
    (keydown)="onKeyDown($event)"
  >
    <a
      href="javascript:void(0)"
      (click)="whenPress.emit()"
      (keydown)="whenKeyDown.emit()"
      [attr.role]="role"
      [attr.tabindex]="ifFocus ? 0 : -1"
      [attr.aria-posinset]="tabIndex"
      [attr.aria-setsize]="tabSize"
      [attr.aria-selected]="ifCurrent"
      [attr.aria-disabled]="disabled"
    >
      <ng-content></ng-content>
    </a>
  </li>
  `
            }] }
];
/** @nocollapse */
TabComponent.ctorParameters = () => [
    { type: TabsService },
    { type: ElementRef }
];
TabComponent.propDecorators = {
    className: [{ type: Input }],
    disabled: [{ type: Input }],
    role: [{ type: Input }],
    whenPress: [{ type: Output }],
    whenKeyDown: [{ type: Output }],
    attrRole: [{ type: HostBinding, args: ['attr.role',] }],
    select: [{ type: HostListener, args: ['click',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TabContentComponent {
    constructor() { }
    /**
     * @return {?}
     */
    get className() {
        return 'md-tab__content';
    }
    /**
     * @return {?}
     */
    ngOnInit() { }
}
TabContentComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-tab-content',
                template: `
    <ng-content></ng-content>
  `
            }] }
];
/** @nocollapse */
TabContentComponent.ctorParameters = () => [];
TabContentComponent.propDecorators = {
    className: [{ type: HostBinding, args: ['class',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TabPaneComponent {
    /**
     * @param {?} tabsService
     */
    constructor(tabsService) {
        this.tabsService = tabsService;
        this.tabIndex = tabsService.registerPane();
        this.tabsService.current$.subscribe((/**
         * @param {?} currentIndex
         * @return {?}
         */
        currentIndex => {
            this.ifCurrent = this.tabIndex === currentIndex;
        }));
    }
    /**
     * @return {?}
     */
    get className() {
        return 'md-tab__pane' + `${(this.ifCurrent && ' active') || ''}` + ``;
    }
    /**
     * @return {?}
     */
    ngOnInit() { }
}
TabPaneComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-tab-pane',
                template: `
    <div class="md-tab__content">
      <ng-content></ng-content>
    </div>
  `
            }] }
];
/** @nocollapse */
TabPaneComponent.ctorParameters = () => [
    { type: TabsService }
];
TabPaneComponent.propDecorators = {
    className: [{ type: HostBinding, args: ['class',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TabsModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: TabsModule,
            providers: [],
        };
    }
}
TabsModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [
                    TabsComponent,
                    TabHeaderComponent,
                    TabListComponent,
                    TabComponent,
                    TabContentComponent,
                    TabPaneComponent
                ],
                exports: [
                    TabsComponent,
                    TabHeaderComponent,
                    TabListComponent,
                    TabComponent,
                    TabContentComponent,
                    TabPaneComponent
                ],
                schemas: [CUSTOM_ELEMENTS_SCHEMA]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// tslint:disable:no-use-before-declare
/** @type {?} */
const CUSTOM_TOGGLE_SWITCH_VALUE_ACCESSOR = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef((/**
     * @return {?}
     */
    () => ToggleSwitchComponent)),
    multi: true,
};
// tslint:enable:no-use-before-declare
class ToggleSwitchComponent {
    /**
     * @param {?} cdr
     */
    constructor(cdr) {
        this.cdr = cdr;
        /**
         * \@prop Optional CSS class name | ''
         */
        this.class = '';
        /**
         * \@prop Sets the attribute disabled to the ToggleSwitch | false
         */
        this.disabled = false;
        /**
         * \@prop Unique HTML ID used for tying label to HTML input for automated testing
         */
        this.htmlId = '';
        /**
         * \@prop ToggleSwitch label text | ''
         */
        this.label = '';
        /**
         * \@prop ToggleSwitch name for group | ''
         */
        this.name = '';
        /**
         * \@prop String value that corresponds with ToggleSwitch button | ''
         */
        this.value = '';
        /**
         * \@prop Callback function invoked when user clicks the ToggleSwitch button | null
         */
        this.change = new EventEmitter();
        // pass in boolean to ngModel for filled.
        this.checked = false;
        this.onSwitchChange = (/**
         * @return {?}
         */
        () => { });
        this.onSwitchTouch = (/**
         * @return {?}
         */
        () => { });
    }
    /**
     * @param {?} checked
     * @return {?}
     */
    writeValue(checked) {
        this.checked = checked;
        this.cdr.markForCheck();
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnChange(fn) {
        this.onSwitchChange = fn;
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnTouched(fn) {
        this.onSwitchTouch = fn;
    }
    /**
     * @param {?} isDisabled
     * @return {?}
     */
    setDisabledState(isDisabled) {
        this.disabled = isDisabled;
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onSwitch(event) {
        if (!this.disabled) {
            /** @type {?} */
            const isChecked = ((/** @type {?} */ (event.target))).checked;
            this.updateSwitch(event, isChecked);
        }
    }
    /**
     * @param {?} event
     * @param {?} bool
     * @return {?}
     */
    updateSwitch(event, bool) {
        this.checked = bool;
        this.onSwitchChange(this.checked);
        this.change.emit({ switchEvent: event, checked: this.checked });
        event.stopPropagation();
    }
}
ToggleSwitchComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-toggle-switch',
                template: `
    <input
      class="md-input md-toggle-switch__input"
      type="checkbox"
      (change)="onSwitch($event)"
      [attr.id]="htmlId"
      [attr.name]="name"
      [attr.tabindex]="tabIndex"
      [checked]="checked"
      [disabled]="disabled"
    />
    <label class="md-toggle-switch__label" [attr.for]="htmlId">
      <span class="md-toggle-switch__label__container"></span>
      <span class="md-toggle-switch__label__text">{{ label }}</span>
    </label>
  `,
                host: {
                    class: 'md-input-container md-toggle-switch',
                },
                providers: [CUSTOM_TOGGLE_SWITCH_VALUE_ACCESSOR]
            }] }
];
/** @nocollapse */
ToggleSwitchComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
ToggleSwitchComponent.propDecorators = {
    class: [{ type: Input }],
    disabled: [{ type: Input }],
    htmlId: [{ type: Input }],
    label: [{ type: Input }],
    name: [{ type: Input }],
    tabIndex: [{ type: Input }],
    value: [{ type: Input }],
    change: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ToggleSwitchModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: ToggleSwitchModule,
            providers: [],
        };
    }
}
ToggleSwitchModule.decorators = [
    { type: NgModule, args: [{
                declarations: [ToggleSwitchComponent],
                imports: [CommonModule, FormsModule, ReactiveFormsModule],
                exports: [ToggleSwitchComponent],
                schemas: [CUSTOM_ELEMENTS_SCHEMA],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TopbarComponent {
}
TopbarComponent.decorators = [
    { type: Component, args: [{
                selector: 'header[md-top-bar]',
                template: `
    <div class="md-top-bar__container">
      <div class="md-top-bar__brand">
        <ng-content select="brand"></ng-content>
      </div>
      <ng-content></ng-content>
    </div>
  `,
                host: {
                    'attr.role': 'navigation',
                    class: 'md-top-bar',
                    '[class.md-top-bar--fixed]': 'fixed',
                    '[class.md-top-bar--absolute]': 'absolute',
                    '[class.md-top-bar--blue]': 'color === "blue"',
                    '[class.md-top-bar--dark]': 'color === "dark"',
                    '[class.md-top-bar--light]': 'color === "light"',
                }
            }] }
];
TopbarComponent.propDecorators = {
    color: [{ type: Input }],
    fixed: [{ type: Input }],
    absolute: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TopbarBrandComponent {
    constructor() {
        /**
         * \@option Icon class name | 'icon-cisco-logo'
         */
        this.icon = 'icon-cisco-logo';
    }
}
TopbarBrandComponent.decorators = [
    { type: Component, args: [{
                selector: '[md-top-bar-brand]',
                exportAs: 'mdTopbarBrand',
                template: `
    <div class="md-brand__logo">
      <img *ngIf="image" src="{{ image }}" alt="{{ alt }}" />
      <i *ngIf="!image" [ngClass]="['icon', icon]"></i>
    </div>
    <div class="md-brand__title">{{ title }}</div>
  `,
                host: {
                    class: 'md-brand',
                }
            }] }
];
TopbarBrandComponent.propDecorators = {
    alt: [{ type: Input }],
    icon: [{ type: Input }],
    image: [{ type: Input }],
    title: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TopbarMobileComponent {
    constructor() {
        /**
         * \@option Aria Label for close Button | 'Close Menu'
         */
        this.closeMenuAriaLabel = 'Close Menu';
        /**
         * \@option Aria Label for open Button | 'Open Menu
         */
        this.openMenuAriaLabel = 'Open Menu';
        /**
         * \@option Set mobile menu to close on any click | true
         */
        this.shouldCloseOnClick = true;
        this.isMobileOpen = false;
    }
    /**
     * @param {?} e
     * @return {?}
     */
    handleKeydown(e) {
        if (e.code === 'Enter') {
            this.handleClose();
            e.preventDefault();
        }
    }
    /**
     * @return {?}
     */
    handleClose() {
        this.isMobileOpen = false;
    }
    /**
     * @return {?}
     */
    handleOpen() {
        this.isMobileOpen = true;
    }
}
TopbarMobileComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-top-bar-mobile',
                template: `
    <md-icon
      *ngIf="!isMobileOpen"
      name="list-menu_20"
      buttonClassName="md-top-bar__mobile-menu-button"
      [attr.aria-pressed]="isMobileOpen"
      [ariaLabel]="openMenuAriaLabel"
      (click)="handleOpen()"
    ></md-icon>
    <div
      [ngClass]="[
        'md-top-bar__mobile',
        'md-tb-mobile',
        (isMobileOpen && 'open') || ''
      ]"
      (click)="shouldCloseOnClick ? handleClose() : null"
      (keydown)="handleKeydown($event)"
      role="menu"
      tabIndex="0"
    >
      <md-icon
        name="cancel_20"
        buttonClassName="md-tb-mobile__close"
        [attr.aria-pressed]="isMobileOpen"
        [ariaLabel]="closeMenuAriaLabel"
        (click)="handleClose()"
      ></md-icon>
      <span (click)="handleClose()" (keydown)="handleKeydown($event)">
        <div class="md-top-bar__brand">
          <ng-content select="brand"></ng-content>
        </div>
      </span>
      <md-list-separator backgroundColor="transparent"></md-list-separator>
      <nav
        class="md-tb-mobile__nav"
        (click)="!shouldCloseOnClick ? handleClose() : null"
      >
        <ng-content></ng-content>
      </nav>
    </div>
    <div
      [ngClass]="['md-tb-mobile__mask', (isMobileOpen && 'open') || '']"
      (click)="handleClose()"
      role="none"
    ></div>
  `
            }] }
];
TopbarMobileComponent.propDecorators = {
    closeMenuAriaLabel: [{ type: Input }],
    openMenuAriaLabel: [{ type: Input }],
    shouldCloseOnClick: [{ type: Input }],
    handleKeydown: [{ type: HostListener, args: ['document:keydown', ['$event'],] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TopbarNavComponent {
}
TopbarNavComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-top-bar-nav',
                template: `
    <md-list tabType="horizontal">
      <ng-content></ng-content>
    </md-list>
  `,
                host: {
                    class: 'md-top-bar__nav',
                }
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TopbarRightComponent {
}
TopbarRightComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-top-bar-right',
                template: `
    <ng-content></ng-content>
  `,
                host: {
                    class: 'md-top-bar__right',
                }
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TopbarModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: TopbarModule,
            providers: [],
        };
    }
}
TopbarModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    IconModule,
                    ListModule,
                    ListItemModule,
                    ListSeparatorModule,
                ],
                declarations: [
                    TopbarComponent,
                    TopbarBrandComponent,
                    TopbarMobileComponent,
                    TopbarNavComponent,
                    TopbarRightComponent,
                ],
                exports: [
                    TopbarComponent,
                    TopbarBrandComponent,
                    TopbarMobileComponent,
                    TopbarNavComponent,
                    TopbarRightComponent,
                ],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AccordionService {
    constructor() {
        this.focus = new BehaviorSubject(0);
        this.focus$ = this.focus.asObservable();
    }
    /**
     * @param {?} focusIndex
     * @return {?}
     */
    setFocus(focusIndex) {
        this.focus.next(focusIndex);
    }
}
AccordionService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
AccordionService.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AccordionTabComponent {
    /**
     * @param {?} accordion
     * @param {?} el
     * @param {?} accordionService
     * @param {?} cdr
     */
    constructor(accordion, el, accordionService, cdr) {
        this.accordion = accordion;
        this.el = el;
        this.accordionService = accordionService;
        this.cdr = cdr;
        /**
         * \@prop Set Accordion tab header string | false
         */
        this.header = '';
        /**
         * \@prop Set accordion tab to be expanded | false
         */
        this.isExpanded = false;
        /**
         * \@prop Set the attribute disabled to the accordion tab | false
         */
        this.disabled = false;
        /**
         * \@prop Optional accordion tab css class string | ''
         */
        this.className = '';
        /**
         * \@prop Optional underline under Accordion menu item | false
         */
        this.showSeparator = false;
        /**
         * \@prop Optional accordion header css class string | ''
         */
        this.headerClass = '';
        /**
         * \@prop Handler to be called when the user taps the Accordion Tab | null
         */
        this.contentClick = new EventEmitter();
        /**
         * \@prop Handler to be called when the user presses a key | null
         */
        this.handleKeyDown = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.height && this.height !== 56) {
            throw new Error(`md-list: Accordion Header height option must be either the default or 56`);
        }
        this.accordionService.focus$.subscribe((/**
         * @param {?} focus
         * @return {?}
         */
        focus => this.focus = focus));
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        this.index = this.findTabIndex();
        this.cdr.detectChanges();
    }
    /**
     * @param {?} event
     * @return {?}
     */
    handleContentClick(event) {
        this.contentClick.emit({ originalEvent: event, tab: this.accordion.tabs[this.index] });
        event.stopPropagation();
    }
    /**
     * @param {?} event
     * @return {?}
     */
    toggle(event) {
        if (this.disabled) {
            return false;
        }
        this.index = this.findTabIndex();
        this.accordionService.setFocus(this.index);
        if (this.isExpanded) {
            this.isExpanded = false;
        }
        else {
            if (!this.accordion.multipleVisible) {
                for (let i = 0; i < this.accordion.tabs.length; i++) {
                    this.accordion.tabs[i].isExpanded = false;
                }
            }
            this.isExpanded = true;
        }
        event.preventDefault();
    }
    /**
     * @return {?}
     */
    findTabIndex() {
        /** @type {?} */
        let index = -1;
        this.accordion.tabs.map((/**
         * @param {?} tab
         * @param {?} idx
         * @return {?}
         */
        (tab, idx) => {
            if (tab === this) {
                index = idx;
            }
        }));
        return index;
    }
    /**
     * @param {?} currentIndex
     * @param {?} change
     * @param {?} lastIdx
     * @return {?}
     */
    getNewIndex(currentIndex, change, lastIdx) {
        /** @type {?} */
        const getPossibleIndex = (/**
         * @return {?}
         */
        () => {
            if (currentIndex + change < 0) {
                return lastIdx;
            }
            else if (currentIndex + change > lastIdx) {
                return 0;
            }
            return currentIndex + change;
        });
        /** @type {?} */
        const possibleIndex = getPossibleIndex();
        if (this.accordion.tabs[possibleIndex].disabled) {
            return this.getNewIndex(possibleIndex, change, lastIdx);
        }
        return possibleIndex;
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onKeyDown(event) {
        /** @type {?} */
        let newIndex;
        // tslint:disable-next-line: deprecation
        /** @type {?} */
        const key = event.key || event.which || event.keyCode;
        this.handleKeyDown.emit(event.code);
        switch (key) {
            case SPACE:
            case ENTER:
            case ' ':
            case 'Enter':
                this.toggle(event);
                break;
            case UP_ARROW:
            case LEFT_ARROW:
            case 'ArrowUp':
            case 'ArrowLeft':
                newIndex = this.getNewIndex(this.index, -1, this.accordion.tabs.length - 1);
                this.accordionService.setFocus(newIndex);
                if (this.accordion.tabs[this.focus]) {
                    this.accordion.tabs[this.focus].headerRef.nativeElement.focus();
                }
                break;
            case RIGHT_ARROW:
            case DOWN_ARROW:
            case 'ArrowRight':
            case 'ArrowDown':
                newIndex = this.getNewIndex(this.index, 1, this.accordion.tabs.length - 1);
                this.accordionService.setFocus(newIndex);
                if (this.accordion.tabs[this.focus]) {
                    this.accordion.tabs[this.focus].headerRef.nativeElement.focus();
                }
                break;
            case PAGE_UP:
            case HOME:
            case 'PageUp':
            case 'Home':
                this.accordionService.setFocus(0);
                this.accordion.tabs[0].headerRef.nativeElement.focus();
                break;
            case PAGE_DOWN:
            case END:
            case 'PageDown':
            case 'End':
                this.accordionService.setFocus(this.accordion.tabs.length - 1);
                this.accordion.tabs[this.accordion.tabs.length - 1].headerRef.nativeElement.focus();
                break;
            default:
                break;
        }
        event.preventDefault();
    }
}
AccordionTabComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-accordion-tab',
                template: `
    <div
      [attr.aria-expanded]="isExpanded"
      class="md-accordion__group"
      [ngClass]="[
        disabled ? 'md-accordion__group--disabled' : '',
        isExpanded ? 'md-accordion__group--active' : '',
        className
      ]"
    >
      <div
        #headerRef
        role="button"
        class="md-accordion__header"
        [ngClass]="[
          height === 56 ? 'md-accordion__header--' + height : '',
          showSeparator ? 'md-accordion__header--separator' : '',
          headerClass
        ]"
        (click) = "toggle($event)"
        (keydown)="onKeyDown($event)"
        [attr.tabindex]="!disabled ? 0 : -1"
      >
        <div>{{header}}</div>
        <span class="md-accordion__header-icon"></span>
      </div>

      <div class="md-accordion__content">
        <div
          class="md-list-item"
          id="md-list-item-12"
          role="listItem"
          (click) = "handleContentClick($event)"
        >
          <ng-content></ng-content>
        </div>
      </div>
    </div>
  `,
                providers: [AccordionService]
            }] }
];
/** @nocollapse */
AccordionTabComponent.ctorParameters = () => [
    { type: AccordionComponent, decorators: [{ type: Inject, args: [forwardRef((/**
                     * @return {?}
                     */
                    () => AccordionComponent)),] }] },
    { type: ElementRef },
    { type: AccordionService },
    { type: ChangeDetectorRef }
];
AccordionTabComponent.propDecorators = {
    header: [{ type: Input }],
    isExpanded: [{ type: Input }],
    disabled: [{ type: Input }],
    className: [{ type: Input }],
    height: [{ type: Input }],
    showSeparator: [{ type: Input }],
    headerClass: [{ type: Input }],
    headerRef: [{ type: ViewChild, args: ['headerRef',] }],
    contentRef: [{ type: ViewChild, args: ['contentRef',] }],
    contentClick: [{ type: Output }],
    handleKeyDown: [{ type: Output }]
};
// Accordion Below
class AccordionComponent {
    constructor() {
        /**
         * \@prop Set to allow expansion of multiple AccordionGroups | false
         */
        this.multipleVisible = false;
        /**
         * \@prop Optional css class string | ''
         */
        this.class = '';
        /**
         * \@prop Specifies if AccordionHeader automatically gets focus when page loads | false
         */
        this.focus = false;
        this.tabs = [];
    }
    /**
     * @return {?}
     */
    ngAfterContentInit() {
        this.tabs = this.tabList.toArray();
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        if (this.focus) {
            this.tabs[0].headerRef.nativeElement.focus();
        }
    }
}
AccordionComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-accordion',
                template: `<ng-content></ng-content>`,
                host: {
                    class: 'md-accordion',
                }
            }] }
];
/** @nocollapse */
AccordionComponent.ctorParameters = () => [];
AccordionComponent.propDecorators = {
    multipleVisible: [{ type: Input }],
    class: [{ type: Input }],
    focus: [{ type: Input }],
    tabList: [{ type: ContentChildren, args: [AccordionTabComponent,] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AccordionModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: AccordionModule,
            providers: [],
        };
    }
}
AccordionModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [AccordionComponent, AccordionTabComponent],
                exports: [AccordionComponent, AccordionTabComponent],
                schemas: [CUSTOM_ELEMENTS_SCHEMA],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SidebarService {
    constructor() {
        this.tier = new BehaviorSubject(false);
        this.tier$ = this.tier.asObservable().pipe(distinctUntilChanged());
    }
    /**
     * @param {?} level
     * @return {?}
     */
    changeTier(level) {
        this.tier.next(level);
    }
}
SidebarService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
SidebarService.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SideBarComponent {
    /**
     * @param {?} sidebarService
     */
    constructor(sidebarService) {
        this.sidebarService = sidebarService;
        /**
         * \@prop Sets Sidebar to position fixed | false
         */
        this.isFixed = false;
        /**
         * \@prop Sets Sidebar styling for page level | false
         */
        this.isPageLevel = false;
        /**
         * \@prop Sets padding for Topbar | false
         */
        this.withTopbar = false;
        /**
         * \@prop show minimized sidebar with icons only on toggle | true
         */
        this.withIcons = true;
        /**
         * \@prop Set to make the navigation expandable | true
         */
        this.expandable = true;
        /**
         * \@prop Set navigation expanded or collapsed | true
         */
        this.expanded = true;
        /**
         * \@prop Optional CSS class string for sidebar | ''
         */
        this.wrapperClass = '';
        /**
         * \@prop Optional color theme | ''
         */
        this.theme = '';
        /**
         * \@prop optional toggle button to expand/collapse sidebar | false
         */
        this.withToggle = false;
        /**
         * \@prop optional toggle behavior to automatically expand/collapse sidebar | false
         */
        this.autoToggle = false;
        /**
         * \@prop optional auto toggle width to automatically trigger toggle behavior | 960
         */
        this.autoToggleWidth = 960;
        /**
         * \@prop optional CSS class for the toggle button
         */
        this.buttonClass = '';
        this.toggle = new EventEmitter();
        this.hasTier = false;
        this.subs = new Subscription();
        this.isAutoToggled = true;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.subs.add(this.sidebarService.tier$.subscribe((/**
         * @param {?} tier
         * @return {?}
         */
        tier => this.hasTier = tier)));
        if (this.autoToggle) {
            this.subs.add(fromEvent(window, 'resize').pipe(debounceTime(250), map((/**
             * @return {?}
             */
            () => this.isSmallScreen()))).subscribe((/**
             * @param {?} isSmallScreen
             * @return {?}
             */
            isSmallScreen => this.autoToggleExpanded(isSmallScreen))));
        }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.subs.unsubscribe();
    }
    /**
     * @param {?=} __0
     * @return {?}
     */
    toggleExpanded({ expanded = !this.expanded, isAutoToggled = false } = {}) {
        this.expanded = expanded;
        this.isAutoToggled = isAutoToggled;
        this.toggle.emit({
            expanded,
        });
    }
    /**
     * @private
     * @param {?} isSmallScreen
     * @return {?}
     */
    autoToggleExpanded(isSmallScreen) {
        if (!this.isAutoToggled) {
            return;
        }
        if (isSmallScreen && this.expanded) {
            this.toggleExpanded({
                expanded: false,
                isAutoToggled: true,
            });
        }
        else if (!isSmallScreen && !this.expanded) {
            this.toggleExpanded({
                expanded: true,
                isAutoToggled: true,
            });
        }
    }
    /**
     * @private
     * @return {?}
     */
    isSmallScreen() {
        /** @type {?} */
        const width = window.innerWidth > 0 ? window.innerWidth : screen.width;
        return width < this.autoToggleWidth;
    }
}
SideBarComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-sidebar',
                template: `

  <div class="md-sidebar" [ngClass]="[
    theme ? 'md-sidebar--' + theme : '',
    isFixed ? 'md-sidebar--fixed' : '',
    !isPageLevel ? 'md-sidebar--global' : '',
    withTopbar ? 'md-sidebar--topbar' : '',
    withIcons && !isPageLevel ? 'md-sidebar--indented' : '',
    hasTier ? 'md-sidebar--nested' : '',
    expanded ? 'md-sidebar--expanded' : '',
    !expanded && withIcons ? 'md-sidebar--minimized' : '',
    !expanded && !withIcons ? 'md-sidebar--collapsed' : '',
    wrapperClass
  ]">
    <ng-content></ng-content>
  </div>

  <div *ngIf="withToggle" class="md-sidebar__toggle" [ngClass]="[
    !expanded && withIcons ? 'md-sidebar__toggle--minimized' : '',
    !expanded && !withIcons ? 'md-sidebar__toggle--collapsed' : '',
    buttonClass
  ]">
    <button
      (click)="toggleExpanded()"
      class="md-button md-button--36 md-collapse-button"
      type="button"
      aria-label="Hide panels"
    >
      <span class="md-button__children" style="opacity: 1;">
        <i class="md-icon icon" [ngClass]="[
          this.expanded ? 'icon-panel-control-left_12' : 'icon-panel-control-right_12'
        ]"></i>
      </span>
    </button>
  </div>
  `,
                providers: [SidebarService],
                host: {
                    class: 'md-sidebar__wrapper',
                    '[class.md-sidebar__wrapper--fixed]': 'isFixed',
                }
            }] }
];
/** @nocollapse */
SideBarComponent.ctorParameters = () => [
    { type: SidebarService }
];
SideBarComponent.propDecorators = {
    isFixed: [{ type: Input }],
    isPageLevel: [{ type: Input }],
    withTopbar: [{ type: Input }],
    withIcons: [{ type: Input }],
    expandable: [{ type: Input }],
    expanded: [{ type: Input }],
    wrapperClass: [{ type: Input }],
    theme: [{ type: Input }],
    withToggle: [{ type: Input }],
    autoToggle: [{ type: Input }],
    autoToggleWidth: [{ type: Input }],
    buttonClass: [{ type: Input }],
    toggle: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SideBarModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: SideBarModule,
            providers: [],
        };
    }
}
SideBarModule.decorators = [
    { type: NgModule, args: [{
                declarations: [SideBarComponent],
                imports: [
                    CommonModule,
                ],
                exports: [SideBarComponent],
                schemas: [CUSTOM_ELEMENTS_SCHEMA]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SideBarBodyComponent {
    constructor() { }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
SideBarBodyComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-sidebar-body',
                template: `<ng-content></ng-content>`,
                host: {
                    'class': 'md-sidebar__body'
                }
            }] }
];
/** @nocollapse */
SideBarBodyComponent.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SideBarBodyModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: SideBarBodyModule,
            providers: [],
        };
    }
}
SideBarBodyModule.decorators = [
    { type: NgModule, args: [{
                declarations: [SideBarBodyComponent],
                imports: [
                    CommonModule
                ],
                exports: [SideBarBodyComponent],
                schemas: [CUSTOM_ELEMENTS_SCHEMA]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SidebarNavService {
    constructor() {
        this.actions = new Subject();
        this.state$ = this.actions.asObservable().pipe(startWith({
            sidebarNavItems: [],
            focusIndex: 0,
        }), scan((/**
         * @param {?} state
         * @param {?} action
         * @return {?}
         */
        (state, action) => (Object.assign({}, state, action)))), shareReplay(1));
        this.focus$ = this.state$.pipe(map((/**
         * @param {?} state
         * @return {?}
         */
        state => state.focusIndex)), distinctUntilChanged());
        this.sidebarNavItems$ = this.state$.pipe(map((/**
         * @param {?} state
         * @return {?}
         */
        state => state.sidebarNavItems)), distinctUntilChanged());
    }
    /**
     * @param {?} focusIndex
     * @return {?}
     */
    setFocus(focusIndex) {
        this.actions.next({
            focusIndex,
        });
    }
    /**
     * @param {?} sidebarNavItems
     * @return {?}
     */
    setSidebarNavItems(sidebarNavItems) {
        this.actions.next({
            sidebarNavItems,
        });
    }
}
SidebarNavService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
SidebarNavService.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SidebarNavItemComponent {
    /**
     * @param {?} sidebarNavService
     * @param {?} sidebarService
     */
    constructor(sidebarNavService, sidebarService) {
        this.sidebarNavService = sidebarNavService;
        this.sidebarService = sidebarService;
        /**
         * \@prop Title for the side item navigation | ''
         */
        this.title = '';
        /**
         * \@prop establishes the level - primary, secondary, or tertiary | 'primary'
         */
        this.headerLevel = 'primary';
        /**
         * \@prop Set navigation expanded or collapsed | false
         */
        this.expanded = false;
        /**
         * \@prop set active class on side item
         */
        this.active = false;
        /**
         * \@prop Icon string or node for the title | null
         */
        this.icon = '';
        /**
         * \@prop disables the sidebar nav item
         */
        this.disabled = false;
        /**
         * \@prop marks the sidebar nav item as read-only
         */
        this.isReadOnly = false;
        /**
         * \@prop creates a separator line below the sidebar nav item
         */
        this.separator = false;
        /**
         * \@prop optional CSS class for the icon left of sidebar nav item title
         */
        this.iconClass = '';
        /**
         * \@prop optional CSS class on the sidebar nav item wrapper div
         */
        this.className = '';
        this.navItemClick = new EventEmitter();
        this.navItems = [];
        this.subs = new Subscription();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        /** @type {?} */
        const index$ = this.sidebarNavService.sidebarNavItems$.pipe(tap((/**
         * @param {?} sidebarNavItems
         * @return {?}
         */
        sidebarNavItems => (this.children = sidebarNavItems))), map((/**
         * @param {?} sidebarNavItems
         * @return {?}
         */
        sidebarNavItems => sidebarNavItems.findIndex((/**
         * @param {?} sidebarNavItem
         * @return {?}
         */
        sidebarNavItem => sidebarNavItem === this)))), tap((/**
         * @param {?} index
         * @return {?}
         */
        index => (this.index = index))));
        this.subs.add(this.sidebarNavService.focus$.pipe(withLatestFrom(index$)).subscribe((/**
         * @param {?} __0
         * @return {?}
         */
        ([focus, index]) => {
            if (focus === index) {
                this.navItemRef.nativeElement.focus();
            }
        })));
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.subs.unsubscribe();
    }
    /**
     * @return {?}
     */
    ngAfterContentInit() {
        this.navItems = this.navItemList.toArray();
        this.nestedFound = this.navItems.some((/**
         * @param {?} item
         * @return {?}
         */
        item => item.headerLevel === 'secondary' || item.headerLevel === 'tertiary'));
        if (this.nestedFound) {
            this.sidebarService.changeTier(true);
        }
    }
    /**
     * @param {?} e
     * @return {?}
     */
    expandItem(e) {
        if (this.disabled) {
            return;
        }
        this.expanded = !this.expanded;
        for (let i = 0; i < this.children.length; i++) {
            this.children[i].active = false;
        }
        this.children[this.index].active = true;
        this.sidebarNavService.setFocus(this.index);
        this.navItemClick.emit({
            navItem: this.children[this.index],
            title: this.children[this.index].title,
        });
    }
    /**
     * @param {?} __0
     * @return {?}
     */
    getNewIndex({ change, currentIndex = this.index, lastIndex = this.children.length - 1 }) {
        /** @type {?} */
        const getPossibleIndex = (/**
         * @return {?}
         */
        () => {
            if (currentIndex + change < 0) {
                return lastIndex;
            }
            else if (currentIndex + change > lastIndex) {
                return 0;
            }
            return currentIndex + change;
        });
        /** @type {?} */
        const possibleIndex = getPossibleIndex();
        if (this.children[possibleIndex].disabled) {
            return this.getNewIndex({
                change,
                currentIndex: possibleIndex,
                lastIndex,
            });
        }
        return possibleIndex;
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onKeyDown(event) {
        /** @type {?} */
        let newIndex;
        // tslint:disable-next-line: deprecation
        /** @type {?} */
        const key = event.key || event.which || event.keyCode;
        switch (key) {
            case SPACE:
            case ENTER:
            case ' ':
            case 'Enter':
                this.expandItem(event);
                break;
            case UP_ARROW:
            case LEFT_ARROW:
            case 'ArrowUp':
            case 'ArrowLeft':
                newIndex = this.getNewIndex({
                    change: -1,
                });
                this.sidebarNavService.setFocus(newIndex);
                break;
            case RIGHT_ARROW:
            case DOWN_ARROW:
            case 'ArrowRight':
            case 'ArrowDown':
                newIndex = this.getNewIndex({
                    change: 1,
                });
                this.sidebarNavService.setFocus(newIndex);
                break;
            case PAGE_UP:
            case HOME:
            case 'PageUp':
            case 'Home':
                newIndex = this.getNewIndex({
                    currentIndex: this.children.length - 1,
                    change: 1,
                });
                this.sidebarNavService.setFocus(newIndex);
                break;
            case PAGE_DOWN:
            case END:
            case 'PageDown':
            case 'End':
                newIndex = this.getNewIndex({
                    currentIndex: 0,
                    change: -1,
                });
                this.sidebarNavService.setFocus(newIndex);
                break;
            default:
                break;
        }
        event.preventDefault();
    }
}
SidebarNavItemComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-sidebar-nav-item',
                template: `
    <!-- default always here -->
    <div
      #navItemRef
      aria-current="false"
      class="md-list-item"
      [ngClass]="[
        active ? 'active' : '',
        disabled ? 'disabled' : '',
        isReadOnly ? 'md-list-item--read-only' : '',
        separator ? 'md-list-item--separator' : '',
        className
      ]"
      role="listitem"
      tabindex="0"
      (click)="expandItem($event)"
      (keydown)="onKeyDown($event)"
    >
      <!-- Icon conditional here -->
      <div class="md-list-item__left" *ngIf="icon">
        <i class="md-icon icon" [ngClass]="[
          icon ? 'icon-' + this.icon : '',
          iconClass
        ]"></i>
      </div>

      <div class="md-list-item__center">{{ title }}</div>

      <!-- Conditional based on children -->
      <div class="md-list-item__right" *ngIf="navItems.length > 1">
        <i class="md-icon icon" [ngClass]="[
          expanded ? 'icon-arrow-up_12' : 'icon-arrow-down_12'
        ]"></i>
      </div>
    </div>

    <!-- Expansion conditional -->
    <div
      *ngIf="navItems?.length > 1"
      class="md-sidebar-nav__group"
      [ngClass]="[
        headerLevel ? 'md-sidebar-nav__group--' + headerLevel : '',
        navItems.length > 1 || expanded ? 'md-sidebar-nav__group--expanded' : '',
        navItems.length === 0 || !expanded ? 'md-sidebar-nav__group--collapsed' : ''
      ]"
    >
      <ng-content> </ng-content>
    </div>
  `
            }] }
];
/** @nocollapse */
SidebarNavItemComponent.ctorParameters = () => [
    { type: SidebarNavService },
    { type: SidebarService }
];
SidebarNavItemComponent.propDecorators = {
    title: [{ type: Input }],
    headerLevel: [{ type: Input }],
    expanded: [{ type: Input }],
    active: [{ type: Input }],
    icon: [{ type: Input }],
    disabled: [{ type: Input }],
    isReadOnly: [{ type: Input }],
    separator: [{ type: Input }],
    iconClass: [{ type: Input }],
    className: [{ type: Input }],
    navItemRef: [{ type: ViewChild, args: ['navItemRef',] }],
    navItemClick: [{ type: Output }],
    navItemList: [{ type: ContentChildren, args: [SidebarNavItemComponent,] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SidebarNavComponent {
    /**
     * @param {?} sidebarNavService
     */
    constructor(sidebarNavService) {
        this.sidebarNavService = sidebarNavService;
        /**
         * \@prop Optional string to be used for Section Title | ''
         */
        this.title = '';
        /**
         * \@prop Optional css class string with md-list | ''
         */
        this.listClass = '';
        this.navItems = [];
        this.subs = new Subscription();
    }
    /**
     * @return {?}
     */
    ngAfterContentInit() {
        this.sidebarNavService.setSidebarNavItems(this.navItemLists.toArray());
        this.subs.add(this.navItemLists.changes.subscribe((/**
         * @param {?} navItems
         * @return {?}
         */
        navItems => {
            this.sidebarNavService.setSidebarNavItems(navItems.toArray());
        })));
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.subs.unsubscribe();
    }
}
SidebarNavComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-sidebar-nav',
                template: `
    <div
      class="md-sidebar-nav"
      [ngClass]="{
        'md-sidebar-nav--header': title
      }"
    >
      <div *ngIf="title" class="md-sidebar-nav__header">
        {{ title }}
      </div>

      <div
        class="md-list md-sidebar-nav__group md-sidebar-nav__group--primary"
        [ngClass]="[listClass]"
        role="list"
      >
        <ng-content></ng-content>
      </div>
    </div>
  `,
                providers: [SidebarNavService]
            }] }
];
/** @nocollapse */
SidebarNavComponent.ctorParameters = () => [
    { type: SidebarNavService }
];
SidebarNavComponent.propDecorators = {
    title: [{ type: Input }],
    listClass: [{ type: Input }],
    navItemLists: [{ type: ContentChildren, args: [SidebarNavItemComponent, { descendants: true },] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SidebarNavModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: SidebarNavModule,
            providers: [],
        };
    }
}
SidebarNavModule.decorators = [
    { type: NgModule, args: [{
                declarations: [SidebarNavComponent],
                imports: [
                    CommonModule,
                ],
                exports: [SidebarNavComponent],
                schemas: [CUSTOM_ELEMENTS_SCHEMA],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SidebarNavItemModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: SidebarNavItemModule,
            providers: [],
        };
    }
}
SidebarNavItemModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    AvatarModule,
                ],
                exports: [SidebarNavItemComponent],
                declarations: [SidebarNavItemComponent],
                schemas: [CUSTOM_ELEMENTS_SCHEMA],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SidebarHeaderComponent {
    /**
     * @return {?}
     */
    ngOnInit() { }
}
SidebarHeaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-sidebar-header',
                template: `<ng-content></ng-content>`,
                host: {
                    'class': 'md-sidebar__header',
                }
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SidebarHeaderModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: SidebarHeaderModule,
            providers: [],
        };
    }
}
SidebarHeaderModule.decorators = [
    { type: NgModule, args: [{
                declarations: [SidebarHeaderComponent],
                imports: [
                    CommonModule
                ],
                exports: [SidebarHeaderComponent],
                schemas: [CUSTOM_ELEMENTS_SCHEMA],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SidebarFooterComponent {
    constructor() { }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
SidebarFooterComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-sidebar-footer',
                template: `<ng-content></ng-content>`,
                host: {
                    'class': 'md-sidebar__footer'
                }
            }] }
];
/** @nocollapse */
SidebarFooterComponent.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SidebarFooterModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: SidebarFooterModule,
            providers: [],
        };
    }
}
SidebarFooterModule.decorators = [
    { type: NgModule, args: [{
                declarations: [SidebarFooterComponent],
                imports: [
                    CommonModule
                ],
                exports: [SidebarFooterComponent],
                schemas: [CUSTOM_ELEMENTS_SCHEMA]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
let moment = require('moment');
if ('default' in moment) {
    moment = moment['default'];
}
class TimePickerService {
    constructor() {
        this.dayChange = 0;
        this.regIsHM = /^h|m$/i;
        this.regIsHMValue = /^\d*\d$/;
        this.regIsPre = /^pre$/i;
        this.regIsPreValue = /^am|pm$/i;
        this.config = {
            time: {
                format: 'HH:mm'
            },
            m: {
                interval: 1,
                intervalUnit: 'm',
                format: 'mm'
            },
            h: {
                interval: 1,
                intervalUnit: 'h',
                format: 'HH'
            },
            pre: {
                interval: 12,
                intervalUnit: 'h',
                format: 'A'
            }
        };
        this.selectedTime = moment();
        this.selected = new Subject();
        this.selected$ = this.selected.asObservable();
        this.militaryTime = false;
        this.military = new Subject();
        this.military$ = this.military.asObservable();
        this.isShow = new Subject();
        this.isShow$ = this.isShow.asObservable();
        this.validTime = (/**
         * @param {?} unit
         * @param {?} v
         * @return {?}
         */
        (unit, v) => {
            return this.regIsHM.test(unit) && this.regIsHMValue.test(v);
        });
        this.validPre = (/**
         * @param {?} unit
         * @param {?} v
         * @return {?}
         */
        (unit, v) => {
            return this.regIsPre.test(unit) && this.regIsPreValue.test(v);
        });
        this.getTimeString = (/**
         * @return {?}
         */
        () => {
            return this.selectedTime.format(this.config.time.format);
        });
        this.initTime = (/**
         * @param {?} v
         * @return {?}
         */
        (v) => {
            this.selected.next(moment(v));
        });
        this.setMilitary = (/**
         * @param {?} v
         * @return {?}
         */
        (v) => {
            this.military.next(v);
        });
        this.setMinuteInterval = (/**
         * @param {?} v
         * @return {?}
         */
        (v) => {
            this.config.m.interval = v;
        });
        this.getUnitText = (/**
         * @param {?} unit
         * @return {?}
         */
        (unit) => {
            return this.selectedTime.format(this.config[unit].format);
        });
        this.changeTimeByInterval = (/**
         * @param {?} unit
         * @param {?} multiplier
         * @return {?}
         */
        (unit, multiplier) => {
            /** @type {?} */
            const conf = this.config[unit];
            this.changeTime(conf.intervalUnit, conf.interval * multiplier);
        });
        this.changeTime = (/**
         * @param {?} unit
         * @param {?} change
         * @return {?}
         */
        (unit, change) => {
            /** @type {?} */
            const newTime = moment(this.selectedTime).add(change, unit);
            /** @type {?} */
            const startDay = moment().startOf('day');
            if (change > 0) {
                if (newTime.clone().startOf('day').isAfter(startDay)) {
                    newTime.add(-1, 'day');
                    this.dayChange = 1;
                }
            }
            else {
                if (newTime.clone().startOf('day').isAfter(startDay)) {
                    newTime.add(1, 'day');
                    this.dayChange = -1;
                }
            }
            this.selected.next(newTime);
        });
        this.setTime = (/**
         * @param {?=} hour
         * @param {?=} minute
         * @param {?=} pre
         * @return {?}
         */
        (hour = this.getUnitText('h'), minute = this.getUnitText('m'), pre = this.getUnitText('pre')) => {
            /** @type {?} */
            const meridianHour = pre === 'PM' && parseInt(hour, 10) < 12
                ? parseInt(hour, 10) + 12
                : pre === 'AM' && parseInt(hour, 10) === 12 ? 0 : hour;
            this.dayChange = 0;
            this.selected.next(this.selectedTime.clone().hour(meridianHour).minute(minute));
        });
        this.setTimeByUnit = (/**
         * @param {?} unit
         * @param {?} value
         * @return {?}
         */
        (unit, value) => {
            /** @type {?} */
            const maxHour = this.military ? 24 : 13;
            if (unit === 'm' && value > -1 && value < 60) {
                this.setTime(undefined, value, undefined);
            }
            else if (unit === 'h' && value > -1 && value < maxHour) {
                this.setTime(value, undefined, undefined);
            }
            else if (unit === 'pre') {
                this.setTime(undefined, undefined, value);
            }
        });
        this.selected$.subscribe((/**
         * @param {?} v
         * @return {?}
         */
        v => {
            this.selectedTime = v;
        }));
        this.military$.subscribe((/**
         * @param {?} v
         * @return {?}
         */
        v => {
            this.militaryTime = v;
            /** @type {?} */
            const conf = this.config;
            if (v) {
                conf.h.format = 'HH';
                conf.time.format = 'HH:mm';
            }
            else {
                conf.h.format = 'hh';
                conf.time.format = 'LT';
            }
        }));
    }
    /**
     * @param {?} isOpen
     * @return {?}
     */
    show(isOpen) {
        this.isShow.next(isOpen);
    }
}
TimePickerService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
TimePickerService.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TimePickerComponent {
    /**
     * @param {?} timePickerService
     * @param {?} overlay
     * @param {?} elementRef
     * @param {?} viewContainerRef
     */
    constructor(timePickerService, overlay, elementRef, viewContainerRef) {
        this.timePickerService = timePickerService;
        this.overlay = overlay;
        this.elementRef = elementRef;
        this.viewContainerRef = viewContainerRef;
        /**
         * \@prop Set the value of the Input element | ''
         */
        this.value = '';
        /**
         * \@prop Choose to use military time | false
         */
        this.militaryTime = false;
        /**
         * \@prop Determine the minute interval | 1
         */
        this.minuteInterval = 1;
        /**
         * \@prop Optional overlay positioin | ''
         */
        this.originX = 'start';
        /**
         * \@prop Optional overlay positioin | ''
         */
        this.originY = 'bottom';
        /**
         * \@prop Optional overlay positioin | ''
         */
        this.overlayX = 'start';
        /**
         * \@prop Optional overlay positioin | ''
         */
        this.overlayY = 'top';
        /**
         * \@prop Callback function invoked when user makes a change | null
         */
        this.whenChange = new EventEmitter();
        this.onFocus = (/**
         * @return {?}
         */
        () => {
            this.show();
        });
        this.show = (/**
         * @return {?}
         */
        () => {
            this.timePickerService.show(true);
        });
        this.dismiss = (/**
         * @return {?}
         */
        () => {
            this.timePickerService.show(false);
        });
        this.showContent = (/**
         * @return {?}
         */
        () => {
            if (this.overlayRef && !this.overlayRef.hasAttached()) {
                this.overlayRef.attach(this.tp);
            }
        });
        this.dismissContent = (/**
         * @return {?}
         */
        () => {
            if (this.overlayRef && this.overlayRef.hasAttached()) {
                this.overlayRef.detach();
                if (this.overlayRef.backdropElement) {
                    this.overlayRef.backdropElement.remove();
                }
            }
        });
    }
    /**
     * \@prop Optional css class string | ''
     * @param {?} value
     * @return {?}
     */
    set className(value) {
        this.elementRef.nativeElement.classList.add(value);
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        /** @type {?} */
        const ts = this.timePickerService;
        ts.setMilitary(this.militaryTime);
        ts.setMinuteInterval(this.minuteInterval);
        ts.selected$.subscribe((/**
         * @param {?} v
         * @return {?}
         */
        v => {
            this.value = ts.getTimeString();
            this.whenChange.emit(v);
        }));
        ts.initTime(this.selectedTime);
        /** @type {?} */
        const strategy = this.overlay
            .position()
            .flexibleConnectedTo(this.connectToInput)
            .withPositions([
            {
                originX: this.originX,
                originY: this.originY,
                overlayX: this.overlayX, overlayY: this.overlayY
            }
        ]);
        /** @type {?} */
        const config = new OverlayConfig({
            hasBackdrop: true,
            panelClass: ['md-datepicker-container', 'md-timepicker-container'],
            backdropClass: 'cdk-overlay-transparent-backdrop',
            positionStrategy: strategy
        });
        this.overlayRef = this.overlay.create(config);
        this.tp = new TemplatePortal(this.timePickerCon, this.viewContainerRef);
        this.timePickerService.isShow$.subscribe((/**
         * @param {?} isOpen
         * @return {?}
         */
        isOpen => {
            if (isOpen) {
                this.showContent();
            }
            else {
                this.dismissContent();
            }
        }));
        this.overlayRef.backdropClick().subscribe((/**
         * @return {?}
         */
        () => {
            this.dismiss();
        }));
        this.dismiss();
    }
}
TimePickerComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-time-picker',
                template: `
    <div class='md-input-container  read-only' #connectToInput>
      <input class="md-input read-only dirty"
      tabindex="0"
      type="text"
      name="md-timepicker__input-407"
      readonly=""
      (focus) = 'onFocus()'
      [value]="value">
    </div>
    <ng-template #timePickerCon>
      <md-time-picker-dropdown>
        <md-time-selector unit='h'></md-time-selector>:
        <md-time-selector unit='m'></md-time-selector>
        <md-time-selector unit='pre' *ngIf='!militaryTime'></md-time-selector>
      </md-time-picker-dropdown>
    </ng-template>
  `,
                host: {
                    class: 'md-timepicker-container'
                },
                providers: [TimePickerService]
            }] }
];
/** @nocollapse */
TimePickerComponent.ctorParameters = () => [
    { type: TimePickerService },
    { type: Overlay },
    { type: ElementRef },
    { type: ViewContainerRef }
];
TimePickerComponent.propDecorators = {
    value: [{ type: Input }],
    className: [{ type: Input }],
    militaryTime: [{ type: Input }],
    minuteInterval: [{ type: Input }],
    selectedTime: [{ type: Input }],
    originX: [{ type: Input }],
    originY: [{ type: Input }],
    overlayX: [{ type: Input }],
    overlayY: [{ type: Input }],
    whenChange: [{ type: Output }],
    timePickerCon: [{ type: ViewChild, args: ['timePickerCon',] }],
    connectToInput: [{ type: ViewChild, args: ['connectToInput',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TimePickerDropdownComponent {
    constructor() { }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
TimePickerDropdownComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-time-picker-dropdown',
                template: `
    <div class='md-timepicker__dropdown'>
      <div class="inline-flex">
        <ng-content></ng-content>
      </div>
    </div>
  `,
                host: {
                    class: 'md-timepicker__dropdown-container'
                }
            }] }
];
/** @nocollapse */
TimePickerDropdownComponent.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TimePickerDropdownModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: TimePickerDropdownModule,
            providers: [],
        };
    }
}
TimePickerDropdownModule.decorators = [
    { type: NgModule, args: [{
                declarations: [TimePickerDropdownComponent],
                imports: [
                    CommonModule
                ],
                exports: [TimePickerDropdownComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TimeSelectorComponent {
    /**
     * @param {?} timePickerService
     */
    constructor(timePickerService) {
        this.timePickerService = timePickerService;
        this.regNumOnly = /^\d$/;
        /**
         * \@prop Set the type for the Input element | 'text'
         */
        this.type = 'text';
        /**
         * \@prop Set the unit of time | ''
         */
        this.unit = 'm';
        /**
         * \@prop Set the value of the Input element | ''
         */
        this.value = '00';
        this.updateText = (/**
         * @return {?}
         */
        () => {
            this.value = this.timePickerService.getUnitText(this.unit);
        });
        this.updateValue = (/**
         * @return {?}
         */
        () => {
            /** @type {?} */
            const el = this.selectInput.nativeElement;
            /** @type {?} */
            const s = this.timePickerService;
            /** @type {?} */
            let newValue = el.value;
            if (s.validTime(this.unit, newValue)) {
                /** @type {?} */
                const numValue = parseInt(newValue, 10);
                if (this.unit === 'h') {
                    /** @type {?} */
                    const maxHour = s.militaryTime ? 23 : 12;
                    if (numValue > maxHour) {
                        newValue = maxHour;
                        el.value = newValue;
                    }
                    else {
                        newValue = numValue;
                    }
                }
                else if (this.unit === 'm') {
                    if (numValue > 59) {
                        newValue = 59;
                        el.value = newValue;
                    }
                    else {
                        newValue = numValue;
                    }
                }
                s.setTimeByUnit(this.unit, newValue);
            }
            else if (s.validPre(this.unit, newValue)) {
                newValue = newValue.toUpperCase();
                s.setTimeByUnit(this.unit, newValue);
            }
            else {
                return false;
            }
            return true;
        });
        this.updatePre = (/**
         * @param {?} v
         * @return {?}
         */
        (v) => {
            if (this.unit === 'pre') {
                this.timePickerService.setTimeByUnit(this.unit, v);
            }
        });
        this.onUpClick = (/**
         * @return {?}
         */
        () => {
            this.timePickerService.changeTimeByInterval(this.unit, 1);
        });
        this.onDownClick = (/**
         * @return {?}
         */
        () => {
            this.timePickerService.changeTimeByInterval(this.unit, -1);
        });
        this.onChange = (/**
         * @param {?} e
         * @return {?}
         */
        (e) => {
            if (!this.updateValue()) {
                e.stopPropagation();
                return false;
            }
        });
        this.onWheel = (/**
         * @param {?} e
         * @return {?}
         */
        (e) => {
            if (e.deltaY < 0) {
                this.timePickerService.changeTimeByInterval(this.unit, 1);
            }
            else if (e.deltaY > 0) {
                this.timePickerService.changeTimeByInterval(this.unit, -1);
            }
            e.preventDefault();
        });
        this.onBlur = (/**
         * @return {?}
         */
        () => {
            if (!this.updateValue()) {
                this.selectInput.nativeElement.value = this.value;
            }
        });
        this.onKeydown = (/**
         * @param {?} e
         * @return {?}
         */
        (e) => {
            /** @type {?} */
            let stopFlag = false;
            /** @type {?} */
            let preventFlay = !this.regNumOnly.test(e.key);
            switch (e.keyCode) {
                case 38:
                    this.onUpClick();
                    stopFlag = true;
                    break;
                case 40:
                    this.onDownClick();
                    stopFlag = true;
                    break;
                case 65:
                    this.updatePre('AM');
                    stopFlag = true;
                    break;
                case 80:
                    this.updatePre('PM');
                    stopFlag = true;
                    break;
                // detele
                case 8:
                case 46:
                    this.selectInput.nativeElement.value = '';
                    preventFlay = false;
                    break;
                // tab enter
                case 9:
                case 108:
                case 13:
                    preventFlay = false;
                    break;
                default:
                    break;
            }
            if (stopFlag) {
                e.stopPropagation();
            }
            if (preventFlay) {
                e.preventDefault();
            }
        });
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.timePickerService.selected$.subscribe((/**
         * @param {?} v
         * @return {?}
         */
        v => {
            this.updateText();
        }));
        this.updateText();
    }
}
TimeSelectorComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-time-selector',
                template: `
    <i class='icon icon-arrow-up_24 arrow' (click)='onUpClick()' role="button"></i>
    <input [type]='type'
    minLength=2
    maxLength=2
    tabIndex=0
    [value]='value'
    (change)='onChange($event)'
    (wheel)='onWheel($event)'
    (blur)='onBlur()'
    (keydown)='onKeydown($event)'
    #selectInput />
    <i class='icon icon-arrow-down_24 arrow' (click)='onDownClick()' role="button"></i>
  `,
                styles: [':host{display: flex; flex-flow: column; padding-right: 0.4375rem; padding-left: 0.4375rem;}',
                    ':host *{ width: 3rem !important; display: inline-block !important;}',
                    '.arrow { line-height: 2.25rem !important; }']
            }] }
];
/** @nocollapse */
TimeSelectorComponent.ctorParameters = () => [
    { type: TimePickerService }
];
TimeSelectorComponent.propDecorators = {
    type: [{ type: Input }],
    unit: [{ type: Input }],
    value: [{ type: Input }],
    selectInput: [{ type: ViewChild, args: ['selectInput',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TimeSelectorModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: TimeSelectorModule,
            providers: [],
        };
    }
}
TimeSelectorModule.decorators = [
    { type: NgModule, args: [{
                declarations: [TimeSelectorComponent],
                imports: [
                    CommonModule
                ],
                exports: [TimeSelectorComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TimePickerModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: TimePickerModule,
            providers: [],
        };
    }
}
TimePickerModule.decorators = [
    { type: NgModule, args: [{
                declarations: [TimePickerComponent],
                imports: [
                    CommonModule,
                    TimePickerDropdownModule,
                    TimeSelectorModule
                ],
                exports: [TimePickerComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
let moment$1 = require('moment');
if ('default' in moment$1) {
    moment$1 = moment$1['default'];
}
/**
 * @param {?} utcOffset
 * @return {?}
 */
function newDateWithOffset(utcOffset) {
    return moment$1()
        .utc()
        .utcOffset(utcOffset);
}
/**
 * @param {?} maybeFixedUtcOffset
 * @return {?}
 */
function now(maybeFixedUtcOffset) {
    if (maybeFixedUtcOffset == null) {
        return moment$1();
    }
    return newDateWithOffset(maybeFixedUtcOffset);
}
/**
 * @param {?} date
 * @return {?}
 */
function getStartOfWeek(date) {
    return date.startOf('week');
}
/**
 * @param {?} date
 * @return {?}
 */
function getStartOfMonth(date) {
    return date.startOf('month');
}
// Returns day of month
/**
 * @param {?} date
 * @return {?}
 */
function getDate(date) {
    return date.get('date');
}
/**
 * @param {?} date
 * @return {?}
 */
function getMonth(date) {
    return date.get('month');
}
/**
 * @param {?} date
 * @param {?} amount
 * @return {?}
 */
function addDays(date, amount) {
    return date.add(amount, 'days');
}
/**
 * @param {?} date
 * @param {?} amount
 * @return {?}
 */
function addWeeks(date, amount) {
    return date.add(amount, 'weeks');
}
/**
 * @param {?} date
 * @param {?} amount
 * @return {?}
 */
function addMonths(date, amount) {
    return date.add(amount, 'months');
}
/**
 * @param {?} date
 * @param {?} amount
 * @return {?}
 */
function subtractDays(date, amount) {
    return date.subtract(amount, 'days');
}
/**
 * @param {?} date
 * @param {?} amount
 * @return {?}
 */
function subtractMonths(date, amount) {
    return date.subtract(amount, 'months');
}
/**
 * @param {?} date
 * @return {?}
 */
function getLocaleData(date) {
    return date.localeData();
}
/**
 * @param {?} locale
 * @param {?} date
 * @return {?}
 */
function getWeekdayMinInLocale(locale, date) {
    return locale.weekdaysMin(date).substr(0, 1);
}
/**
 * @param {?} date
 * @param {?=} locale
 * @return {?}
 */
function localizeDate(date, locale = moment$1.locale()) {
    return date.clone().locale(locale);
}
/**
 * @param {?} moment1
 * @param {?} moment2
 * @return {?}
 */
function isSameDay(moment1, moment2) {
    if (moment1 && moment2) {
        return moment1.isSame(moment2, 'day');
    }
    else {
        return !moment1 && !moment2;
    }
}
/**
 * @param {?} date1
 * @param {?} date2
 * @return {?}
 */
function isSameMonth(date1, date2) {
    if (date1 && date2) {
        return date1.isSame(date2, 'month');
    }
    else {
        return !date1 && !date2;
    }
}
/**
 * @param {?} day
 * @param {?} o
 * @return {?}
 */
function isDayDisabled(day, o) {
    /** @type {?} */
    const minDate = o.minDate;
    /** @type {?} */
    const maxDate = o.maxDate;
    /** @type {?} */
    const filterDate = o.filterDate;
    return ((minDate && day.isBefore(moment$1(minDate), 'day')) ||
        (maxDate && day.isAfter(moment$1(maxDate), 'day')) ||
        (filterDate && filterDate(day.clone())) ||
        false);
}
/**
 * @param {?} day
 * @param {?} minDate
 * @return {?}
 */
function shouldPrevMonthDisable(day, minDate) {
    /** @type {?} */
    const firstDayOfCurrMonth = day.clone().startOf('month');
    return (minDate && !moment$1(minDate).isBefore(firstDayOfCurrMonth));
}
/**
 * @param {?} day
 * @param {?} maxDate
 * @return {?}
 */
function shouldNextMonthDisable(day, maxDate) {
    /** @type {?} */
    const lastDayOfCurrMonth = day.clone().endOf('month');
    return (maxDate && !moment$1(maxDate).isAfter(lastDayOfCurrMonth));
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
let moment$2 = require('moment');
if ('default' in moment$2) {
    moment$2 = moment$2['default'];
}
class DatePickerService {
    constructor() {
        this.selectedDate = moment$2();
        this.focusedDate = moment$2(); // auto focus today
        // auto focus today
        this.viewedDate = moment$2();
        this.targetStart = true;
        this.weekDaysMap = [0, 1, 2, 3, 4, 5, 6];
        this.nowDate = moment$2();
        this.selected = new Subject();
        this.selected$ = this.selected.asObservable();
        this.focused = new Subject();
        this.focused$ = this.focused.asObservable();
        this.viewed = new Subject();
        this.viewed$ = this.viewed.asObservable();
        this.hovered = new Subject();
        this.hovered$ = this.hovered.asObservable();
        this.startDate = new Subject();
        this.startDate$ = this.startDate.asObservable();
        this.endDate = new Subject();
        this.endDate$ = this.endDate.asObservable();
        this.viewMonthChange = new Subject();
        this.viewMonthChange$ = this.viewMonthChange.asObservable();
        this.isShowDatepicker = new Subject();
        this.isShowDatepicker$ = this.isShowDatepicker.asObservable();
        this.constStartOfWeek = getStartOfWeek(moment$2());
        this.initConfig = (/**
         * @param {?} config
         * @return {?}
         */
        (config) => {
            for (const n in config) {
                if (config.hasOwnProperty(n)) {
                    this[n] = config[n];
                }
            }
            this.config = config;
        });
        this.select = (/**
         * @param {?} d
         * @return {?}
         */
        (d) => {
            if (this.isRange) {
                if (!d || this.isDayInRange(d)) {
                    if (this.targetStart) {
                        this.startDate.next(d);
                    }
                    else {
                        this.endDate.next(d);
                    }
                }
            }
            else {
                this.selected.next(d);
            }
        });
        this.getNewDayByOffset = (/**
         * @param {?} d
         * @param {?=} offset
         * @return {?}
         */
        (d, offset) => {
            if (!d) {
                return d;
            }
            /** @type {?} */
            let _d = d.clone();
            if (offset !== undefined) {
                if (offset >= 0) {
                    _d = addDays(_d, offset);
                }
                else {
                    _d = subtractDays(_d, -offset);
                }
            }
            return _d;
        });
        this.focus = (/**
         * @param {?} d
         * @param {?=} offset
         * @return {?}
         */
        (d, offset) => {
            /** @type {?} */
            const _d = offset ? this.getNewDayByOffset(d, offset) : d;
            this.focused.next(_d);
        });
        this.view = (/**
         * @param {?} d
         * @return {?}
         */
        (d) => {
            this.viewed.next(d);
        });
        this.hover = (/**
         * @param {?} d
         * @param {?=} offset
         * @return {?}
         */
        (d, offset) => {
            /** @type {?} */
            const _d = offset ? this.getNewDayByOffset(d, offset) : d;
            this.hovered.next(_d);
        });
        this.isSameDay = (/**
         * @param {?} d1
         * @param {?} d2
         * @return {?}
         */
        (d1, d2) => {
            return isSameDay(d1, d2);
        });
        // calendar
        this.getMonthName = (/**
         * @param {?} date
         * @return {?}
         */
        date => {
            return localizeDate(date, this.locale).format(this.monthFormat);
        });
        this.shouldNextMonthDisable = (/**
         * @param {?} date
         * @return {?}
         */
        date => {
            return shouldNextMonthDisable(date, this.maxDate);
        });
        this.shouldPrevMonthDisable = (/**
         * @param {?} date
         * @return {?}
         */
        date => {
            return shouldPrevMonthDisable(date, this.maxDate);
        });
        this.getWeekDayName = (/**
         * @param {?} offset
         * @return {?}
         */
        offset => {
            /** @type {?} */
            const day = addDays(localizeDate(this.constStartOfWeek, this.locale), offset);
            /** @type {?} */
            const localeData = getLocaleData(day);
            return getWeekdayMinInLocale(localeData, day);
        });
        this.getLocaleData = (/**
         * @param {?} d
         * @return {?}
         */
        (d) => {
            return getLocaleData(d);
        });
        // month
        this.getMonth = (/**
         * @param {?} day
         * @return {?}
         */
        day => {
            return getMonth(day);
        });
        this.getStartWeekOfMonth = (/**
         * @param {?} day
         * @return {?}
         */
        day => {
            return getStartOfWeek(getStartOfMonth(day.clone()));
        });
        this.getNextWeekStart = (/**
         * @param {?} day
         * @return {?}
         */
        day => {
            return addWeeks(day.clone(), 1);
        });
        this.isSameMonth = (/**
         * @param {?} d1
         * @param {?} d2
         * @return {?}
         */
        (d1, d2) => {
            return isSameMonth(d1, d2);
        });
        this.viewNextMonth = (/**
         * @return {?}
         */
        () => {
            this.view(addMonths(this.viewedDate.clone(), 1));
        });
        this.viewPreMonth = (/**
         * @return {?}
         */
        () => {
            this.view(subtractMonths(this.viewedDate.clone(), 1));
        });
        // week
        this.getDaysInWeek = (/**
         * @param {?} day
         * @return {?}
         */
        day => {
            /** @type {?} */
            const days = [];
            /** @type {?} */
            const startDay = getStartOfWeek(day.clone());
            for (const n in this.weekDaysMap) {
                if (this.weekDaysMap.hasOwnProperty(n)) {
                    days.push(addDays(startDay.clone(), n));
                }
            }
            return days;
        });
        // day
        this.getDate = (/**
         * @param {?} day
         * @return {?}
         */
        day => {
            return getDate(day);
        });
        this.isToday = (/**
         * @param {?} day
         * @return {?}
         */
        (day) => {
            return isSameDay(day, now(null));
        });
        this.isSelected = (/**
         * @param {?} day
         * @return {?}
         */
        (day) => {
            return isSameDay(day, this.selectedDate);
        });
        this.isFocus = (/**
         * @param {?} day
         * @return {?}
         */
        (day) => {
            return isSameDay(day, this.focusedDate);
        });
        this.isOutsideMonth = (/**
         * @param {?} day
         * @param {?} month
         * @return {?}
         */
        (day, month) => {
            return month !== getMonth(day);
        });
        this.isDayDisabled = (/**
         * @param {?} day
         * @return {?}
         */
        (day) => {
            return isDayDisabled(day, {
                minDate: this.minDate,
                maxDate: this.maxDate,
                filterDate: this.filterDate
            });
        });
        this.selected$.subscribe((/**
         * @param {?} o
         * @return {?}
         */
        o => {
            this.selectedDate = o;
            this.focus(o);
        }));
        this.focused$.subscribe((/**
         * @param {?} o
         * @return {?}
         */
        o => {
            this.focusedDate = o;
            this.view(o);
        }));
        this.viewed$.subscribe((/**
         * @param {?} o
         * @return {?}
         */
        o => {
            if (this.viewedDate && !isSameMonth(this.viewedDate, o)) {
                this.viewMonthChange.next(this.getMonth(o));
            }
            this.viewedDate = o;
        }));
        this.hovered$.subscribe((/**
         * @param {?} o
         * @return {?}
         */
        o => {
            this.hoverDate = o;
        }));
        this.startDate$.subscribe((/**
         * @param {?} o
         * @return {?}
         */
        o => {
            this.start = o;
            if (o) {
                this.minDate = addDays(o.clone(), 1);
                this.focus(o);
            }
            else {
                this.minDate = undefined;
                this.view(this.end || this.nowDate);
            }
            this.hover(o);
        }));
        this.endDate$.subscribe((/**
         * @param {?} o
         * @return {?}
         */
        o => {
            this.end = o;
            if (o) {
                this.maxDate = subtractDays(o.clone(), 1);
                this.focus(o);
            }
            else {
                this.maxDate = undefined;
                this.view(this.start || this.nowDate);
            }
            this.hover(o);
        }));
    }
    /**
     * @param {?} ifStart
     * @return {?}
     */
    changeTarget(ifStart) {
        this.targetStart = ifStart;
    }
    /**
     * @return {?}
     */
    getDateRangeString() {
        return (this.start ? this.start : '') + '-' + (this.end ? this.end : '');
    }
    /**
     * @param {?} day
     * @return {?}
     */
    isDayInRange(day) {
        return !isDayDisabled(day, {
            minDate: this.start ? this.start : this.hoverDate,
            maxDate: this.end ? this.end : this.hoverDate,
            filterDate: this.filterDate
        });
    }
    /**
     * @param {?} day
     * @param {?} op
     * @return {?}
     */
    isActiveDay(day, op) {
        return !isDayDisabled(day, op);
    }
    /**
     * @return {?}
     */
    hasEitherRange() {
        return this.start || this.end;
    }
    /**
     * @return {?}
     */
    hasFinishRange() {
        return this.start && this.end;
    }
    /**
     * @param {?} day
     * @return {?}
     */
    isStartDay(day) {
        return isSameDay(day, this.start);
    }
    /**
     * @param {?} day
     * @return {?}
     */
    isEndDay(day) {
        return isSameDay(day, this.end);
    }
    /**
     * @param {?} v
     * @return {?}
     */
    changeStartDate(v) {
        this.startDate.next(v);
    }
    /**
     * @param {?} v
     * @return {?}
     */
    changeEndDate(v) {
        this.endDate.next(v);
    }
    // public
    /**
     * @param {?} isOpen
     * @return {?}
     */
    setOpenStatus(isOpen) {
        this.isShowDatepicker.next(isOpen);
    }
}
DatePickerService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
DatePickerService.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
let moment$3 = require('moment');
if ('default' in moment$3) {
    moment$3 = moment$3['default'];
}
class DatePickerComponent {
    /**
     * @param {?} datePickerService
     * @param {?} overlay
     * @param {?} elementRef
     * @param {?} viewContainerRef
     */
    constructor(datePickerService, overlay, elementRef, viewContainerRef) {
        this.datePickerService = datePickerService;
        this.overlay = overlay;
        this.elementRef = elementRef;
        this.viewContainerRef = viewContainerRef;
        /**
         * \@prop Set the direction in which the DatePicker opens | 'bottom-center'
         */
        this.direction = 'bottom-center';
        /**
         * \@prop Sets the language of the DatePicker | 'en'
         */
        this.locale = 'en';
        /**
         * \@prop Sets the format of the month | 'MMMM YYYY'
         */
        this.monthFormat = 'MMMM YYYY';
        /**
         * \@prop Text to display for blindness accessibility features | 'next'
         */
        this.nextArialLabel = 'next';
        /**
         * \@prop Text to display for blindness accessibility features | 'previous'
         */
        this.previousArialLabel = 'previous';
        /**
         * \@prop Initial Selected Date for DatePicker | moment().toDate()
         */
        this.selectedDate = moment$3();
        /**
         * \@prop Determines if the DatePicker should close when a date is selected | true
         */
        this.shouldCloseOnSelect = true;
        /**
         * \@prop Determines if the DatePicker should show the open/close arrow | false
         */
        this.showArrow = false;
        /**
         * \@prop To enable/disable clicking on underlay to exit modal | false
         */
        this.backdropClickExit = false;
        /**
         * \@prop Optional overlay positioin | ''
         */
        this.originX = 'end';
        /**
         * \@prop Optional overlay positioin | ''
         */
        this.originY = 'top';
        /**
         * \@prop Optional overlay positioin | ''
         */
        this.overlayX = 'start';
        /**
         * \@prop Optional overlay positioin | ''
         */
        this.overlayY = 'bottom';
        /**
         * \@prop Handler invoked when user makes a change within the DatePicker | null
         */
        this.whenChange = new EventEmitter();
        /**
         * \@prop Handler invoked when user makes a change to the selected month within DatePicker | null
         */
        this.whenMonthChange = new EventEmitter();
        /**
         * \@prop Handler invoked when user selects a date within DatePicker | null
         */
        this.whenSelect = new EventEmitter();
        this.show = (/**
         * @return {?}
         */
        () => {
            this.datePickerService.setOpenStatus(true);
        });
        this.dismiss = (/**
         * @return {?}
         */
        () => {
            this.datePickerService.setOpenStatus(false);
        });
        this.showContent = (/**
         * @return {?}
         */
        () => {
            if (this.overlayRef && !this.overlayRef.hasAttached()) {
                this.overlayRef.attach(this.tp);
                this.datePickerService.view(this.selectedDate);
            }
        });
        this.dismissContent = (/**
         * @return {?}
         */
        () => {
            if (this.overlayRef && this.overlayRef.hasAttached()) {
                this.overlayRef.detach();
                if (this.overlayRef.backdropElement) {
                    this.overlayRef.backdropElement.remove();
                }
            }
        });
        this.onPress = (/**
         * @param {?} e
         * @return {?}
         */
        (e) => {
            /** @type {?} */
            const key = e.keyCode;
            /** @type {?} */
            const s = this.datePickerService;
            /** @type {?} */
            let flag = false;
            /** @type {?} */
            let nextDay;
            switch (key) {
                case ENTER:
                case SPACE:
                    s.select(s.focusedDate);
                    this.dismiss();
                    flag = true;
                    break;
                // up
                case UP_ARROW:
                    nextDay = s.getNewDayByOffset(s.focusedDate, -7);
                    s.focus(nextDay);
                    flag = true;
                    break;
                // left
                case LEFT_ARROW:
                    nextDay = s.getNewDayByOffset(s.focusedDate, -1);
                    s.focus(nextDay);
                    flag = true;
                    break;
                // right
                case RIGHT_ARROW:
                    nextDay = s.getNewDayByOffset(s.focusedDate, 1);
                    s.focus(nextDay);
                    flag = true;
                    break;
                // bottom
                case DOWN_ARROW:
                    nextDay = s.getNewDayByOffset(s.focusedDate, 7);
                    s.focus(nextDay);
                    flag = true;
                    break;
                default:
                    break;
            }
            if (flag) {
                e.stopPropagation();
                e.preventDefault();
                return false;
            }
        });
        /** @type {?} */
        const s = this.datePickerService;
        s.initConfig({
            locale: this.locale,
            maxDate: this.maxDate,
            minDate: this.minDate,
            monthFormat: this.monthFormat,
            nextArialLabel: this.nextArialLabel,
            previousArialLabel: this.previousArialLabel,
            filterDate: this.filterDate
        });
        s.selected$.subscribe((/**
         * @param {?} date
         * @return {?}
         */
        date => {
            this.selectedDate = date;
            this.whenSelect.emit(date);
        }));
        s.viewMonthChange$.subscribe((/**
         * @param {?} date
         * @return {?}
         */
        date => {
            this.whenMonthChange.emit(date);
        }));
        s.focused$.subscribe((/**
         * @param {?} date
         * @return {?}
         */
        date => {
            this.whenChange.emit(date);
        }));
    }
    /**
     * \@prop Optional css class string | ''
     * @param {?} value
     * @return {?}
     */
    set className(value) {
        this.elementRef.nativeElement.classList.add(value);
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        /** @type {?} */
        const strategy = this.overlay
            .position()
            .flexibleConnectedTo(this.connectToButton)
            .withPositions([
            {
                originX: this.originX,
                originY: this.originY,
                overlayX: this.overlayX, overlayY: this.overlayY
            }
        ]);
        /** @type {?} */
        const config = new OverlayConfig({
            hasBackdrop: true,
            panelClass: 'md-datepicker-container',
            backdropClass: 'cdk-overlay-transparent-backdrop',
            positionStrategy: strategy
        });
        this.overlayRef = this.overlay.create(config);
        this.tp = new TemplatePortal(this.tempDatepicker, this.viewContainerRef);
        this.overlayRef.keydownEvents().subscribe((/**
         * @param {?} e
         * @return {?}
         */
        (e) => {
            this.onPress(e);
        }));
        this.overlayRef.backdropClick().subscribe((/**
         * @return {?}
         */
        () => {
            this.dismiss();
        }));
        this.datePickerService.isShowDatepicker$.subscribe((/**
         * @param {?} isOpen
         * @return {?}
         */
        isOpen => {
            if (isOpen) {
                this.showContent();
            }
            else {
                this.dismissContent();
            }
        }));
    }
}
DatePickerComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-date-picker',
                template: `
    <div #connectToButton>
      <ng-content></ng-content>
    </div>
    <ng-template #tempDatepicker>
      <div class='md-event-overlay'>
        <div class='md-event-overlay__children md-date-picker'>
          <md-date-picker-calendar></md-date-picker-calendar>
        </div>
      </div>
    </ng-template>
  `,
                host: {
                    class: 'md-datepicker-container'
                },
                providers: [DatePickerService]
            }] }
];
/** @nocollapse */
DatePickerComponent.ctorParameters = () => [
    { type: DatePickerService },
    { type: Overlay },
    { type: ElementRef },
    { type: ViewContainerRef }
];
DatePickerComponent.propDecorators = {
    className: [{ type: Input }],
    direction: [{ type: Input }],
    locale: [{ type: Input }],
    maxDate: [{ type: Input }],
    minDate: [{ type: Input }],
    filterDate: [{ type: Input }],
    monthFormat: [{ type: Input }],
    nextArialLabel: [{ type: Input }],
    previousArialLabel: [{ type: Input }],
    selectedDate: [{ type: Input }],
    shouldCloseOnSelect: [{ type: Input }],
    showArrow: [{ type: Input }],
    backdropClickExit: [{ type: Input }],
    originX: [{ type: Input }],
    originY: [{ type: Input }],
    overlayX: [{ type: Input }],
    overlayY: [{ type: Input }],
    whenChange: [{ type: Output }],
    whenMonthChange: [{ type: Output }],
    whenSelect: [{ type: Output }],
    tempDatepicker: [{ type: ViewChild, args: ['tempDatepicker',] }],
    connectToButton: [{ type: ViewChild, args: ['connectToButton',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DatePickerCalendarComponent {
    /**
     * @param {?} datePickerService
     */
    constructor(datePickerService) {
        this.datePickerService = datePickerService;
        this.offsets = [0, 1, 2, 3, 4, 5, 6];
        this.getWeekDayName = (/**
         * @param {?} offset
         * @return {?}
         */
        offset => {
            return this.datePickerService.getWeekDayName(offset);
        });
        this.onClickPre = (/**
         * @param {?} e
         * @return {?}
         */
        (e) => {
            this.datePickerService.viewPreMonth();
            e.stopPropagation();
            e.preventDefault();
            return false;
        });
        this.onClickNext = (/**
         * @param {?} e
         * @return {?}
         */
        (e) => {
            this.datePickerService.viewNextMonth();
            e.stopPropagation();
            e.preventDefault();
            return false;
        });
        /** @type {?} */
        const s = this.datePickerService;
        this.previousArialLabel = s.previousArialLabel;
        this.nextArialLabel = s.nextArialLabel;
        this.today = s.viewedDate;
        s.viewed$.subscribe((/**
         * @param {?} date
         * @return {?}
         */
        date => {
            this.monthName = s.getMonthName(date);
            this.allNextDaysDisabled = s.shouldNextMonthDisable(date);
            this.allPrevDaysDisabled = s.shouldPrevMonthDisable(date);
        }));
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
DatePickerCalendarComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-date-picker-calendar',
                template: `
  <div class='md-datepicker__header'>
    <div class='md-datepicker__navigation'>
      <div class='md-datepicker__navigation--current-month'>
        {{ monthName }}
      </div>
      <div class='md-datepicker__navigation--buttons'>
        <md-icon name='arrow-left_16'
          [attr.disabled]='this.allPrevDaysDisabled'
          [ariaLabel]='previousArialLabel'
        (click)='onClickPre($event)'>
        </md-icon>
        <md-icon name='arrow-right_16'
          [attr.disabled]='this.allNextDaysDisabled'
          [ariaLabel]='nextArialLabel'
          (click)='onClickNext($event)'>
        </md-icon>
      </div>
    </div>
    <div class='md-datepicker__day--names'>
      <div *ngFor='let offset of offsets' class='md-datepicker__day--name'>
        {{ getWeekDayName(offset) }}
      </div>
    </div>
  </div>
  <md-date-picker-month></md-date-picker-month>
  `,
                host: {
                    class: 'md-datepicker__month-container'
                }
            }] }
];
/** @nocollapse */
DatePickerCalendarComponent.ctorParameters = () => [
    { type: DatePickerService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DatePickerMonthComponent {
    /**
     * @param {?} datePickerService
     * @param {?} viewContainerRef
     */
    constructor(datePickerService, viewContainerRef) {
        this.datePickerService = datePickerService;
        this.viewContainerRef = viewContainerRef;
        this.weeks = [];
        this.RegInnerClass = /md-button--circle md-button--28 md-datepicker__day|md-datepicker__week|md-datepicker__month|speicalRangeClass/;
        this.handleMouseleave = (/**
         * @param {?} event
         * @return {?}
         */
        (event) => {
            if (this.isNotDayComponent(event.relatedTarget)) {
                this.datePickerService.hover(undefined);
            }
        });
        this.isNotDayComponent = (/**
         * @param {?} dom
         * @return {?}
         */
        (dom) => {
            return !(dom && dom.className && this.RegInnerClass.test(dom.className));
        });
        this.initWeeks = (/**
         * @param {?} day
         * @return {?}
         */
        (day) => {
            /** @type {?} */
            const _weeks = [];
            /** @type {?} */
            let currentWeekStart = this.datePickerService.getStartWeekOfMonth(day);
            do {
                _weeks.push(currentWeekStart);
                currentWeekStart = this.datePickerService.getNextWeekStart(currentWeekStart);
            } while (this.datePickerService.isSameMonth(day, currentWeekStart));
            this.weeks = _weeks;
        });
        this.datePickerService.viewed$.subscribe((/**
         * @param {?} date
         * @return {?}
         */
        date => {
            this.month = this.datePickerService.getMonth(date);
            this.initWeeks(date);
        }));
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.datePickerService.isRange) {
            /** @type {?} */
            const root = this.viewContainerRef.element.nativeElement;
            root.addEventListener('mouseleave', (/**
             * @param {?} e
             * @return {?}
             */
            (e) => {
                this.handleMouseleave(e);
            }));
        }
    }
}
DatePickerMonthComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-date-picker-month',
                template: `
    <md-date-picker-week *ngFor='let _day of weeks' [day]='_day' [month]='month' ></md-date-picker-week>
  `,
                host: {
                    class: 'md-datepicker__month'
                }
            }] }
];
/** @nocollapse */
DatePickerMonthComponent.ctorParameters = () => [
    { type: DatePickerService },
    { type: ViewContainerRef }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DatePickerWeekComponent {
    /**
     * @param {?} datePickerService
     */
    constructor(datePickerService) {
        this.datePickerService = datePickerService;
        this.days = [];
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.days = this.datePickerService.getDaysInWeek(this.day);
    }
}
DatePickerWeekComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-date-picker-week',
                template: `
    <md-date-picker-day *ngFor='let _day of days' [day]='_day' [month]='month'></md-date-picker-day>
  `,
                host: {
                    class: 'md-datepicker__week'
                }
            }] }
];
/** @nocollapse */
DatePickerWeekComponent.ctorParameters = () => [
    { type: DatePickerService }
];
DatePickerWeekComponent.propDecorators = {
    day: [{ type: Input }],
    month: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DatePickerDayComponent {
    /**
     * @param {?} datePickerService
     * @param {?} viewContainerRef
     */
    constructor(datePickerService, viewContainerRef) {
        this.datePickerService = datePickerService;
        this.viewContainerRef = viewContainerRef;
        this.isDisable = false;
        this.isSelected = false;
        this.isFocus = false;
        this.isToday = false;
        this.isOutsideMonth = false;
        this.isInRange = false;
        this.isUnselectable = false;
        this.isStartDay = false;
        this.isEndDay = false;
        this.isHovered = false;
        this.isInRangeSelected = false;
        this.isNormalView = true;
        this.specialRangeClass = '';
        this.onClick = (/**
         * @return {?}
         */
        () => {
            /** @type {?} */
            const s = this.datePickerService;
            if (!s.isRange) {
                s.select(this.day);
                s.setOpenStatus(false);
            }
            else if (!s.hasFinishRange() && !s.isDayDisabled(this.day)) {
                s.select(this.day);
            }
        });
        this.onHover = (/**
         * @return {?}
         */
        () => {
            /** @type {?} */
            const s = this.datePickerService;
            if (!s.hoverDate || !s.isSameDay(s.hoverDate, this.day)) {
                if (!s.isDayDisabled(this.day)) {
                    s.hover(this.day);
                }
                else {
                    s.hover(undefined);
                }
            }
        });
        this.checkState = (/**
         * @return {?}
         */
        () => {
            /** @type {?} */
            const s = this.datePickerService;
            /** @type {?} */
            const d = this.day;
            this.isDisable = s.isDayDisabled(d);
            this.isSelected = s.isSelected(d);
            this.isFocus = s.isFocus(d);
            this.isToday = s.isToday(d);
            this.isOutsideMonth = s.isOutsideMonth(d, this.month);
            if (s.isRange) {
                this.specialRangeClass = '';
                if (s.hasEitherRange()) {
                    this.isInRange = s.isDayInRange(d);
                    if (s.hasFinishRange()) {
                        this.isStartDay = s.isStartDay(d);
                        this.isEndDay = s.isEndDay(d);
                        this.isHovered = false;
                        this.isSelected = this.isInRange;
                        this.isUnselectable = false;
                        this.isInRangeSelected = this.isSelected && !this.isUnselectable;
                        this.isNormalView = true;
                    }
                    else {
                        this.isDisable = false;
                        if (s.start) {
                            this.isStartDay = s.isStartDay(d);
                            this.isEndDay = s.isSameDay(s.hoverDate, d);
                        }
                        else {
                            this.isStartDay = s.isSameDay(s.hoverDate, d);
                            this.isEndDay = s.isEndDay(d);
                        }
                        if (this.isStartDay) {
                            this.specialRangeClass = 'selected-edge-day';
                        }
                        if (this.isEndDay) {
                            this.specialRangeClass = 'selected-edge-day';
                        }
                        this.isUnselectable = !this.isInRange;
                        this.isHovered = s.hoverDate && this.isInRange;
                        this.isSelected = false;
                        this.isHovered = this.isHovered;
                        this.isInRangeSelected = false;
                        this.isNormalView = !(this.isStartDay || this.isEndDay);
                    }
                    if (this.isStartDay && this.isEndDay) {
                        this.isStartDay = false;
                        this.isEndDay = false;
                        this.isInRange = false;
                    }
                }
                else {
                    this.isNormalView = true;
                    this.isInRange = false;
                    this.isUnselectable = false;
                    this.isStartDay = false;
                    this.isEndDay = false;
                    this.isHovered = false;
                    this.isInRangeSelected = false;
                }
            }
        });
        /** @type {?} */
        const s = this.datePickerService;
        s.focused$.subscribe((/**
         * @param {?} date
         * @return {?}
         */
        date => {
            this.checkState();
        }));
        s.selected$.subscribe((/**
         * @param {?} date
         * @return {?}
         */
        date => {
            this.checkState();
        }));
        s.startDate$.subscribe((/**
         * @param {?} date
         * @return {?}
         */
        date => {
            this.checkState();
        }));
        s.endDate$.subscribe((/**
         * @param {?} date
         * @return {?}
         */
        date => {
            this.checkState();
        }));
        s.viewed$.subscribe((/**
         * @param {?} date
         * @return {?}
         */
        date => {
            this.checkState();
        }));
        s.hovered$.subscribe((/**
         * @param {?} date
         * @return {?}
         */
        date => {
            this.checkState();
        }));
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.displayDay = this.datePickerService.getDate(this.day);
        if (this.datePickerService.isRange) {
            /** @type {?} */
            const root = this.viewContainerRef.element.nativeElement;
            root.addEventListener('mouseenter', (/**
             * @return {?}
             */
            () => {
                this.onHover();
            }));
        }
        this.checkState();
    }
}
DatePickerDayComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-date-picker-day',
                template: `
    <ng-template [ngIf]="isNormalView" [ngIfElse]="selectedRangeEdge">
      {{ displayDay }}
    </ng-template>
    <ng-template #selectedRangeEdge>
      <span [class]='specialRangeClass'>{{ displayDay }}</span>
    </ng-template>
  `,
                host: {
                    class: 'md-button md-button--circle md-button--28 md-datepicker__day',
                    '[class.md-button--disabled]': 'isDisable',
                    '[class.md-datepicker__day--selected]': 'isSelected',
                    '[class.md-datepicker__day--focus]': 'isFocus',
                    '[class.md-datepicker__day--today]': 'isToday',
                    '[class.md-datepicker__day--outside-month]': 'isOutsideMonth',
                    '[class.md-datepicker__day--inrange]': 'isInRange',
                    '[class.md-datepicker__day--start]': 'isStartDay',
                    '[class.md-datepicker__day--end]': 'isEndDay',
                    '[class.md-datepicker__day--hovered]': 'isHovered',
                    '[class.md-datepicker__day--unselectable]': 'isUnselectable',
                    '[class.md-datepicker__day--inrange-selected]': 'isInRangeSelected',
                    '[attr.aria-label]': '""',
                    '[attr.aria-selected]': 'false',
                    '[attr.tabIndex]': '-1',
                    '(click)': 'onClick()'
                }
            }] }
];
/** @nocollapse */
DatePickerDayComponent.ctorParameters = () => [
    { type: DatePickerService },
    { type: ViewContainerRef }
];
DatePickerDayComponent.propDecorators = {
    day: [{ type: Input }],
    month: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DatePickerDayModule {
}
DatePickerDayModule.decorators = [
    { type: NgModule, args: [{
                declarations: [DatePickerDayComponent],
                imports: [
                    CommonModule,
                    ButtonModule
                ],
                exports: [DatePickerDayComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DatePickerWeekModule {
}
DatePickerWeekModule.decorators = [
    { type: NgModule, args: [{
                declarations: [DatePickerWeekComponent],
                imports: [
                    CommonModule,
                    DatePickerDayModule
                ],
                exports: [DatePickerWeekComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DatePickerMonthModule {
}
DatePickerMonthModule.decorators = [
    { type: NgModule, args: [{
                declarations: [DatePickerMonthComponent],
                imports: [
                    CommonModule,
                    DatePickerWeekModule
                ],
                exports: [DatePickerMonthComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DatePickerCalendarModule {
}
DatePickerCalendarModule.decorators = [
    { type: NgModule, args: [{
                declarations: [DatePickerCalendarComponent],
                imports: [
                    CommonModule,
                    DatePickerMonthModule,
                    IconModule
                ],
                exports: [DatePickerCalendarComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DatePickerModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: DatePickerModule,
            providers: [],
        };
    }
}
DatePickerModule.decorators = [
    { type: NgModule, args: [{
                declarations: [DatePickerComponent],
                imports: [
                    CommonModule,
                    OverlayModule,
                    DatePickerCalendarModule
                ],
                exports: [DatePickerComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DateRangeInputComponent {
    /**
     * @param {?} datePickerService
     */
    constructor(datePickerService) {
        this.datePickerService = datePickerService;
        /**
         * \@prop the value of the label
         */
        this.labelValue = '';
        /**
         * \@prop the value of the placeholder
         */
        this.placeholder = '';
        /**
         * \@prop Handler invoked when clear the date | null
         */
        this.whenClear = new EventEmitter();
        /**
         * \@prop Handler invoked when select the component | null
         */
        this.whenSelect = new EventEmitter();
        /**
         * \@prop is used for start date or end date | 'start'
         */
        this.ObserverPrefix = 'start';
        this.isShowCloseBtn = false;
        this.stop = (/**
         * @param {?} event
         * @return {?}
         */
        (event) => {
            event.stopPropagation();
        });
        this.isInnerDom = (/**
         * @param {?} dom
         * @return {?}
         */
        (dom) => {
            return dom === this.closeBtn.nativeElement || dom === this.closeSpan.nativeElement || dom === this.closeI.nativeElement;
        });
        this.showCloseBtn = (/**
         * @return {?}
         */
        () => {
            if (!this.isShowCloseBtn && this.dateRangeInput.nativeElement.value !== '') {
                this.closeBtn.nativeElement.style.display = '';
                this.isShowCloseBtn = true;
            }
        });
        this.hideCloseBtn = (/**
         * @return {?}
         */
        () => {
            if (this.isShowCloseBtn) {
                this.closeBtn.nativeElement.style.display = 'none';
                this.isShowCloseBtn = false;
            }
        });
        this.handleMouseover = (/**
         * @return {?}
         */
        () => {
            this.showCloseBtn();
        });
        this.handleMouseout = (/**
         * @param {?} event
         * @return {?}
         */
        (event) => {
            if (!this.isInnerDom(event.relatedTarget)) {
                this.hideCloseBtn();
            }
        });
        this.handleFocus = (/**
         * @param {?} event
         * @return {?}
         */
        (event) => {
            this.whenSelect.emit();
            this.showCloseBtn();
            event.stopPropagation();
        });
        this.handleBlur = (/**
         * @param {?} event
         * @return {?}
         */
        (event) => {
            if (this.isInnerDom(event.relatedTarget)) {
                return;
            }
            this.hideCloseBtn();
            event.stopPropagation();
        });
        this.clear = (/**
         * @param {?} event
         * @return {?}
         */
        (event) => {
            this.whenClear.emit();
            this.dateRangeInput.nativeElement.value = '';
            event.stopPropagation();
        });
        this.getValue = (/**
         * @return {?}
         */
        () => {
            return (this.selectDate && this.selectDate.format) ? this.selectDate.format('MMMM Do') : '';
        });
        this.onInputPress = (/**
         * @param {?} e
         * @return {?}
         */
        (e) => {
            /** @type {?} */
            const key = e.keyCode;
            switch (key) {
                case ENTER:
                case SPACE:
                    this.handleFocus(e);
                    break;
                case BACKSPACE:
                case DELETE:
                    this.clear(e);
                    break;
                default:
                    break;
            }
        });
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.datePickerService[this.ObserverPrefix + 'Date$'].subscribe((/**
         * @param {?} o
         * @return {?}
         */
        o => {
            if (!o) {
                this.hideCloseBtn();
            }
        }));
    }
}
DateRangeInputComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-date-range-input',
                template: `
    <label class="md-label" for="dateRangeInput">{{labelValue}}</label>
    <div class="md-input__icon-container">
      <input type="text"
        #dateRangeInput
        class="md-input dirty"
        tabIndex="0"
        [value]="getValue()"
        id="dateRangeInput"
        name="dateRangeInput"
        [placeholder]="placeholder"
        (focus)='handleFocus($event)'
        (blur)='handleBlur($event)'
        (keydown)='onInputPress($event)'
        (mouseover)='handleMouseover()'
        (mouseout)='handleMouseout($event)'
        readonly />
      <button #closeBtn
        type="button"
        (focus)='stop($event)'
        (click)='clear($event)'
        style="display:none;"
        class="md-button md-button--36 md-button--icon"
        alt="clear input"
        type="button"
        tabIndex="-1">
        <span #closeSpan class="md-button__children">
          <i #closeI class="icon icon-clear-active_16"></i>
        </span>
      </button>
    </div>
  `,
                host: {
                    class: 'md-input-container small-5 columns'
                }
            }] }
];
/** @nocollapse */
DateRangeInputComponent.ctorParameters = () => [
    { type: DatePickerService }
];
DateRangeInputComponent.propDecorators = {
    labelValue: [{ type: Input }],
    selectDate: [{ type: Input }],
    placeholder: [{ type: Input }],
    whenClear: [{ type: Output }],
    whenSelect: [{ type: Output }],
    ObserverPrefix: [{ type: Output }],
    dateRangeInput: [{ type: ViewChild, args: ['dateRangeInput',] }],
    closeBtn: [{ type: ViewChild, args: ['closeBtn',] }],
    closeSpan: [{ type: ViewChild, args: ['closeSpan',] }],
    closeI: [{ type: ViewChild, args: ['closeI',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
let moment$4 = require('moment');
if ('default' in moment$4) {
    moment$4 = moment$4['default'];
}
class DateRangePickerComponent {
    /**
     * @param {?} datePickerService
     * @param {?} overlay
     * @param {?} elementRef
     * @param {?} viewContainerRef
     */
    constructor(datePickerService, overlay, elementRef, viewContainerRef) {
        this.datePickerService = datePickerService;
        this.overlay = overlay;
        this.elementRef = elementRef;
        this.viewContainerRef = viewContainerRef;
        /**
         * \@prop Set the direction in which the DatePicker opens | 'bottom-center'
         */
        this.direction = 'bottom-center';
        /**
         * \@prop Sets the language of the DatePicker | 'en'
         */
        this.locale = 'en';
        /**
         * \@prop Sets the format of the month | 'MMMM YYYY'
         */
        this.monthFormat = 'MMMM YYYY';
        /**
         * \@prop Text to display for blindness accessibility features | 'next'
         */
        this.nextArialLabel = 'next';
        /**
         * \@prop Text to display for blindness accessibility features | 'previous'
         */
        this.previousArialLabel = 'previous';
        /**
         * \@prop Determines if the DatePicker should close when a date is selected | true
         */
        this.shouldCloseOnSelect = true;
        /**
         * \@prop To enable/disable clicking on underlay to exit modal | false
         */
        this.backdropClickExit = false;
        /**
         * \@prop Optional overlay positioin | ''
         */
        this.originX = 'end';
        /**
         * \@prop Optional overlay positioin | ''
         */
        this.originY = 'top';
        /**
         * \@prop Optional overlay positioin | ''
         */
        this.overlayX = 'start';
        /**
         * \@prop Optional overlay positioin | ''
         */
        this.overlayY = 'bottom';
        /**
         * \@prop To the format of the date | 'MMMM Do'
         */
        this.dateFormat = 'MMMM Do';
        /**
         * \@prop Handler invoked when user makes a change within the DatePicker | null
         */
        this.whenFocusChange = new EventEmitter();
        /**
         * \@prop Handler invoked when user makes a change to the selected month within DatePicker | null
         */
        this.whenMonthChange = new EventEmitter();
        /**
         * \@prop Handler invoked when user selects a date within DateRangePicker | null
         */
        this.whenSelectChange = new EventEmitter();
        this.initService = (/**
         * @return {?}
         */
        () => {
            /** @type {?} */
            const s = this.datePickerService;
            s.initConfig({
                locale: this.locale,
                maxDate: this.maxDate,
                minDate: this.minDate,
                monthFormat: this.monthFormat,
                nextArialLabel: this.nextArialLabel,
                previousArialLabel: this.previousArialLabel,
                filterDate: this.filterDate,
                isRange: true
            });
            this.datePickerService.changeStartDate(this.startDate);
            this.datePickerService.changeEndDate(this.endDate);
            s.viewMonthChange$.subscribe((/**
             * @param {?} date
             * @return {?}
             */
            date => {
                this.whenMonthChange.emit(date);
            }));
            s.focused$.subscribe((/**
             * @param {?} date
             * @return {?}
             */
            date => {
                this.whenFocusChange.emit(date);
            }));
            s.startDate$.subscribe((/**
             * @param {?} date
             * @return {?}
             */
            date => {
                this.startDate = date;
                this.inputStartDate.selectDate = date;
                this.handleStartOrEndChange(date, true);
            }));
            s.endDate$.subscribe((/**
             * @param {?} date
             * @return {?}
             */
            date => {
                this.endDate = date;
                this.inputEndDate.selectDate = date;
                this.handleStartOrEndChange(date, false);
            }));
        });
        this.initOverLay = (/**
         * @return {?}
         */
        () => {
            /** @type {?} */
            const strategy = this.overlay
                .position()
                .flexibleConnectedTo(this.connectToButton)
                .withPositions([
                {
                    originX: this.originX,
                    originY: this.originY,
                    overlayX: this.overlayX,
                    overlayY: this.overlayY
                }
            ]);
            /** @type {?} */
            const config = new OverlayConfig({
                hasBackdrop: true,
                panelClass: 'md-datepicker-container',
                backdropClass: 'cdk-overlay-transparent-backdrop',
                positionStrategy: strategy
            });
            this.overlayRef = this.overlay.create(config);
            this.tp = new TemplatePortal(this.tempDatepicker, this.viewContainerRef);
            this.overlayRef.keydownEvents().subscribe((/**
             * @param {?} e
             * @return {?}
             */
            (e) => {
                this.onPress(e);
            }));
            this.overlayRef.backdropClick().subscribe((/**
             * @return {?}
             */
            () => {
                this.dismiss();
            }));
            this.datePickerService.isShowDatepicker$.subscribe((/**
             * @param {?} isOpen
             * @return {?}
             */
            isOpen => {
                if (isOpen) {
                    this.showContent();
                }
                else {
                    this.dismissContent();
                }
            }));
        });
        this.targetChange = (/**
         * @param {?} ifStart
         * @return {?}
         */
        (ifStart) => {
            /** @type {?} */
            const s = this.datePickerService;
            s.changeTarget(ifStart);
            if (ifStart) {
                s.view(s.start || s.end || s.nowDate);
            }
            else {
                s.view(s.end || s.start || s.nowDate);
            }
        });
        this.handleStartOrEndChange = (/**
         * @param {?} date
         * @param {?} ifStart
         * @return {?}
         */
        (date, ifStart) => {
            if (date) {
                /** @type {?} */
                const s = this.datePickerService;
                if (this.shouldCloseOnSelect && s.hasFinishRange()) {
                    this.dismiss();
                    // select another
                }
                else {
                    this.targetChange(!ifStart);
                }
                // date === undefined
            }
            else {
                this.targetChange(ifStart);
            }
            this.whenSelectChange.emit(this.getDateInfo());
        });
        this.clearStartDate = (/**
         * @return {?}
         */
        () => {
            this.datePickerService.changeStartDate(undefined);
        });
        this.clearEndDate = (/**
         * @return {?}
         */
        () => {
            this.datePickerService.changeEndDate(undefined);
        });
        this.show = (/**
         * @return {?}
         */
        () => {
            this.datePickerService.setOpenStatus(true);
        });
        this.dismiss = (/**
         * @return {?}
         */
        () => {
            this.datePickerService.setOpenStatus(false);
        });
        this.showContent = (/**
         * @return {?}
         */
        () => {
            if (this.overlayRef && !this.overlayRef.hasAttached()) {
                /** @type {?} */
                const s = this.datePickerService;
                this.overlayRef.attach(this.tp);
                s.view(s.start || s.end || s.nowDate);
            }
        });
        this.dismissContent = (/**
         * @return {?}
         */
        () => {
            if (this.overlayRef && this.overlayRef.hasAttached()) {
                this.overlayRef.detach();
                if (this.overlayRef.backdropElement) {
                    this.overlayRef.backdropElement.remove();
                }
            }
        });
        this.onPressMove = (/**
         * @param {?} offset
         * @return {?}
         */
        (offset) => {
            /** @type {?} */
            const s = this.datePickerService;
            /** @type {?} */
            const nextDay = s.getNewDayByOffset(s.focusedDate, offset);
            s.focus(nextDay);
            if (!s.isDayDisabled(nextDay)) {
                s.hover(nextDay);
            }
            else {
                s.hover(undefined);
            }
        });
        this.onPress = (/**
         * @param {?} e
         * @return {?}
         */
        (e) => {
            /** @type {?} */
            const key = e.keyCode;
            /** @type {?} */
            const s = this.datePickerService;
            /** @type {?} */
            let flag = false;
            switch (key) {
                case SPACE:
                case ENTER:
                    if (!s.hasFinishRange() && !s.isDayDisabled(s.focusedDate)) {
                        s.select(s.focusedDate);
                    }
                    flag = true;
                    break;
                // up
                case UP_ARROW:
                    this.onPressMove(-7);
                    flag = true;
                    break;
                // left
                case LEFT_ARROW:
                    this.onPressMove(-1);
                    flag = true;
                    break;
                // right
                case RIGHT_ARROW:
                    this.onPressMove(1);
                    flag = true;
                    break;
                // bottom
                case DOWN_ARROW:
                    this.onPressMove(7);
                    flag = true;
                    break;
                default:
                    break;
            }
            if (flag) {
                e.stopPropagation();
                e.preventDefault();
                return false;
            }
        });
    }
    /**
     * \@prop Optional css class string | ''
     * @param {?} value
     * @return {?}
     */
    set className(value) {
        this.elementRef.nativeElement.classList.add(value);
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.initService();
        this.initOverLay();
    }
    /**
     * @return {?}
     */
    getDateInfo() {
        /** @type {?} */
        const s = this.datePickerService;
        /** @type {?} */
        const strStart = s.start ? s.start.format(this.dateFormat) : '';
        /** @type {?} */
        const strEnd = s.end ? s.end.format(this.dateFormat) : '';
        /** @type {?} */
        const str = (strEnd !== '' || strStart !== '') ? strStart + '-' + strEnd : '';
        return {
            startDate: s.start,
            endDate: s.end,
            startDateStr: strStart,
            strEndStr: strEnd,
            str: str
        };
    }
}
DateRangePickerComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-date-range-picker',
                template: `
    <div #connectToButton>
      <ng-content></ng-content>
    </div>
    <ng-template #tempDatepicker>
      <div class='md-event-overlay'>
        <div class='md-event-overlay__children  md-date-picker md-date-range-picker'>
          <md-date-picker-calendar></md-date-picker-calendar>
          <div class='md-data-range-picker-button-group'>
          <md-date-range-input #inputStartDate
            labelValue='Start Date'
            placeholder ='Start Date'
            [selectDate]='startDate'
            (whenSelect)='targetChange(true)'
            (whenClear) = 'clearStartDate()'
          ></md-date-range-input>
          <md-date-range-input #inputEndDate
            labelValue='End Date'
            placeholder ='End Date'
            ObserverPrefix = 'end'
            [selectDate]='endDate'
            (whenSelect)='targetChange(false)'
            (whenClear) = 'clearEndDate()'
          ></md-date-range-input>
          </div>
        </div>
      </div>
    </ng-template>
  `,
                host: {
                    class: 'md-datepicker-container'
                },
                providers: [DatePickerService]
            }] }
];
/** @nocollapse */
DateRangePickerComponent.ctorParameters = () => [
    { type: DatePickerService },
    { type: Overlay },
    { type: ElementRef },
    { type: ViewContainerRef }
];
DateRangePickerComponent.propDecorators = {
    className: [{ type: Input }],
    direction: [{ type: Input }],
    locale: [{ type: Input }],
    maxDate: [{ type: Input }],
    minDate: [{ type: Input }],
    filterDate: [{ type: Input }],
    monthFormat: [{ type: Input }],
    nextArialLabel: [{ type: Input }],
    previousArialLabel: [{ type: Input }],
    startDate: [{ type: Input }],
    endDate: [{ type: Input }],
    shouldCloseOnSelect: [{ type: Input }],
    backdropClickExit: [{ type: Input }],
    originX: [{ type: Input }],
    originY: [{ type: Input }],
    overlayX: [{ type: Input }],
    overlayY: [{ type: Input }],
    dateFormat: [{ type: Input }],
    whenFocusChange: [{ type: Output }],
    whenMonthChange: [{ type: Output }],
    whenSelectChange: [{ type: Output }],
    tempDatepicker: [{ type: ViewChild, args: ['tempDatepicker',] }],
    connectToButton: [{ type: ViewChild, args: ['connectToButton',] }],
    inputStartDate: [{ type: ViewChild, args: ['inputStartDate',] }],
    inputEndDate: [{ type: ViewChild, args: ['inputEndDate',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DateRangeInputModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: DateRangeInputModule,
            providers: [],
        };
    }
}
DateRangeInputModule.decorators = [
    { type: NgModule, args: [{
                declarations: [DateRangeInputComponent],
                imports: [
                    CommonModule
                ],
                exports: [DateRangeInputComponent],
                schemas: [CUSTOM_ELEMENTS_SCHEMA]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DateRangePickerModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: DateRangePickerModule,
            providers: [],
        };
    }
}
DateRangePickerModule.decorators = [
    { type: NgModule, args: [{
                declarations: [DateRangePickerComponent],
                imports: [
                    CommonModule,
                    DatePickerCalendarModule,
                    DateRangeInputModule
                ],
                exports: [DateRangePickerComponent],
                schemas: [CUSTOM_ELEMENTS_SCHEMA]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class BreadcrumbsComponent {
    /**
     * @param {?} viewContainerRef
     */
    constructor(viewContainerRef) {
        this.viewContainerRef = viewContainerRef;
    }
    /**
     * @return {?}
     */
    ngOnInit() { }
    /**
     * @return {?}
     */
    ngAfterContentInit() {
        /** @type {?} */
        const list = this.viewContainerRef.element.nativeElement.getElementsByTagName('LI');
        /** @type {?} */
        const len = list.length;
        if (len > 0) {
            list[len - 1].className += ' current';
        }
    }
}
BreadcrumbsComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-breadcrumbs',
                template: `
    <ng-content></ng-content>
  `,
                host: {
                    class: 'md-breadcrumbs'
                }
            }] }
];
/** @nocollapse */
BreadcrumbsComponent.ctorParameters = () => [
    { type: ViewContainerRef }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class BreadcrumbsModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: BreadcrumbsModule,
            providers: [],
        };
    }
}
BreadcrumbsModule.decorators = [
    { type: NgModule, args: [{
                declarations: [BreadcrumbsComponent],
                imports: [
                    CommonModule
                ],
                exports: [BreadcrumbsComponent],
                schemas: [CUSTOM_ELEMENTS_SCHEMA]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class PopoverDirective extends TooltipDirective {
    /**
     * @param {?} overlay
     * @param {?} overlayPositionBuilder
     * @param {?} _sso
     * @param {?} elementRef
     */
    constructor(overlay, overlayPositionBuilder, _sso, elementRef) {
        super(overlay, overlayPositionBuilder, _sso, elementRef);
        /**
         * \@prop shows the arrow or not
         */
        this.showArrow = true;
        /**
         * \@prop Sets the popover trigger MouseEnter, Click or Focus - Click is default
         */
        this.popoverTrigger = 'Click';
    }
    /**
     * @return {?}
     */
    showPopover() {
        if (this.popoverTrigger === 'MouseEnter') {
            this.show();
        }
    }
    /**
     * @return {?}
     */
    hide() {
        if (this.popoverTrigger === 'MouseEnter' || this.popoverTrigger === 'Click') {
            this.close();
        }
    }
    /**
     * @return {?}
     */
    onClick() {
        if (this.popoverTrigger === 'Click') {
            this.show();
        }
    }
    /**
     * @param {?} targetElement
     * @return {?}
     */
    closePopover(targetElement) {
        if (this.popoverTrigger === 'Click') {
            /** @type {?} */
            const clickedOutside = !this.elementRef.nativeElement.contains(targetElement);
            if (clickedOutside) {
                this.close();
            }
        }
    }
    /**
     * @return {?}
     */
    onFocus() {
        if (this.popoverTrigger === 'Focus') {
            this.show();
        }
    }
    /**
     * @return {?}
     */
    onFocusout() {
        if (this.popoverTrigger === 'Focus') {
            this.close();
        }
    }
    /**
     * @return {?}
     */
    show() {
        super.show();
        this.tooltipRef.instance.isTooltip = false;
        this.tooltipRef.instance.classList['md-popover'] = true;
        this.tooltipRef.instance.showArrow = this.showArrow;
    }
    /**
     * @return {?}
     */
    close() {
        super.close();
    }
}
PopoverDirective.decorators = [
    { type: Directive, args: [{ selector: '[mdPopover]' },] }
];
/** @nocollapse */
PopoverDirective.ctorParameters = () => [
    { type: Overlay },
    { type: OverlayPositionBuilder },
    { type: ScrollStrategyOptions },
    { type: ElementRef }
];
PopoverDirective.propDecorators = {
    content: [{ type: Input, args: ['mdPopover',] }],
    showArrow: [{ type: Input }],
    popoverTrigger: [{ type: Input }],
    showPopover: [{ type: HostListener, args: ['mouseenter',] }],
    hide: [{ type: HostListener, args: ['mouseleave',] }],
    onClick: [{ type: HostListener, args: ['click',] }],
    closePopover: [{ type: HostListener, args: ['document:click', ['$event.target'],] }],
    onFocus: [{ type: HostListener, args: ['focus',] }],
    onFocusout: [{ type: HostListener, args: ['focusout',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class PopoverModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: PopoverModule,
            providers: [],
        };
    }
}
PopoverModule.decorators = [
    { type: NgModule, args: [{
                declarations: [PopoverDirective],
                imports: [
                    CommonModule,
                    OverlayModule
                ],
                exports: [PopoverDirective],
                schemas: [CUSTOM_ELEMENTS_SCHEMA],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CardComponent {
    /**
     * @param {?} el
     */
    constructor(el) {
        this.el = el;
        /**
         * catch this event to know the card was clicked on
         */
        this.cardClicked = new EventEmitter();
        /**
         * \@prop clickable whether or not the card is clickable | false
         */
        this.clickable = false;
    }
    /**
     * @return {?}
     */
    onClick() {
        if (this.clickable) {
            this.el.nativeElement.classList.add('active');
            this.cardClicked.emit();
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onKeydown(event) {
        // tslint:disable-next-line: deprecation
        /** @type {?} */
        const key = event.key || event.which || event.keyCode;
        switch (key) {
            case SPACE:
            case ENTER:
            case ' ':
            case 'Enter':
                this.onClick();
                break;
            default:
                break;
        }
    }
}
CardComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-card',
                template: `
    <ng-content></ng-content>
  `,
                host: {
                    'class': 'md-card',
                    '[class.md-card--clickable]': 'clickable',
                    '[attr.tabindex]': 'clickable ? "0" : null',
                    '(click)': 'clickable ? onClick() : null',
                    '(keydown)': 'clickable ? onKeydown($event) : null'
                }
            }] }
];
/** @nocollapse */
CardComponent.ctorParameters = () => [
    { type: ElementRef }
];
CardComponent.propDecorators = {
    cardClicked: [{ type: Output }],
    clickable: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CardSectionComponent {
}
CardSectionComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-card-section',
                template: `
    <ng-content></ng-content>
  `,
                host: {
                    'class': 'md-card-section',
                    '[class.md-card-section--full]': 'full',
                }
            }] }
];
CardSectionComponent.propDecorators = {
    full: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CardModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: CardModule,
            providers: [],
        };
    }
}
CardModule.decorators = [
    { type: NgModule, args: [{
                declarations: [CardComponent, CardSectionComponent],
                imports: [
                    CommonModule
                ],
                exports: [CardComponent, CardSectionComponent],
                schemas: [CUSTOM_ELEMENTS_SCHEMA]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CoachmarkService {
    constructor() {
        this.showed = new Subject();
        this.showed$ = this.showed.asObservable();
        this.setVisiable = (/**
         * @param {?} ifShow
         * @return {?}
         */
        (ifShow) => {
            this.showed.next(ifShow);
        });
    }
}
CoachmarkService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
CoachmarkService.ctorParameters = () => [];
/** @nocollapse */ CoachmarkService.ngInjectableDef = defineInjectable({ factory: function CoachmarkService_Factory() { return new CoachmarkService(); }, token: CoachmarkService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CoachmarkComponent {
    /**
     * @param {?} coachmarkService
     * @param {?} overlay
     * @param {?} overlayContainer
     * @param {?} viewContainerRef
     */
    constructor(coachmarkService, overlay, overlayContainer, viewContainerRef) {
        this.coachmarkService = coachmarkService;
        this.overlay = overlay;
        this.overlayContainer = overlayContainer;
        this.viewContainerRef = viewContainerRef;
        /**
         * \@prop Allows user to click outside of element | false
         */
        this.allowClickAway = false;
        /**
         * \@prop Optional css class string | ''
         */
        this.className = '';
        /**
         * \@prop Allows Coachmark to be closed by a click from the user | false
         */
        this.closeOnClick = false;
        /**
         * \@prop Sets the time the timer is delayed | 0
         */
        this.delay = 0;
        /**
         * \@prop Sets the time delay to hide the Coachmark | 0
         */
        this.hideDelay = 0;
        /**
         * \@prop Sets the initial visibility of Coachmark | false
         */
        this.isOpen = false;
        /**
         * \@prop Optional overlay positioin | ''
         */
        this.originX = 'start';
        /**
         * \@prop Optional overlay positioin | ''
         */
        this.originY = 'bottom';
        /**
         * \@prop Optional overlay positioin | ''
         */
        this.overlayX = 'start';
        /**
         * \@prop Optional overlay positioin | ''
         */
        this.overlayY = 'top';
        /**
         * \@prop Handler to be called when the user clicks the Coachmark | null
         */
        this.whenClick = new EventEmitter();
        /**
         * \@prop Handler to be called when Coachmark is closed, should be provided when allowClickAway is true | null
         */
        this.whenClose = new EventEmitter();
        this.positionHash = {
            'start': 0,
            'top': 0,
            'center': 1,
            'end': 2,
            'bottom': 2
        };
        this.classArray = ['top', 'bottom', 'left', 'right'];
        this.initOverlayer = (/**
         * @return {?}
         */
        () => {
            this.checkArrowName();
            /** @type {?} */
            const strategy = this.overlay
                .position()
                .flexibleConnectedTo(this.archor)
                .withPositions([
                {
                    offsetX: this.ArrowPositionClass === 'left' ? -14 : 0,
                    offsetY: this.ArrowPositionClass === 'top' ? -14 : 0,
                    originX: this.originX,
                    originY: this.originY,
                    overlayX: this.overlayX,
                    overlayY: this.overlayY,
                }
            ]);
            /** @type {?} */
            const arrowClass = 'md-event-overlay--' + this.ArrowPositionClass;
            /** @type {?} */
            const panelClass = [
                'md-event-overlay',
                'md-event-overlay--arrow',
                arrowClass,
                'md-coachmark'
            ];
            if (!!this.className) {
                panelClass.push(this.className);
            }
            /** @type {?} */
            const config = new OverlayConfig({
                hasBackdrop: !this.allowClickAway,
                panelClass: panelClass,
                positionStrategy: strategy,
                width: this.width,
                height: this.height,
                maxWidth: this.maxWidth,
                minWidth: this.minWidth,
                maxHeight: this.maxHeight,
                minHeight: this.minHeight
            });
            strategy.positionChanges.subscribe((/**
             * @return {?}
             */
            () => {
                this.checkDom();
                this.setArrowPosition();
            }));
            this.overlayRef = this.overlay.create(config);
            this.tp = new TemplatePortal(this.tempCoachmark, this.viewContainerRef);
            this.coachmarkService.showed$.subscribe((/**
             * @param {?} isShow
             * @return {?}
             */
            isShow => {
                if (isShow) {
                    this.showContent();
                }
                else {
                    this.dismissContent();
                }
            }));
        });
        this.position = (/**
         * @param {?} pObj
         * @return {?}
         */
        (pObj) => {
            /** @type {?} */
            let _left = pObj.offsetLeft || 0;
            /** @type {?} */
            let _top = pObj.offsetTop || 0;
            /** @type {?} */
            const w = pObj.offsetWidth;
            /** @type {?} */
            const h = pObj.offsetHeight;
            while (pObj = pObj.offsetParent) {
                _left += pObj.offsetLeft;
                _top += pObj.offsetTop;
            }
            return {
                x: _left,
                y: _top,
                w: w,
                h: h
            };
        });
        /**
         * get the offset of the arrow
         * @param cl the left / top of the pop over
         * @param cw the witdh / height of the pop over
         * @param al the left / top of arrow
         * @param aw the witdh / height of arrow
         */
        this.setArrowHelp = (/**
         * @param {?} cl
         * @param {?} cw
         * @param {?} al
         * @param {?} aw
         * @return {?}
         */
        (cl, cw, al, aw) => {
            /** @type {?} */
            let point;
            /** @type {?} */
            const adjustLength = 15;
            /** @type {?} */
            const max = cl + cw - adjustLength;
            /** @type {?} */
            const min = cl + adjustLength;
            if (cw > aw) {
                point = Math.floor(al + aw / 2);
                if (point < min) {
                    point = min;
                }
                else if (point > max) {
                    point = max;
                }
            }
            else {
                point = Math.floor(cl + cw / 2);
            }
            return point;
        });
        this.setArrowPosition = (/**
         * @return {?}
         */
        () => {
            /** @type {?} */
            const con = this.overlayContainer.getContainerElement();
            /** @type {?} */
            const child = con.querySelector('.md-event-overlay__children');
            /** @type {?} */
            const arrow = con.querySelector('.md-event-overlay__arrow');
            /** @type {?} */
            const cpos = this.position(child);
            /** @type {?} */
            const apos = this.position(this.archor);
            /** @type {?} */
            let l = 0;
            /** @type {?} */
            let t = 0;
            if (this.ArrowPositionClass === 'top' || this.ArrowPositionClass === 'bottom') {
                if (this.ArrowPositionClass === 'top') {
                    t = cpos.h;
                }
                l = this.arrowOffset != null ?
                    this.arrowOffset :
                    this.setArrowHelp(cpos.x, cpos.w, apos.x, apos.w) - cpos.x;
            }
            else {
                if (this.ArrowPositionClass === 'left') {
                    l = cpos.w;
                }
                t = this.arrowOffset != null ?
                    this.arrowOffset :
                    this.setArrowHelp(cpos.y, cpos.h, apos.y, apos.h) - cpos.y;
            }
            switch (this.ArrowPositionClass) {
                case 'top':
                    t = cpos.h;
                    break;
                case 'bottom':
                    break;
                case 'right':
                    break;
                case 'left':
                    l = cpos.w;
                    break;
            }
            arrow.setAttribute('style', 'transform:translate(' + l + 'px,' + t + 'px)');
        });
        /**
         * get the weighted value of the direction
         */
        this.checkArrowHelp = (/**
         * @param {?} origin
         * @param {?} overlay
         * @return {?}
         */
        (origin, overlay) => {
            /** @type {?} */
            const originV = this.positionHash[origin];
            /** @type {?} */
            const overlayV = this.positionHash[overlay];
            /** @type {?} */
            let pos = -1;
            /** @type {?} */
            let score = 0;
            if (originV !== 1) {
                pos = (originV) / 2;
                score = 20 + Math.abs(originV - overlayV) * 10;
            }
            else if (overlayV !== 1) {
                pos = (2 - originV) / 2;
                score = 10;
            }
            return {
                pos,
                score
            };
        });
        /**
         * get the direction of the arrow
         */
        this.checkArrowName = (/**
         * @return {?}
         */
        () => {
            if (this.arrowPosition !== undefined) {
                this.ArrowPositionClass = this.arrowPosition;
            }
            else {
                /** @type {?} */
                const positionPoint = [4, 2, 3, 1];
                // Weighted value of [ top, bottom, left, right ]
                /** @type {?} */
                const yPlus = this.checkArrowHelp(this.originY, this.overlayY);
                /** @type {?} */
                const xPlus = this.checkArrowHelp(this.originX, this.overlayX);
                positionPoint[yPlus.pos] += yPlus.score;
                positionPoint[xPlus.pos + 2] += xPlus.score;
                this.ArrowPositionClass = this.classArray[positionPoint.indexOf(Math.max.apply(null, positionPoint))];
            }
        });
        /**
         * Remove the container of head and subhead if no content
         */
        this.checkDom = (/**
         * @return {?}
         */
        () => {
            /** @type {?} */
            const container = this.overlayContainer.getContainerElement();
            /** @type {?} */
            const header = container.querySelector('.md-coachmark__header');
            /** @type {?} */
            const subheader = container.querySelector('.md-coachmark__subheader');
            this.checkEmpty(header);
            this.checkEmpty(subheader);
        });
        this.checkEmpty = (/**
         * @param {?} dom
         * @return {?}
         */
        (dom) => {
            if (dom.childNodes.length < 1) {
                dom.parentNode.removeChild(dom);
            }
        });
        this.showContent = (/**
         * @return {?}
         */
        () => {
            if (this.overlayRef && !this.overlayRef.hasAttached()) {
                this.overlayRef.attach(this.tp);
            }
        });
        this.dismissContent = (/**
         * @return {?}
         */
        () => {
            if (this.overlayRef && this.overlayRef.hasAttached()) {
                this.overlayRef.detach();
                if (this.overlayRef.backdropElement) {
                    this.overlayRef.backdropElement.remove();
                }
            }
        });
        this.handleClick = (/**
         * @param {?} e
         * @return {?}
         */
        (e) => {
            this.whenClick.emit(e);
        });
        this.show = (/**
         * @return {?}
         */
        () => {
            this.coachmarkService.setVisiable(true);
        });
        this.dismiss = (/**
         * @return {?}
         */
        () => {
            this.coachmarkService.setVisiable(false);
        });
        this.delayedShow = (/**
         * @return {?}
         */
        () => {
            if (this.showTimerId) {
                clearTimeout(this.showTimerId);
                this.showTimerId = null;
            }
            /** @type {?} */
            const delay = this.showDelay ? this.showDelay : this.delay;
            this.showTimerId = setTimeout((/**
             * @return {?}
             */
            () => {
                this.show();
            }), delay);
        });
        this.delayedHide = (/**
         * @return {?}
         */
        () => {
            if (this.hideTimerId) {
                clearTimeout(this.hideTimerId);
                this.hideTimerId = null;
            }
            /** @type {?} */
            const delay = this.hideDelay ? this.hideDelay : this.delay;
            this.hideTimerId = setTimeout((/**
             * @return {?}
             */
            () => {
                this.dismiss();
            }), delay);
        });
    }
    /**
     * @return {?}
     */
    ngAfterContentInit() {
        if (this.coachmark_close && this.coachmark_close.nativeElement) {
            this.coachmark_close.nativeElement.addEventListener('click', (/**
             * @return {?}
             */
            () => {
                this.delayedHide();
            }));
        }
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        this.initOverlayer();
        if (!this.allowClickAway && this.closeOnClick) {
            this.overlayRef.backdropClick().subscribe((/**
             * @return {?}
             */
            () => {
                this.dismissContent();
            }));
        }
        this.overlayRef.detachments().subscribe((/**
         * @return {?}
         */
        () => {
            this.whenClose.emit();
        }));
        if (this.isOpen) {
            this.delayedShow();
        }
    }
}
CoachmarkComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-coachmark',
                template: `
  <ng-template #tempCoachmark>
    <div class='md-event-overlay__arrow'></div>
    <div class='md-event-overlay__children' (click)='handleClick($event)'>
      <div class='md-coachmark__container'>
        <div class='md-coachmark__header'>
          <ng-content select='[coachmark_header]'></ng-content>
        </div>
        <div class='md-coachmark__subheader'>
          <ng-content select='[coahmark_subheader]'></ng-content>
        </div>
        <ng-content></ng-content>
      </div>
    </div>
  </ng-template>
  `,
                providers: [CoachmarkService],
                styles: ['.md-event-overlay__arrow{position:absolute;}',
                    '.md-event-overlay__children{position:static;box-shadow: inset 0 0 0 1px #D2D5D6, 0 4px 12px 0 rgba(0, 0, 0, 0.16) !important;}']
            }] }
];
/** @nocollapse */
CoachmarkComponent.ctorParameters = () => [
    { type: CoachmarkService },
    { type: Overlay },
    { type: OverlayContainer },
    { type: ViewContainerRef }
];
CoachmarkComponent.propDecorators = {
    archor: [{ type: Input }],
    allowClickAway: [{ type: Input }],
    className: [{ type: Input }],
    closeOnClick: [{ type: Input }],
    delay: [{ type: Input }],
    hideDelay: [{ type: Input }],
    isOpen: [{ type: Input }],
    maxWidth: [{ type: Input }],
    minWidth: [{ type: Input }],
    maxHeight: [{ type: Input }],
    minHeight: [{ type: Input }],
    width: [{ type: Input }],
    height: [{ type: Input }],
    showDelay: [{ type: Input }],
    originX: [{ type: Input }],
    originY: [{ type: Input }],
    overlayX: [{ type: Input }],
    overlayY: [{ type: Input }],
    arrowPosition: [{ type: Input }],
    arrowOffset: [{ type: Input }],
    whenClick: [{ type: Output }],
    whenClose: [{ type: Output }],
    tempCoachmark: [{ type: ViewChild, args: ['tempCoachmark',] }],
    coachmark_close: [{ type: ContentChild, args: ['coachmark_close',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CoachmarkModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: CoachmarkModule,
            providers: [],
        };
    }
}
CoachmarkModule.decorators = [
    { type: NgModule, args: [{
                declarations: [CoachmarkComponent],
                imports: [
                    CommonModule
                ],
                exports: [CoachmarkComponent],
                schemas: [CUSTOM_ELEMENTS_SCHEMA]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class PageHeaderContentComponent {
    /**
     * @param {?} viewContainerRef
     */
    constructor(viewContainerRef) {
        this.viewContainerRef = viewContainerRef;
        /**
         * \@prop Text to display for title features | ''
         */
        this.title = '';
        /**
         * \@prop Text to display for descriptions features | ''
         */
        this.lead = '';
        /**
         * \@prop define if the component if fixed dom | false
         */
        this.ifFixed = false;
        this.setVisibility = (/**
         * @param {?} scrollState
         * @return {?}
         */
        (scrollState) => {
            if (this.ifFixed) {
                this.viewContainerRef.element.nativeElement.style.display = scrollState === 0 ? 'none' : '';
            }
            else {
                this.viewContainerRef.element.nativeElement.style.visibility = scrollState === 0 ? '' : 'hidden';
            }
        });
        this.setWarpFixedState = (/**
         * @param {?} left
         * @param {?} top
         * @param {?} scale
         * @param {?} leadOpacity
         * @return {?}
         */
        (left, top, scale, leadOpacity) => {
            /** @type {?} */
            const con = this.viewContainerRef.element.nativeElement;
            con.style.left = left + 'px';
            con.style.top = top + 'px';
            con.style.transform = 'scale(' + scale + ')';
            this.leadRef.nativeElement.style.opacity = leadOpacity;
        });
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.ifFixed) {
            /** @type {?} */
            const con = this.viewContainerRef.element.nativeElement;
            con.style.position = 'fixed';
            con.style.zIndex = 1200;
            con.style.top = 0;
            con.style.display = 'none';
        }
    }
}
PageHeaderContentComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-page-header-content',
                template: `
  <div class="md-page-header__title">{{title}}</div>
  <h4 #leadRef class="md-page-header__lead">{{lead}}</h4>
  `,
                host: {
                    class: 'md-page-header__container'
                },
                styles: [':host{transform-origin: 0 0; z-index: 1100; margin: 0 auto 3rem 1.5rem;display:block;}',
                    '.md-page-header__title{font-size: 2.25rem; line-height: 3rem;}',
                    '.md-page-header__lead{ margin-top: .75rem; }']
            }] }
];
/** @nocollapse */
PageHeaderContentComponent.ctorParameters = () => [
    { type: ViewContainerRef }
];
PageHeaderContentComponent.propDecorators = {
    title: [{ type: Input }],
    lead: [{ type: Input }],
    ifFixed: [{ type: Input }],
    leadRef: [{ type: ViewChild, args: ['leadRef',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class PageHeaderComponent {
    /**
     * @param {?} eventManager
     * @param {?} viewContainerRef
     */
    constructor(eventManager, viewContainerRef) {
        this.eventManager = eventManager;
        this.viewContainerRef = viewContainerRef;
        /**
         * \@prop Text to display for title features | ''
         */
        this.title = '';
        /**
         * \@prop Text to display for descriptions features | ''
         */
        this.lead = '';
        /**
         * \@prop Sets css style (text-align) for the component | 'center'
         */
        this.textAlign = 'center';
        /**
         * \@prop Sets whether to fix component when scrolling | true
         */
        this.enableScrollFix = false;
        /**
         * \@prop shrink motion will be called when the scrollTop of the container is bigger than this value | 0
         */
        this.shrinkStartScrollTop = 0;
        /**
         * \@prop Sets the css top value which  the component will be fixed at finally | 20
         */
        this.shrinkEndFixedTop = 20;
        /**
         * \@prop Sets the range which the leader hiding motion will be called | 20
         */
        this.leaderHideLength = 20;
        /**
         * \@prop Sets the css transform:scale(X) for the fixed state | 0.42
         */
        this.ratioMin = 1;
        /**
         * \@prop Sets the easing formula for the shrinking motion | 'linear'
         */
        this.tween = 'linear';
        this.checkDomTime = 0;
        this.scrollState = 0; // 0 top 1 shrinking 2 fixed on the top
        // 0 top 1 shrinking 2 fixed on the top
        this.warpX = 0;
        this.warpY = 0;
        this.warpH = 0;
        this.shrinkEndScrollTop = 0;
        this.shrinkLength = 0;
        this.leaderShrinkStartScrollTop = 0;
        this.Tween = {
            linear: (/**
             * @param {?} t
             * @param {?} b
             * @param {?} c
             * @param {?} d
             * @return {?}
             */
            function (t, b, c, d) {
                return c * t / d + b;
            }),
            easeIn: (/**
             * @param {?} t
             * @param {?} b
             * @param {?} c
             * @param {?} d
             * @return {?}
             */
            function (t, b, c, d) {
                return c * (t /= d) * t + b;
            }),
            easeOut: (/**
             * @param {?} t
             * @param {?} b
             * @param {?} c
             * @param {?} d
             * @return {?}
             */
            function (t, b, c, d) {
                return -c * (t /= d) * (t - 2) + b;
            })
        };
        this.ifContainerClassLeft = true;
        this.onScroll = (/**
         * @return {?}
         */
        () => {
            this.checkDom();
            /** @type {?} */
            const scrollTop = window.pageYOffset || document.documentElement.scrollTop || 0;
            if (scrollTop <= this.shrinkStartScrollTop) {
                this.checkScrollState(0, (/**
                 * @return {?}
                 */
                () => {
                    this.fixElement.setWarpFixedState(this.warpX, this.warpY, 1, 1);
                }));
            }
            else if (scrollTop <= this.shrinkEndScrollTop) {
                this.checkScrollState(1);
                /** @type {?} */
                const _t = scrollTop - this.shrinkStartScrollTop;
                /** @type {?} */
                const _top = this.Tween.linear(_t, this.warpY, this.shrinkEndFixedTop - this.warpY, this.shrinkLength);
                /** @type {?} */
                const _scale = this.Tween[this.tween](_t, 1, this.ratioMin - 1, this.shrinkLength);
                /** @type {?} */
                let _leadOpacity = 1;
                if (_t >= this.leaderShrinkStartScrollTop) {
                    _leadOpacity = this.Tween[this.tween](_t - this.leaderShrinkStartScrollTop, 1, -1, this.shrinkLength - this.shrinkStartScrollTop);
                }
                this.fixElement.setWarpFixedState(this.warpX, Math.floor(_top), _scale, _leadOpacity);
            }
            else {
                this.checkScrollState(2, (/**
                 * @return {?}
                 */
                () => {
                    this.fixElement.setWarpFixedState(this.warpX, this.shrinkEndFixedTop, this.ratioMin, 0);
                }));
            }
        });
        this.checkDom = (/**
         * @return {?}
         */
        () => {
            if (this.checkDomTime < 2) {
                /** @type {?} */
                const warp = this.viewContainerRef.element.nativeElement;
                /** @type {?} */
                const pos = this.getDomPosition(warp);
                this.warpX = pos.x;
                this.warpY = pos.y;
                this.warpH = warp.clientHeight;
                this.checkDomTime++;
                /** @type {?} */
                const plusScroll = Math.floor(this.warpH * (1 - this.ratioMin));
                this.shrinkLength = this.warpY - this.shrinkEndFixedTop + plusScroll;
                if (this.leaderHideLength < this.shrinkLength) {
                    this.leaderShrinkStartScrollTop = this.shrinkStartScrollTop + this.shrinkLength - this.leaderHideLength;
                }
                else {
                    this.leaderShrinkStartScrollTop = Math.floor(this.shrinkStartScrollTop + this.shrinkLength / 4 * 3);
                }
                this.shrinkEndScrollTop = this.shrinkStartScrollTop + this.shrinkLength;
            }
        });
        // 0 top 1 shrinking 2 fixed on the top
        this.checkScrollState = (/**
         * @param {?} scrollState
         * @param {?=} callback
         * @return {?}
         */
        (scrollState, callback) => {
            if (scrollState !== this.scrollState) {
                this.scrollState = scrollState;
                this.fixElement.setVisibility(scrollState);
                this.staticElement.setVisibility(scrollState);
                if (callback !== undefined) {
                    callback();
                }
            }
        });
        this.getDomPosition = (/**
         * @param {?} pObj
         * @return {?}
         */
        pObj => {
            /** @type {?} */
            let _left = pObj.offsetLeft || 0;
            /** @type {?} */
            let _top = pObj.offsetTop || 0;
            while (pObj === pObj.offsetParent) {
                _left += pObj.offsetLeft;
                _top += pObj.offsetTop;
            }
            return { x: _left, y: _top };
        });
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.ifContainerClassLeft = this.textAlign === 'center';
        if (this.enableScrollFix) {
            this.eventManager.addGlobalEventListener('window', 'scroll', (/**
             * @param {?} e
             * @return {?}
             */
            (e) => {
                this.onScroll();
            }));
        }
    }
}
PageHeaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-page-header',
                template: `
    <md-page-header-content #staticElement [title]='title' [lead]='lead'></md-page-header-content>
    <md-page-header-content *ngIf='enableScrollFix' #fixElement [title]='title' [lead]='lead' [ifFixed]='true'></md-page-header-content>
  `,
                host: {
                    class: 'md-page-header',
                    '[class.md-page-header--left]': 'textAlign'
                },
                styles: [':host{grid-area: page-header; display:block;}']
            }] }
];
/** @nocollapse */
PageHeaderComponent.ctorParameters = () => [
    { type: EventManager },
    { type: ViewContainerRef }
];
PageHeaderComponent.propDecorators = {
    title: [{ type: Input }],
    lead: [{ type: Input }],
    textAlign: [{ type: Input }],
    enableScrollFix: [{ type: Input }],
    shrinkStartScrollTop: [{ type: Input }],
    shrinkEndFixedTop: [{ type: Input }],
    leaderHideLength: [{ type: Input }],
    ratioMin: [{ type: Input }],
    tween: [{ type: Input }],
    fixElement: [{ type: ViewChild, args: ['fixElement',] }],
    staticElement: [{ type: ViewChild, args: ['staticElement',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class PageHeaderContentModule {
}
PageHeaderContentModule.decorators = [
    { type: NgModule, args: [{
                declarations: [PageHeaderContentComponent],
                imports: [
                    CommonModule
                ],
                exports: [PageHeaderContentComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class PageHeaderModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: PageHeaderModule,
            providers: [],
        };
    }
}
PageHeaderModule.decorators = [
    { type: NgModule, args: [{
                declarations: [PageHeaderComponent],
                imports: [
                    CommonModule,
                    PageHeaderContentModule
                ],
                exports: [PageHeaderComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class PaginationService {
    /**
     * @param {?} sanitizer
     */
    constructor(sanitizer) {
        this.sanitizer = sanitizer;
        this.href = '';
        this.hrefReplaceReg = '$page$';
        this.current = new Subject();
        this.focused = new Subject();
        this.total = new Subject();
        this.current$ = this.current.asObservable();
        this.focused$ = this.focused.asObservable();
        this.total$ = this.total.asObservable();
        this.getHref = (/**
         * @param {?} index
         * @return {?}
         */
        (index) => {
            if (this.href !== '' && this.href) {
                return this.href.replace(this.hrefReplaceReg, index);
            }
            else {
                return this.sanitizer.bypassSecurityTrustUrl('javascript:void(0)');
            }
        });
        this.focusInList = (/**
         * @param {?} list
         * @param {?} offset
         * @return {?}
         */
        (list, offset) => {
            /** @type {?} */
            let index = list.indexOf(this.focusPage || this.currentPage);
            /** @type {?} */
            const lastIndex = list.length - 1;
            if (lastIndex > -1) {
                if (index === -1) {
                    index = 0;
                }
                if (offset > 0) {
                    index = Math.min(lastIndex, index + offset);
                }
                else {
                    index = Math.max(0, index + offset);
                }
                this.focus(list[index]);
            }
        });
        this.selectfocus = (/**
         * @return {?}
         */
        () => {
            if (this.focusPage === 'previous') {
                this.selectPrevious();
            }
            else if (this.focusPage === 'next') {
                this.selectNext();
            }
            else {
                this.select(this.focusPage);
            }
        });
        this.current$.subscribe((/**
         * @param {?} v
         * @return {?}
         */
        (v) => {
            this.currentPage = v;
        }));
        this.focused$.subscribe((/**
         * @param {?} v
         * @return {?}
         */
        (v) => {
            this.focusPage = v;
        }));
        this.total$.subscribe((/**
         * @param {?} v
         * @return {?}
         */
        (v) => {
            this.totalPage = v;
        }));
    }
    /**
     * @param {?} href
     * @param {?} hrefReplaceReg
     * @param {?} totalPage
     * @return {?}
     */
    initConfig(href, hrefReplaceReg, totalPage) {
        this.href = href;
        this.hrefReplaceReg = hrefReplaceReg;
        this.totalPage = totalPage;
    }
    /**
     * @param {?} index
     * @return {?}
     */
    isClickable(index) {
        return index !== this.currentPage && index > 0 && index <= this.totalPage;
    }
    /**
     * @return {?}
     */
    isFirstOrLastNow() {
        return this.currentPage === 0 || this.currentPage === this.totalPage;
    }
    /**
     * @param {?} index
     * @return {?}
     */
    isCurrent(index) {
        return this.currentPage === index;
    }
    /**
     * @return {?}
     */
    isCurrentFirst() {
        return this.currentPage === 1;
    }
    /**
     * @return {?}
     */
    isCurrentLast() {
        return this.currentPage === this.totalPage;
    }
    /**
     * @param {?} index
     * @return {?}
     */
    select(index) {
        if (this.isClickable(index)) {
            this.current.next(index);
        }
    }
    /**
     * @return {?}
     */
    selectNext() {
        this.select(this.currentPage + 1);
    }
    /**
     * @return {?}
     */
    selectPrevious() {
        this.select(this.currentPage - 1);
    }
    /**
     * @param {?} index
     * @return {?}
     */
    focus(index) {
        if (index !== this.focusPage) {
            this.focused.next(index);
        }
    }
}
PaginationService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
PaginationService.ctorParameters = () => [
    { type: DomSanitizer }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class PaginationComponent {
    /**
     * @param {?} paginationService
     */
    constructor(paginationService) {
        this.paginationService = paginationService;
        /**
         * \@option set the href format | ''
         */
        this.href = '';
        /**
         * \@option set the replace placeholder of href
         */
        this.hrefReplaceReg = '$page$';
        /**
         * \@props set total | ''
         */
        this.total = 10;
        /**
         * \@props set current | ''
         */
        this.current = 1;
        /**
         * \@props set the first button group | ''
         */
        this.firstGroupNum = 2;
        /**
         * \@props set the mid button group | ''
         */
        this.midGroupNum = 3;
        /**
         * \@props set the last button group | ''
         */
        this.lastGroupNum = 2;
        /**
         * \@option Callback function invoked when user clicks buttons
         */
        this.whenClick = new EventEmitter();
        this.renderGroupFirst = [];
        this.renderGroupMid = [];
        this.renderGroupLast = [];
        this.renderGroup = [];
        this.firstGroupEnd = -1;
        this.midGroupStart = 1;
        this.midGroupEnd = 1;
        this.lastGroupStart = Infinity;
        this.ifPreventDefault = false;
        this.minCurrentForFirstGroup = 0;
        this.maxCurrentForLastGroup = 0;
        this.handleKeydown = (/**
         * @param {?} event
         * @return {?}
         */
        (event) => {
            /** @type {?} */
            const s = this.paginationService;
            /** @type {?} */
            let ifStop = false;
            switch (event.keyCode) {
                case LEFT_ARROW: // <-
                    s.focusInList(this.renderGroup, -1);
                    ifStop = true;
                    break;
                case RIGHT_ARROW: // ->
                    s.focusInList(this.renderGroup, 1);
                    ifStop = true;
                    break;
                case ENTER: // Enter
                    s.selectfocus();
                    ifStop = true;
                    break;
                default:
                    break;
            }
            if (ifStop) {
                event.stopPropagation();
            }
        });
        this.build = (/**
         * @return {?}
         */
        () => {
            /** @type {?} */
            const s = this.paginationService;
            /** @type {?} */
            const current = s.currentPage;
            /** @type {?} */
            const total = s.totalPage;
            /** @type {?} */
            const preMidLen = Math.floor((this.midGroupNum - 1) / 2);
            /** @type {?} */
            const nextMidLen = this.midGroupNum - preMidLen - 1;
            this.minCurrentForFirstGroup = this.firstGroupNum + 1 + preMidLen; // > this
            this.maxCurrentForLastGroup = total - this.lastGroupNum - 1 - nextMidLen + 1; // > this
            if (current <= this.minCurrentForFirstGroup && current >= this.maxCurrentForLastGroup) { // merge all
                this.firstGroupEnd = -1;
                this.lastGroupStart = Infinity;
                this.midGroupStart = 1;
                this.midGroupEnd = total;
            }
            else {
                if (current > this.minCurrentForFirstGroup) {
                    this.firstGroupEnd = this.firstGroupNum;
                    this.midGroupStart = current - preMidLen;
                    this.midGroupEnd = Math.min(total, this.midGroupStart + this.midGroupNum - 1);
                }
                else { // merge start and middle
                    this.firstGroupEnd = -1;
                    this.midGroupStart = 1;
                    this.midGroupEnd = Math.min(total, Math.max(current + nextMidLen, this.minCurrentForFirstGroup));
                }
                if (current < this.maxCurrentForLastGroup) {
                    this.lastGroupStart = total - this.lastGroupNum + 1;
                }
                else { // merge end and middle
                    this.lastGroupStart = Infinity;
                    this.midGroupStart = Math.max(1, Math.min(current - preMidLen, this.maxCurrentForLastGroup));
                    this.midGroupEnd = total;
                }
            }
            // get template
            this.renderGroupFirst = [];
            this.renderGroupMid = [];
            this.renderGroupLast = [];
            this.renderGroup = [];
            /** @type {?} */
            let i = 1;
            if (current > 1) {
                this.renderGroup.push('previous');
            }
            for (i = 1; i <= this.firstGroupEnd; i++) {
                this.renderGroupFirst.push(i);
                this.renderGroup.push(i);
            }
            if (this.firstGroupEnd === this.midGroupStart) {
                this.renderGroupFirst.pop();
            }
            for (i = this.midGroupStart; i <= this.midGroupEnd; i++) {
                this.renderGroupMid.push(i);
                this.renderGroup.push(i);
            }
            if (this.midGroupEnd === this.lastGroupStart) {
                this.renderGroupMid.pop();
            }
            for (i = this.lastGroupStart; i <= total; i++) {
                this.renderGroupLast.push(i);
                this.renderGroup.push(i);
            }
            if (s.currentPage < total) {
                this.renderGroup.push('next');
            }
        });
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        /** @type {?} */
        const s = this.paginationService;
        s.initConfig(this.href, this.hrefReplaceReg, this.total);
        s.current$.subscribe((/**
         * @param {?} v
         * @return {?}
         */
        (v) => {
            this.build();
            this.whenClick.emit(v);
        }));
        this.paginationService.select(this.current);
    }
}
PaginationComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-pagination',
                template: `
    <md-pagination-arrow
      [isPrevious]='true'
      [ifPreventDefault]='ifPreventDefault'
    ></md-pagination-arrow>
    <md-pagination-number *ngFor='let item of renderGroupFirst'
      [index]='item'
      [ifPreventDefault]='ifPreventDefault'
    ></md-pagination-number>
    <li class='pagination_li ellipsis' *ngIf='firstGroupEnd > 0 && firstGroupEnd < midGroupStart - 1' aria-hidden="true">...</li>
    <md-pagination-number *ngFor='let item of renderGroupMid'
      [index]='item'
      [ifPreventDefault]='ifPreventDefault'
    ></md-pagination-number>
    <li class='pagination_li ellipsis' *ngIf='lastGroupStart < total && lastGroupStart > midGroupEnd + 1' aria-hidden="true">...</li>
    <md-pagination-number *ngFor='let item of renderGroupLast'
      [index]='item'
      [ifPreventDefault]='ifPreventDefault'
    ></md-pagination-number>
    <md-pagination-arrow
      [isPrevious]='false'
      [ifPreventDefault]='ifPreventDefault'
    ></md-pagination-arrow>
  `,
                host: {
                    class: 'pagination',
                    'style': `
      display: block;
      min-height: 1.5rem;
      list-style-position: outside;
      clear:both;
    `,
                    'attr.role': 'navigation',
                    'attr.aria-label': 'Pagination',
                    'tabindex': '0',
                    '(keydown)': 'handleKeydown($event)'
                },
                providers: [PaginationService],
                styles: [".ellipsis{width:11px;height:16px;color:#666;font-size:12px;font-family:CiscoSans;text-align:center;letter-spacing:0}.pagination_li{display:block;float:left;font-size:12px;margin:0 20px 0 0;height:20px;line-height:20px;min-width:20px;border-radius:10px!important;text-align:center!important}.pagination_li_last{margin-right:0}.pagination_li_a{transition:background-color .3s ease-out;display:block;font-size:12px;color:#05a1bf;border-radius:10px!important;text-align:center!important;padding:0 4px;line-height:20px}.pagination_current,.pagination_li_a:focus,.pagination_li_a:hover{background:#07c1e4;color:#fff;padding:0 4px}.pagination_disable{color:rgba(0,0,0,.4);padding:0 4px}.pagination_li_a_focus,.pagination_li_focus{border-color:transparent;outline:0;box-shadow:0 0 4px 2px rgba(0,160,209,.75)}"]
            }] }
];
/** @nocollapse */
PaginationComponent.ctorParameters = () => [
    { type: PaginationService }
];
PaginationComponent.propDecorators = {
    href: [{ type: Input }],
    hrefReplaceReg: [{ type: Input }],
    total: [{ type: Input }],
    current: [{ type: Input }],
    firstGroupNum: [{ type: Input }],
    midGroupNum: [{ type: Input }],
    lastGroupNum: [{ type: Input }],
    whenClick: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class PaginationArrowComponent {
    /**
     * @param {?} paginationService
     */
    constructor(paginationService) {
        this.paginationService = paginationService;
        /**
         * \@option set isPrevious | ''
         */
        this.isPrevious = true;
        /**
         * \@option set ifPreventDefault | ''
         */
        this.ifPreventDefault = false;
        this.isEnable = false;
        this.name = 'Previous page';
        this.myHref = '';
        this.ngClassA = {
            'pagination_li_a': true,
            'icon--b1': true,
            'md-icon': true,
            'icon': true,
            'pagination_li_a_focus': false,
            'icon-arrow-left_20': true,
            'icon-arrow-right_20': false
        };
        this.handleClick = (/**
         * @param {?} event
         * @return {?}
         */
        (event) => {
            if (this.isPrevious) {
                this.paginationService.focus('previous');
                this.paginationService.selectPrevious();
            }
            else {
                this.paginationService.focus('next');
                this.paginationService.selectNext();
            }
            event.stopPropagation();
            if (this.ifPreventDefault) {
                event.preventDefault();
            }
        });
        this.build = (/**
         * @return {?}
         */
        () => {
            /** @type {?} */
            const s = this.paginationService;
            if (this.isPrevious) {
                this.isEnable = !s.isCurrentFirst();
                this.name = 'Previous page';
                this.ngClassA['icon-arrow-left_20'] = true;
                this.ngClassA['icon-arrow-right_20'] = false;
                this.myHref = s.getHref(s.currentPage - 1);
            }
            else {
                this.isEnable = !s.isCurrentLast();
                this.name = 'Next page';
                this.ngClassA['icon-arrow-left_20'] = false;
                this.ngClassA['icon-arrow-right_20'] = true;
                this.myHref = s.getHref(s.currentPage + 1);
            }
        });
        this.paginationService.current$.subscribe((/**
         * @return {?}
         */
        () => {
            this.build();
        }));
        this.paginationService.focused$.subscribe((/**
         * @param {?} v
         * @return {?}
         */
        (v) => {
            if (this.isPrevious) {
                this.ngClassA.pagination_li_a_focus = v === 'previous';
            }
            else {
                this.ngClassA.pagination_li_a_focus = v === 'next';
            }
        }));
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.build();
    }
}
PaginationArrowComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-pagination-arrow',
                template: `
    <a #btn *ngIf="isEnable;else disableTemplate"
      [ngClass]='ngClassA'
      [href]='myHref'
      [attr.aria-label]='name'
      (click)='handleClick($event)'
    ><span class="show-for-sr">page</span></a>
    <ng-template #disableTemplate>
      <span class="show-for-sr">page</span>
    </ng-template>
  `,
                host: {
                    'class': 'pagination-previous pagination_li md-icon icon',
                    '[class.pagination_li_last]': '!isPrevious',
                    '[class.pagination_disable]': '!isEnable',
                    '[class.icon-arrow-left-optical_20]': 'isPrevious && !isEnable',
                    '[class.icon-arrow-right-optical_20]': '!isPrevious && !isEnable'
                },
                styles: [".ellipsis{width:11px;height:16px;color:#666;font-size:12px;font-family:CiscoSans;text-align:center;letter-spacing:0}.pagination_li{display:block;float:left;font-size:12px;margin:0 20px 0 0;height:20px;line-height:20px;min-width:20px;border-radius:10px!important;text-align:center!important}.pagination_li_last{margin-right:0}.pagination_li_a{transition:background-color .3s ease-out;display:block;font-size:12px;color:#05a1bf;border-radius:10px!important;text-align:center!important;padding:0 4px;line-height:20px}.pagination_current,.pagination_li_a:focus,.pagination_li_a:hover{background:#07c1e4;color:#fff;padding:0 4px}.pagination_disable{color:rgba(0,0,0,.4);padding:0 4px}.pagination_li_a_focus,.pagination_li_focus{border-color:transparent;outline:0;box-shadow:0 0 4px 2px rgba(0,160,209,.75)}"]
            }] }
];
/** @nocollapse */
PaginationArrowComponent.ctorParameters = () => [
    { type: PaginationService }
];
PaginationArrowComponent.propDecorators = {
    isPrevious: [{ type: Input }],
    ifPreventDefault: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class PaginationArrowModule {
}
PaginationArrowModule.decorators = [
    { type: NgModule, args: [{
                declarations: [PaginationArrowComponent],
                imports: [
                    CommonModule
                ],
                exports: [PaginationArrowComponent],
                schemas: [CUSTOM_ELEMENTS_SCHEMA]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class PaginationNumberComponent {
    /**
     * @param {?} paginationService
     */
    constructor(paginationService) {
        this.paginationService = paginationService;
        /**
         * \@option set ifPreventDefault | ''
         */
        this.ifPreventDefault = false;
        this.isCurrent = false;
        this.isFocus = false;
        this.ngClassA = {
            'pagination_li_a': true,
            'pagination_li_a_focus': false
        };
        this.build = (/**
         * @return {?}
         */
        () => {
            /** @type {?} */
            const s = this.paginationService;
            this.myHref = s.getHref(this.index);
            this.isCurrent = s.isCurrent(this.index);
        });
        this.handleClick = (/**
         * @param {?} event
         * @return {?}
         */
        (event) => {
            this.paginationService.focus(this.index);
            this.paginationService.select(this.index);
            event.stopPropagation();
            if (this.ifPreventDefault) {
                event.preventDefault();
            }
        });
        this.paginationService.current$.subscribe((/**
         * @return {?}
         */
        () => {
            this.build();
        }));
        this.paginationService.focused$.subscribe((/**
         * @param {?} v
         * @return {?}
         */
        (v) => {
            this.isFocus = v === this.index;
            this.ngClassA.pagination_li_a_focus = this.isFocus;
        }));
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.build();
    }
}
PaginationNumberComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-pagination-number',
                template: `
    <a [ngClass]='ngClassA' *ngIf="!isCurrent;else other_content"
    [href]='myHref'
    [attr.aria-label]="'Page '+index"
    (click)='handleClick($event)'
    >{{ index }}</a>
    <ng-template #other_content>{{ index }}</ng-template>
  `,
                host: {
                    'class': 'pagination_li',
                    '[class.pagination_current]': 'isCurrent',
                    '[class.pagination_li_focus]': 'isCurrent && isFocus'
                },
                styles: [".ellipsis{width:11px;height:16px;color:#666;font-size:12px;font-family:CiscoSans;text-align:center;letter-spacing:0}.pagination_li{display:block;float:left;font-size:12px;margin:0 20px 0 0;height:20px;line-height:20px;min-width:20px;border-radius:10px!important;text-align:center!important}.pagination_li_last{margin-right:0}.pagination_li_a{transition:background-color .3s ease-out;display:block;font-size:12px;color:#05a1bf;border-radius:10px!important;text-align:center!important;padding:0 4px;line-height:20px}.pagination_current,.pagination_li_a:focus,.pagination_li_a:hover{background:#07c1e4;color:#fff;padding:0 4px}.pagination_disable{color:rgba(0,0,0,.4);padding:0 4px}.pagination_li_a_focus,.pagination_li_focus{border-color:transparent;outline:0;box-shadow:0 0 4px 2px rgba(0,160,209,.75)}"]
            }] }
];
/** @nocollapse */
PaginationNumberComponent.ctorParameters = () => [
    { type: PaginationService }
];
PaginationNumberComponent.propDecorators = {
    index: [{ type: Input }],
    ifPreventDefault: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class PaginationNumberModule {
}
PaginationNumberModule.decorators = [
    { type: NgModule, args: [{
                declarations: [PaginationNumberComponent],
                imports: [
                    CommonModule
                ],
                exports: [PaginationNumberComponent],
                schemas: [CUSTOM_ELEMENTS_SCHEMA]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class PaginationModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: PaginationModule,
            providers: [],
        };
    }
}
PaginationModule.decorators = [
    { type: NgModule, args: [{
                declarations: [PaginationComponent],
                imports: [
                    CommonModule,
                    PaginationArrowModule,
                    PaginationNumberModule
                ],
                exports: [PaginationComponent],
                schemas: [CUSTOM_ELEMENTS_SCHEMA]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DrawerComponent {
    /**
     * @param {?} el
     */
    constructor(el) {
        this._visible = false;
        /**
         * \@prop css class names | ''
         */
        this.class = '';
        /**
         * \@prop Sets the openFrom opens | 'right'
         */
        this.openFrom = 'right';
        /**
         * \@prop Sets the openFrom opens defaults | 'medium
         */
        this.size = 'medium';
        /**
         * \@prop set the text for accessibilty on the close button | 'close'
         */
        this.closeAriaLabel = 'close';
        /**
         * use this event to know when the drawer has changed
         */
        this.drawerChanged = new EventEmitter();
    }
    /**
     * @return {?}
     */
    get className() {
        return 'md-drawer '
            + `${'md-drawer--' + this.openFrom} `
            + `${'md-drawer--' + this.openFrom + '--' + this.size} `
            + `${!this.isOpen ? 'md-drawer--' + this.openFrom + '--closed' : ''}`
            + `${this.class ? this.class : ''} `;
    }
    /**
     * \@prop Set whether the drawer is open or not | 'false'
     * @param {?} value
     * @return {?}
     */
    set isOpen(value) {
        this._visible = value;
    }
    /**
     * @return {?}
     */
    get isOpen() {
        return this._visible;
    }
    /**
     * @return {?}
     */
    close() {
        this.isOpen = false;
        this.drawerChanged.emit(this.isOpen);
    }
}
DrawerComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-drawer',
                template: `
    <ng-content></ng-content>
    <md-icon
      className="md-drawer__close"
      name="cancel_14"
      ariaLabel="{{closeAriaLabel}}"
      (click)="close()" >
    </md-icon>
  `
            }] }
];
/** @nocollapse */
DrawerComponent.ctorParameters = () => [
    { type: ElementRef }
];
DrawerComponent.propDecorators = {
    class: [{ type: Input }],
    className: [{ type: HostBinding, args: ['class',] }],
    isOpen: [{ type: Input }],
    openFrom: [{ type: Input }],
    size: [{ type: Input }],
    closeAriaLabel: [{ type: Input }],
    drawerChanged: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DrawerModule {
}
DrawerModule.decorators = [
    { type: NgModule, args: [{
                declarations: [DrawerComponent],
                imports: [
                    CommonModule,
                    IconModule
                ],
                exports: [DrawerComponent],
                schemas: [CUSTOM_ELEMENTS_SCHEMA]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CheckboxGroupComponent {
    constructor() { }
}
CheckboxGroupComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-checkbox-group',
                template: `
    <ng-content></ng-content>
  `,
                host: {
                    class: 'md-checkbox-group',
                },
                styles: [`
      :host {
        display: block;
      }
    `]
            }] }
];
/** @nocollapse */
CheckboxGroupComponent.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CheckboxGroupModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: CheckboxGroupModule,
            providers: [],
        };
    }
}
CheckboxGroupModule.decorators = [
    { type: NgModule, args: [{
                declarations: [CheckboxGroupComponent],
                imports: [
                    CommonModule
                ],
                exports: [CheckboxGroupComponent],
                schemas: [CUSTOM_ELEMENTS_SCHEMA],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class RadioGroupComponent {
    constructor() { }
    /**
     * @return {?}
     */
    ngOnInit() { }
}
RadioGroupComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-radio-group',
                template: `
    <ng-content></ng-content>
  `,
                host: {
                    class: 'md-radio-group',
                },
                styles: [`
      :host {
        display: block;
      }
    `]
            }] }
];
/** @nocollapse */
RadioGroupComponent.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class RadioGroupModule {
}
RadioGroupModule.decorators = [
    { type: NgModule, args: [{
                declarations: [RadioGroupComponent],
                imports: [
                    CommonModule
                ],
                exports: [RadioGroupComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class Handler {
    /**
     * @param {?} el
     * @return {?}
     */
    static getOffset(el) {
        /** @type {?} */
        const rect = el.getBoundingClientRect();
        return {
            top: rect.top + document.body.scrollTop,
            left: rect.left + document.body.scrollLeft
        };
    }
    /**
     * @param {?} element
     * @param {?} selector
     * @return {?}
     */
    static findSingle(element, selector) {
        if (element) {
            return element.querySelector(selector);
        }
        return null;
    }
    /**
     * @param {?=} el
     * @return {?}
     */
    static calculateScrollbarWidth(el) {
        if (el) {
            /** @type {?} */
            const style = getComputedStyle(el);
            return (el.offsetWidth - el.clientWidth - parseFloat(style.borderLeftWidth) - parseFloat(style.borderRightWidth));
        }
        else {
            if (this.calculatedScrollbarWidth !== null) {
                return this.calculatedScrollbarWidth;
            }
            /** @type {?} */
            const scrollDiv = document.createElement('div');
            scrollDiv.className = 'md-data-table__scrollbar';
            document.body.appendChild(scrollDiv);
            /** @type {?} */
            const scrollbarWidth = scrollDiv.offsetWidth - scrollDiv.clientWidth;
            document.body.removeChild(scrollDiv);
            this.calculatedScrollbarWidth = scrollbarWidth;
            return scrollbarWidth;
        }
    }
    /**
     * @param {?} el
     * @param {?=} margin
     * @return {?}
     */
    static getOuterWidth(el, margin) {
        /** @type {?} */
        let width = el.offsetWidth;
        if (margin) {
            /** @type {?} */
            const style = getComputedStyle(el);
            width += parseFloat(style.marginLeft) + parseFloat(style.marginRight);
        }
        return width;
    }
    /**
     * @param {?} el
     * @param {?=} margin
     * @return {?}
     */
    static getOuterHeight(el, margin) {
        /** @type {?} */
        let height = el.offsetHeight;
        if (margin) {
            /** @type {?} */
            const style = getComputedStyle(el);
            height += parseFloat(style.marginTop) + parseFloat(style.marginBottom);
        }
        return height;
    }
}
Handler.calculatedScrollbarWidth = null;

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DataTableComponent {
    /**
     * @param {?} el
     * @param {?} zone
     * @param {?} tableService
     * @param {?} cd
     */
    constructor(el, zone, tableService, cd) {
        this.el = el;
        this.zone = zone;
        this.tableService = tableService;
        this.cd = cd;
        /**
         * \@prop set the css class on the wrapper container div | ''
         */
        this.containerClass = '';
        /**
         * \@prop sets the table columns to allow for resize | false
         */
        this.resizableColumns = false;
        /**
         * \@prop set css class on table element | ''
         */
        this.tableClass = '';
        /**
         * \@prop start of table in ascending or descending order || 1
         */
        this.defaultSortOrder = 1;
        /**
         * \@prop set the scroll height of the table | ''
         */
        this.scrollHeight = '';
        /**
         * \@prop sets lazy load mode for small sections of data to load instead of entire data | false
         */
        this.lazy = false;
        /**
         * \@prop sets virtual scroll on the data table | false
         */
        this.virtualScroll = false;
        /**
         * \@prop set the setTimeout delay in handling virtual scroll | 150
         */
        this.virtualScrollDelay = 150;
        /**
         * \@prop set the virtual row height
         */
        this.virtualRowHeight = 34;
        /**
         * \@prop sets the widths of the table and its cells to fit for the content | false
         */
        this.autoLayout = false;
        /**
         * \@prop allows for row selection click \ false
         */
        this.rowSelection = false;
        /**
         * \@prop show column dividers css border | false
         */
        this.columnDividers = false;
        /**
         * \@prop use custom sort function | false
         */
        this.customSort = false;
        /**
         * \@prop change theme of the data table | null
         */
        this.theme = '';
        /**
         * \@prop emit custom sort function
         */
        this.sortBy = new EventEmitter();
        /**
         * \@prop emit function after column sort
         */
        this.afterSort = new EventEmitter();
        /**
         * \@prop emit function after column resize end
         */
        this.afterColResize = new EventEmitter();
        /**
         * \@prop emit function triggering load data
         */
        this.lazyLoad = new EventEmitter();
        /**
         * \@prop emit function when toggling header checkbox
         */
        this.headerCheckboxToggle = new EventEmitter();
        /**
         * \@prop emit function when checked selection changes
         */
        this.selectionChange = new EventEmitter();
        /**
         * \@prop emit function when row is checked
         */
        this.rowCheck = new EventEmitter();
        /**
         * \@prop emit function when row is unchecked
         */
        this.rowUncheck = new EventEmitter();
        /**
         * \@prop emit function when table row is selected
         */
        this.rowSelect = new EventEmitter();
        /**
         * \@prop emit function when table row is unselected
         */
        this.rowUnselect = new EventEmitter();
        this._data = [];
        this._dataCount = 0;
        this._sortOrder = 1;
        this._first = 0;
        this.selectionKeys = {}; // for adding and removing to selection
        this.rowTrackBy = (/**
         * @param {?} index
         * @param {?} item
         * @return {?}
         */
        (index, item) => item);
    }
    /**
     * \@prop set the data for the table
     * @return {?}
     */
    get data() {
        return this._data;
    }
    /**
     * @param {?} val
     * @return {?}
     */
    set data(val) {
        this._data = val;
        if (!this.lazy) {
            this.dataCount = (this._data ? this._data.length : 0);
            if (this.sortField) {
                this.applySort();
            }
        }
        if (this.virtualScroll && this.virtualScrollCb) {
            this.virtualScrollCb();
        }
        this.tableService.onDataChange(val);
    }
    /**
     * \@prop set the column's header and field data
     * @return {?}
     */
    get columns() {
        return this._columns;
    }
    /**
     * @param {?} cols
     * @return {?}
     */
    set columns(cols) {
        this._columns = cols;
        this.tableService.onColumnsChange(cols);
    }
    /**
     * \@prop number of records in data set | 0
     * @return {?}
     */
    get dataCount() {
        return this._dataCount;
    }
    /**
     * @param {?} val
     * @return {?}
     */
    set dataCount(val) {
        this._dataCount = val;
        this.tableService.onDataCountChange(this._dataCount);
    }
    /**
     * \@prop sets field being sorted on
     * @return {?}
     */
    get sortField() {
        return this._sortField;
    }
    /**
     * @param {?} val
     * @return {?}
     */
    set sortField(val) {
        this._sortField = val;
        if (this.initialized) {
            this.applySort();
        }
    }
    /**
     * \@prop set the sort order, used with sort icons on header | 1
     * @return {?}
     */
    get sortOrder() {
        return this._sortOrder;
    }
    /**
     * @param {?} val
     * @return {?}
     */
    set sortOrder(val) {
        this._sortOrder = val;
        if (this.initialized) {
            this.applySort();
        }
    }
    /**
     * \@prop get the row number of which virtual scroll starts load
     * @return {?}
     */
    get first() {
        return this._first;
    }
    /**
     * @param {?} val
     * @return {?}
     */
    set first(val) {
        this._first = val;
    }
    /**
     * @return {?}
     */
    get selection() {
        return this._selection;
    }
    /**
     * @param {?} val
     * @return {?}
     */
    set selection(val) {
        this._selection = val;
        if (!this.preventPropagation) {
            this.updateSelectionKeys();
            this.tableService.onSelectionChange();
        }
        this.preventPropagation = false;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.initialized = true;
    }
    /**
     * @return {?}
     */
    ngAfterContentInit() {
        // sort out mdTemplateName to the correct templateOutlet
        this.templates.forEach((/**
         * @param {?} item
         * @return {?}
         */
        (item) => {
            switch (item.getType()) {
                case 'header':
                    this.headerTemplate = item.template;
                    break;
                case 'body':
                    this.bodyTemplate = item.template;
                    break;
                case 'colgroup':
                    this.colGroupTemplate = item.template;
                    break;
            }
        }));
    }
    // Sort Methods
    /**
     * @param {?} field
     * @return {?}
     */
    isColumnSorted(field) {
        return (this.sortField === field);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    sort(event) {
        this._sortOrder = (this.sortField === event.field) ? this.sortOrder * -1 : this.defaultSortOrder;
        this._sortField = event.field;
        this.applySort();
    }
    /**
     * @return {?}
     */
    applySort() {
        if (this.sortField && this.sortOrder) {
            if (this.data) {
                if (this.customSort) {
                    this.sortBy.emit({
                        data: this.data,
                        field: this.sortField,
                        order: this.sortOrder
                    });
                }
                else {
                    this.data.sort((/**
                     * @param {?} data1
                     * @param {?} data2
                     * @return {?}
                     */
                    (data1, data2) => {
                        /** @type {?} */
                        const value1 = data1[this.sortField];
                        /** @type {?} */
                        const value2 = data2[this.sortField];
                        /** @type {?} */
                        let result;
                        if (value1 === null && value2 !== null) {
                            result = -1;
                        }
                        else if (value1 !== null && value2 === null) {
                            result = 1;
                        }
                        else if (value1 === null && value2 === null) {
                            result = 0;
                        }
                        else if (typeof value1 === 'string' && typeof value2 === 'string') {
                            result = value1.localeCompare(value2);
                        }
                        else {
                            result = (value1 < value2) ? -1 : (value1 > value2) ? 1 : 0;
                        }
                        return (this.sortOrder * result);
                    }));
                }
            }
            /** @type {?} */
            const sortObj = {
                field: this.sortField,
                order: this.sortOrder
            };
            this.afterSort.emit(sortObj);
            this.tableService.afterSort(sortObj);
        }
    }
    // Resize Methods
    /**
     * @param {?} event
     * @return {?}
     */
    onColumnResizeStart(event) {
        /** @type {?} */
        const leftContainer = Handler.getOffset(this.containerViewChild.nativeElement).left;
        this.resizerX = (event.pageX - leftContainer + this.containerViewChild.nativeElement.scrollLeft);
        event.preventDefault();
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onColumnResize(event) {
        /** @type {?} */
        const leftContainer = Handler.getOffset(this.containerViewChild.nativeElement).left;
        this.resizeHelperViewChild.nativeElement.style.height = this.containerViewChild.nativeElement.offsetHeight + 'px';
        this.resizeHelperViewChild.nativeElement.style.top = 0 + 'px';
        // tslint:disable-next-line: max-line-length
        this.resizeHelperViewChild.nativeElement.style.left = (event.pageX - leftContainer + this.containerViewChild.nativeElement.scrollLeft) + 'px';
        // display none start
        this.resizeHelperViewChild.nativeElement.style.display = 'block';
    }
    /**
     * @param {?} event
     * @param {?} column
     * @return {?}
     */
    onColumnResizeEnd(event, column) {
        /** @type {?} */
        let movedDistance = this.resizeHelperViewChild.nativeElement.offsetLeft - this.resizerX;
        /** @type {?} */
        const columnWidth = column.offsetWidth;
        /** @type {?} */
        const minWidth = parseInt(column.style.minWidth || 15, 10);
        if (columnWidth + movedDistance < minWidth) {
            movedDistance = minWidth - columnWidth;
        }
        /** @type {?} */
        const newColumnWidth = columnWidth + movedDistance;
        if (newColumnWidth >= minWidth) {
            /** @type {?} */
            let nextColumn = column.nextElementSibling;
            while (!nextColumn.offsetParent) {
                nextColumn = nextColumn.nextElementSibling;
            }
            if (nextColumn) {
                /** @type {?} */
                const nextColumnWidth = nextColumn.offsetWidth - movedDistance;
                /** @type {?} */
                const nextColumnMinWidth = nextColumn.style.minWidth || 15;
                if (newColumnWidth > 15 && nextColumnWidth > parseInt(nextColumnMinWidth, 10)) {
                    if (this.scrollable) {
                        /** @type {?} */
                        const scrollableView = this.findParentScrollableView(column);
                        // finds element
                        /** @type {?} */
                        const scrollableBodyTable = Handler.findSingle(scrollableView, 'table.md-data-table__scrollable--body-table');
                        /** @type {?} */
                        const scrollableHeaderTable = Handler.findSingle(scrollableView, 'table.md-data-table__scrollable--header-table');
                        /** @type {?} */
                        let resizeColumnIndex;
                        /** @type {?} */
                        let num = 0;
                        /** @type {?} */
                        const columns = column.parentNode.childNodes;
                        for (let i = 0; i < columns.length; i++) {
                            if (columns[i] === column) {
                                resizeColumnIndex = num;
                            }
                            if (columns[i].nodeType === 1) {
                                num++;
                            }
                        }
                        // resize both the header and the body to match new width
                        this.resizeColumnGroup(scrollableHeaderTable, resizeColumnIndex, newColumnWidth, nextColumnWidth);
                        this.resizeColumnGroup(scrollableBodyTable, resizeColumnIndex, newColumnWidth, nextColumnWidth);
                    }
                    else {
                        column.style.width = newColumnWidth + 'px';
                        if (nextColumn) {
                            nextColumn.style.width = nextColumnWidth + 'px';
                        }
                    }
                }
            }
            this.afterColResize.emit({
                element: column,
                movedDistance: movedDistance
            });
        }
        // hide resize helper line on end
        this.resizeHelperViewChild.nativeElement.style.display = 'none';
    }
    /**
     * @param {?} column
     * @return {?}
     */
    findParentScrollableView(column) {
        if (column) {
            /** @type {?} */
            let parent = column.parentElement;
            while (parent && !parent.classList.contains('md-data-table__scrollable--view')) {
                parent = parent.parentElement;
            }
            return parent;
        }
        else {
            return null;
        }
    }
    /**
     * @param {?} tableSection
     * @param {?} resizeColumnIndex
     * @param {?} newColumnWidth
     * @param {?} nextColumnWidth
     * @return {?}
     */
    resizeColumnGroup(tableSection, resizeColumnIndex, newColumnWidth, nextColumnWidth) {
        if (tableSection) {
            // find colGroup
            /** @type {?} */
            const colGroup = tableSection.children[0].nodeName === 'COLGROUP' ? tableSection.children[0] : null;
            if (colGroup) {
                /** @type {?} */
                const col = colGroup.children[resizeColumnIndex];
                /** @type {?} */
                const nextColumn = col.nextElementSibling;
                col.style.width = newColumnWidth + 'px';
                if (nextColumn && nextColumnWidth) {
                    nextColumn.style.width = nextColumnWidth + 'px';
                }
            }
            else {
                throw new Error('Tables with scroll that resize require a colgroup, refer to example');
            }
        }
    }
    // Virtual Scroll
    /**
     * @param {?} event
     * @return {?}
     */
    handleVirtualScroll(event) {
        this.first = (event.page - 1) * this.numberOfRowsToLoad;
        this.virtualScrollCb = event.callback;
        this.zone.run((/**
         * @return {?}
         */
        () => {
            if (this.virtualScrollTimer) {
                clearTimeout(this.virtualScrollTimer);
            }
            this.virtualScrollTimer = setTimeout((/**
             * @return {?}
             */
            () => {
                this.lazyLoad.emit(this.createLazyData());
            }), this.virtualScrollDelay);
        }));
    }
    /**
     * @return {?}
     */
    createLazyData() {
        return {
            first: this.first,
            numberOfRowsToLoad: this.numberOfRowsToLoad,
            sortField: this.sortField,
            sortOrder: this.sortOrder,
        };
    }
    // Select
    /**
     * @return {?}
     */
    updateSelectionKeys() {
        if (this.dataKey && this._selection) {
            this.selectionKeys = {};
            if (Array.isArray(this._selection)) {
                for (const data of this._selection) {
                    this.selectionKeys[String(data[this.dataKey])] = 1;
                }
            }
            else {
                this.selectionKeys[String(this._selection[this.dataKey])] = 1;
            }
        }
    }
    /**
     * @param {?} rowData
     * @return {?}
     */
    isSelected(rowData) {
        if (rowData && this.selection) {
            if (this.dataKey) {
                for (let i = 0; i < this.selection.length; i++) {
                    if (this.selection[i][this.dataKey] === rowData[this.dataKey]) {
                        this.selectionKeys[rowData[this.dataKey]] = 1;
                    }
                }
                return this.selectionKeys[rowData[this.dataKey]] !== undefined; // found in selection
            }
            else {
                if (this.selection instanceof Array) {
                    return findIndex(this.selection, rowData) > -1;
                }
                else {
                    return this.selection === rowData;
                }
            }
        }
        return false;
    }
    /**
     * @param {?} event
     * @param {?} check
     * @return {?}
     */
    toggleRowsWithCheckbox(event, check) {
        this._selection = check ? this.data.slice() : [];
        this.preventPropagation = true;
        this.updateSelectionKeys();
        this.selectionChange.emit(this._selection);
        this.tableService.onSelectionChange();
        this.headerCheckboxToggle.emit({ originalEvent: event, checked: check });
    }
    /**
     * @param {?} event
     * @param {?} rowData
     * @return {?}
     */
    toggleRowWithCheckbox(event, rowData) {
        this.selection = this.selection || [];
        /** @type {?} */
        const isChecked = this.isSelected(rowData);
        /** @type {?} */
        const rowDataKeyValue = this.dataKey ? String(rowData[this.dataKey]) : null;
        this.preventPropagation = true;
        if (isChecked) { // then uncheck from selection
            // then uncheck from selection
            /** @type {?} */
            const checkedIndex = findIndex(this.selection, rowData);
            this._selection = this.selection.filter((/**
             * @param {?} val
             * @param {?} i
             * @return {?}
             */
            (val, i) => i !== checkedIndex));
            this.selectionChange.emit(this.selection);
            this.rowUncheck.emit({
                originalEvent: event.originalEvent,
                data: rowData,
            });
            if (rowDataKeyValue) {
                delete this.selectionKeys[rowDataKeyValue];
            }
        }
        else { // add to selection
            this._selection = this.selection ? [...this.selection, rowData] : [rowData];
            this.selectionChange.emit(this.selection);
            this.rowCheck.emit({
                originalEvent: event.originalEvent,
                data: rowData,
            });
            if (rowDataKeyValue) {
                this.selectionKeys[rowDataKeyValue] = 1;
            }
        }
        this.tableService.onSelectionChange();
    }
    // row click selection
    /**
     * @param {?} event
     * @return {?}
     */
    handleRowClick(event) {
        if (this.rowSelection) {
            this.preventPropagation = true;
            /** @type {?} */
            const rowData = event.rowData;
            /** @type {?} */
            const selected = this.isSelected(rowData);
            /** @type {?} */
            const dataKeyValue = this.dataKey ? String(rowData[this.dataKey]) : null;
            if (selected) { // then unselect to null
                this._selection = null;
                this.selectionKeys = {};
                this.selectionChange.emit(this.selection);
                this.rowUnselect.emit({ originalEvent: event.originalEvent, data: rowData, type: 'row' });
            }
            else { // select
                this._selection = rowData;
                this.selectionChange.emit(this.selection);
                this.rowSelect.emit({
                    originalEvent: event.originalEvent,
                    data: rowData,
                    type: 'row',
                });
                if (dataKeyValue) {
                    this.selectionKeys = {};
                    this.selectionKeys[dataKeyValue] = 1;
                }
            }
            this.tableService.onSelectionChange();
        }
    }
}
DataTableComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-data-table',
                template: `
    <div
      #container
      class="md-data-table"
      [ngClass]="[
        resizableColumns ? 'md-data-table--resizable' : '',
        autoLayout ? 'md-data-table--auto-layout' : '',
        columnDividers ? 'md-data-table--dividers' : '',
        theme ? 'md-data-table--zebra': '',
        containerClass
      ]"
      [ngStyle]="containerStyle"
    >

      <div
        *ngIf="!scrollable"
        class="md-data-table__wrapper"
      >
        <table
          #table
          [ngClass]="tableClass"
          [ngStyle]="tableStyle"
        >

          <thead class="md-data-table__thead">
            <ng-container
              *ngTemplateOutlet="headerTemplate;
              context: {$implicit: columns}">
            </ng-container>
          </thead>

          <tbody
            class="md-data-table__tbody"
            [mdBodyColumns]="columns"
            [bodyTemplate]="bodyTemplate">
          </tbody>
        </table>
      </div>

      <!-- Scroll Condition -->
      <div
        *ngIf="scrollable"
        class="md-data-table__scrollable--wrappper"
      >

        <div
          class="md-data-table__scrollable--view"
          [mdScrollView]="columns"
          [scrollHeight]="scrollHeight">
        </div>
      </div>

        <!-- Resize Helper -->
        <div
          *ngIf="resizableColumns"
          #resizeHelper
          class="md-data-table__resizer--helper md-data-table__resizer--highlight"
          style="display:none">
        </div>

    </div>
  `,
                providers: [TableService],
                encapsulation: ViewEncapsulation.None
            }] }
];
/** @nocollapse */
DataTableComponent.ctorParameters = () => [
    { type: ElementRef },
    { type: NgZone },
    { type: TableService },
    { type: ChangeDetectorRef }
];
DataTableComponent.propDecorators = {
    data: [{ type: Input }],
    columns: [{ type: Input }],
    dataCount: [{ type: Input }],
    sortField: [{ type: Input }],
    sortOrder: [{ type: Input }],
    first: [{ type: Input }],
    selection: [{ type: Input }],
    containerClass: [{ type: Input }],
    resizableColumns: [{ type: Input }],
    tableClass: [{ type: Input }],
    tableStyle: [{ type: Input }],
    containerStyle: [{ type: Input }],
    defaultSortOrder: [{ type: Input }],
    scrollable: [{ type: Input }],
    scrollHeight: [{ type: Input }],
    numberOfRowsToLoad: [{ type: Input }],
    lazy: [{ type: Input }],
    virtualScroll: [{ type: Input }],
    virtualScrollDelay: [{ type: Input }],
    virtualRowHeight: [{ type: Input }],
    autoLayout: [{ type: Input }],
    dataKey: [{ type: Input }],
    rowSelection: [{ type: Input }],
    columnDividers: [{ type: Input }],
    customSort: [{ type: Input }],
    theme: [{ type: Input }],
    sortBy: [{ type: Output }],
    afterSort: [{ type: Output }],
    afterColResize: [{ type: Output }],
    lazyLoad: [{ type: Output }],
    headerCheckboxToggle: [{ type: Output }],
    selectionChange: [{ type: Output }],
    rowCheck: [{ type: Output }],
    rowUncheck: [{ type: Output }],
    rowSelect: [{ type: Output }],
    rowUnselect: [{ type: Output }],
    containerViewChild: [{ type: ViewChild, args: ['container',] }],
    resizeHelperViewChild: [{ type: ViewChild, args: ['resizeHelper',] }],
    tableViewChild: [{ type: ViewChild, args: ['table',] }],
    templates: [{ type: ContentChildren, args: [TemplateNameDirective,] }],
    rowTrackBy: [{ type: Input }]
};
// Body Component
class TableBodyComponent {
    /**
     * @param {?} dt
     */
    constructor(dt) {
        this.dt = dt;
    }
}
TableBodyComponent.decorators = [
    { type: Component, args: [{
                selector: '[mdBodyColumns]',
                template: `
    <ng-container>

      <ng-template
        ngFor let-row let-rowIndex="index"
        [ngForOf]="dt.data"
        [ngForTrackBy]="dt.rowTrackBy"
      >
        <ng-container
          *ngTemplateOutlet="bodyTemplate;
          context: {
            $implicit: row,
            columns: columns,
            rowIndex: rowIndex
          }">
        </ng-container>
      </ng-template>

    </ng-container>
  `
            }] }
];
/** @nocollapse */
TableBodyComponent.ctorParameters = () => [
    { type: DataTableComponent }
];
TableBodyComponent.propDecorators = {
    columns: [{ type: Input, args: ['mdBodyColumns',] }],
    bodyTemplate: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DataTableCheckboxHeaderComponent {
    /**
     * @param {?} dt
     * @param {?} tableService
     */
    constructor(dt, tableService) {
        this.dt = dt;
        this.tableService = tableService;
        this.className = '';
        this.id = uniqueId('md-data-table-header-checkbox-');
        this.valueChangeSubscription = this.dt.tableService.dataSource$.subscribe((/**
         * @return {?}
         */
        () => {
            this.checked = this.updateCheckedState();
        }));
        this.selectionChangeSubscription = this.dt.tableService.selectionSource$.subscribe((/**
         * @return {?}
         */
        () => {
            this.checked = this.updateCheckedState();
        }));
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.checked = this.updateCheckedState();
    }
    /**
     * @param {?} event
     * @return {?}
     */
    handleClick(event) {
        if (!this.disabled) {
            if (this.dt.data && this.dt.data.length > 0) {
                this.dt.toggleRowsWithCheckbox(event, !this.checked);
            }
        }
    }
    /**
     * @return {?}
     */
    updateCheckedState() {
        return (this.dt.data && this.dt.data.length > 0
            && this.dt.selection && this.dt.selection.length > 0
            && this.dt.selection.length === this.dt.data.length);
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this.selectionChangeSubscription) {
            this.selectionChangeSubscription.unsubscribe();
        }
        if (this.valueChangeSubscription) {
            this.valueChangeSubscription.unsubscribe();
        }
    }
}
DataTableCheckboxHeaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-data-table-header-checkbox',
                template: `
  <div
    class="md-data-table__checkbox--wrapper"
    [ngClass]="[className]"
    (click)="handleClick($event)"
  >
    <md-checkbox
      [(checkStatus)]="checked"
      [disabled]="disabled"
      (click)="handleClick($event)"
      htmlId="{{id}}-checkbox">
    </md-checkbox>
  </div>
  `
            }] }
];
/** @nocollapse */
DataTableCheckboxHeaderComponent.ctorParameters = () => [
    { type: DataTableComponent },
    { type: TableService }
];
DataTableCheckboxHeaderComponent.propDecorators = {
    disabled: [{ type: Input }],
    className: [{ type: Input }],
    id: [{ type: Input }]
};
class DataTableCheckboxComponent {
    /**
     * @param {?} dt
     * @param {?} tableService
     */
    constructor(dt, tableService) {
        this.dt = dt;
        this.tableService = tableService;
        this.disabled = false;
        this.className = '';
        this.id = uniqueId('md-data-table-checkbox-');
        this.subscription = this.dt.tableService.selectionSource$.subscribe((/**
         * @return {?}
         */
        () => {
            this.checked = this.dt.isSelected(this.data);
        }));
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.checked = this.dt.isSelected(this.data);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    handleClick(event) {
        if (!this.disabled) {
            this.dt.toggleRowWithCheckbox({
                originalEvent: event,
            }, this.data);
        }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this.subscription) {
            this.subscription.unsubscribe();
        }
    }
}
DataTableCheckboxComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-data-table-checkbox',
                template: `
    <div
      class="md-data-table__checkbox--wrapper"
      [ngClass]="[className]"
      (click)="handleClick($event)"
    >
      <md-checkbox
        [(checkStatus)]="checked"
        [disabled]="disabled"
        htmlId="{{id}}-checkbox">
      </md-checkbox>
    </div>
  `
            }] }
];
/** @nocollapse */
DataTableCheckboxComponent.ctorParameters = () => [
    { type: DataTableComponent },
    { type: TableService }
];
DataTableCheckboxComponent.propDecorators = {
    data: [{ type: Input }],
    disabled: [{ type: Input }],
    className: [{ type: Input }],
    id: [{ type: Input }],
    boxViewChild: [{ type: ViewChild, args: ['box',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SortColumnDirective {
    /**
     * @param {?} dt
     */
    constructor(dt) {
        this.dt = dt;
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onClick(event) {
        this.dt.sort({
            originalEvent: event,
            field: this.field
        });
    }
}
SortColumnDirective.decorators = [
    { type: Directive, args: [{
                selector: '[mdSortColumn]',
                host: {
                    class: 'md-data-table__sortable-column',
                }
            },] }
];
/** @nocollapse */
SortColumnDirective.ctorParameters = () => [
    { type: DataTableComponent }
];
SortColumnDirective.propDecorators = {
    field: [{ type: Input, args: ['mdSortColumn',] }],
    onClick: [{ type: HostListener, args: ['click', ['$event'],] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ResizableColumnDirective {
    /**
     * @param {?} dt
     * @param {?} el
     * @param {?} zone
     */
    constructor(dt, el, zone) {
        this.dt = dt;
        this.el = el;
        this.zone = zone;
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        this.el.nativeElement.classList.add('md-data-table__resizable-column');
        // create span for resizer
        this.resizeHelper = document.createElement('span');
        this.resizeHelper.className = 'md-data-table__column-resizer';
        this.el.nativeElement.appendChild(this.resizeHelper);
        this.zone.runOutsideAngular((/**
         * @return {?}
         */
        () => {
            this.mouseDownListener = this.onMouseDown.bind(this);
            this.resizeHelper.addEventListener('mousedown', this.mouseDownListener);
        }));
    }
    /**
     * @return {?}
     */
    bindDocEvents() {
        this.zone.runOutsideAngular((/**
         * @return {?}
         */
        () => {
            this.docMouseMoveListener = this.onDocMouseMove.bind(this);
            document.addEventListener('mousemove', this.docMouseMoveListener);
            this.docMouseUpListener = this.onDocMouseUp.bind(this);
            document.addEventListener('mouseup', this.docMouseUpListener);
        }));
    }
    /**
     * @return {?}
     */
    unbindDocEvents() {
        if (this.docMouseMoveListener) {
            document.removeEventListener('mousemove', this.docMouseMoveListener);
            this.docMouseMoveListener = null;
        }
        if (this.docMouseUpListener) {
            document.removeEventListener('mouseup', this.docMouseUpListener);
            this.docMouseUpListener = null;
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onMouseDown(event) {
        this.dt.onColumnResizeStart(event);
        this.bindDocEvents();
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onDocMouseMove(event) {
        this.dt.onColumnResize(event);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onDocMouseUp(event) {
        this.dt.onColumnResizeEnd(event, this.el.nativeElement);
        this.unbindDocEvents();
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this.mouseDownListener) {
            this.resizeHelper.removeEventListener('mousedown', this.mouseDownListener);
        }
        this.unbindDocEvents();
    }
}
ResizableColumnDirective.decorators = [
    { type: Directive, args: [{
                selector: '[mdResizableColumn]'
            },] }
];
/** @nocollapse */
ResizableColumnDirective.ctorParameters = () => [
    { type: DataTableComponent },
    { type: ElementRef },
    { type: NgZone }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ScrollComponent {
    /**
     * @param {?} dt
     * @param {?} el
     * @param {?} zone
     */
    constructor(dt, el, zone) {
        this.dt = dt;
        this.el = el;
        this.zone = zone;
        this.page = 0;
        this.subscription = this.dt.tableService.dataSource$.subscribe((/**
         * @return {?}
         */
        () => {
            this.zone.runOutsideAngular((/**
             * @return {?}
             */
            () => {
                setTimeout((/**
                 * @return {?}
                 */
                () => {
                    this.alignScrollBar();
                    if (this.scrollLoadingTableViewChild && this.scrollLoadingTableViewChild.nativeElement) {
                        this.scrollLoadingTableViewChild.nativeElement.style.display = 'none';
                    }
                }), 50);
            }));
        }));
        if (this.dt.virtualScroll) {
            this.dataCountSubscription = this.dt.tableService.dataCountSource$.subscribe((/**
             * @return {?}
             */
            () => {
                this.zone.runOutsideAngular((/**
                 * @return {?}
                 */
                () => {
                    setTimeout((/**
                     * @return {?}
                     */
                    () => {
                        this.setVirtualScrollerHeight();
                    }), 50);
                }));
            }));
        }
        this.initialized = false;
    }
    /**
     * @return {?}
     */
    get scrollHeight() {
        return this._scrollHeight;
    }
    /**
     * @param {?} val
     * @return {?}
     */
    set scrollHeight(val) {
        this._scrollHeight = val;
        this.setScrollHeight();
    }
    /**
     * @return {?}
     */
    ngAfterViewChecked() {
        if (!this.initialized && this.el.nativeElement.offsetParent) {
            this.alignScrollBar();
            this.setScrollHeight();
            this.initialized = true;
        }
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        /** @type {?} */
        const view = this.el.nativeElement.previousElementSibling;
        if (view) {
            this.siblingBody = Handler.findSingle(view, '.md-data-table__scrollable--body');
        }
        this.bindEvents();
        this.setScrollHeight();
        this.alignScrollBar();
        if (this.dt.virtualScroll) {
            this.setVirtualScrollerHeight();
            if (this.scrollLoadingTableViewChild && this.scrollLoadingTableViewChild.nativeElement) {
                this.scrollLoadingTableViewChild.nativeElement.style.display = 'table';
            }
        }
    }
    /**
     * @return {?}
     */
    bindEvents() {
        this.zone.runOutsideAngular((/**
         * @return {?}
         */
        () => {
            if (this.scrollHeaderViewChild && this.scrollHeaderViewChild.nativeElement) {
                this.headerScrollListener = this.onHeaderScroll.bind(this);
                this.scrollHeaderViewChild.nativeElement.addEventListener('scroll', this.headerScrollListener);
            }
            this.bodyScrollListener = this.onBodyScroll.bind(this);
            this.scrollBodyViewChild.nativeElement.addEventListener('scroll', this.bodyScrollListener);
        }));
    }
    /**
     * @return {?}
     */
    unbindEvents() {
        if (this.scrollHeaderViewChild && this.scrollHeaderViewChild.nativeElement) {
            this.scrollHeaderViewChild.nativeElement.removeEventListener('scroll', this.headerScrollListener);
        }
        this.scrollBodyViewChild.nativeElement.removeEventListener('scroll', this.bodyScrollListener);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onHeaderScroll(event) {
        /** @type {?} */
        const scrollLeft = this.scrollHeaderViewChild.nativeElement.scrollLeft;
        this.scrollBodyViewChild.nativeElement.scrollLeft = scrollLeft;
        this.preventBodyScrollPropagation = true;
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onBodyScroll(event) {
        if (this.preventBodyScrollPropagation) {
            this.preventBodyScrollPropagation = false;
            return;
        }
        if (this.scrollHeaderViewChild && this.scrollHeaderViewChild.nativeElement) {
            this.scrollHeaderBoxViewChild.nativeElement.style.marginLeft = -1 * this.scrollBodyViewChild.nativeElement.scrollLeft + 'px';
        }
        if (this.siblingBody) {
            this.siblingBody.scrollTop = this.scrollBodyViewChild.nativeElement.scrollTop;
        }
        if (this.dt.virtualScroll) {
            /** @type {?} */
            const viewport = Handler.getOuterHeight(this.scrollBodyViewChild.nativeElement);
            /** @type {?} */
            const tableHeight = Handler.getOuterHeight(this.scrollTableViewChild.nativeElement);
            /** @type {?} */
            const pageHeight = this.dt.virtualRowHeight * this.dt.numberOfRowsToLoad;
            /** @type {?} */
            const virtualTableHeight = Handler.getOuterHeight(this.virtualScrollerViewChild.nativeElement);
            /** @type {?} */
            const pageCount = (virtualTableHeight / pageHeight) || 1;
            /** @type {?} */
            const scrollBodyTop = this.scrollTableViewChild.nativeElement.style.top || '0';
            // if at end of scroll
            if (event.target.offsetHeight + event.target.scrollTop >= event.target.scrollHeight) {
                /** @type {?} */
                const page = Math.floor((this.scrollBodyViewChild.nativeElement.scrollTop * pageCount) / (this.scrollBodyViewChild.nativeElement.scrollHeight)) + 1;
                this.dt.handleVirtualScroll({
                    page: page,
                    callback: (/**
                     * @return {?}
                     */
                    () => {
                        if (this.scrollLoadingTableViewChild && this.scrollLoadingTableViewChild.nativeElement) {
                            this.scrollLoadingTableViewChild.nativeElement.style.display = 'none';
                        }
                        if (this.siblingBody) {
                            ((/** @type {?} */ (this.siblingBody.children[0]))).style.top = this.scrollTableViewChild.nativeElement.style.top;
                        }
                    })
                });
            }
        }
    }
    /**
     * @return {?}
     */
    setScrollHeight() {
        /** @type {?} */
        const scrollBodyElement = this.scrollBodyViewChild.nativeElement;
        /** @type {?} */
        const scrollHeight = this.scrollHeight;
        if (scrollHeight && this.scrollBodyViewChild && scrollBodyElement) {
            if (scrollHeight.indexOf('%') !== -1) { // if scrollHeight is a % value
                // if scrollHeight is a % value
                /** @type {?} */
                let relativeHeight;
                scrollBodyElement.style.visibility = 'hidden';
                scrollBodyElement.style.height = '100px';
                /** @type {?} */
                const containerHeight = Handler.getOuterHeight(this.dt.el.nativeElement.children[0]);
                if (scrollHeight.includes('calc')) {
                    /** @type {?} */
                    const percentHeight = parseInt(scrollHeight.slice(scrollHeight.indexOf('(') + 1, scrollHeight.indexOf('%')), 10);
                    /** @type {?} */
                    const diffValue = parseInt(scrollHeight.slice(scrollHeight.indexOf('-') + 1, scrollHeight.indexOf(')')), 10);
                    relativeHeight = (Handler.getOuterHeight(this.dt.el.nativeElement.parentElement) * percentHeight / 100) - diffValue;
                }
                else {
                    relativeHeight = Handler.getOuterHeight(this.dt.el.nativeElement.parentElement) * parseInt(scrollHeight, 10) / 100;
                }
                /** @type {?} */
                const staticHeight = containerHeight - 100;
                // total height of everything
                /** @type {?} */
                const scrollBodyHeight = (relativeHeight - staticHeight);
                scrollBodyElement.style.height = scrollBodyHeight + 'px';
                scrollBodyElement.style.maxHeight = scrollBodyHeight + 'px';
                scrollBodyElement.style.visibility = 'visible';
            }
            else {
                scrollBodyElement.style.maxHeight = scrollHeight;
            }
        }
    }
    /**
     * @return {?}
     */
    setVirtualScrollerHeight() {
        if (this.virtualScrollerViewChild.nativeElement) {
            this.virtualScrollerViewChild.nativeElement.style.height = (this.dt.dataCount) * this.dt.virtualRowHeight + 'px';
        }
    }
    /**
     * @return {?}
     */
    hasVerticalOverflow() {
        return Handler.getOuterHeight(this.scrollTableViewChild.nativeElement) > Handler.getOuterHeight(this.scrollBodyViewChild.nativeElement);
    }
    /**
     * @return {?}
     */
    alignScrollBar() {
        /** @type {?} */
        const scrollBarWidth = this.hasVerticalOverflow() ? Handler.calculateScrollbarWidth() : 0;
        this.scrollHeaderBoxViewChild.nativeElement.style.marginRight = scrollBarWidth + 'px';
        this.initialized = false;
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.unbindEvents();
        this.siblingBody = null;
        if (this.subscription) {
            this.subscription.unsubscribe();
        }
        if (this.dataCountSubscription) {
            this.dataCountSubscription.unsubscribe();
        }
        this.initialized = false;
    }
}
ScrollComponent.decorators = [
    { type: Component, args: [{
                selector: '[mdScrollView]',
                template: `
    <div #scrollHeader class="md-data-table__scrollable--header">
        <div #scrollHeaderBox>

          <table
            class="md-data-table__scrollable--header-table"
            [ngClass]="dt.tableClass"
            [ngStyle]="dt.tableStyle"
          >

            <ng-container
              *ngTemplateOutlet="dt.colGroupTemplate; context {$implicit: columns}">
            </ng-container>

            <thead class="md-data-table__thead">
              <ng-container
                *ngTemplateOutlet="dt.headerTemplate; context {$implicit: columns}">
              </ng-container>
            </thead>

            <tbody class="md-data-table__tbody">
              <ng-template
                ngFor let-rowData let-rowIndex="index"
                [ngForOf]="dt.data"
                [ngForTrackBy]="dt.rowTrackBy"
              >
              </ng-template>
            </tbody>
          </table>

        </div>
    </div>

    <div #scrollBody class="md-data-table__scrollable--body">

        <table
          #scrollTable
          [ngClass]="{'md-data-table__scrollable--body-table': true, 'md-data-table__scrollable--virtual-table': dt.virtualScroll}"
          [class]="dt.tableClass"
          [ngStyle]="dt.tableStyle"
        >

          <ng-container
            *ngTemplateOutlet="dt.colGroupTemplate; context {$implicit: columns}">
          </ng-container>

          <tbody
            class="md-data-table__tbody"
            [mdBodyColumns]="columns"
            [bodyTemplate]="dt.bodyTemplate">
          </tbody>
        </table>


        <table
          #loadingTable
          *ngIf="dt.virtualScroll"
          [ngClass]="
            {'md-data-table__scrollable--body-table md-data-table__scrollable--loading-table': true,
            'md-data-table__scrollable--virtual-table': dt.virtualScroll
            }"
        >

          <tbody class="md-data-table__tbody ">

            <md-spinner
              class="md-data-table__spinner"
              [ngStyle]="{ height: scrollHeight }">
            </md-spinner>

           </tbody>

        </table>

        <div
          #virtualScroller
          class="md-data-table__scrollable--virtual-scroller"
          *ngIf="dt.virtualScroll">
        </div>
    </div>
  `
            }] }
];
/** @nocollapse */
ScrollComponent.ctorParameters = () => [
    { type: DataTableComponent },
    { type: ElementRef },
    { type: NgZone }
];
ScrollComponent.propDecorators = {
    columns: [{ type: Input, args: ['mdScrollView',] }],
    scrollHeaderViewChild: [{ type: ViewChild, args: ['scrollHeader',] }],
    scrollHeaderBoxViewChild: [{ type: ViewChild, args: ['scrollHeaderBox',] }],
    scrollBodyViewChild: [{ type: ViewChild, args: ['scrollBody',] }],
    scrollTableViewChild: [{ type: ViewChild, args: ['scrollTable',] }],
    scrollLoadingTableViewChild: [{ type: ViewChild, args: ['loadingTable',] }],
    virtualScrollerViewChild: [{ type: ViewChild, args: ['virtualScroller',] }],
    scrollHeight: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TableSortIconComponent {
    /**
     * @param {?} dt
     */
    constructor(dt) {
        this.dt = dt;
        this.subscription = this.dt.tableService.sortSource$.subscribe((/**
         * @return {?}
         */
        () => {
            this.updateSortIcon();
        }));
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.updateSortIcon();
    }
    /**
     * @return {?}
     */
    updateSortIcon() {
        this.sorted = this.dt.isColumnSorted(this.field) ? this.dt.sortOrder : -1;
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this.subscription) {
            this.subscription.unsubscribe();
        }
    }
}
TableSortIconComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-sortIcon',
                template: `
    <i class="md-icon icon md-sortIcon"
      [ngClass]="[
        sorted === 1 ? 'icon-arrow-filled-down_12' : 'icon-arrow-filled-up_12'
      ]">
    </i>
  `
            }] }
];
/** @nocollapse */
TableSortIconComponent.ctorParameters = () => [
    { type: DataTableComponent }
];
TableSortIconComponent.propDecorators = {
    field: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SelectRowDirective {
    /**
     * @param {?} dt
     * @param {?} tableService
     */
    constructor(dt, tableService) {
        this.dt = dt;
        this.tableService = tableService;
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onClick(event) {
        this.dt.handleRowClick({
            originalEvent: event,
            rowData: this.rowData,
        });
    }
    /**
     * @return {?}
     */
    isSelected() {
        return this.rowData === this.dt.selection;
    }
}
SelectRowDirective.decorators = [
    { type: Directive, args: [{
                selector: '[mdSelectRow]',
                host: {
                    class: 'md-data-table__row',
                    '[class.md-data-table__row--selected]': 'isSelected()',
                    '[attr.tabindex]': '0',
                }
            },] }
];
/** @nocollapse */
SelectRowDirective.ctorParameters = () => [
    { type: DataTableComponent },
    { type: TableService }
];
SelectRowDirective.propDecorators = {
    rowData: [{ type: Input, args: ['mdSelectRow',] }],
    onClick: [{ type: HostListener, args: ['click', ['$event'],] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DataTableModule {
}
DataTableModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    SpinnerModule,
                    IconModule,
                    AvatarModule,
                    CheckboxModule,
                    SelectModule
                ],
                exports: [
                    DataTableComponent,
                    SharedModule,
                    TableBodyComponent,
                    SortColumnDirective,
                    ResizableColumnDirective,
                    ScrollComponent,
                    DataTableCheckboxHeaderComponent,
                    DataTableCheckboxComponent,
                    TableSortIconComponent,
                    SelectRowDirective
                ],
                declarations: [
                    DataTableComponent,
                    TableBodyComponent,
                    SortColumnDirective,
                    ResizableColumnDirective,
                    ScrollComponent,
                    DataTableCheckboxHeaderComponent,
                    DataTableCheckboxComponent,
                    TableSortIconComponent,
                    SelectRowDirective
                ],
                schemas: [CUSTOM_ELEMENTS_SCHEMA]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ActivityButtonComponent {
    constructor() {
        /**
         * \@prop Text to display for blindness accessibility features | ''
         */
        this.ariaLabel = '';
        /**
         * \@prop Sets the attribute disabled to the button | false
         */
        this.disabled = false;
        /**
         * \@prop Sets the button's size | 68
         */
        this.size = 68;
        /**
         * \@prop Sets the button's activity type
         */
        this.type = '';
        /**
         * \@prop Sets the button's class
         */
        this.className = '';
        this.whenClick = new EventEmitter();
        this.regIntial = /\b\w+\b/g;
        this.containerClassName = 'md-button__container--small';
        this.iconClassName = 'icon icon-chat_36';
        this.labelName = '';
        this.buttonNgClass = {
            'md-button': true,
            'md-button--circle': true,
            'md-activity': true
        };
        this.buttonToIconSizeMapping = {
            56: '24',
            68: '28',
            84: '36'
        };
        this.getLabel = (/**
         * @return {?}
         */
        () => {
            return this.ariaLabel || this.type.replace('-', ' ').replace(this.regIntial, (/**
             * @param {?} word
             * @return {?}
             */
            function (word) {
                return word.substring(0, 1).toUpperCase() + word.substring(1);
            }));
        });
        this.handleClick = (/**
         * @param {?} event
         * @return {?}
         */
        (event) => {
            this.whenClick.emit(event);
        });
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.size === 84) {
            this.containerClassName = 'md-button__container';
        }
        if (this.className) {
            this.buttonNgClass[this.className] = true;
        }
        this.labelName = this.getLabel();
        this.buttonNgClass['md-button--' + this.size] = true;
        this.buttonNgClass['md-activity__' + this.type] = true;
        this.iconClassName = 'icon icon-' + this.type + '_' + this.buttonToIconSizeMapping[this.size];
    }
}
ActivityButtonComponent.decorators = [
    { type: Component, args: [{
                selector: 'md-activity-button',
                template: `
  <button
    [ngClass]='buttonNgClass'
    [attr.aria-label] = 'labelName'
    [attr.alt]="labelName"
    [disabled] = 'disabled'
    type="button"
    tabindex="0"
    (click)="handleClick($event)"
  >
    <span class="md-button__children" *ngIf='type!==""'>
      <i [class]="iconClassName"></i>
    </span>
    <ng-content></ng-content>
  </button>
  <div class="md-button__label">{{ labelName }}</div>
  `,
                host: {
                    '[class]': 'containerClassName',
                }
            }] }
];
/** @nocollapse */
ActivityButtonComponent.ctorParameters = () => [];
ActivityButtonComponent.propDecorators = {
    ariaLabel: [{ type: Input }],
    disabled: [{ type: Input }],
    size: [{ type: Input }],
    type: [{ type: Input }],
    className: [{ type: Input }],
    whenClick: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ActivityButtonModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: ActivityButtonModule,
            providers: [],
        };
    }
}
ActivityButtonModule.decorators = [
    { type: NgModule, args: [{
                declarations: [ActivityButtonComponent],
                imports: [
                    CommonModule,
                    ButtonModule,
                    IconModule
                ],
                exports: [ActivityButtonComponent],
                schemas: [CUSTOM_ELEMENTS_SCHEMA]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { AlertBannerModule, AlertBannerComponent, AlertCallModule, AlertCallComponent, AlertCallConfig, AlertCallContainerComponent, AlertCallService, AlertCallDevice, DeviceListCallComponent, AlertMeetingModule, AlertMeetingService, AlertMeetingContainerComponent, AlertMeetingConfig, AlertMeetingComponent, AlertModule, AlertService, AlertContainerComponent, AlertConfig, AlertComponent, AvatarModule, AvatarComponent, BadgeModule, BadgeComponent, ButtonModule, ButtonComponent, ButtonGroupModule, ButtonGroupComponent, CallControlModule, CallControlComponent, CheckboxModule, CheckboxComponent, ComboBoxModule, ComboBoxComponent, CompositeAvatarModule, CompositeAvatarComponent, EditableTextfieldModule, EditableTextfieldComponent, FormModule, FormComponent, FormContentComponent, FormInfoComponent, FormSectionComponent, FormSubSectionComponent, IconModule, IconComponent, InputDirective, InputService, InputContainerComponent, InputHelperComponent, InputMessageComponent, InputSectionComponent, InputModule, InputContainerModule, InputContainerService, InputHelperModule, InputMessageModule, InputSectionModule, LabelModule, LabelComponent, LightboxModule, LightboxComponent, LightboxService, LightboxTooltips, LightboxConfig, ListModule, ListComponent, ListItemModule, OptionSelectionChange, ListItemComponent, ListItemHeaderModule, ListItemHeaderComponent, ListItemSectionModule, ListItemSectionComponent, ListSeparatorModule, ListSeparatorComponent, LoadingModule, LoadingComponent, MenuComponent, MenuModule, MenuContentComponent, MenuItemComponent, MenuTriggerDirective, ModalModule, ModalBodyComponent, ModalContainerComponent, ModalFooterComponent, ModalHeaderComponent, ModalRef, ModalComponent, ModalService, RadioModule, RadioComponent, SliderModule, SliderComponent, SliderPointerComponent, SelectModule, SelectChange, SelectComponent, SelectItemComponent, SelectCheckboxComponent, SpinnerModule, SpinnerComponent, TabsModule, TabsComponent, ToggleSwitchModule, ToggleSwitchComponent, TopbarModule, TopbarComponent, TopbarBrandComponent, TopbarMobileComponent, TopbarNavComponent, TopbarRightComponent, AccordionModule, AccordionTabComponent, AccordionComponent, SideBarModule, SideBarComponent, SideBarBodyModule, SideBarBodyComponent, SidebarNavModule, SidebarNavComponent, SidebarNavItemModule, SidebarNavItemComponent, SidebarHeaderModule, SidebarHeaderComponent, SidebarFooterModule, SidebarFooterComponent, TimePickerComponent, TimePickerModule, TimePickerDropdownComponent, TimePickerDropdownModule, TimeSelectorComponent, TimeSelectorModule, DatePickerComponent, DatePickerModule, DatePickerCalendarComponent, DatePickerCalendarModule, DatePickerMonthComponent, DatePickerMonthModule, DatePickerWeekComponent, DatePickerWeekModule, DatePickerDayComponent, DatePickerDayModule, DateRangePickerModule, DateRangePickerComponent, BreadcrumbsComponent, BreadcrumbsModule, PopoverModule, PopoverDirective, CardModule, CardComponent, CoachmarkModule, CoachmarkComponent, PageHeaderComponent, PageHeaderModule, PageHeaderContentComponent, PageHeaderContentModule, TooltipModule, TooltipComponent, TooltipDirective, PaginationModule, PaginationComponent, DrawerModule, DrawerComponent, CheckboxGroupModule, CheckboxGroupComponent, RadioGroupModule, RadioGroupComponent, DataTableModule, DataTableComponent, TableBodyComponent, ScrollComponent, ActivityButtonModule, ActivityButtonComponent, AccordionService as ɵm, CardSectionComponent as ɵt, CoachmarkService as ɵu, DataTableCheckboxComponent as ɵbd, DataTableCheckboxHeaderComponent as ɵbc, SelectRowDirective as ɵbf, TableSortIconComponent as ɵbe, TableService as ɵf, ResizableColumnDirective as ɵbb, SharedModule as ɵd, TemplateNameDirective as ɵc, SortColumnDirective as ɵba, DatePickerService as ɵq, DateRangeInputComponent as ɵs, DateRangeInputModule as ɵr, PaginationArrowComponent as ɵx, PaginationArrowModule as ɵw, PaginationNumberComponent as ɵz, PaginationNumberModule as ɵy, PaginationService as ɵv, SelectService as ɵe, SidebarNavService as ɵo, SidebarService as ɵn, TabContentComponent as ɵk, TabHeaderComponent as ɵh, TabListComponent as ɵi, TabPaneComponent as ɵl, TabComponent as ɵj, TabsService as ɵg, TimePickerService as ɵp, TooltipContainerComponent as ɵb, RemoveHostDirective as ɵa };

//# sourceMappingURL=momentum-ui-angular.js.map